@@ -1,10 +1,11 @@
-/**
+/** \file
  * \brief  The top level class for managing the application.
  *
- * Author:
+ * Authors:
  *   Bryce W. Harrington <bryce@bryceharrington.org>
+ *   Ralf Stephan <ralf@ark.in-berlin.de>
  *
- * Copyright (C) 2005 Bryce Harrington
+ * Copyright (C) 2005 Authors
  *
  * Released under GNU GPL.  Read the file 'COPYING' for more information.
  */
@@ -12,18 +13,14 @@
 #ifndef INKSCAPE_APPLICATION_APPLICATION_H
 #define INKSCAPE_APPLICATION_APPLICATION_H
 
-#include <gtkmm/main.h>
+#include <glib/gtypes.h>
 
-namespace Inkscape {
-namespace XML {
-class Document;
+namespace Gtk {
+class Main;
 }
-}
-
 
 namespace Inkscape {
 namespace NSApplication {
-
 class AppPrototype;
 
 class Application
@@ -32,28 +29,23 @@ public:
     Application(int argc, char **argv, bool use_gui=true, bool new_gui=false);
     virtual ~Application();
 
-    bool        loadPreferences();
-    bool        savePreferences();
+    gchar const *homedir() const;
 
-    const gchar*    homedir() const;
-
-    gint            run();
-    void            exit();
+    gint run();
 
+    static bool getUseGui();
+    static bool getNewGui();
+    static void exit();
+    
 protected:
     Application(Application const &);
     Application& operator=(Application const &);
 
-    Gtk::Main      *_gtk_main;
     gint            _argc;
     char           **_argv;
-    Inkscape::XML::Document      *_preferences;
     AppPrototype   *_app_impl;
 
     mutable gchar  *_path_home;
-
-    bool        _save_preferences;
-    bool        _use_gui;
 };
 
 } // namespace NSApplication
