@@ -18,32 +18,27 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#include <math.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "macros.h"
 #include <glibmm/i18n.h>
 #include "display/sp-canvas.h"
-#include "inkscape.h"
 #include "sp-ellipse.h"
 #include "document.h"
 #include "sp-namedview.h"
 #include "selection.h"
 #include "desktop-handles.h"
-#include "desktop-affine.h"
 #include "snap.h"
 #include "pixmaps/cursor-ellipse.xpm"
 #include "sp-metrics.h"
-#include "knotholder.h"
 #include "xml/repr.h"
 #include "xml/node-event-vector.h"
 #include "object-edit.h"
 #include "prefs-utils.h"
-#include "widgets/spw-utilities.h"
 #include "message-context.h"
 #include "desktop.h"
-#include "widgets/desktop-widget.h"
 #include "desktop-style.h"
+#include "context-fns.h"
 
 #include "arc-context.h"
 
@@ -132,7 +127,7 @@ static void sp_arc_context_dispose(GObject *object)
 
     if (ec->shape_repr) { // remove old listener
         sp_repr_remove_listener_by_data(ec->shape_repr, ec);
-        sp_repr_unref(ec->shape_repr);
+        Inkscape::GC::release(ec->shape_repr);
         ec->shape_repr = 0;
     }
 
@@ -141,9 +136,7 @@ static void sp_arc_context_dispose(GObject *object)
         sp_arc_finish(ac);
     }
 
-    if (ac->_message_context) {
-        delete ac->_message_context;
-    }
+    delete ac->_message_context;
 
     G_OBJECT_CLASS(parent_class)->dispose(object);
 }
@@ -172,7 +165,7 @@ void sp_arc_context_selection_changed(Inkscape::Selection * selection, gpointer
 
     if (ec->shape_repr) { // remove old listener
         sp_repr_remove_listener_by_data(ec->shape_repr, ec);
-        sp_repr_unref(ec->shape_repr);
+        Inkscape::GC::release(ec->shape_repr);
         ec->shape_repr = 0;
     }
 
@@ -182,9 +175,8 @@ void sp_arc_context_selection_changed(Inkscape::Selection * selection, gpointer
         Inkscape::XML::Node *shape_repr = SP_OBJECT_REPR(item);
         if (shape_repr) {
             ec->shape_repr = shape_repr;
-            sp_repr_ref(shape_repr);
+            Inkscape::GC::anchor(shape_repr);
             sp_repr_add_listener(shape_repr, &ec_shape_repr_events, ec);
-            sp_repr_synthesize_events(shape_repr, &ec_shape_repr_events, ec);
         }
     }
 }
@@ -192,26 +184,28 @@ void sp_arc_context_selection_changed(Inkscape::Selection * selection, gpointer
 static void sp_arc_context_setup(SPEventContext *ec)
 {
     SPArcContext *ac = SP_ARC_CONTEXT(ec);
+    Inkscape::Selection *selection = sp_desktop_selection(ec->desktop);
 
     if (((SPEventContextClass *) parent_class)->setup) {
         ((SPEventContextClass *) parent_class)->setup(ec);
     }
 
-    SPItem *item = SP_DT_SELECTION(ec->desktop)->singleItem();
+    SPItem *item = selection->singleItem();
 
     if (item) {
         ec->shape_knot_holder = sp_item_knot_holder(item, ec->desktop);
         Inkscape::XML::Node *shape_repr = SP_OBJECT_REPR(item);
         if (shape_repr) {
             ec->shape_repr = shape_repr;
-            sp_repr_ref(shape_repr);
+            Inkscape::GC::anchor(shape_repr);
             sp_repr_add_listener(shape_repr, &ec_shape_repr_events, ec);
-            sp_repr_synthesize_events(shape_repr, &ec_shape_repr_events, ec);
         }
     }
 
     ac->sel_changed_connection.disconnect();
-    ac->sel_changed_connection = SP_DT_SELECTION(ec->desktop)->connectChanged(sigc::bind(sigc::ptr_fun(&sp_arc_context_selection_changed), (gpointer)ac));
+    ac->sel_changed_connection = selection->connectChanged(
+        sigc::bind(sigc::ptr_fun(&sp_arc_context_selection_changed), (gpointer) ac)
+        );
 
     if (prefs_get_int_attribute("tools.shapes", "selcue", 0) != 0) {
         ec->enableSelectionCue();
@@ -221,7 +215,7 @@ static void sp_arc_context_setup(SPEventContext *ec)
         ec->enableGrDrag();
     }
 
-    ac->_message_context = new Inkscape::MessageContext((ec->desktop)->messageStack());
+    ac->_message_context = new Inkscape::MessageContext(ec->desktop->messageStack());
 }
 
 static gint sp_arc_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEvent *event)
@@ -232,15 +226,7 @@ static gint sp_arc_context_item_handler(SPEventContext *event_context, SPItem *i
     switch (event->type) {
         case GDK_BUTTON_PRESS:
             if (event->button.button == 1) {
-
-                // save drag origin
-                event_context->xp = (gint) event->button.x;
-                event_context->yp = (gint) event->button.y;
-                event_context->within_tolerance = true;
-
-                // remember clicked item, disregarding groups, honoring Alt
-                event_context->item_to_select = sp_event_context_find_item (desktop, NR::Point(event->button.x, event->button.y), event->button.state & GDK_MOD1_MASK, TRUE);
-
+                Inkscape::setup_for_drag_start(desktop, event_context, event);
                 ret = TRUE;
             }
             break;
@@ -261,8 +247,7 @@ static gint sp_arc_context_root_handler(SPEventContext *event_context, GdkEvent
     static bool dragging;
 
     SPDesktop *desktop = event_context->desktop;
-    Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
-
+    Inkscape::Selection *selection = sp_desktop_selection(desktop);
     SPArcContext *ac = SP_ARC_CONTEXT(event_context);
 
     event_context->tolerance = prefs_get_int_attribute_limited("options.dragtolerance", "value", 0, 0, 100);
@@ -272,22 +257,15 @@ static gint sp_arc_context_root_handler(SPEventContext *event_context, GdkEvent
     switch (event->type) {
         case GDK_BUTTON_PRESS:
             if (event->button.button == 1) {
-                // save drag origin
-                event_context->xp = (gint) event->button.x;
-                event_context->yp = (gint) event->button.y;
-                event_context->within_tolerance = true;
-
-                // remember clicked item, disregarding groups, honoring Alt
-                event_context->item_to_select = sp_event_context_find_item (desktop, NR::Point(event->button.x, event->button.y), event->button.state & GDK_MOD1_MASK, TRUE);
 
                 dragging = true;
-                /* Position center */
-                ac->center = sp_desktop_w2d_xy_point(event_context->desktop,
-                                                     NR::Point(event->button.x, event->button.y));
-                /* Snap center to nearest magnetic point */
-                namedview_free_snap(event_context->desktop->namedview, Snapper::SNAP_POINT, ac->center);
+                ac->center = Inkscape::setup_for_drag_start(desktop, event_context, event);
+
+                SnapManager const &m = desktop->namedview->snap_manager;
+                ac->center = m.freeSnap(Inkscape::Snapper::SNAP_POINT, ac->center, ac->item).getPoint();
                 sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
-                                    GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
+                                    GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
+                                    GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
                                     NULL, event->button.time);
                 ret = TRUE;
             }
@@ -306,7 +284,7 @@ static gint sp_arc_context_root_handler(SPEventContext *event_context, GdkEvent
                 event_context->within_tolerance = false;
 
                 NR::Point const motion_w(event->motion.x, event->motion.y);
-                NR::Point const motion_dt(sp_desktop_w2d_xy_point(event_context->desktop, motion_w));
+                NR::Point const motion_dt(desktop->w2d(motion_w));
                 sp_arc_drag(ac, motion_dt, event->motion.state);
                 ret = TRUE;
             }
@@ -362,15 +340,12 @@ static gint sp_arc_context_root_handler(SPEventContext *event_context, GdkEvent
                 case GDK_x:
                 case GDK_X:
                     if (MOD__ALT_ONLY) {
-                        gpointer hb = sp_search_by_data_recursive(desktop->owner->aux_toolbox, (gpointer) "altx-arc");
-                        if (hb && GTK_IS_WIDGET(hb)) {
-                            gtk_widget_grab_focus(GTK_WIDGET(hb));
-                        }
+                        desktop->setToolboxFocusTo ("altx-arc");
                         ret = TRUE;
                     }
                     break;
                 case GDK_Escape:
-                    SP_DT_SELECTION(desktop)->clear();
+                    sp_desktop_selection(desktop)->clear();
                     //TODO: make dragging escapable by Esc
                 default:
                     break;
@@ -411,91 +386,31 @@ static void sp_arc_drag(SPArcContext *ac, NR::Point pt, guint state)
 
     if (!ac->item) {
 
-        SPItem *layer=SP_ITEM(desktop->currentLayer());
-        if ( !layer || desktop->itemIsHidden(layer)) {
-            ac->_message_context->set(Inkscape::ERROR_MESSAGE, _("<b>Current layer is hidden</b>. Unhide it to be able to draw on it."));
-            return;
-        }
-        if ( !layer || layer->isLocked()) {
-            ac->_message_context->set(Inkscape::ERROR_MESSAGE, _("<b>Current layer is locked</b>. Unlock it to be able to draw on it."));
+        if (Inkscape::have_viable_layer(desktop, ac->_message_context) == false) {
             return;
         }
 
         /* Create object */
         Inkscape::XML::Node *repr = sp_repr_new("svg:path");
-        sp_repr_set_attr(repr, "sodipodi:type", "arc");
+        repr->setAttribute("sodipodi:type", "arc");
 
         /* Set style */
         sp_desktop_apply_style_tool(desktop, repr, "tools.shapes.arc", false);
 
         ac->item = SP_ITEM(desktop->currentLayer()->appendChildRepr(repr));
-        sp_repr_unref(repr);
+        Inkscape::GC::release(repr);
         ac->item->transform = SP_ITEM(desktop->currentRoot())->getRelativeTransform(desktop->currentLayer());
         ac->item->updateRepr();
     }
 
-    /* This is bit ugly, but so we are */
+    NR::Rect const r = Inkscape::snap_rectangular_box(desktop, ac->item, pt, ac->center, state);
 
-    NR::Point p0, p1;
-    if (state & GDK_CONTROL_MASK) {
-        NR::Point delta = pt - ac->center;
-        /* fixme: Snapping */
-        if ((fabs(delta[0]) > fabs(delta[1])) && (delta[1] != 0.0)) {
-            delta[0] = floor(delta[0]/delta[1] + 0.5) * delta[1];
-        } else if (delta[0] != 0.0) {
-            delta[1] = floor(delta[1]/delta[0] + 0.5) * delta[0];
-        }
-        p1 = ac->center + delta;
-        if (state & GDK_SHIFT_MASK) {
-            p0 = ac->center - delta;
-            const NR::Coord l0 = namedview_vector_snap(desktop->namedview, Snapper::SNAP_POINT, p0, p0 - p1);
-            const NR::Coord l1 = namedview_vector_snap(desktop->namedview, Snapper::SNAP_POINT, p1, p1 - p0);
+    sp_arc_position_set(SP_ARC(ac->item),
+                        r.midpoint()[NR::X], r.midpoint()[NR::Y],
+                        r.dimensions()[NR::X] / 2, r.dimensions()[NR::Y] / 2);
 
-            if (l0 < l1) {
-                p1 = 2 * ac->center - p0;
-            } else {
-                p0 = 2 * ac->center - p1;
-            }
-        } else {
-            p0 = ac->center;
-            namedview_vector_snap(desktop->namedview, Snapper::SNAP_POINT, p1, p1 - p0);
-        }
-    } else if (state & GDK_SHIFT_MASK) {
-        /* Corner point movements are bound */
-        p1 = pt;
-        p0 = 2 * ac->center - p1;
-        for (int d = 0 ; d < 2 ; ++d) {
-            NR::Coord snap_movement[2];
-            snap_movement[0] = namedview_dim_snap(desktop->namedview, Snapper::SNAP_POINT, p0, NR::Dim2(d));
-            snap_movement[1] = namedview_dim_snap(desktop->namedview, Snapper::SNAP_POINT, p1, NR::Dim2(d));
-            if ( snap_movement[0] <
-                 snap_movement[1] ) {
-                /* Use point 0 position. */
-                p1[d] = 2 * ac->center[d] - p0[d];
-            } else {
-                p0[d] = 2 * ac->center[d] - p1[d];
-            }
-        }
-    } else {
-        /* Free movement for corner point */
-        p0 = ac->center;
-        p1 = pt;
-        namedview_free_snap(desktop->namedview, Snapper::SNAP_POINT, p1);
-    }
-
-    p0 = sp_desktop_dt2root_xy_point(desktop, p0);
-    p1 = sp_desktop_dt2root_xy_point(desktop, p1);
-
-    // FIXME: use NR::Rect
-    const NR::Coord x0 = MIN(p0[NR::X], p1[NR::X]);
-    const NR::Coord y0 = MIN(p0[NR::Y], p1[NR::Y]);
-    const NR::Coord x1 = MAX(p0[NR::X], p1[NR::X]);
-    const NR::Coord y1 = MAX(p0[NR::Y], p1[NR::Y]);
-
-    sp_arc_position_set(SP_ARC(ac->item), (x0 + x1) / 2, (y0 + y1) / 2, (x1 - x0) / 2, (y1 - y0) / 2);
-
-    GString *xs = SP_PX_TO_METRIC_STRING(fabs(x1-x0), desktop->namedview->getDefaultMetric());
-    GString *ys = SP_PX_TO_METRIC_STRING(fabs(y1-y0), desktop->namedview->getDefaultMetric());
+    GString *xs = SP_PX_TO_METRIC_STRING(r.dimensions()[NR::X], desktop->namedview->getDefaultMetric());
+    GString *ys = SP_PX_TO_METRIC_STRING(r.dimensions()[NR::Y], desktop->namedview->getDefaultMetric());
     ac->_message_context->setF(Inkscape::NORMAL_MESSAGE, _("<b>Ellipse</b>: %s &#215; %s; with <b>Ctrl</b> to make circle or integer-ratio ellipse; with <b>Shift</b> to draw around the starting point"), xs->str, ys->str);
     g_string_free(xs, FALSE);
     g_string_free(ys, FALSE);
@@ -510,8 +425,8 @@ static void sp_arc_finish(SPArcContext *ac)
 
         SP_OBJECT(ac->item)->updateRepr();
 
-        SP_DT_SELECTION(desktop)->set(ac->item);
-        sp_document_done(SP_DT_DOCUMENT(desktop));
+        sp_desktop_selection(desktop)->set(ac->item);
+        sp_document_done(sp_desktop_document(desktop));
 
         ac->item = NULL;
     }
