@@ -13,6 +13,8 @@
 #define SEEN_COLOR_RGBA_H
 
 #include <glib/gmessages.h>
+#include "libnr/nr-pixops.h"
+#include "decimal-round.h"
 
 /**
     \brief  A class to contain a floating point RGBA color.
@@ -44,6 +46,24 @@ public:
             _c[i] = 0.0;
     }
 
+    /**
+        \brief  A constructor to create the color from an unsigned
+                int, as found everywhere when dealing with colors
+        \param  intcolor   rgba32 "unsigned int representation (0xRRGGBBAA)
+
+        Separate the values and load them into the array of floats in this object.
+        TODO : maybe get rid of the NR_RGBA32_x C-style functions and replace
+            the calls with the bitshifting they do
+    */
+    ColorRGBA(unsigned int intcolor)
+    {
+         _c[0] = NR_RGBA32_R(intcolor)/255.0;
+         _c[1] = NR_RGBA32_G(intcolor)/255.0;
+         _c[2] = NR_RGBA32_B(intcolor)/255.0;
+         _c[3] = NR_RGBA32_A(intcolor)/255.0;
+
+    }
+
     /**
         \brief  Create a ColorRGBA using an array of floats
         \param  in_array  The values to be placed into the object
@@ -94,9 +114,13 @@ public:
     bool operator== (const ColorRGBA other) const {
         for (int i = 0; i < 4; i++) {
             if (_c[i] != other[i])
-                return FALSE;
+                return false;
         }
-        return TRUE;
+        return true;
+    }
+
+    bool operator!=(ColorRGBA const &o) const {
+        return !(*this == o);
     }
 
     /**
@@ -121,6 +145,21 @@ public:
         return ColorRGBA(returnval[0], returnval[1], returnval[2], returnval[3]);
     }
 
+    /**
+        \brief  Give the rgba32 "unsigned int" representation of the color
+
+        round each components*255 and combine them (RRGGBBAA).
+        WARNING : this reduces color precision (from float to 0->255 int per component)
+            but it should be expected since we request this kind of output
+    */
+    unsigned int getIntValue() const {
+
+         return   (int(Inkscape::decimal_round(_c[0]*255, 0)) << 24) | 
+                        (int(Inkscape::decimal_round(_c[1]*255, 0))  << 16) | 
+                        (int(Inkscape::decimal_round(_c[2]*255, 0))  << 8) | 
+                        (int(Inkscape::decimal_round(_c[3]*255, 0)));
+    }
+
 private:
     /** \brief  Array of values that are stored. */
     float _c[4];
