@@ -13,9 +13,12 @@
  */
 
 
-#include <forward.h>
 #include <sigc++/connection.h>
-#include "libavoid/shape.h"
+
+struct SPItem;
+namespace Avoid {
+    class ShapeRef;
+}
 
 class SPAvoidRef {
 public:
@@ -27,6 +30,14 @@ public:
 
     void setAvoid(char const *value);
     void handleSettingChange(void);
+    
+    // Returns a list of SPItems of all connectors/shapes attached to
+    // this object.  Pass one of the following for 'type':
+    //     Avoid::runningTo
+    //     Avoid::runningFrom
+    //     Avoid::runningToAndFrom
+    GSList *getAttachedShapes(const unsigned int type);
+    GSList *getAttachedConnectors(const unsigned int type);
 
 private:
     SPItem *item;
@@ -39,6 +50,12 @@ private:
     sigc::connection _transformed_connection;
 };
 
+extern GSList *get_avoided_items(GSList *list, SPObject *from,
+        SPDesktop *desktop, bool initialised = true);
+extern void avoid_item_move(NR::Matrix const *mp, SPItem *moved_item);
+extern void init_avoided_shape_geometry(SPDesktop *desktop);
+
+static const double defaultConnSpacing = 10.0;
 
 #endif /* !SEEN_CONN_AVOID_REF */
 
