@@ -16,17 +16,17 @@
  *     connector starts outside of S but inside C, or if the best route around
  *     an object involves going inside C but without entering S.)
  *  o  Draw connectors to shape edges rather than bounding box.
- *  o  Fix minor endpoint position error for connected objects.
  *  o  Show a visual indicator for objects with the 'avoid' property set.
+ *  o  Allow user to change a object between a path and connector through
+ *     the interface.
  *  o  Create an interface for setting markers (arrow heads).
  *  o  Better distinguish between paths and connectors to prevent problems
  *     in the node tool and paths accidently being turned into connectors
  *     in the connector tool.  Perhaps have a way to convert between.
  *  o  Only call libavoid's updateEndPoint as required.  Currently we do it
  *     for both endpoints, even if only one is moving.
- *  o  Cleanup to remove unecessary borrowed DrawContext code.
  *  o  Allow user-placeable connection points.
- *  o  Deal sanely with connectors with both endpoints attached to the 
+ *  o  Deal sanely with connectors with both endpoints attached to the
  *     same connection point, and drawing of connectors attaching
  *     overlaping shapes (currently tries to adjust connector to be
  *     outside both bounding boxes).
@@ -35,14 +35,13 @@
  *           attached to each other.
  *     e.g., detach connector when it is moved or transformed in
  *           one of the other contexts.
- *  o  Cope with shapes whose ids change when they have attached 
+ *  o  Cope with shapes whose ids change when they have attached
  *     connectors.
  *  o  gobble_motion_events(GDK_BUTTON1_MASK)?;
  *
  */
 
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtksignal.h>
 
 #include "connector-context.h"
 #include "pixmaps/cursor-connector.xpm"
@@ -59,22 +58,19 @@
 #include "selection.h"
 #include "inkscape.h"
 #include "prefs-utils.h"
-#include "sp-item.h"
 #include "sp-path.h"
 #include "display/canvas-bpath.h"
-#include "display/sp-canvas.h"
-#include "display/sp-ctrlline.h"
 #include "display/sodipodi-ctrl.h"
 #include <glibmm/i18n.h>
-#include "libnr/n-art-bpath.h"
-#include "libnr/nr-point-matrix-ops.h"
 #include "snap.h"
 #include "knot.h"
 #include "sp-conn-end.h"
 #include "conn-avoid-ref.h"
 #include "libavoid/vertices.h"
-
-#include "prefs-utils.h"  // for prefs_get_int_attribute_limited
+#include "context-fns.h"
+#include "sp-namedview.h"
+#include "sp-text.h"
+#include "sp-flowtext.h"
 
 
 static void sp_connector_context_class_init(SPConnectorContextClass *klass);
@@ -190,12 +186,12 @@ sp_connector_context_init(SPConnectorContext *cc)
     ec->yp = 0;
 
     cc->red_color = 0xff00007f;
-    
+
     cc->newconn = NULL;
     cc->newConnRef = NULL;
-   
+
     cc->sel_changed_connection = sigc::connection();
-    
+
     cc->active_shape = NULL;
     cc->active_shape_repr = NULL;
     cc->active_shape_layer_repr = NULL;
@@ -204,10 +200,10 @@ sp_connector_context_init(SPConnectorContext *cc)
     cc->active_conn_repr = NULL;
 
     cc->active_handle = NULL;
-    
+
     cc->clickeditem = NULL;
     cc->clickedhandle = NULL;
-    
+
     cc->connpthandle = NULL;
     for (int i = 0; i < 2; ++i) {
         cc->endpt_handle[i] = NULL;
@@ -261,15 +257,15 @@ sp_connector_context_setup(SPEventContext *ec)
         ((SPEventContextClass *) parent_class)->setup(ec);
     }
 
-    cc->selection = SP_DT_SELECTION(dt);
+    cc->selection = sp_desktop_selection(dt);
 
     cc->sel_changed_connection.disconnect();
     cc->sel_changed_connection = cc->selection->connectChanged(
             sigc::bind(sigc::ptr_fun(&cc_selection_changed),
             (gpointer) cc));
-    
+
     /* Create red bpath */
-    cc->red_bpath = sp_canvas_bpath_new(SP_DT_SKETCH(ec->desktop), NULL);
+    cc->red_bpath = sp_canvas_bpath_new(sp_desktop_sketch(ec->desktop), NULL);
     sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(cc->red_bpath), cc->red_color,
             1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
     sp_canvas_bpath_set_fill(SP_CANVAS_BPATH(cc->red_bpath), 0x00000000,
@@ -282,10 +278,14 @@ sp_connector_context_setup(SPEventContext *ec)
 
     // Notice the initial selection.
     cc_selection_changed(cc->selection, (gpointer) cc);
-    
+
     if (prefs_get_int_attribute("tools.connector", "selcue", 0) != 0) {
         ec->enableSelectionCue();
     }
+
+    // Make sure we see all enter events for canvas items,
+    // even if a mouse button is depressed.
+    dt->canvas->gen_all_enter_events = true;
 }
 
 
@@ -293,18 +293,22 @@ static void
 sp_connector_context_finish(SPEventContext *ec)
 {
     SPConnectorContext *cc = SP_CONNECTOR_CONTEXT(ec);
-    
+
     spcc_connector_finish(cc);
 
     if (((SPEventContextClass *) parent_class)->finish) {
         ((SPEventContextClass *) parent_class)->finish(ec);
     }
-    
+
     if (cc->selection) {
         cc->selection = NULL;
     }
     cc_clear_active_shape(cc);
     cc_clear_active_conn(cc);
+
+    // Restore the default event generating behaviour.
+    SPDesktop *desktop = SP_EVENT_CONTEXT_DESKTOP(ec);
+    desktop->canvas->gen_all_enter_events = false;
 }
 
 
@@ -324,11 +328,11 @@ cc_clear_active_shape(SPConnectorContext *cc)
 
     if (cc->active_shape_repr) {
         sp_repr_remove_listener_by_data(cc->active_shape_repr, cc);
-        sp_repr_unref(cc->active_shape_repr);
+        Inkscape::GC::release(cc->active_shape_repr);
         cc->active_shape_repr = NULL;
-        
+
         sp_repr_remove_listener_by_data(cc->active_shape_layer_repr, cc);
-        sp_repr_unref(cc->active_shape_layer_repr);
+        Inkscape::GC::release(cc->active_shape_layer_repr);
         cc->active_shape_layer_repr = NULL;
     }
 
@@ -351,7 +355,7 @@ cc_clear_active_conn(SPConnectorContext *cc)
 
     if (cc->active_conn_repr) {
         sp_repr_remove_listener_by_data(cc->active_conn_repr, cc);
-        sp_repr_unref(cc->active_conn_repr);
+        Inkscape::GC::release(cc->active_conn_repr);
         cc->active_conn_repr = NULL;
     }
 
@@ -369,7 +373,7 @@ conn_pt_handle_test(SPConnectorContext *cc, NR::Point& p)
 {
     // TODO: this will need to change when there are more connection
     //       points available for each shape.
-   
+
     SPKnot *centerpt = cc->connpthandle;
     if (cc->active_handle && (cc->active_handle == centerpt))
     {
@@ -482,19 +486,14 @@ connector_handle_button_press(SPConnectorContext *const cc, GdkEventButton const
 {
     NR::Point const event_w(bevent.x, bevent.y);
     /* Find desktop coordinates */
-    NR::Point p = sp_desktop_w2d_xy_point(cc->desktop, event_w);
+    NR::Point p = cc->desktop->w2d(event_w);
 
     gint ret = FALSE;
     if ( bevent.button == 1 ) {
 
         SPDesktop *desktop = SP_EVENT_CONTEXT_DESKTOP(cc);
-        SPItem *layer=SP_ITEM(desktop->currentLayer());
-        if ( !layer || desktop->itemIsHidden(layer)) {
-            cc->_message_context->flash(Inkscape::WARNING_MESSAGE, _("<b>Current layer is hidden</b>. Unhide it to be able to draw on it."));
-            return TRUE;
-        }
-        if ( !layer || layer->isLocked()) {
-            cc->_message_context->flash(Inkscape::WARNING_MESSAGE, _("<b>Current layer is locked</b>. Unlock it to be able to draw on it."));
+
+        if (Inkscape::have_viable_layer(desktop, cc->_message_context) == false) {
             return TRUE;
         }
 
@@ -503,7 +502,7 @@ connector_handle_button_press(SPConnectorContext *const cc, GdkEventButton const
         connector_drag_origin_w = event_w;
         connector_within_tolerance = true;
 
-        NR::Point const event_dt(sp_desktop_w2d_xy_point(cc->desktop, event_w));
+        NR::Point const event_dt = cc->desktop->w2d(event_w);
         switch (cc->state) {
             case SP_CONNECTOR_CONTEXT_STOP:
                 /* This is allowed, if we just cancelled curve */
@@ -512,33 +511,35 @@ connector_handle_button_press(SPConnectorContext *const cc, GdkEventButton const
                 if ( cc->npoints == 0 ) {
                     /* Set start anchor */
                     NR::Point p;
-                        
+
                     cc_clear_active_conn(cc);
 
                     SP_EVENT_CONTEXT_DESKTOP(cc)->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Creating new connector"));
 
                     /* Create green anchor */
                     p = event_dt;
-                    
+
                     // Test whether we clicked on a connection point
                     cc->sid = conn_pt_handle_test(cc, p);
-                    
+
                     if (!cc->sid) {
                         // This is the first point, so just snap it to the grid
                         // as there's no other points to go off.
-                        namedview_free_snap_all_types(cc->desktop->namedview, p);
-                    }                        
+                        SnapManager const &m = cc->desktop->namedview->snap_manager;
+                        p = m.freeSnap(Inkscape::Snapper::SNAP_POINT | Inkscape::Snapper::BBOX_POINT,
+                                       p, NULL).getPoint();
+                    }
                     spcc_connector_set_initial_point(cc, p);
-                    
+
                 }
                 cc->state = SP_CONNECTOR_CONTEXT_DRAGGING;
                 ret = TRUE;
                 break;
-            }   
+            }
             case SP_CONNECTOR_CONTEXT_DRAGGING:
             {
                 // This is the second click of a connector creation.
-                
+
                 spcc_connector_set_subsequent_point(cc, p);
                 spcc_connector_finish_segment(cc, p);
                 // Test whether we clicked on a connection point
@@ -596,13 +597,13 @@ connector_handle_motion_notify(SPConnectorContext *const cc, GdkEventMotion cons
     SPDesktop *const dt = cc->desktop;
 
     /* Find desktop coordinates */
-    NR::Point p = sp_desktop_w2d_xy_point(dt, event_w);
+    NR::Point p = dt->w2d(event_w);
 
     switch (cc->state) {
         case SP_CONNECTOR_CONTEXT_DRAGGING:
         {
             // This is movement during a connector creation.
-            
+
             if ( cc->npoints > 0 ) {
                 cc->selection->clear();
                 spcc_connector_set_subsequent_point(cc, p);
@@ -655,12 +656,12 @@ connector_handle_button_release(SPConnectorContext *const cc, GdkEventButton con
     if ( revent.button == 1 ) {
 
         SPDesktop *desktop = SP_EVENT_CONTEXT_DESKTOP(cc);
-        SPDocument *doc = SP_DT_DOCUMENT(desktop);
+        SPDocument *doc = sp_desktop_document(desktop);
 
         NR::Point const event_w(revent.x, revent.y);
 
         /* Find desktop coordinates */
-        NR::Point p = sp_desktop_w2d_xy_point(cc->desktop, event_w);
+        NR::Point p = cc->desktop->w2d(event_w);
 
         switch (cc->state) {
             //case SP_CONNECTOR_CONTEXT_POINT:
@@ -705,7 +706,7 @@ connector_handle_button_release(SPConnectorContext *const cc, GdkEventButton con
                 }
                 cc->clickeditem->setHidden(false);
                 sp_conn_adjust_path(SP_PATH(cc->clickeditem));
-                cc->clickeditem->updateRepr(); 
+                cc->clickeditem->updateRepr();
                 sp_document_done(doc);
                 cc_set_active_conn(cc, cc->clickeditem);
                 sp_document_ensure_up_to_date(doc);
@@ -760,7 +761,7 @@ spcc_reset_colors(SPConnectorContext *cc)
     /* Red */
     sp_curve_reset(cc->red_curve);
     sp_canvas_bpath_set_bpath(SP_CANVAS_BPATH(cc->red_bpath), NULL);
-    
+
     sp_curve_reset(cc->green_curve);
     cc->npoints = 0;
 }
@@ -784,13 +785,14 @@ spcc_connector_set_subsequent_point(SPConnectorContext *const cc, NR::Point cons
     g_assert( cc->npoints != 0 );
 
     SPDesktop *dt = cc->desktop;
-    NR::Point o = sp_desktop_d2doc_xy_point(dt, cc->p[0]);
-    NR::Point d = sp_desktop_d2doc_xy_point(dt, p);
+    NR::Point o = dt->dt2doc(cc->p[0]);
+    NR::Point d = dt->dt2doc(p);
     Avoid::Point src = { o[NR::X], o[NR::Y] };
     Avoid::Point dst = { d[NR::X], d[NR::Y] };
 
     if (!cc->newConnRef) {
-        cc->newConnRef = new Avoid::ConnRef(0, src, dst);
+        Avoid::Router *router = sp_desktop_document(dt)->router;
+        cc->newConnRef = new Avoid::ConnRef(router, 0, src, dst);
         cc->newConnRef->updateEndPoint(Avoid::VertID::src, src);
     }
     cc->newConnRef->updateEndPoint(Avoid::VertID::tar, dst);
@@ -809,7 +811,7 @@ spcc_connector_set_subsequent_point(SPConnectorContext *const cc, NR::Point cons
         NR::Point p(route.ps[i].x, route.ps[i].y);
         sp_curve_lineto(cc->red_curve, p);
     }
-    sp_curve_transform(cc->red_curve, dt->doc2dt);
+    sp_curve_transform(cc->red_curve, dt->doc2dt());
     sp_canvas_bpath_set_bpath(SP_CANVAS_BPATH(cc->red_bpath), cc->red_curve);
 }
 
@@ -864,7 +866,7 @@ spcc_flush_white(SPConnectorContext *cc, SPCurve *gc)
             sp_desktop_dt2root_affine(SP_EVENT_CONTEXT_DESKTOP(cc)));
 
     SPDesktop *desktop = SP_EVENT_CONTEXT_DESKTOP(cc);
-    SPDocument *doc = SP_DT_DOCUMENT(desktop);
+    SPDocument *doc = sp_desktop_document(desktop);
 
     if ( c && !sp_curve_empty(c) ) {
         /* We actually have something to write */
@@ -875,13 +877,13 @@ spcc_flush_white(SPConnectorContext *cc, SPCurve *gc)
 
         gchar *str = sp_svg_write_path(SP_CURVE_BPATH(c));
         g_assert( str != NULL );
-        sp_repr_set_attr(repr, "d", str);
+        repr->setAttribute("d", str);
         g_free(str);
 
         /* Attach repr */
         cc->newconn = SP_ITEM(desktop->currentLayer()->appendChildRepr(repr));
         cc->selection->set(repr);
-        sp_repr_unref(repr);
+        Inkscape::GC::release(repr);
         cc->newconn->transform = i2i_affine(desktop->currentRoot(), desktop->currentLayer());
         cc->newconn->updateRepr();
 
@@ -942,7 +944,7 @@ spcc_connector_finish(SPConnectorContext *const cc)
     spcc_concat_colors_and_flush(cc);
 
     cc->npoints = 0;
-    
+
     if (cc->newConnRef) {
         cc->newConnRef->removeFromGraph();
         delete cc->newConnRef;
@@ -956,6 +958,8 @@ static gboolean
 cc_generic_knot_handler(SPCanvasItem *, GdkEvent *event, SPKnot *knot)
 {
     g_assert (knot != NULL);
+    
+    g_object_ref(knot);
 
     SPConnectorContext *cc = SP_CONNECTOR_CONTEXT(
             knot->desktop->event_context);
@@ -964,11 +968,8 @@ cc_generic_knot_handler(SPCanvasItem *, GdkEvent *event, SPKnot *knot)
 
     switch (event->type) {
         case GDK_ENTER_NOTIFY:
-            gtk_object_set (GTK_OBJECT (knot->item), "fill_color",
-                    knot->fill [SP_KNOT_STATE_MOUSEOVER], NULL);
-            gtk_object_set (GTK_OBJECT (knot->item), "stroke_color",
-                    knot->stroke [SP_KNOT_STATE_MOUSEOVER], NULL);
-
+            sp_knot_set_flag(knot, SP_KNOT_MOUSEOVER, TRUE);
+            
             cc->active_handle = knot;
 
             if (knot->tip)
@@ -976,32 +977,31 @@ cc_generic_knot_handler(SPCanvasItem *, GdkEvent *event, SPKnot *knot)
                 knot->desktop->event_context->defaultMessageContext()->set(
                         Inkscape::NORMAL_MESSAGE, knot->tip);
             }
-
+            
             consumed = TRUE;
             break;
         case GDK_LEAVE_NOTIFY:
-            gtk_object_set (GTK_OBJECT (knot->item), "fill_color",
-                    knot->fill [SP_KNOT_STATE_NORMAL], NULL);
-            gtk_object_set (GTK_OBJECT (knot->item), "stroke_color",
-                    knot->stroke [SP_KNOT_STATE_NORMAL], NULL);
-            
-            cc->active_handle = NULL;
+            sp_knot_set_flag(knot, SP_KNOT_MOUSEOVER, FALSE);
 
+            cc->active_handle = NULL;
+            
             if (knot->tip) {
                 knot->desktop->event_context->defaultMessageContext()->clear();
             }
-
+            
             consumed = TRUE;
             break;
         default:
             break;
     }
+    
+    g_object_unref(knot);
 
     return consumed;
 }
 
 
-static gboolean 
+static gboolean
 endpt_handler(SPKnot *knot, GdkEvent *event, SPConnectorContext *cc)
 {
     g_assert( SP_IS_CONNECTOR_CONTEXT(cc) );
@@ -1017,11 +1017,11 @@ endpt_handler(SPKnot *knot, GdkEvent *event, SPConnectorContext *cc)
                 cc->clickedhandle = cc->active_handle;
                 cc_clear_active_conn(cc);
                 cc->state = SP_CONNECTOR_CONTEXT_REROUTING;
-                
+
                 // Disconnect from attached shape
                 unsigned ind = (cc->active_handle == cc->endpt_handle[0]) ? 0 : 1;
                 sp_conn_end_detach(cc->clickeditem, ind);
-              
+
                 NR::Point origin;
                 if (cc->clickedhandle == cc->endpt_handle[0]) {
                     origin = cc->endpt_handle[1]->pos;
@@ -1055,69 +1055,60 @@ endpt_handler(SPKnot *knot, GdkEvent *event, SPConnectorContext *cc)
 static void cc_set_active_shape(SPConnectorContext *cc, SPItem *item)
 {
     g_assert(item != NULL );
-   
+
     cc->active_shape = item;
 
     // Remove existing active shape listeners
     if (cc->active_shape_repr) {
         sp_repr_remove_listener_by_data(cc->active_shape_repr, cc);
-        sp_repr_unref(cc->active_shape_repr);
-        
+        Inkscape::GC::release(cc->active_shape_repr);
+
         sp_repr_remove_listener_by_data(cc->active_shape_layer_repr, cc);
-        sp_repr_unref(cc->active_shape_layer_repr);
+        Inkscape::GC::release(cc->active_shape_layer_repr);
     }
-    
+
     // Listen in case the active shape changes
-    cc->active_shape_repr = SP_OBJECT_REPR(item); 
+    cc->active_shape_repr = SP_OBJECT_REPR(item);
     if (cc->active_shape_repr) {
-        sp_repr_ref(cc->active_shape_repr);
+        Inkscape::GC::anchor(cc->active_shape_repr);
         sp_repr_add_listener(cc->active_shape_repr, &shape_repr_events, cc);
-    
+
         cc->active_shape_layer_repr = cc->active_shape_repr->parent();
-        sp_repr_ref(cc->active_shape_layer_repr);
+        Inkscape::GC::anchor(cc->active_shape_layer_repr);
         sp_repr_add_listener(cc->active_shape_layer_repr, &layer_repr_events, cc);
     }
 
- 
+
     // Set center connection point.
     if ( cc->connpthandle == NULL ) {
-	SPKnot * knot = (SPKnot*)g_object_new (SP_TYPE_KNOT, 0);
+        SPKnot *knot = sp_knot_new(cc->desktop, 
+                _("<b>Connection point</b>: click or drag to create a new connector"));
 
-	knot->desktop = cc->desktop;
-	knot->flags = SP_KNOT_VISIBLE;
+        knot->setShape(SP_KNOT_SHAPE_SQUARE);
+        knot->setSize(8);
+        knot->setAnchor(GTK_ANCHOR_CENTER);
+        knot->setFill(0xffffff00, 0xff0000ff, 0xff0000ff);
+        sp_knot_update_ctrl(knot);
 
-	knot->item = sp_canvas_item_new (SP_DT_CONTROLS(cc->desktop),
-		SP_TYPE_CTRL,
-		"anchor", GTK_ANCHOR_CENTER,
-		"filled", TRUE,
-		"stroked", TRUE,
-		"mode", SP_KNOT_MODE_XOR,
-		NULL);
+        // We don't want to use the standard knot handler,
+        //since we don't want this knot to be draggable.
+        g_signal_handler_disconnect(G_OBJECT(knot->item),
+                knot->_event_handler_id);
+        knot->_event_handler_id = 0;
 
-	gtk_signal_connect (GTK_OBJECT (knot->item), "event",
-		GTK_SIGNAL_FUNC (cc_generic_knot_handler), knot);
+        gtk_signal_connect(GTK_OBJECT(knot->item), "event",
+                GTK_SIGNAL_FUNC(cc_generic_knot_handler), knot);
 
-        knot->fill [SP_KNOT_STATE_NORMAL] = 0xffffff00;
-        knot->fill [SP_KNOT_STATE_MOUSEOVER] = 0xff0000ff;
-        knot->stroke [SP_KNOT_STATE_NORMAL] = 0x01000000;
-
-        g_object_set(G_OBJECT(knot),
-                     "shape", SP_KNOT_SHAPE_SQUARE,
-                     "size", 8,
-                     "anchor", GTK_ANCHOR_CENTER,
-                     "tip", _("<b>Connection point</b>: click or drag to create a new connector"),
-                     NULL);
-        
         cc->connpthandle = knot;
     }
-    
+
 
     NR::Rect bbox = sp_item_bbox_desktop(cc->active_shape);
     NR::Point center = bbox.midpoint();
     sp_knot_set_position(cc->connpthandle, &center, 0);
 
     sp_knot_show(cc->connpthandle);
-    
+
 }
 
 
@@ -1128,32 +1119,32 @@ cc_set_active_conn(SPConnectorContext *cc, SPItem *item)
 
     SPCurve *curve = SP_SHAPE(SP_PATH(item))->curve;
     NR::Matrix i2d = sp_item_i2d_affine(item);
-    
+
     if (cc->active_conn == item)
     {
         // Just adjust handle positions.
         NR::Point startpt = sp_curve_first_point(curve) * i2d;
         sp_knot_set_position(cc->endpt_handle[0], &startpt, 0);
-        
+
         NR::Point endpt = sp_curve_last_point(curve) * i2d;
         sp_knot_set_position(cc->endpt_handle[1], &endpt, 0);
-        
+
         return;
     }
-    
+
     cc->active_conn = item;
 
     // Remove existing active conn listeners
     if (cc->active_conn_repr) {
         sp_repr_remove_listener_by_data(cc->active_conn_repr, cc);
-        sp_repr_unref(cc->active_conn_repr);
+        Inkscape::GC::release(cc->active_conn_repr);
         cc->active_conn_repr = NULL;
     }
-    
+
     // Listen in case the active conn changes
-    cc->active_conn_repr = SP_OBJECT_REPR(item); 
+    cc->active_conn_repr = SP_OBJECT_REPR(item);
     if (cc->active_conn_repr) {
-        sp_repr_ref(cc->active_conn_repr);
+        Inkscape::GC::anchor(cc->active_conn_repr);
         sp_repr_add_listener(cc->active_conn_repr, &shape_repr_events, cc);
     }
 
@@ -1161,36 +1152,28 @@ cc_set_active_conn(SPConnectorContext *cc, SPItem *item)
 
         // Create the handle if it doesn't exist
         if ( cc->endpt_handle[i] == NULL ) {
-            SPKnot * knot = (SPKnot*) g_object_new (SP_TYPE_KNOT, 0);
+            SPKnot *knot = sp_knot_new(cc->desktop, 
+                    _("<b>Connector endpoint</b>: drag to reroute or connect to new shapes"));
 
-            knot->desktop = cc->desktop;
-            knot->flags = SP_KNOT_VISIBLE;
+            knot->setShape(SP_KNOT_SHAPE_SQUARE);
+            knot->setSize(7);
+            knot->setAnchor(GTK_ANCHOR_CENTER);
+            knot->setFill(0xffffff00, 0xff0000ff, 0xff0000ff);
+            knot->setStroke(0x000000ff, 0x000000ff, 0x000000ff);
+            sp_knot_update_ctrl(knot);
 
-            knot->item = sp_canvas_item_new (SP_DT_CONTROLS (cc->desktop),
-                    SP_TYPE_CTRL,
-                    "anchor", GTK_ANCHOR_CENTER,
-                    "filled", TRUE,
-                    "stroked", TRUE,
-                    "mode", SP_KNOT_MODE_XOR,
-                    NULL);
+            // We don't want to use the standard knot handler,
+            //since we don't want this knot to be draggable.
+            g_signal_handler_disconnect(G_OBJECT(knot->item),
+                    knot->_event_handler_id);
+            knot->_event_handler_id = 0;
 
-            knot->fill [SP_KNOT_STATE_NORMAL] = 0xffffff00;
-            knot->stroke [SP_KNOT_STATE_NORMAL] = 0x000000ff;
-            knot->stroke [SP_KNOT_STATE_DRAGGING] = 0x000000ff;
-            knot->stroke [SP_KNOT_STATE_MOUSEOVER] = 0x000000ff;
-
-            g_object_set(G_OBJECT(knot),
-                    "shape", SP_KNOT_SHAPE_DIAMOND,
-                    "size", 10,
-                    "tip", _("<b>Connector endpoint</b>: drag to reroute or connect to new shapes"),
-                    NULL);
-
-            gtk_signal_connect (GTK_OBJECT (knot->item), "event",
-                    GTK_SIGNAL_FUNC (cc_generic_knot_handler), knot);
+            gtk_signal_connect(GTK_OBJECT(knot->item), "event",
+                    GTK_SIGNAL_FUNC(cc_generic_knot_handler), knot);
 
             cc->endpt_handle[i] = knot;
         }
-    
+
         // Remove any existing handlers
         if (cc->endpt_handler_id[i]) {
             g_signal_handlers_disconnect_by_func(
@@ -1199,20 +1182,20 @@ cc_set_active_conn(SPConnectorContext *cc, SPItem *item)
             cc->endpt_handler_id[i] = 0;
         }
 
-        // Setup handlers for connector endpoints, this is 
+        // Setup handlers for connector endpoints, this is
         // is as 'after' so that cc_generic_knot_handler is
         // triggered first for any endpoint.
         cc->endpt_handler_id[i] = g_signal_connect_after(
                 G_OBJECT(cc->endpt_handle[i]->item), "event",
                 G_CALLBACK(endpt_handler), cc);
     }
-    
+
     NR::Point startpt = sp_curve_first_point(curve) * i2d;
     sp_knot_set_position(cc->endpt_handle[0], &startpt, 0);
-    
+
     NR::Point endpt = sp_curve_last_point(curve) * i2d;
     sp_knot_set_position(cc->endpt_handle[1], &endpt, 0);
-    
+
     sp_knot_show(cc->endpt_handle[0]);
     sp_knot_show(cc->endpt_handle[1]);
 }
@@ -1227,6 +1210,12 @@ static bool cc_item_is_shape(SPItem *item)
             return false;
         }
     }
+    else if (SP_IS_TEXT(item) || SP_IS_FLOWTEXT(item)) {
+        if (prefs_get_int_attribute("tools.connector", "ignoretext", 1) == 1) {
+            // Don't count text as a shape we can connect connector to.
+            return false;
+        }
+    }
     return true;
 }
 
@@ -1242,7 +1231,7 @@ bool cc_item_is_connector(SPItem *item)
     return false;
 }
 
-    
+
 void cc_selection_set_avoid(bool const set_avoid)
 {
     SPDesktop *desktop = inkscape_active_desktop();
@@ -1250,9 +1239,9 @@ void cc_selection_set_avoid(bool const set_avoid)
         return;
     }
 
-    SPDocument *document = SP_DT_DOCUMENT(desktop);
+    SPDocument *document = sp_desktop_document(desktop);
 
-    Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+    Inkscape::Selection *selection = sp_desktop_selection(desktop);
 
     GSList *l = (GSList *) selection->itemList();
 
@@ -1262,14 +1251,14 @@ void cc_selection_set_avoid(bool const set_avoid)
         SPItem *item = (SPItem *) l->data;
 
         char const *value = (set_avoid) ? "true" : NULL;
-        
+
         if (cc_item_is_shape(item)) {
             sp_object_setAttribute(item, "inkscape:connector-avoid",
                     value, false);
             item->avoidRef->handleSettingChange();
             changes++;
         }
-        
+
         l = l->next;
     }
 
@@ -1281,7 +1270,7 @@ void cc_selection_set_avoid(bool const set_avoid)
 
     sp_document_done(document);
 }
-    
+
 
 static void
 cc_selection_changed(Inkscape::Selection *selection, gpointer data)
@@ -1290,10 +1279,10 @@ cc_selection_changed(Inkscape::Selection *selection, gpointer data)
     //SPEventContext *ec = SP_EVENT_CONTEXT(cc);
 
     SPItem *item = selection->singleItem();
-    
+
     if (cc->active_conn == item)
     {
-        // Noting to change.
+        // Nothing to change.
         return;
     }
     if (item == NULL)
@@ -1301,7 +1290,7 @@ cc_selection_changed(Inkscape::Selection *selection, gpointer data)
         cc_clear_active_conn(cc);
         return;
     }
-    
+
     if (cc_item_is_connector(item)) {
         cc_set_active_conn(cc, item);
     }
@@ -1329,7 +1318,7 @@ shape_event_attr_changed(Inkscape::XML::Node *repr, gchar const *name,
 {
     g_assert(data);
     SPConnectorContext *cc = SP_CONNECTOR_CONTEXT(data);
-  
+
     // Look for changes than result in onscreen movement.
     if (!strcmp(name, "d") || !strcmp(name, "x") || !strcmp(name, "y") ||
             !strcmp(name, "width") || !strcmp(name, "height") ||
