@@ -13,7 +13,7 @@
 #define SEEN_INKSCAPE_DEBUG_HEAP_H
 
 #include <cstddef>
-#include "util/shared-c-string-ptr.h"
+#include "util/share.h"
 
 namespace Inkscape {
 
@@ -36,7 +36,7 @@ public:
 
     virtual int features() const=0;
 
-    virtual Util::SharedCStringPtr name() const=0;
+    virtual Util::ptr_shared<char> name() const=0;
     virtual Stats stats() const=0;
     virtual void force_collect()=0;
 };
@@ -55,9 +55,9 @@ void register_extra_heap(Heap &heap);
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
