@@ -5,22 +5,21 @@
  *
  * Authors:
  *   bulia byak
+ *   verbalshadow
  *
- * Copyright (C) 2004 authors
+ * Copyright (C) 2004, 2006 authors
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "macros.h"
 #include "desktop.h"
-#include "sp-object.h"
-#include "color.h"
 #include "color-rgba.h"
 #include "svg/css-ostringstream.h"
 #include "svg/svg.h"
+#include "svg/svg-color.h"
 #include "selection.h"
 #include "sp-tspan.h"
-#include "fontsize-expansion.h"
+#include "sp-textpath.h"
 #include "inkscape.h"
 #include "style.h"
 #include "prefs-utils.h"
@@ -28,13 +27,13 @@
 #include "sp-flowtext.h"
 #include "sp-flowregion.h"
 #include "sp-flowdiv.h"
-#include "sp-gradient.h"
 #include "sp-linear-gradient.h"
 #include "sp-radial-gradient.h"
 #include "sp-pattern.h"
 #include "xml/repr.h"
 #include "libnrtype/font-style-to-pos.h"
 
+
 #include "desktop-style.h"
 
 /**
@@ -86,7 +85,7 @@ sp_desktop_apply_css_recursive(SPObject *o, SPCSSAttr *css, bool skip_lines)
 
     // 2. Generally we allow setting style on clones, but when it's inside flowRegion, do not touch
     // it, be it clone or not; it's just styleless shape (because that's how Inkscape does
-    // flowtext). 
+    // flowtext).
 
     if (!(skip_lines
           && ((SP_IS_TSPAN(o) && SP_TSPAN(o)->role == SP_TSPAN_ROLE_LINE)
@@ -147,17 +146,19 @@ sp_desktop_apply_css_recursive(SPObject *o, SPCSSAttr *css, bool skip_lines)
  * Apply style on selection on desktop.
  */
 void
-sp_desktop_set_style(SPDesktop *desktop, SPCSSAttr *css, bool change)
+sp_desktop_set_style(SPDesktop *desktop, SPCSSAttr *css, bool change, bool write_current)
 {
+    if (write_current) {
 // 1. Set internal value
-    sp_repr_css_merge(desktop->current, css);
+        sp_repr_css_merge(desktop->current, css);
 
 // 1a. Write to prefs; make a copy and unset any URIs first
-    SPCSSAttr *css_write = sp_repr_css_attr_new();
-    sp_repr_css_merge(css_write, css);
-    sp_css_attr_unset_uris(css_write);
-    sp_repr_css_change(inkscape_get_repr(INKSCAPE, "desktop"), css_write, "style");
-    sp_repr_css_attr_unref(css_write);
+        SPCSSAttr *css_write = sp_repr_css_attr_new();
+        sp_repr_css_merge(css_write, css);
+        sp_css_attr_unset_uris(css_write);
+        sp_repr_css_change(inkscape_get_repr(INKSCAPE, "desktop"), css_write, "style");
+        sp_repr_css_attr_unref(css_write);
+    }
 
     if (!change)
         return;
@@ -166,8 +167,8 @@ sp_desktop_set_style(SPDesktop *desktop, SPCSSAttr *css, bool change)
     bool intercepted = desktop->_set_style_signal.emit(css);
 
 /** \todo
- * FIXME: in set_style, compensate pattern and gradient fills, stroke width, 
- * rect corners, font size for the object's own transform so that pasting 
+ * FIXME: in set_style, compensate pattern and gradient fills, stroke width,
+ * rect corners, font size for the object's own transform so that pasting
  * fills does not depend on preserve/optimize.
  */
 
@@ -220,6 +221,91 @@ sp_desktop_get_color(SPDesktop *desktop, bool is_fill)
     return r;
 }
 
+double
+sp_desktop_get_master_opacity_tool(SPDesktop *desktop, char const *tool)
+{
+    SPCSSAttr *css = NULL;
+    gfloat value = 1.0; // default if nothing else found
+    if (prefs_get_double_attribute(tool, "usecurrent", 0) != 0) {
+        css = sp_desktop_get_style(desktop, true);
+    } else { 
+        Inkscape::XML::Node *tool_repr = inkscape_get_repr(INKSCAPE, tool);
+        if (tool_repr) {
+            css = sp_repr_css_attr_inherited(tool_repr, "style");
+        }
+    }
+   
+    if (css) {
+        gchar const *property = css ? sp_repr_css_property(css, "opacity", "1.000") : 0;
+           
+        if (desktop->current && property) { // if there is style and the property in it,
+            if ( !sp_svg_number_read_f(property, &value) ) {
+                value = 1.0; // things failed. set back to the default
+            }
+        }
+
+        sp_repr_css_attr_unref(css);
+    }
+
+    return value;
+}
+double
+sp_desktop_get_opacity_tool(SPDesktop *desktop, char const *tool, bool is_fill)
+{
+    SPCSSAttr *css = NULL;
+    gfloat value = 1.0; // default if nothing else found
+    if (prefs_get_double_attribute(tool, "usecurrent", 0) != 0) {
+        css = sp_desktop_get_style(desktop, true);
+    } else { 
+        Inkscape::XML::Node *tool_repr = inkscape_get_repr(INKSCAPE, tool);
+        if (tool_repr) {
+            css = sp_repr_css_attr_inherited(tool_repr, "style");
+        }
+    }
+   
+    if (css) {
+        gchar const *property = css ? sp_repr_css_property(css, is_fill ? "fill-opacity": "stroke-opacity", "1.000") : 0;
+           
+        if (desktop->current && property) { // if there is style and the property in it,
+            if ( !sp_svg_number_read_f(property, &value) ) {
+                value = 1.0; // things failed. set back to the default
+            }
+        }
+
+        sp_repr_css_attr_unref(css);
+    }
+
+    return value;
+}
+guint32
+sp_desktop_get_color_tool(SPDesktop *desktop, char const *tool, bool is_fill)
+{
+    SPCSSAttr *css = NULL;
+    guint32 r = 0; // if there's no color, return black
+    if (prefs_get_int_attribute(tool, "usecurrent", 0) != 0) {
+        css = sp_desktop_get_style(desktop, true);
+    } else {
+        Inkscape::XML::Node *tool_repr = inkscape_get_repr(INKSCAPE, tool);
+        if (tool_repr) {
+            css = sp_repr_css_attr_inherited(tool_repr, "style");
+        }
+    }
+   
+    if (css) {
+        gchar const *property = sp_repr_css_property(css, is_fill ? "fill" : "stroke", "#000");
+           
+        if (desktop->current && property) { // if there is style and the property in it,
+            if (strncmp(property, "url", 3)) { // and if it's not url,
+                // read it
+                r = sp_svg_read_color(property, r);
+            }
+        }
+
+        sp_repr_css_attr_unref(css);
+    }
+
+    return r | 0xff;
+}
 /**
  * Apply the desktop's current style or the tool style to repr.
  */
@@ -243,7 +329,7 @@ sp_desktop_apply_style_tool(SPDesktop *desktop, Inkscape::XML::Node *repr, char
 }
 
 /**
- * Returns the font size (in SVG pixels) of the text tool style (if text 
+ * Returns the font size (in SVG pixels) of the text tool style (if text
  * tool uses its own style) or desktop style (otherwise).
 */
 double
@@ -271,6 +357,7 @@ sp_desktop_get_font_size_tool(SPDesktop *desktop)
 }
 
 /** Determine average stroke width, simple method */
+// see TODO in dialogs/stroke-style.cpp on how to get rid of this eventually
 gdouble
 stroke_average_width (GSList const *objects)
 {
@@ -305,71 +392,8 @@ stroke_average_width (GSList const *objects)
     return avgwidth / (g_slist_length ((GSList *) objects) - n_notstroked);
 }
 
-/** Determines if the stroke width differs among objects */
-bool
-stroke_width_varying (GSList const *objects)
-{
-    if (g_slist_length ((GSList *) objects) <= 1)
-        return false;
-
-    gdouble width = NR_HUGE;
-
-    for (GSList const *l = objects; l != NULL; l = l->next) {
-
-        if (!SP_IS_ITEM (l->data))
-            continue;
-
-        SPObject *object = SP_OBJECT(l->data);
-
-        if ( SP_OBJECT_STYLE (object)->stroke.type == SP_PAINT_TYPE_NONE ) {
-            continue;
-        }
-
-        NR::Matrix i2d = sp_item_i2d_affine (SP_ITEM(l->data));
-
-        if (width == NR_HUGE) {
-            width = SP_OBJECT_STYLE (object)->stroke_width.computed * i2d.expansion();
-        } else {
-            if (fabs (width - SP_OBJECT_STYLE (object)->stroke_width.computed * i2d.expansion()) > 1e-3)
-                return true;
-        }
-
-    }
-
-    return false;
-}
-
-/** Determine average miterlimit */
-gdouble
-stroke_average_miterlimit (GSList const *objects)
-{
-    if (g_slist_length ((GSList *)objects) == 0)
-        return NR_HUGE;
-
-    gdouble avgml = 0.0;
-    bool notstroked = true;
-
-    for (GSList const *l = objects; l != NULL; l = l->next) {
-        if (!SP_IS_ITEM (l->data))
-            continue;
-
-        SPObject *object = SP_OBJECT(l->data);
-
-        avgml += object->style->stroke_miterlimit.value;
-
-        if ( object->style->stroke.type != SP_PAINT_TYPE_NONE ) {
-            notstroked = false;
-        }
-    }
-
-    if (notstroked)
-        return NR_HUGE;
-
-    return avgml / g_slist_length ((GSList *) objects);
-}
-
 /**
- * Return average fill or stroke of list of objects, if applicable.
+ * Write to style_res the average fill or stroke of list of objects, if applicable.
  */
 int
 objects_query_fillstroke (GSList *objects, SPStyle *style_res, bool const isfill)
@@ -438,7 +462,7 @@ objects_query_fillstroke (GSList *objects, SPStyle *style_res, bool const isfill
 
                 if (!SP_IS_PATTERN(server))
                    return QUERY_STYLE_MULTIPLE_DIFFERENT;  // different kind of server
- 
+
                 SPPattern *pat = pattern_getroot (SP_PATTERN (server));
                 SPPattern *pat_res = pattern_getroot (SP_PATTERN (server_res));
                 if (pat_res != pat)
@@ -472,7 +496,7 @@ objects_query_fillstroke (GSList *objects, SPStyle *style_res, bool const isfill
             num ++;
         }
 
-       if (paint_res->set && paint->set && paint->type == SP_PAINT_TYPE_PAINTSERVER) { // copy the server
+       if (paint_res->set && paint_effectively_set && paint->type == SP_PAINT_TYPE_PAINTSERVER) { // copy the server
            if (isfill) {
                SP_STYLE_FILL_SERVER (style_res) = SP_STYLE_FILL_SERVER (style);
            } else {
@@ -501,7 +525,7 @@ objects_query_fillstroke (GSList *objects, SPStyle *style_res, bool const isfill
         if (num > 1) {
             if (same_color)
                 return QUERY_STYLE_MULTIPLE_SAME;
-            else 
+            else
                 return QUERY_STYLE_MULTIPLE_AVERAGED;
         } else {
             return QUERY_STYLE_SINGLE;
@@ -517,7 +541,265 @@ objects_query_fillstroke (GSList *objects, SPStyle *style_res, bool const isfill
 }
 
 /**
- * Returns style with average font size and spacing of objects.
+ * Write to style_res the average opacity of a list of objects.
+ */
+int
+objects_query_opacity (GSList *objects, SPStyle *style_res)
+{
+    if (g_slist_length(objects) == 0) {
+        /* No objects, set empty */
+        return QUERY_STYLE_NOTHING;
+    }
+
+    gdouble opacity_sum = 0;
+    gdouble opacity_prev = -1;
+    bool same_opacity = true;
+    guint opacity_items = 0;
+
+
+    for (GSList const *i = objects; i != NULL; i = i->next) {
+        SPObject *obj = SP_OBJECT (i->data);
+        SPStyle *style = SP_OBJECT_STYLE (obj);
+        if (!style) continue;
+
+        double opacity = SP_SCALE24_TO_FLOAT(style->opacity.value);
+        opacity_sum += opacity;
+        if (opacity_prev != -1 && opacity != opacity_prev)
+            same_opacity = false;
+        opacity_prev = opacity;
+        opacity_items ++;
+    }
+    if (opacity_items > 1)
+        opacity_sum /= opacity_items;
+
+    style_res->opacity.value = SP_SCALE24_FROM_FLOAT(opacity_sum);
+
+    if (opacity_items == 0) {
+        return QUERY_STYLE_NOTHING;
+    } else if (opacity_items == 1) {
+        return QUERY_STYLE_SINGLE;
+    } else {
+        if (same_opacity)
+            return QUERY_STYLE_MULTIPLE_SAME;
+        else
+            return QUERY_STYLE_MULTIPLE_AVERAGED;
+    }
+}
+
+/**
+ * Write to style_res the average stroke width of a list of objects.
+ */
+int
+objects_query_strokewidth (GSList *objects, SPStyle *style_res)
+{
+    if (g_slist_length(objects) == 0) {
+        /* No objects, set empty */
+        return QUERY_STYLE_NOTHING;
+    }
+
+    gdouble avgwidth = 0.0;
+
+    gdouble prev_sw = -1;
+    bool same_sw = true;
+
+    int n_stroked = 0;
+
+    for (GSList const *i = objects; i != NULL; i = i->next) {
+        SPObject *obj = SP_OBJECT (i->data);
+        if (!SP_IS_ITEM(obj)) continue;
+        SPStyle *style = SP_OBJECT_STYLE (obj);
+        if (!style) continue;
+
+        if ( style->stroke.type == SP_PAINT_TYPE_NONE ) {
+            continue;
+        }
+
+        n_stroked ++;
+
+        NR::Matrix i2d = sp_item_i2d_affine (SP_ITEM(obj));
+        double sw = style->stroke_width.computed * i2d.expansion();
+
+        if (prev_sw != -1 && fabs(sw - prev_sw) > 1e-3)
+            same_sw = false;
+        prev_sw = sw;
+
+        avgwidth += sw;
+    }
+
+    if (n_stroked > 1)
+        avgwidth /= (n_stroked);
+
+    style_res->stroke_width.computed = avgwidth;
+    style_res->stroke_width.set = true;
+
+    if (n_stroked == 0) {
+        return QUERY_STYLE_NOTHING;
+    } else if (n_stroked == 1) {
+        return QUERY_STYLE_SINGLE;
+    } else {
+        if (same_sw)
+            return QUERY_STYLE_MULTIPLE_SAME;
+        else
+            return QUERY_STYLE_MULTIPLE_AVERAGED;
+    }
+}
+
+/**
+ * Write to style_res the average miter limit of a list of objects.
+ */
+int
+objects_query_miterlimit (GSList *objects, SPStyle *style_res)
+{
+    if (g_slist_length(objects) == 0) {
+        /* No objects, set empty */
+        return QUERY_STYLE_NOTHING;
+    }
+
+    gdouble avgml = 0.0;
+    int n_stroked = 0;
+
+    gdouble prev_ml = -1;
+    bool same_ml = true;
+
+    for (GSList const *i = objects; i != NULL; i = i->next) {
+        SPObject *obj = SP_OBJECT (i->data);
+        if (!SP_IS_ITEM(obj)) continue;
+        SPStyle *style = SP_OBJECT_STYLE (obj);
+        if (!style) continue;
+
+        if ( style->stroke.type == SP_PAINT_TYPE_NONE ) {
+            continue;
+        }
+
+        n_stroked ++;
+
+        if (prev_ml != -1 && fabs(style->stroke_miterlimit.value - prev_ml) > 1e-3)
+            same_ml = false;
+        prev_ml = style->stroke_miterlimit.value;
+
+        avgml += style->stroke_miterlimit.value;
+    }
+
+    if (n_stroked > 1)
+        avgml /= (n_stroked);
+
+    style_res->stroke_miterlimit.value = avgml;
+    style_res->stroke_miterlimit.set = true;
+
+    if (n_stroked == 0) {
+        return QUERY_STYLE_NOTHING;
+    } else if (n_stroked == 1) {
+        return QUERY_STYLE_SINGLE;
+    } else {
+        if (same_ml)
+            return QUERY_STYLE_MULTIPLE_SAME;
+        else
+            return QUERY_STYLE_MULTIPLE_AVERAGED;
+    }
+}
+
+/**
+ * Write to style_res the stroke cap of a list of objects.
+ */
+int
+objects_query_strokecap (GSList *objects, SPStyle *style_res)
+{
+    if (g_slist_length(objects) == 0) {
+        /* No objects, set empty */
+        return QUERY_STYLE_NOTHING;
+    }
+
+    int cap = -1;
+    gdouble prev_cap = -1;
+    bool same_cap = true;
+    int n_stroked = 0;
+
+    for (GSList const *i = objects; i != NULL; i = i->next) {
+        SPObject *obj = SP_OBJECT (i->data);
+        if (!SP_IS_ITEM(obj)) continue;
+        SPStyle *style = SP_OBJECT_STYLE (obj);
+        if (!style) continue;
+
+        if ( style->stroke.type == SP_PAINT_TYPE_NONE ) {
+            continue;
+        }
+
+        n_stroked ++;
+
+        if (prev_cap != -1 && style->stroke_linecap.value != prev_cap)
+            same_cap = false;
+        prev_cap = style->stroke_linecap.value;
+
+        cap = style->stroke_linecap.value;
+    }
+
+    style_res->stroke_linecap.value = cap;
+    style_res->stroke_linecap.set = true;
+
+    if (n_stroked == 0) {
+        return QUERY_STYLE_NOTHING;
+    } else if (n_stroked == 1) {
+        return QUERY_STYLE_SINGLE;
+    } else {
+        if (same_cap)
+            return QUERY_STYLE_MULTIPLE_SAME;
+        else
+            return QUERY_STYLE_MULTIPLE_DIFFERENT;
+    }
+}
+
+/**
+ * Write to style_res the stroke join of a list of objects.
+ */
+int
+objects_query_strokejoin (GSList *objects, SPStyle *style_res)
+{
+    if (g_slist_length(objects) == 0) {
+        /* No objects, set empty */
+        return QUERY_STYLE_NOTHING;
+    }
+
+    int join = -1;
+    gdouble prev_join = -1;
+    bool same_join = true;
+    int n_stroked = 0;
+
+    for (GSList const *i = objects; i != NULL; i = i->next) {
+        SPObject *obj = SP_OBJECT (i->data);
+        if (!SP_IS_ITEM(obj)) continue;
+        SPStyle *style = SP_OBJECT_STYLE (obj);
+        if (!style) continue;
+
+        if ( style->stroke.type == SP_PAINT_TYPE_NONE ) {
+            continue;
+        }
+
+        n_stroked ++;
+
+        if (prev_join != -1 && style->stroke_linejoin.value != prev_join)
+            same_join = false;
+        prev_join = style->stroke_linejoin.value;
+
+        join = style->stroke_linejoin.value;
+    }
+
+    style_res->stroke_linejoin.value = join;
+    style_res->stroke_linejoin.set = true;
+
+    if (n_stroked == 0) {
+        return QUERY_STYLE_NOTHING;
+    } else if (n_stroked == 1) {
+        return QUERY_STYLE_SINGLE;
+    } else {
+        if (same_join)
+            return QUERY_STYLE_MULTIPLE_SAME;
+        else
+            return QUERY_STYLE_MULTIPLE_DIFFERENT;
+    }
+}
+
+/**
+ * Write to style_res the average font size and spacing of objects.
  */
 int
 objects_query_fontnumbers (GSList *objects, SPStyle *style_res)
@@ -560,7 +842,7 @@ objects_query_fontnumbers (GSList *objects, SPStyle *style_res)
             letterspacing_normal = false;
         }
 
-        double linespacing_current; 
+        double linespacing_current;
         if (style->line_height.normal) {
             linespacing_current = Inkscape::Text::Layout::LINE_HEIGHT_NORMAL;
             if (!different && (linespacing_prev == 0 || linespacing_prev == linespacing_current))
@@ -621,7 +903,7 @@ objects_query_fontnumbers (GSList *objects, SPStyle *style_res)
 }
 
 /**
- * Return style with average font style of objects.
+ * Write to style_res the average font style of objects.
  */
 int
 objects_query_fontstyle (GSList *objects, SPStyle *style_res)
@@ -644,7 +926,7 @@ objects_query_fontstyle (GSList *objects, SPStyle *style_res)
 
         texts ++;
 
-        if (set && 
+        if (set &&
             font_style_to_pos(*style_res).signature() != font_style_to_pos(*style).signature() ) {
             different = true;  // different styles
         }
@@ -654,6 +936,7 @@ objects_query_fontstyle (GSList *objects, SPStyle *style_res)
         style_res->font_style.value = style_res->font_style.computed = style->font_style.computed;
         style_res->font_stretch.value = style_res->font_stretch.computed = style->font_stretch.computed;
         style_res->font_variant.value = style_res->font_variant.computed = style->font_variant.computed;
+        style_res->text_align.value = style_res->text_align.computed = style->text_align.computed;
     }
 
     if (texts == 0 || !set)
@@ -671,7 +954,7 @@ objects_query_fontstyle (GSList *objects, SPStyle *style_res)
 }
 
 /**
- * Return style with average font family of objects.
+ * Write to style_res the average font family of objects.
  */
 int
 objects_query_fontfamily (GSList *objects, SPStyle *style_res)
@@ -698,7 +981,7 @@ objects_query_fontfamily (GSList *objects, SPStyle *style_res)
 
         texts ++;
 
-        if (style_res->text->font_family.value && style->text->font_family.value && 
+        if (style_res->text->font_family.value && style->text->font_family.value &&
             strcmp (style_res->text->font_family.value, style->text->font_family.value)) {
             different = true;  // different fonts
         }
@@ -727,46 +1010,76 @@ objects_query_fontfamily (GSList *objects, SPStyle *style_res)
 }
 
 /**
- * Query selection on desktop for property.
+ * Query the given list of objects for the given property, write
+ * the result to style, return appropriate flag.
+ */
+int
+sp_desktop_query_style_from_list (GSList *list, SPStyle *style, int property)
+{
+    if (property == QUERY_STYLE_PROPERTY_FILL) {
+        return objects_query_fillstroke (list, style, true);
+    } else if (property == QUERY_STYLE_PROPERTY_STROKE) {
+        return objects_query_fillstroke (list, style, false);
+
+    } else if (property == QUERY_STYLE_PROPERTY_STROKEWIDTH) {
+        return objects_query_strokewidth (list, style);
+    } else if (property == QUERY_STYLE_PROPERTY_STROKEMITERLIMIT) {
+        return objects_query_miterlimit (list, style);
+    } else if (property == QUERY_STYLE_PROPERTY_STROKECAP) {
+        return objects_query_strokecap (list, style);
+    } else if (property == QUERY_STYLE_PROPERTY_STROKEJOIN) {
+        return objects_query_strokejoin (list, style);
+
+    } else if (property == QUERY_STYLE_PROPERTY_MASTEROPACITY) {
+        return objects_query_opacity (list, style);
+
+    } else if (property == QUERY_STYLE_PROPERTY_FONTFAMILY) {
+        return objects_query_fontfamily (list, style);
+    } else if (property == QUERY_STYLE_PROPERTY_FONTSTYLE) {
+        return objects_query_fontstyle (list, style);
+    } else if (property == QUERY_STYLE_PROPERTY_FONTNUMBERS) {
+        return objects_query_fontnumbers (list, style);
+    }
+
+    return QUERY_STYLE_NOTHING;
+}
+
+
+/**
+ * Query the subselection (if any) or selection on the given desktop for the given property, write
+ * the result to style, return appropriate flag.
  */
 int
 sp_desktop_query_style(SPDesktop *desktop, SPStyle *style, int property)
 {
     int ret = desktop->_query_style_signal.emit(style, property);
 
-    if (ret != QUERY_STYLE_NOTHING)  
+    if (ret != QUERY_STYLE_NOTHING)
         return ret; // subselection returned a style, pass it on
 
     // otherwise, do querying and averaging over selection
-    if (property == QUERY_STYLE_PROPERTY_FILL) {
-        return objects_query_fillstroke ((GSList *) desktop->selection->itemList(), style, true);
-    } else if (property == QUERY_STYLE_PROPERTY_STROKE) {
-        return objects_query_fillstroke ((GSList *) desktop->selection->itemList(), style, false);
-
-    } else if (property == QUERY_STYLE_PROPERTY_FONTFAMILY) {
-        return objects_query_fontfamily ((GSList *) desktop->selection->itemList(), style);
-    } else if (property == QUERY_STYLE_PROPERTY_FONTSTYLE) {
-        return objects_query_fontstyle ((GSList *) desktop->selection->itemList(), style);
-    } else if (property == QUERY_STYLE_PROPERTY_FONTNUMBERS) {
-        return objects_query_fontnumbers ((GSList *) desktop->selection->itemList(), style);
-    }
-
-    return QUERY_STYLE_NOTHING;
+    return sp_desktop_query_style_from_list ((GSList *) desktop->selection->itemList(), style, property);
 }
 
 /**
- * Compute average style for all selected objects and style properties.
+ * Do the same as sp_desktop_query_style for all (defined) style properties, return true if none of
+ * the properties returned QUERY_STYLE_NOTHING.
  */
 bool
 sp_desktop_query_style_all (SPDesktop *desktop, SPStyle *query)
 {
         int result_family = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_FONTFAMILY);
-        int result_fstyle = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_FONTSTYLE); 
-        int result_fnumbers = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_FONTNUMBERS); 
+        int result_fstyle = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_FONTSTYLE);
+        int result_fnumbers = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_FONTNUMBERS);
         int result_fill = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_FILL);
         int result_stroke = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_STROKE);
+        int result_strokewidth = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_STROKEWIDTH);
+        int result_strokemiterlimit = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_STROKEMITERLIMIT);
+        int result_strokecap = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_STROKECAP);
+        int result_strokejoin = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_STROKEJOIN);
+        int result_opacity = sp_desktop_query_style (desktop, query, QUERY_STYLE_PROPERTY_MASTEROPACITY);
 
-        return (result_family != QUERY_STYLE_NOTHING && result_fstyle != QUERY_STYLE_NOTHING && result_fnumbers != QUERY_STYLE_NOTHING && result_fill != QUERY_STYLE_NOTHING && result_stroke != QUERY_STYLE_NOTHING);
+        return (result_family != QUERY_STYLE_NOTHING && result_fstyle != QUERY_STYLE_NOTHING && result_fnumbers != QUERY_STYLE_NOTHING && result_fill != QUERY_STYLE_NOTHING && result_stroke != QUERY_STYLE_NOTHING && result_opacity != QUERY_STYLE_NOTHING && result_strokewidth != QUERY_STYLE_NOTHING && result_strokemiterlimit != QUERY_STYLE_NOTHING && result_strokecap != QUERY_STYLE_NOTHING && result_strokejoin != QUERY_STYLE_NOTHING);
 }
 
 
