@@ -23,9 +23,11 @@
 
 #include <gtk/gtktypeutils.h>
 #include <sigc++/sigc++.h>
-#include <libnr/nr-matrix.h>
-#include <libnr/nr-matrix-fns.h>
+#include "libnr/nr-matrix.h"
+#include "libnr/nr-matrix-fns.h"
+#include "libnr/nr-rect.h"
 #include "ui/view/view.h"
+#include "ui/view/edit-widget-interface.h"
 
 class NRRect;
 class SPCSSAttr;
@@ -38,6 +40,7 @@ struct SPItem;
 struct SPNamedView;
 struct SPObject;
 struct SPStyle;
+struct SPViewWidget;
 
 typedef int sp_verb_t;
 
@@ -46,6 +49,7 @@ namespace Inkscape {
   class MessageContext;
   class Selection; 
   class ObjectHierarchy;
+  class LayerManager;
   namespace UI { 
       namespace Dialog { 
           class DialogManager; 
@@ -63,16 +67,13 @@ namespace Inkscape {
  */
 struct SPDesktop : public Inkscape::UI::View::View
 {
-    SPDesktopWidget           *owner;
     Inkscape::UI::Dialog::DialogManager *_dlg_mgr;
     SPNamedView               *namedview;
-    Inkscape::Selection       *selection;        ///< current selection; will 
-                                                 ///< never generally be NULL
+    SPCanvas                  *canvas;
+    /// current selection; will never generally be NULL
+    Inkscape::Selection       *selection;
     SPEventContext            *event_context;
-
-    Inkscape::MessageContext *guidesMessageContext() const {
-	return _guides_message_context;
-    }
+    Inkscape::LayerManager    *layer_manager;
 
     SPCanvasItem  *acetate;
     SPCanvasGroup *main;
@@ -86,7 +87,6 @@ struct SPDesktop : public Inkscape::UI::View::View
     SPCanvasItem  *page_border; ///< page border
     SPCSSAttr     *current;     ///< current style
 
-    NR::Matrix d2w, w2d, doc2dt;
     GList *zooms_past;
     GList *zooms_future;
     unsigned int dkey;
@@ -104,11 +104,15 @@ struct SPDesktop : public Inkscape::UI::View::View
 
     Inkscape::ObjectHierarchy *_layer_hierarchy;
     gchar * _reconstruction_old_layer_id;
-    sigc::signal<void, SPObject *>     _layer_changed_signal;
 
-    sigc::signal<bool, const SPCSSAttr *>::accumulated<StopOnTrue> _set_style_signal;
-    sigc::signal<int, SPStyle *, int>::accumulated<StopOnTrue> _query_style_signal;
     sigc::signal<void, sp_verb_t>      _tool_changed;
+    sigc::signal<void, SPObject *>     _layer_changed_signal;
+    sigc::signal<bool, const SPCSSAttr *>::accumulated<StopOnTrue> _set_style_signal;
+    sigc::signal<int, SPStyle *, int>::accumulated<StopOnNonZero> _query_style_signal;
+    sigc::connection connectDocumentReplaced (const sigc::slot<void,SPDesktop*,SPDocument*> & slot)
+    {
+        return _document_replaced_signal.connect (slot);
+    }
     
     sigc::connection connectEventContextChanged (const sigc::slot<void,SPDesktop*,SPEventContext*> & slot) 
     {
@@ -127,6 +131,9 @@ struct SPDesktop : public Inkscape::UI::View::View
 	return _tool_subselection_changed.connect(slot);
     }
     void emitToolSubselectionChanged(gpointer data); 
+    sigc::connection connectCurrentLayerChanged(const sigc::slot<void, SPObject *> & slot) {
+	return _layer_changed_signal.connect(slot);
+    }
     
 	// Whiteboard changes
 
@@ -143,13 +150,17 @@ struct SPDesktop : public Inkscape::UI::View::View
     ~SPDesktop();
     void destroy();
 
+    Inkscape::MessageContext *guidesMessageContext() const {
+	return _guides_message_context;
+    }
+
+    void setDisplayModeNormal();
+    void setDisplayModeOutline();
+
     void set_active (bool new_active);
     SPObject *currentRoot() const;
     SPObject *currentLayer() const;
     void setCurrentLayer(SPObject *object);
-    sigc::connection connectCurrentLayerChanged(const sigc::slot<void, SPObject *> & slot) {
-	return _layer_changed_signal.connect(slot);
-    }
     SPObject *layerForObject(SPObject *object);
     bool isLayer(SPObject *object) const;
     bool isWithinViewport(SPItem *item) const;
@@ -161,14 +172,15 @@ struct SPDesktop : public Inkscape::UI::View::View
     void set_event_context (GtkType type, const gchar *config);
     void push_event_context (GtkType type, const gchar *config, unsigned int key);
 
-    void set_coordinate_status (NR::Point p, guint underline);
+    void set_coordinate_status (NR::Point p);
     SPItem *item_from_list_at_point_bottom (const GSList *list, NR::Point const p) const;
     SPItem *item_at_point (NR::Point const p, bool into_groups, SPItem *upto = NULL) const;
     SPItem *group_at_point (NR::Point const p) const;
     NR::Point point() const;
 
-    NRRect *get_display_area (NRRect *area) const;
+    NR::Rect get_display_area() const;
     void set_display_area (double x0, double y0, double x1, double y1, double border, bool log = true);
+    void set_display_area(NR::Rect const &a, NR::Coord border, bool log = true);
     void zoom_absolute (double cx, double cy, double zoom);
     void zoom_relative (double cx, double cy, double zoom);
     void zoom_absolute_keep_point (double cx, double cy, double px, double py, double zoom);
@@ -184,7 +196,8 @@ struct SPDesktop : public Inkscape::UI::View::View
     void zoom_page_width();
     void zoom_drawing();
     void zoom_selection();
-    double current_zoom() const  { return d2w.expansion(); }
+    void zoom_grab_focus();
+    double current_zoom() const  { return _d2w.expansion(); }
     void prev_zoom();
     void next_zoom();
 
@@ -196,20 +209,50 @@ struct SPDesktop : public Inkscape::UI::View::View
 	using NR::Y;
 	scroll_world(scroll[X], scroll[Y]);
     }
+
+    void getWindowGeometry (gint &x, gint &y, gint &w, gint &h);
+    void setWindowPosition (NR::Point p);
+    void setWindowSize (gint w, gint h);
+    void setWindowTransient (void* p, int transient_policy=1);
+    void presentWindow();
+    bool warnDialog (gchar *text);
+    void toggleRulers();
+    void toggleScrollbars();
+    void layoutWidget();
+    void destroyWidget();
+    void setToolboxFocusTo (gchar const* label);
+    void setToolboxAdjustmentValue (gchar const* id, double val);
+    bool isToolboxButtonActive (gchar const *id);
     
     void fullscreen();
 
+    void registerEditWidget (Inkscape::UI::View::EditWidgetInterface *widget)
+    { _widget = widget; }
+
+    NR::Matrix w2d() const;
+    NR::Point w2d(NR::Point const &p) const;
+    NR::Point d2w(NR::Point const &p) const;
+    NR::Matrix doc2dt() const;
+    NR::Point doc2dt(NR::Point const &p) const;
+    NR::Point dt2doc(NR::Point const &p) const;
+
+    virtual void setDocument (SPDocument* doc);
     virtual bool shutdown();
     virtual void mouseover() {}
     virtual void mouseout() {}
 
 private:
-    Inkscape::Application     *inkscape;
+    Inkscape::UI::View::EditWidgetInterface       *_widget;
+    Inkscape::Application     *_inkscape;
     Inkscape::MessageContext  *_guides_message_context;
-    bool active;
+    bool _active;
+    NR::Matrix _w2d;
+    NR::Matrix _d2w;
+    NR::Matrix _doc2dt;
     
     void push_current_zoom (GList**);
 
+    sigc::signal<void,SPDesktop*,SPDocument*>     _document_replaced_signal;
     sigc::signal<void>                 _activate_signal;
     sigc::signal<void>                 _deactivate_signal;
     sigc::signal<void,SPDesktop*,SPEventContext*> _event_context_changed_signal;
@@ -222,8 +265,6 @@ private:
     sigc::connection _reconstruction_start_connection;
     sigc::connection _reconstruction_finish_connection;
     
-    virtual void setDoc (SPDocument* doc);
-
     virtual void onPositionSet (double, double);
     virtual void onResized (double, double);
     virtual void onRedrawRequested();
@@ -231,6 +272,9 @@ private:
     virtual void onDocumentURISet (gchar const* uri);
     virtual void onDocumentResized (double, double);
 
+    static void _onActivate (SPDesktop* dt);
+    static void _onDeactivate (SPDesktop* dt);
+    static void _onSelectionModified (Inkscape::Selection *selection, guint flags, SPDesktop *dt);
 };
 
 #endif
