@@ -15,18 +15,10 @@
 # include "config.h"
 #endif
 
-#include <glib.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtksignal.h>
-#include <time.h>
-#include "helper/window.h"
-#include "widgets/sp-widget.h"
 #include "macros.h"
-#include "inkscape.h"
 #include <gtk/gtk.h>
-#include "desktop-events.h"
-#include "desktop-handles.h"
-#include "widgets/desktop-widget.h"
+#include "desktop.h"
 #include "inkscape-private.h"
 #include "prefs-utils.h"
 #include "event-context.h"
@@ -36,11 +28,11 @@
 
 
 /**
-* \brief  This function is called to zero the transientize semaphore by a 
+* \brief  This function is called to zero the transientize semaphore by a
 *         timeout.
 */
-gboolean 
-sp_allow_again (gpointer *wd) 
+gboolean
+sp_allow_again (gpointer *wd)
 {
     ((win_data *) wd)->stop = 0;
     return FALSE; // so that it is only called once
@@ -59,7 +51,7 @@ sp_dialog_defocus (GtkWindow *win)
     //find out the document window we're transient for
     w = gtk_window_get_transient_for ((GtkWindow *) win);
     //switch to it
-    
+
     if (w) {
         gtk_window_present (w);
     }
@@ -74,7 +66,7 @@ sp_dialog_defocus (GtkWindow *win)
 void
 sp_dialog_defocus_callback (GtkWindow *win, gpointer data)
 {
-    sp_dialog_defocus ((GtkWindow *) 
+    sp_dialog_defocus ((GtkWindow *)
         gtk_widget_get_toplevel ((GtkWidget *) data));
 }
 
@@ -83,7 +75,7 @@ sp_dialog_defocus_callback (GtkWindow *win, gpointer data)
 void
 sp_dialog_defocus_on_enter (GtkWidget *w)
 {
-    g_signal_connect ( G_OBJECT (w), "activate", 
+    g_signal_connect ( G_OBJECT (w), "activate",
                        G_CALLBACK (sp_dialog_defocus_callback), w );
 }
 
@@ -99,26 +91,26 @@ sp_dialog_event_handler (GtkWindow *win, GdkEvent *event, gpointer data)
         return FALSE;
     }
 
-    gboolean ret = FALSE; 
+    gboolean ret = FALSE;
 
     switch (event->type) {
-    
+
         case GDK_KEY_PRESS:
-        
+
             switch (get_group0_keyval (&event->key)) {
-                case GDK_Escape: 
+                case GDK_Escape:
                     sp_dialog_defocus (win);
-                    ret = TRUE; 
+                    ret = TRUE;
                     break;
                 case GDK_F4:
                 case GDK_w:
                 case GDK_W:
                     // close dialog
                     if (MOD__CTRL_ONLY) {
-                    
-                        /* this code sends a delete_event to the dialog, 
-                         * instead of just destroying it, so that the 
-                         * dialog can do some housekeeping, such as remember 
+
+                        /* this code sends a delete_event to the dialog,
+                         * instead of just destroying it, so that the
+                         * dialog can do some housekeeping, such as remember
                          * its position.
                          */
                         GdkEventAny event;
@@ -130,7 +122,7 @@ sp_dialog_event_handler (GtkWindow *win, GdkEvent *event, gpointer data)
                         gtk_main_do_event ((GdkEvent*)&event);
                         g_object_unref (G_OBJECT (event.window));
 
-                        ret = TRUE; 
+                        ret = TRUE;
                     }
                     break;
                 default: // pass keypress to the canvas
@@ -139,15 +131,15 @@ sp_dialog_event_handler (GtkWindow *win, GdkEvent *event, gpointer data)
     default:
         ;
     }
-    
-    return ret; 
-    
+
+    return ret;
+
 }
 
 
 
 /**
- * \brief  Make the argument dialog transient to the currently active document 
+ * \brief  Make the argument dialog transient to the currently active document
            window.
  */
 void
@@ -160,29 +152,23 @@ sp_transientize (GtkWidget *dialog)
     gint transient_policy = prefs_get_int_attribute_limited ( "options.transientpolicy", "value", 1, 0, 2 );
 
     if (transient_policy) {
-    /* transientzing does not work on windows; when you minimize a document 
-     * and then open it back, only its transient emerges and you cannot access 
-     * the document window.
-     */
-#ifndef WIN32
-    
+   
     // if there's an active document window, attach dialog to it as a transient:
     
-        if ( SP_ACTIVE_DESKTOP && (SP_DT_WIDGET(SP_ACTIVE_DESKTOP))->window )
+        if ( SP_ACTIVE_DESKTOP )
         {
-        
-            gtk_window_set_transient_for ( (GtkWindow *) dialog, 
-                                           (SP_DT_WIDGET(SP_ACTIVE_DESKTOP))->window );
+            SP_ACTIVE_DESKTOP->setWindowTransient (dialog, transient_policy);
         }
-#endif
-   
     }
 } // end of sp_transientize()
 
-
+void on_transientize (SPDesktop *desktop, win_data *wd )
+{
+    sp_transientize_callback (0, desktop, wd);
+}
 
 void
-sp_transientize_callback ( Inkscape::Application *inkscape, 
+sp_transientize_callback ( Inkscape::Application * /*inkscape*/, 
                            SPDesktop *desktop, win_data *wd )
 {
     gint transient_policy = 
@@ -192,62 +178,46 @@ sp_transientize_callback ( Inkscape::Application *inkscape,
     if (!transient_policy) 
         return;
 
-#ifndef WIN32
     if (wd->stop) { 
-    
         /* 
          * if retransientizing of this dialog is still forbidden after 
          * previous call warning turned off because it was confusingly fired 
          * when loading many files from command line
          */
-         
          // g_warning("Retranzientize aborted! You're switching windows too fast!"); 
-        
         return;
-        
     }
     
-    GtkWindow *w;
-
-    w = SP_DT_WIDGET(desktop)->window; 
-    
-    if (w && wd->win)
+    if (wd->win)
     {
-        
         wd->stop = 1; // disallow other attempts to retranzientize this dialog
-        
-        gtk_window_set_transient_for ((GtkWindow *) wd->win, w);
-
-        /* 
-         * This enables "aggressive" transientization,
-         * i.e. dialogs always emerging on top when you switch documents. Note 
-         * however that this breaks "click to raise" policy of a window 
-         * manager because the switched-to document will be raised at once 
-         * (so that its transients also could raise)
-         */
-        if (transient_policy == 2)
-        
-            // without this, a transient window not always emerges on top
-            gtk_window_present (w); 
-    
+        desktop->setWindowTransient (wd->win, transient_policy);
     }
     
     // we're done, allow next retransientizing not sooner than after 6 msec
     gtk_timeout_add (6, (GtkFunction) sp_allow_again, (gpointer) wd);  
-#endif
-
 }
 
+void on_dialog_hide (GtkWidget *w)
+{
+    if (w)
+        gtk_widget_hide (w);
+}
 
+void on_dialog_unhide (GtkWidget *w)
+{
+    if (w)
+        gtk_widget_show (w);
+}
 
 gboolean
 sp_dialog_hide (GtkObject *object, gpointer data)
 {
     GtkWidget *dlg = (GtkWidget *) data;
-    
+
     if (dlg)
         gtk_widget_hide (dlg);
-    
+
     return TRUE;
 }
 
@@ -260,7 +230,7 @@ sp_dialog_unhide (GtkObject *object, gpointer data)
 
     if (dlg)
         gtk_widget_show (dlg);
-    
+
     return TRUE;
 }
 
@@ -269,9 +239,9 @@ sp_dialog_unhide (GtkObject *object, gpointer data)
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
