@@ -15,6 +15,18 @@
 #endif
 
 
+
+//Temporary ugly hack
+//Remove these after the get_filter() calls in
+//show() on both classes are fixed
+#include <gtk/gtkfilechooser.h>
+
+//Another hack
+#include <gtk/gtkentry.h>
+#include <gtk/gtkexpander.h>
+
+#include <sys/stat.h>
+#include <glibmm/i18n.h>
 #include <gtkmm/box.h>
 #include <gtkmm/filechooserdialog.h>
 #include <gtkmm/menubar.h>
@@ -25,38 +37,15 @@
 #include <gtkmm/stock.h>
 #include <gdkmm/pixbuf.h>
 
-//Temporary ugly hack
-//Remove these after the get_filter() calls in
-//show() on both classes are fixed
-#include <gtk/gtkfilechooser.h>
-#include <gtk/gtkfilefilter.h>
-
-//Another hack
-#include <gtk/gtkentry.h>
-#include <gtk/gtkexpander.h>
-
-#include <vector>
-#include <map>
-
-#include <string.h>
-#include <sys/stat.h>
-
-#include "interface.h"
-#include "filedialog.h"
-#include <glibmm/i18n.h>
 #include "prefs-utils.h"
-
 #include <dialogs/dialog-events.h>
-#include <extension/extension.h>
 #include <extension/input.h>
 #include <extension/output.h>
 #include <extension/db.h>
-
-//for the preview widget
-#include "document.h"
 #include "inkscape.h"
 #include "svg-view-widget.h"
-#include "uri.h"
+#include "filedialog.h"
+#include "gc-core.h"
 
 #undef INK_DUMP_FILENAME_CONV
 
@@ -187,6 +176,8 @@ bool SVGPreview::setFromMem(char const *xmlBuffer)
 
     sp_document_unref(doc);
 
+    Inkscape::GC::request_early_collection();
+
     return true;
 }
 
@@ -687,10 +678,8 @@ private:
 void FileOpenDialogImpl::updatePreviewCallback()
 {
     Glib::ustring fileName = get_preview_filename();
-
     if (fileName.length() < 1)
         return;
-
     svgPreview.set(fileName, dialogType);
 }
 
@@ -909,6 +898,7 @@ FileOpenDialogImpl::show()
     set_modal (TRUE);                      //Window
     sp_transientize((GtkWidget *)gobj());  //Make transient
     gint b = run();                        //Dialog
+    svgPreview.showNoPreview();
     hide();
 
     if (b == Gtk::RESPONSE_OK)
@@ -1356,6 +1346,7 @@ FileSaveDialogImpl::show()
     set_modal (TRUE);                      //Window
     sp_transientize((GtkWidget *)gobj());  //Make transient
     gint b = run();                        //Dialog
+    svgPreview.showNoPreview();
     hide();
 
     if (b == Gtk::RESPONSE_OK)
