@@ -11,18 +11,14 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <gtkmm/container.h>
-#include <gtkmm/buttonbox.h>
-#include <gtkmm/image.h>
-#include <gtkmm/entry.h>
-#include <gtkmm/tooltips.h>
-#include <gtkmm/table.h>
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 
-#include "dialogs/find.h"
 #include "widgets/icon.h"
 
 #include "message-stack.h"
-#include "verbs.h"
 
 //TODO  : delete this
 GtkWidget * sp_find_dialog_old (void);
@@ -35,29 +31,22 @@ sp_find_dialog(){
     return;
 }
 
-#include "config.h"
 
 #include <gtk/gtk.h>
 
-#include "../inkscape-stock.h"
 #include <glibmm/i18n.h>
 #include "helper/window.h"
-#include "helper/unit-menu.h"
-#include "libnr/nr-scale.h"
-#include "libnr/nr-scale-ops.h"
 #include "macros.h"
 #include "inkscape.h"
 #include "document.h"
 #include "desktop.h"
 #include "selection.h"
-#include "selection-chemistry.h"
 #include "desktop-handles.h"
 
 #include "dialog-events.h"
 #include "../prefs-utils.h"
 #include "../verbs.h"
 #include "../interface.h"
-#include "../sp-object.h"
 #include "../sp-text.h"
 #include "../sp-flowtext.h"
 #include "../text-editing.h"
@@ -68,7 +57,6 @@ sp_find_dialog(){
 #include "../sp-ellipse.h"
 #include "../sp-star.h"
 #include "../sp-spiral.h"
-#include "../sp-polygon.h"
 #include "../sp-path.h"
 #include "../sp-line.h"
 #include "../sp-polyline.h"
@@ -105,6 +93,9 @@ static gboolean sp_find_dialog_delete(GtkObject *, GdkEvent *, gpointer data)
     gtk_window_get_position (GTK_WINDOW (dlg), &x, &y);
     gtk_window_get_size (GTK_WINDOW (dlg), &w, &h);
 
+    if (x<0) x=0;
+    if (y<0) y=0;
+
     prefs_set_int_attribute (prefs_path, "x", x);
     prefs_set_int_attribute (prefs_path, "y", y);
     prefs_set_int_attribute (prefs_path, "w", w);
@@ -358,7 +349,7 @@ void sp_find_dialog_find(GObject *, GObject *dlg)
         if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (gtk_object_get_data (GTK_OBJECT (dlg), "inlayer")))) {
             l = all_items (desktop->currentLayer(), l, hidden, locked);
         } else {
-            l = all_items (SP_DOCUMENT_ROOT (SP_DT_DOCUMENT (desktop)), l, hidden, locked);
+            l = all_items (SP_DOCUMENT_ROOT (sp_desktop_document (desktop)), l, hidden, locked);
         }
     }
     guint all = g_slist_length (l);
@@ -380,7 +371,7 @@ void sp_find_dialog_find(GObject *, GObject *dlg)
                                                  count),
                                         count, all, exact? _("exact") : _("partial"));
 
-        Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+        Inkscape::Selection *selection = sp_desktop_selection (desktop);
         selection->clear();
         selection->setList(n);
         scroll_to_show_item (desktop, SP_ITEM(n->data));
@@ -661,6 +652,10 @@ sp_find_dialog_old (void)
             w = prefs_get_int_attribute (prefs_path, "w", 0);
             h = prefs_get_int_attribute (prefs_path, "h", 0);
         }
+        
+        if (x<0) x=0;
+        if (y<0) y=0;
+
         if (x != 0 || y != 0) {
             gtk_window_move ((GtkWindow *) dlg, x, y);
         } else {
