@@ -19,15 +19,14 @@
 
 #include <gtk/gtk.h>
 
-#include <dialogs/dialog-events.h>
+#include <glib/gmem.h>
 #include <gtk/gtkdialog.h> //for GTK_RESPONSE* types
-#include <gtkmm/togglebutton.h>
 #include <glibmm/i18n.h>
-#include "interface.h"
-#include "verbs.h"
+#include <gtkmm/buttonbox.h>
+#include <gtkmm/stock.h>
+
 #include "prefs-utils.h"
 #include "inkscape.h"
-#include "macros.h"
 #include "document.h"
 #include "desktop-handles.h"
 #include "selection.h"
@@ -35,7 +34,6 @@
 #include "display/nr-arena.h"
 #include "sp-root.h"
 #include "xml/repr.h"
-#include <glib.h>
 
 extern "C" {
 // takes doc, root, icon, and icon name to produce pixels
@@ -163,7 +161,7 @@ IconPreviewPanel::IconPreviewPanel() :
         pixMem[i] = new guchar[4 * sizes[i] * sizes[i]];
         memset( pixMem[i], 0x00, 4 *  sizes[i] * sizes[i] );
 
-        GdkPixbuf *pb = gdk_pixbuf_new_from_data( pixMem[i], GDK_COLORSPACE_RGB, TRUE, 8, sizes[i], sizes[i], sizes[i] * 4, /*(GdkPixbufDestroyNotify)nr_free*/NULL, NULL );
+        GdkPixbuf *pb = gdk_pixbuf_new_from_data( pixMem[i], GDK_COLORSPACE_RGB, TRUE, 8, sizes[i], sizes[i], sizes[i] * 4, /*(GdkPixbufDestroyNotify)g_free*/NULL, NULL );
         GtkImage* img = GTK_IMAGE( gtk_image_new_from_pixbuf( pb ) );
         images[i] = Glib::wrap(img);
         Glib::ustring label(*labels[i]);
@@ -188,7 +186,7 @@ IconPreviewPanel::IconPreviewPanel() :
 
 
     Gtk::HButtonBox* holder = new Gtk::HButtonBox( Gtk::BUTTONBOX_END );
-    pack_end( *holder, false, false );
+    _getContents()->pack_end( *holder, false, false );
 
     selectionButton = new Gtk::ToggleButton(_("Selection")); // , GTK_RESPONSE_APPLY
     holder->pack_start( *selectionButton, false, false );
@@ -204,7 +202,7 @@ IconPreviewPanel::IconPreviewPanel() :
     refreshButton->signal_clicked().connect( sigc::mem_fun(*this, &IconPreviewPanel::refreshPreview) );
 
 
-    pack_start(iconBox, Gtk::PACK_EXPAND_WIDGET);
+    _getContents()->pack_start(iconBox, Gtk::PACK_EXPAND_WIDGET);
 
     show_all_children();
 }
@@ -221,7 +219,7 @@ void IconPreviewPanel::refreshPreview()
 
         if ( selectionButton && selectionButton->get_active() )
         {
-            Inkscape::Selection * sel = SP_DT_SELECTION(desktop);
+            Inkscape::Selection * sel = sp_desktop_selection(desktop);
             if ( sel ) {
                 //g_message("found a selection to play with");
 
