@@ -16,34 +16,24 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-#include <string.h>
-#include <ctype.h>
-#include <libnr/nr-values.h>
-#include <glib.h>
-#include <gtk/gtksignal.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkhbox.h>
-#include <gtk/gtkhscale.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkcheckbutton.h>
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkframe.h>
 #include <gtk/gtktextview.h>
-#include <gtk/gtktextbuffer.h>
 #include <gtk/gtktooltips.h>
 
 #include <glibmm/i18n.h>
 #include "helper/window.h"
-#include "../svg/svg.h"
 #include "../widgets/sp-widget.h"
 #include "../inkscape.h"
 #include "../document.h"
 #include "../desktop-handles.h"
-#include "../desktop-style.h"
 #include "../selection.h"
 #include "../sp-item.h"
-#include "../style.h"
 #include "../macros.h"
 #include "../verbs.h"
 #include "../interface.h"
@@ -51,13 +41,12 @@
 #include "dialog-events.h"
 #include "../prefs-utils.h"
 
-#include "item-properties.h"
 
 static GtkWidget *dlg = NULL;
 static win_data wd;
 
 // impossible original values to make sure they are read from prefs
-static gint x = -1000, y = -1000, w = 0, h = 0; 
+static gint x = -1000, y = -1000, w = 0, h = 0;
 static gchar *prefs_path = "dialogs.object";
 
 static void sp_item_widget_modify_selection (SPWidget *spw, Inkscape::Selection *selection, guint flags, GtkWidget *itemw);
@@ -66,7 +55,6 @@ static void sp_item_widget_setup (SPWidget *spw, Inkscape::Selection *selection)
 static void sp_item_widget_sensitivity_toggled (GtkWidget *widget, SPWidget *spw);
 static void sp_item_widget_hidden_toggled (GtkWidget *widget, SPWidget *spw);
 static void sp_item_widget_label_changed (GtkWidget *widget, SPWidget *spw);
-static void sp_item_widget_transform_value_changed (GtkWidget *widget, SPWidget *spw);
 
 static void
 sp_item_dialog_destroy (GtkObject *object, gpointer data)
@@ -82,6 +70,9 @@ sp_item_dialog_delete (GtkObject *object, GdkEvent *event, gpointer data)
     gtk_window_get_position ((GtkWindow *) dlg, &x, &y);
     gtk_window_get_size ((GtkWindow *) dlg, &w, &h);
 
+    if (x<0) x=0;
+    if (y<0) y=0;
+
     prefs_set_int_attribute (prefs_path, "x", x);
     prefs_set_int_attribute (prefs_path, "y", y);
     prefs_set_int_attribute (prefs_path, "w", w);
@@ -91,22 +82,6 @@ sp_item_dialog_delete (GtkObject *object, GdkEvent *event, gpointer data)
 
 } 
 
-void 
-transform_table_cell (GtkWidget *spw, GtkWidget *t, const gchar *label, int x, int y)
-{
-    GtkObject *a = gtk_adjustment_new (1.0, -NR_HUGE, NR_HUGE, 0.01, 0.1, 0.1);
-    gtk_object_set_data (GTK_OBJECT (spw), label, a);
-    GtkWidget *sb = gtk_spin_button_new (GTK_ADJUSTMENT (a), 0.01, 4);
-    gtk_entry_set_width_chars (GTK_ENTRY (sb), 5);
-    gtk_table_attach ( GTK_TABLE (t), sb, x, x + 1, y, y + 1, 
-                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ), 
-                       (GtkAttachOptions)0, 0, 0 );
-    gtk_signal_connect ( a, "value_changed", 
-                         GTK_SIGNAL_FUNC (sp_item_widget_transform_value_changed), 
-                         spw );
-}
-
-
 /**
  * \brief  Creates new instance of item properties widget 
  *
@@ -122,11 +97,11 @@ sp_item_widget_new (void)
 
     /* Create container widget */
     spw = sp_widget_new_global (INKSCAPE);
-    gtk_signal_connect ( GTK_OBJECT (spw), "modify_selection", 
-                         GTK_SIGNAL_FUNC (sp_item_widget_modify_selection), 
+    gtk_signal_connect ( GTK_OBJECT (spw), "modify_selection",
+                         GTK_SIGNAL_FUNC (sp_item_widget_modify_selection),
                          spw );
-    gtk_signal_connect ( GTK_OBJECT (spw), "change_selection", 
-                         GTK_SIGNAL_FUNC (sp_item_widget_change_selection), 
+    gtk_signal_connect ( GTK_OBJECT (spw), "change_selection",
+                         GTK_SIGNAL_FUNC (sp_item_widget_change_selection),
                          spw );
 
     vb = gtk_vbox_new (FALSE, 0);
@@ -142,8 +117,8 @@ sp_item_widget_new (void)
     /* Create the label for the object id */
     l = gtk_label_new_with_mnemonic (_("_Id"));
     gtk_misc_set_alignment (GTK_MISC (l), 1, 0.5);
-    gtk_table_attach ( GTK_TABLE (t), l, 0, 1, 0, 1, 
-                       (GtkAttachOptions)( GTK_SHRINK | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), l, 0, 1, 0, 1,
+                       (GtkAttachOptions)( GTK_SHRINK | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
     gtk_object_set_data (GTK_OBJECT (spw), "id_label", l);
 
@@ -151,8 +126,8 @@ sp_item_widget_new (void)
     tf = gtk_entry_new ();
     gtk_tooltips_set_tip (tt, tf, _("The id= attribute (only letters, digits, and the characters .-_: allowed)"), NULL);
     gtk_entry_set_max_length (GTK_ENTRY (tf), 64);
-    gtk_table_attach ( GTK_TABLE (t), tf, 1, 2, 0, 1, 
-                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), tf, 1, 2, 0, 1,
+                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
     gtk_object_set_data (GTK_OBJECT (spw), "id", tf);
     gtk_label_set_mnemonic_widget (GTK_LABEL(l), tf);
@@ -164,18 +139,18 @@ sp_item_widget_new (void)
 
     /* Button for setting the object's id, label, title and description. */
     pb = gtk_button_new_with_mnemonic (_("_Set"));
-    gtk_table_attach ( GTK_TABLE (t), pb, 2, 3, 0, 1, 
-                       (GtkAttachOptions)( GTK_SHRINK | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), pb, 2, 3, 0, 1,
+                       (GtkAttachOptions)( GTK_SHRINK | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
-    gtk_signal_connect ( GTK_OBJECT (pb), "clicked", 
-                         GTK_SIGNAL_FUNC (sp_item_widget_label_changed), 
+    gtk_signal_connect ( GTK_OBJECT (pb), "clicked",
+                         GTK_SIGNAL_FUNC (sp_item_widget_label_changed),
                          spw );
 
     /* Create the label for the object label */
     l = gtk_label_new_with_mnemonic (_("_Label"));
     gtk_misc_set_alignment (GTK_MISC (l), 1, 0.5);
-    gtk_table_attach ( GTK_TABLE (t), l, 0, 1, 1, 2, 
-                       (GtkAttachOptions)( GTK_SHRINK | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), l, 0, 1, 1, 2,
+                       (GtkAttachOptions)( GTK_SHRINK | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
     gtk_object_set_data (GTK_OBJECT (spw), "label_label", l);
 
@@ -183,8 +158,8 @@ sp_item_widget_new (void)
     tf = gtk_entry_new ();
     gtk_tooltips_set_tip (tt, tf, _("A freeform label for the object"), NULL);
     gtk_entry_set_max_length (GTK_ENTRY (tf), 256);
-    gtk_table_attach ( GTK_TABLE (t), tf, 1, 2, 1, 2, 
-                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), tf, 1, 2, 1, 2,
+                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
     gtk_object_set_data (GTK_OBJECT (spw), "label", tf);
     gtk_label_set_mnemonic_widget (GTK_LABEL(l), tf);
@@ -195,8 +170,8 @@ sp_item_widget_new (void)
     /* Create the label for the object title */
     l = gtk_label_new (_("Title"));
     gtk_misc_set_alignment (GTK_MISC (l), 1, 0.5);
-    gtk_table_attach ( GTK_TABLE (t), l, 0, 1, 2, 3, 
-                       (GtkAttachOptions)( GTK_SHRINK | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), l, 0, 1, 2, 3,
+                       (GtkAttachOptions)( GTK_SHRINK | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
     gtk_object_set_data (GTK_OBJECT (spw), "title_label", l);
 
@@ -204,15 +179,15 @@ sp_item_widget_new (void)
     tf = gtk_entry_new ();
     gtk_widget_set_sensitive (GTK_WIDGET (tf), FALSE);
     gtk_entry_set_max_length (GTK_ENTRY (tf), 256);
-    gtk_table_attach ( GTK_TABLE (t), tf, 1, 3, 2, 3, 
-                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), tf, 1, 3, 2, 3,
+                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
     gtk_object_set_data (GTK_OBJECT (spw), "title", tf);
 
     /* Create the frame for the object description */
     f = gtk_frame_new (_("Description"));
-    gtk_table_attach ( GTK_TABLE (t), f, 0, 3, 3, 4, 
-                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), f, 0, 3, 3, 4,
+                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ),
                        (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ), 0, 0 );
     gtk_object_set_data (GTK_OBJECT (spw), "desc_frame", l);
 
@@ -239,8 +214,8 @@ sp_item_widget_new (void)
     /* Hide */
     cb = gtk_check_button_new_with_mnemonic (_("_Hide"));
     gtk_tooltips_set_tip (tt, cb, _("Check to make the object invisible"), NULL);
-    gtk_table_attach ( GTK_TABLE (t), cb, 0, 1, 0, 1, 
-                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), cb, 0, 1, 0, 1,
+                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
     g_signal_connect (G_OBJECT(cb), "toggled", G_CALLBACK(sp_item_widget_hidden_toggled), spw);
     gtk_object_set_data(GTK_OBJECT(spw), "hidden", cb);
@@ -249,46 +224,28 @@ sp_item_widget_new (void)
     // TRANSLATORS: "Lock" is a verb here
     cb = gtk_check_button_new_with_mnemonic (_("L_ock"));
     gtk_tooltips_set_tip (tt, cb, _("Check to make the object insensitive (not selectable by mouse)"), NULL);
-    gtk_table_attach ( GTK_TABLE (t), cb, 1, 2, 0, 1, 
-                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ), 
+    gtk_table_attach ( GTK_TABLE (t), cb, 1, 2, 0, 1,
+                       (GtkAttachOptions)( GTK_EXPAND | GTK_FILL ),
                        (GtkAttachOptions)0, 0, 0 );
-    gtk_signal_connect ( GTK_OBJECT (cb), "toggled", 
-                         GTK_SIGNAL_FUNC (sp_item_widget_sensitivity_toggled), 
+    gtk_signal_connect ( GTK_OBJECT (cb), "toggled",
+                         GTK_SIGNAL_FUNC (sp_item_widget_sensitivity_toggled),
                          spw );
     gtk_object_set_data (GTK_OBJECT (spw), "sensitive", cb);
 
-
-    /* Transformation matrix */
-    f = gtk_frame_new (_("Transformation matrix"));
-    gtk_box_pack_start (GTK_BOX (vb), f, FALSE, FALSE, 0);
-
-    t = gtk_table_new (2, 3, TRUE);
-    gtk_container_set_border_width(GTK_CONTAINER(t), 4);
-    gtk_table_set_row_spacings (GTK_TABLE (t), 4);
-    gtk_table_set_col_spacings (GTK_TABLE (t), 4);
-    gtk_container_add (GTK_CONTAINER (f), t);
-
-    transform_table_cell (spw, t, "t0", 0, 0);
-    transform_table_cell (spw, t, "t1", 0, 1);
-    transform_table_cell (spw, t, "t2", 1, 0);
-    transform_table_cell (spw, t, "t3", 1, 1);
-    transform_table_cell (spw, t, "t4", 2, 0);
-    transform_table_cell (spw, t, "t5", 2, 1);
-
     gtk_widget_show_all (spw);
 
-    sp_item_widget_setup (SP_WIDGET (spw), SP_DT_SELECTION (SP_ACTIVE_DESKTOP));
+    sp_item_widget_setup (SP_WIDGET (spw), sp_desktop_selection (SP_ACTIVE_DESKTOP));
 
     return (GtkWidget *) spw;
-    
+
 } //end of sp_item_widget_new()
 
 
 
 static void
-sp_item_widget_modify_selection ( SPWidget *spw, 
-                                  Inkscape::Selection *selection, 
-                                  guint flags, 
+sp_item_widget_modify_selection ( SPWidget *spw,
+                                  Inkscape::Selection *selection,
+                                  guint flags,
                                   GtkWidget *itemw )
 {
     sp_item_widget_setup (spw, selection);
@@ -297,8 +254,8 @@ sp_item_widget_modify_selection ( SPWidget *spw,
 
 
 static void
-sp_item_widget_change_selection ( SPWidget *spw, 
-                                  Inkscape::Selection *selection, 
+sp_item_widget_change_selection ( SPWidget *spw,
+                                  Inkscape::Selection *selection,
                                   GtkWidget *itemw )
 {
     sp_item_widget_setup (spw, selection);
@@ -322,7 +279,7 @@ sp_item_widget_setup ( SPWidget *spw, Inkscape::Selection *selection )
     } else {
         gtk_widget_set_sensitive (GTK_WIDGET (spw), TRUE);
     }
-    
+
     gtk_object_set_data (GTK_OBJECT (spw), "blocked", GUINT_TO_POINTER (TRUE));
 
     SPItem *item = selection->singleItem();
@@ -335,31 +292,22 @@ sp_item_widget_setup ( SPWidget *spw, Inkscape::Selection *selection )
     w = GTK_WIDGET(gtk_object_get_data (GTK_OBJECT (spw), "hidden"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), item->isExplicitlyHidden());
 
-    /* Transform */
-    {
-        char const *const names[] = {"t0", "t1", "t2", "t3", "t4", "t5"};
-        for (unsigned i = 0; i < 6; ++i) {
-            GtkAdjustment *adj = GTK_ADJUSTMENT(gtk_object_get_data(GTK_OBJECT(spw), names[i]));
-            gtk_adjustment_set_value(adj, item->transform[i]);
-        }
-    }
-
     if (SP_OBJECT_IS_CLONED (item)) {
-    
+
         /* ID */
         w = GTK_WIDGET(gtk_object_get_data (GTK_OBJECT (spw), "id"));
         gtk_entry_set_text (GTK_ENTRY (w), "");
         gtk_widget_set_sensitive (w, FALSE);
         w = GTK_WIDGET(gtk_object_get_data (GTK_OBJECT (spw), "id_label"));
         gtk_label_set_text (GTK_LABEL (w), _("Ref"));
-    
+
         /* Label */
         w = GTK_WIDGET(gtk_object_get_data (GTK_OBJECT (spw), "label"));
         gtk_entry_set_text (GTK_ENTRY (w), "");
         gtk_widget_set_sensitive (w, FALSE);
         w = GTK_WIDGET(gtk_object_get_data (GTK_OBJECT (spw), "label_label"));
         gtk_label_set_text (GTK_LABEL (w), _("Ref"));
-    
+
     } else {
         SPObject *obj = (SPObject*)item;
 
@@ -378,8 +326,8 @@ sp_item_widget_setup ( SPWidget *spw, Inkscape::Selection *selection )
     }
 
     gtk_object_set_data (GTK_OBJECT (spw), "blocked", GUINT_TO_POINTER (FALSE));
-    
-    
+
+
 } // end of sp_item_widget_setup()
 
 
@@ -390,7 +338,7 @@ sp_item_widget_sensitivity_toggled (GtkWidget *widget, SPWidget *spw)
     if (gtk_object_get_data (GTK_OBJECT (spw), "blocked"))
         return;
 
-    SPItem *item = SP_DT_SELECTION(SP_ACTIVE_DESKTOP)->singleItem();
+    SPItem *item = sp_desktop_selection(SP_ACTIVE_DESKTOP)->singleItem();
     g_return_if_fail (item != NULL);
 
     gtk_object_set_data (GTK_OBJECT (spw), "blocked", GUINT_TO_POINTER (TRUE));
@@ -408,7 +356,7 @@ sp_item_widget_hidden_toggled(GtkWidget *widget, SPWidget *spw)
     if (gtk_object_get_data (GTK_OBJECT (spw), "blocked"))
         return;
 
-    SPItem *item = SP_DT_SELECTION(SP_ACTIVE_DESKTOP)->singleItem();
+    SPItem *item = sp_desktop_selection(SP_ACTIVE_DESKTOP)->singleItem();
     g_return_if_fail (item != NULL);
 
     gtk_object_set_data (GTK_OBJECT (spw), "blocked", GUINT_TO_POINTER (TRUE));
@@ -423,10 +371,10 @@ sp_item_widget_hidden_toggled(GtkWidget *widget, SPWidget *spw)
 static void
 sp_item_widget_label_changed (GtkWidget *widget, SPWidget *spw)
 {
-    if (gtk_object_get_data (GTK_OBJECT (spw), "blocked")) 
+    if (gtk_object_get_data (GTK_OBJECT (spw), "blocked"))
         return;
 
-    SPItem *item = SP_DT_SELECTION(SP_ACTIVE_DESKTOP)->singleItem();
+    SPItem *item = sp_desktop_selection(SP_ACTIVE_DESKTOP)->singleItem();
     g_return_if_fail (item != NULL);
 
     gtk_object_set_data (GTK_OBJECT (spw), "blocked", GUINT_TO_POINTER (TRUE));
@@ -456,7 +404,7 @@ sp_item_widget_label_changed (GtkWidget *widget, SPWidget *spw)
     g_assert(label != NULL);
 
     /* Give feedback on success of setting the drawing object's label
-     * using the widget's label text 
+     * using the widget's label text
      */
     SPObject *obj = (SPObject*)item;
     if (strcmp (label, obj->defaultLabel())) {
@@ -484,38 +432,8 @@ sp_item_widget_label_changed (GtkWidget *widget, SPWidget *spw)
 } // end of sp_item_widget_label_changed()
 
 
-static void
-sp_item_widget_transform_value_changed ( GtkWidget *widget, SPWidget *spw )
-{
-    if (gtk_object_get_data (GTK_OBJECT (spw), "blocked"))
-        return;
-
-    SPItem *item = SP_DT_SELECTION(SP_ACTIVE_DESKTOP)->singleItem();
-    g_return_if_fail (item != NULL);
-
-    gtk_object_set_data (GTK_OBJECT (spw), "blocked", GUINT_TO_POINTER (TRUE));
-
-    NRMatrix t;
-    for (unsigned i = 0; i < 6; i++) {
-        gchar c[8];
-        g_snprintf (c, 8, "t%u", i);
-        t.c[i] = 
-            GTK_ADJUSTMENT (gtk_object_get_data (GTK_OBJECT (spw), c))->value;
-    }
-
-    gchar c[64];
-    sp_svg_transform_write (c, 64, &t);
-    SPException ex;
-    SP_EXCEPTION_INIT (&ex);
-    sp_object_setAttribute (SP_OBJECT (item), "transform", c, &ex);
-
-    sp_document_maybe_done (SP_ACTIVE_DOCUMENT, "ItemDialog:transform");
-
-    gtk_object_set_data (GTK_OBJECT (spw), "blocked", GUINT_TO_POINTER (FALSE));
-}
-
 /**
- * \brief  Dialog 
+ * \brief  Dialog
  *
  */
 void
@@ -531,26 +449,29 @@ sp_item_dialog (void)
             x = prefs_get_int_attribute (prefs_path, "x", 0);
             y = prefs_get_int_attribute (prefs_path, "y", 0);
         }
-        
+
         if (w ==0 || h == 0) {
             w = prefs_get_int_attribute (prefs_path, "w", 0);
             h = prefs_get_int_attribute (prefs_path, "h", 0);
         }
-        
+
+        if (x<0) x=0;
+        if (y<0) y=0;
+
         if (x != 0 || y != 0) {
             gtk_window_move ((GtkWindow *) dlg, x, y);
         } else {
             gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
         }
-        
+
         if (w && h) {
             gtk_window_resize ((GtkWindow *) dlg, w, h);
         }
-        
+
         sp_transientize (dlg);
         wd.win = dlg;
         wd.stop = 0;
-        
+
         g_signal_connect   ( G_OBJECT (INKSCAPE), "activate_desktop", G_CALLBACK (sp_transientize_callback), &wd);
         gtk_signal_connect ( GTK_OBJECT (dlg), "event", GTK_SIGNAL_FUNC (sp_dialog_event_handler), dlg);
         gtk_signal_connect ( GTK_OBJECT (dlg), "destroy", G_CALLBACK (sp_item_dialog_destroy), dlg);
@@ -563,20 +484,20 @@ sp_item_dialog (void)
         GtkWidget *itemw = sp_item_widget_new ();
         gtk_widget_show (itemw);
         gtk_container_add (GTK_CONTAINER (dlg), itemw);
-      
+
     }
 
     gtk_window_present ((GtkWindow *) dlg);
-} 
+}
 
 
 /*
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
