@@ -4,8 +4,10 @@
  *
  * Author:
  *   Bryce W. Harrington <bryce@bryceharrington.com>
+ *   Andrius R. <knutux@gmail.com>
  *
  * Copyright (C) 2004 Bryce Harrington
+ * Copyright (C) 2006 Andrius R.
  *
  * Released under GNU GPL.  Read the file 'COPYING' for more information
  */
@@ -14,21 +16,17 @@
 # include <config.h>
 #endif
 
-#include <gtkmm/dialog.h>
-#include <gtkmm/notebook.h>
-#include <gtkmm/separator.h>
-#include <gtkmm/frame.h>
-#include <gtkmm/table.h>
 #include <gtkmm/stock.h>
 
-#include "dialogs/dialog-events.h"
 #include <glibmm/i18n.h>
 #include "inkscape.h"
 #include "desktop.h"
 #include "document.h"
+#include "layer-manager.h"
 #include "message-stack.h"
 #include "desktop-handles.h"
-#include "layer-fns.h"
+#include "sp-object.h"
+#include "sp-item.h"
 
 #include "layer-properties.h"
 
@@ -37,19 +35,23 @@ namespace UI {
 namespace Dialogs {
 
 LayerPropertiesDialog::LayerPropertiesDialog()
-: _strategy(NULL), _desktop(NULL), _layer(NULL)
+: _strategy(NULL), _desktop(NULL), _layer(NULL), _position_visible(false)
 {
-    GtkWidget *dlg = GTK_WIDGET(gobj());
-    g_assert(dlg);
-
     Gtk::VBox *mainVBox = get_vbox();
 
+    _layout_table.set_spacings(4);
+    _layout_table.resize (1, 2);
+
     // Layer name widgets
     _layer_name_entry.set_activates_default(true);
-    _layer_name_hbox.pack_end(_layer_name_entry, false, false, 4);
     _layer_name_label.set_label(_("Layer name:"));
-    _layer_name_hbox.pack_end(_layer_name_label, false, false, 4);
-    mainVBox->pack_start(_layer_name_hbox, false, false, 4);
+    _layer_name_label.set_alignment(1.0, 0.5);
+
+    _layout_table.attach(_layer_name_label,
+                         0, 1, 0, 1, Gtk::FILL, Gtk::FILL);
+    _layout_table.attach(_layer_name_entry,
+                         1, 2, 0, 1, Gtk::FILL | Gtk::EXPAND, Gtk::FILL);
+    mainVBox->pack_start(_layout_table, false, false, 4);
 
     // Buttons
     _close_button.set_use_stock(true);
@@ -96,7 +98,7 @@ void LayerPropertiesDialog::_showDialog(LayerPropertiesDialog::Strategy &strateg
     dialog->_strategy->setup(*dialog);
 
     dialog->set_modal(true);
-    gtk_window_set_transient_for(GTK_WINDOW(dialog->gobj()), GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(desktop->owner))));
+    desktop->setWindowTransient (dialog->gobj());
     dialog->property_destroy_with_parent() = true;
 
     dialog->show();
@@ -109,7 +111,7 @@ LayerPropertiesDialog::_apply()
     g_assert(_strategy != NULL);
 
     _strategy->perform(*this);
-    sp_document_done(SP_DT_DOCUMENT(SP_ACTIVE_DESKTOP));
+    sp_document_done(sp_desktop_document(SP_ACTIVE_DESKTOP));
 
     _close();
 }
@@ -128,6 +130,52 @@ LayerPropertiesDialog::_close()
     );
 }
 
+void
+LayerPropertiesDialog::_setup_position_controls() {
+    if ( NULL == _layer || _desktop->currentRoot() == _layer ) {
+        // no layers yet, so option above/below/sublayer is useless
+        return;
+    }
+
+    _position_visible = true;
+    _dropdown_list = Gtk::ListStore::create(_dropdown_columns);
+    _layer_position_combo.set_model(_dropdown_list);
+    _layer_position_combo.pack_start(_label_renderer);
+    _layer_position_combo.set_cell_data_func(_label_renderer,
+                                             sigc::mem_fun(*this, &LayerPropertiesDialog::_prepareLabelRenderer));
+
+    _layout_table.resize (2, 2);
+
+    Gtk::ListStore::iterator row;
+    row = _dropdown_list->append();
+    row->set_value(_dropdown_columns.position, LPOS_ABOVE);
+    row->set_value(_dropdown_columns.name, Glib::ustring(_("Above current")));
+    _layer_position_combo.set_active(row);
+    row = _dropdown_list->append();
+    row->set_value(_dropdown_columns.position, LPOS_BELOW);
+    row->set_value(_dropdown_columns.name, Glib::ustring(_("Below current")));
+    row = _dropdown_list->append();
+    row->set_value(_dropdown_columns.position, LPOS_CHILD);
+    row->set_value(_dropdown_columns.name, Glib::ustring(_("As sublayer of current")));
+
+    _layout_table.attach(_layer_position_combo,
+                         1, 2, 1, 2, Gtk::FILL | Gtk::EXPAND, Gtk::FILL);
+    _layer_position_label.set_label(_("Position:"));
+    _layer_position_label.set_alignment(1.0, 0.5);
+    _layout_table.attach(_layer_position_label,
+                         0, 1, 1, 2, Gtk::FILL, Gtk::FILL);
+    show_all_children();
+}
+
+/** Formats the label for a given layer row 
+ */
+void LayerPropertiesDialog::_prepareLabelRenderer(
+    Gtk::TreeModel::const_iterator const &row
+) {
+    Glib::ustring name=(*row)[_dropdown_columns.name];
+    _label_renderer.property_markup() = name.c_str();
+}
+
 void LayerPropertiesDialog::Rename::setup(LayerPropertiesDialog &dialog) {
     SPDesktop *desktop=dialog._desktop;
     dialog.set_title(_("Rename Layer"));
@@ -139,10 +187,10 @@ void LayerPropertiesDialog::Rename::setup(LayerPropertiesDialog &dialog) {
 void LayerPropertiesDialog::Rename::perform(LayerPropertiesDialog &dialog) {
     SPDesktop *desktop=dialog._desktop;
     Glib::ustring name(dialog._layer_name_entry.get_text());
-    desktop->currentLayer()->setLabel(
-        ( name.empty() ? NULL : (gchar *)name.c_str() )
+    desktop->layer_manager->renameLayer( desktop->currentLayer(),
+                                         ( name.empty() ? NULL : (gchar *)name.c_str() )
     );
-    sp_document_done(SP_DT_DOCUMENT(desktop));
+    sp_document_done(sp_desktop_document(desktop));
     // TRANSLATORS: This means "The layer has been renamed"
     desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Renamed layer"));
 }
@@ -151,18 +199,26 @@ void LayerPropertiesDialog::Create::setup(LayerPropertiesDialog &dialog) {
     dialog.set_title(_("Add Layer"));
     dialog._layer_name_entry.set_text("");
     dialog._apply_button.set_label(_("_Add"));
+    dialog._setup_position_controls();
 }
 
 void LayerPropertiesDialog::Create::perform(LayerPropertiesDialog &dialog) {
     SPDesktop *desktop=dialog._desktop;
-    SPObject *new_layer=Inkscape::create_layer(
-        desktop->currentRoot(), dialog._layer
-    );
+
+    LayerRelativePosition position = LPOS_ABOVE;
+    
+    if (dialog._position_visible) {
+        Gtk::ListStore::iterator activeRow(dialog._layer_position_combo.get_active());
+        position = activeRow->get_value(dialog._dropdown_columns.position);
+    }
+
+    SPObject *new_layer=Inkscape::create_layer(desktop->currentRoot(), dialog._layer, position);
+    
     Glib::ustring name(dialog._layer_name_entry.get_text());
     if (!name.empty()) {
-        new_layer->setLabel((gchar *)name.c_str());
+        desktop->layer_manager->renameLayer( new_layer, (gchar *)name.c_str() );
     }
-    SP_DT_SELECTION(desktop)->clear();
+    sp_desktop_selection(desktop)->clear();
     desktop->setCurrentLayer(new_layer);
     desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("New layer created."));
 }
@@ -196,9 +252,9 @@ void LayerPropertiesDialog::_setLayer(SPObject *layer) {
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
