@@ -15,15 +15,11 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-#include <string.h>
-#include <stdlib.h>
-#include <gtk/gtksignal.h>
 #include <glibmm/i18n.h>
 #include "helper/window.h"
 #include "macros.h"
 #include "sp-anchor.h"
 #include "sp-attribute-widget.h"
-#include "object-attributes.h"
 
 struct SPAttrDesc {
     gchar const *label;
@@ -75,8 +71,8 @@ window_destroyed (GtkObject *window, GtkObject *object)
 
 
 static void
-sp_object_attr_show_dialog ( SPObject *object, 
-                             const SPAttrDesc *desc, 
+sp_object_attr_show_dialog ( SPObject *object,
+                             const SPAttrDesc *desc,
                              const gchar *tag )
 {
     const gchar **labels, **attrs;
@@ -103,10 +99,10 @@ sp_object_attr_show_dialog ( SPObject *object,
     gtk_widget_show (t);
     gtk_container_add (GTK_CONTAINER (w), t);
 
-    g_signal_connect ( G_OBJECT (w), "destroy", 
+    g_signal_connect ( G_OBJECT (w), "destroy",
                        G_CALLBACK (window_destroyed), object );
-                       
-    g_signal_connect ( G_OBJECT (object), "release", 
+
+    g_signal_connect ( G_OBJECT (object), "release",
                        G_CALLBACK (object_released), w );
 
     gtk_widget_show (w);
@@ -136,9 +132,9 @@ sp_object_attributes_dialog (SPObject *object, const gchar *tag)
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
