@@ -5,8 +5,10 @@
  *
  * Authors:
  *   Kees Cook <kees@outflux.net>
+ *   Jon Phillips <jon@rejon.org>
  *
  * Copyright (C) 2004 Kees Cook <kees@outflux.net>
+ * Copyright (C) 2006 Jon Phillips <jon@rejon.org>
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  *
@@ -16,13 +18,8 @@
 # include <config.h>
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
 
-#include <string.h>
-#include <glib.h>
 
-#include "inkscape.h"
 #include "xml/repr.h"
 #include "rdf.h"
 #include "sp-item-group.h"
@@ -178,52 +175,52 @@ struct rdf_double_t rdf_license_freeart [] = {
 };
 
 struct rdf_license_t rdf_licenses [] = {
-    { "CC Attribution", 
-      "http://creativecommons.org/licenses/by/2.0/",
+    { N_("CC Attribution"), 
+      "http://creativecommons.org/licenses/by/2.5/",
       rdf_license_cc_a,
     },
 
-    { "CC Attribution-ShareAlike", 
-      "http://creativecommons.org/licenses/by-sa/2.0/",
+    { N_("CC Attribution-ShareAlike"), 
+      "http://creativecommons.org/licenses/by-sa/2.5/",
       rdf_license_cc_a_sa,
     },
 
-    { "CC Attribution-NoDerivs", 
-      "http://creativecommons.org/licenses/by-nd/2.0/",
+    { N_("CC Attribution-NoDerivs"), 
+      "http://creativecommons.org/licenses/by-nd/2.5/",
       rdf_license_cc_a_nd,
     },
 
-    { "CC Attribution-NonCommercial", 
-      "http://creativecommons.org/licenses/by-nc/2.0/",
+    { N_("CC Attribution-NonCommercial"), 
+      "http://creativecommons.org/licenses/by-nc/2.5/",
       rdf_license_cc_a_nc,
     },
 
-    { "CC Attribution-NonCommercial-ShareAlike", 
-      "http://creativecommons.org/licenses/by-nc-sa/2.0/",
+    { N_("CC Attribution-NonCommercial-ShareAlike"), 
+      "http://creativecommons.org/licenses/by-nc-sa/2.5/",
       rdf_license_cc_a_nc_sa,
     },
 
-    { "CC Attribution-NonCommercial-NoDerivs", 
-      "http://creativecommons.org/licenses/by-nc-nd/2.0/",
+    { N_("CC Attribution-NonCommercial-NoDerivs"), 
+      "http://creativecommons.org/licenses/by-nc-nd/2.5/",
       rdf_license_cc_a_nc_nd,
     },
 
-    { "GNU General Public License", 
+    { N_("GNU General Public License"), 
       "http://creativecommons.org/licenses/GPL/2.0/",
       rdf_license_gpl,
     },
 
-    { "GNU Lesser General Public License", 
+    { N_("GNU Lesser General Public License"), 
       "http://creativecommons.org/licenses/LGPL/2.1/",
       rdf_license_gpl,
     },
 
-    { "Public Domain",
+    { N_("Public Domain"),
       "http://web.resource.org/cc/PublicDomain",
       rdf_license_pd,
     },
 
-    { "FreeArt",
+    { N_("FreeArt"),
       "http://artlibre.org/licence.php/lalgb.html",
       rdf_license_freeart,
     },
@@ -547,7 +544,7 @@ rdf_set_repr_text ( Inkscape::XML::Node * repr,
                 g_return_val_if_fail (temp != NULL, 0);
 
                 parent->appendChild(temp);
-                sp_repr_unref ( temp );
+                Inkscape::GC::release(temp);
 
                 return TRUE;
             }
@@ -563,7 +560,7 @@ rdf_set_repr_text ( Inkscape::XML::Node * repr,
                 g_return_val_if_fail (temp != NULL, 0);
 
                 parent->appendChild(temp);
-                sp_repr_unref ( temp );
+                Inkscape::GC::release(temp);
             }
             parent = temp;
 
@@ -573,7 +570,7 @@ rdf_set_repr_text ( Inkscape::XML::Node * repr,
                 g_return_val_if_fail (temp != NULL, 0);
 
                 parent->appendChild(temp);
-                sp_repr_unref ( temp );
+                Inkscape::GC::release(temp);
             }
             parent = temp;
 
@@ -583,7 +580,7 @@ rdf_set_repr_text ( Inkscape::XML::Node * repr,
                 g_return_val_if_fail (temp != NULL, 0);
 
                 parent->appendChild(temp);
-                sp_repr_unref ( temp );
+                Inkscape::GC::release(temp);
 
                 return TRUE;
             }
@@ -593,7 +590,8 @@ rdf_set_repr_text ( Inkscape::XML::Node * repr,
             }
 
         case RDF_RESOURCE:
-            return sp_repr_set_attr ( parent, "rdf:resource", text );
+            parent->setAttribute("rdf:resource", text );
+            return true;
 
         case RDF_XML:
             return 1;
@@ -604,20 +602,20 @@ rdf_set_repr_text ( Inkscape::XML::Node * repr,
             if ( temp == NULL ) {
                 /* backward compatibility: drop the dc:subject contents */
                 while ( (temp = sp_repr_children( parent )) ) {
-                    sp_repr_remove_child( parent, temp );
+                    parent->removeChild(temp);
                 }
 
                 temp = sp_repr_new ( "rdf:Bag" );
                 g_return_val_if_fail (temp != NULL, 0);
 
                 parent->appendChild(temp);
-                sp_repr_unref ( temp );
+                Inkscape::GC::release(temp);
             }
             parent = temp;
 
             /* toss all the old list items */
             while ( (temp = sp_repr_children( parent )) ) {
-                sp_repr_remove_child( parent, temp );
+                parent->removeChild(temp);
             }
 
             /* chop our list up on commas */
@@ -628,13 +626,13 @@ rdf_set_repr_text ( Inkscape::XML::Node * repr,
                 g_return_val_if_fail (temp != NULL, 0);
 
                 parent->appendChild(temp);
-                sp_repr_unref ( temp );
+                Inkscape::GC::release(temp);
 
                 child = sp_repr_new_text( g_strstrip(str) );
                 g_return_val_if_fail (child != NULL, 0);
 
                 temp->appendChild(child);
-                sp_repr_unref ( child );
+                Inkscape::GC::release(child);
             }
             g_strfreev( strlist );
 
@@ -667,14 +665,14 @@ rdf_get_rdf_root_repr ( SPDocument * doc, bool build )
             g_return_val_if_fail ( parent != NULL, NULL);
 
             svg->appendChild(parent);
-            sp_repr_unref(parent);
+            Inkscape::GC::release(parent);
         }
 
         rdf = sp_repr_new( XML_TAG_NAME_RDF );
         g_return_val_if_fail (rdf != NULL, NULL);
 
         parent->appendChild(rdf);
-        sp_repr_unref(rdf);
+        Inkscape::GC::release(rdf);
     }
 
     /*
@@ -689,13 +687,13 @@ rdf_get_rdf_root_repr ( SPDocument * doc, bool build )
 
             /* attach the metadata node */
             want_metadata->appendChild(metadata);
-            sp_repr_unref ( metadata );
+            Inkscape::GC::release(metadata);
 
             /* move the RDF into it */
-            sp_repr_ref ( rdf );
+            Inkscape::GC::anchor(rdf);
             sp_repr_unparent ( rdf );
             metadata->appendChild(rdf);
-            sp_repr_unref ( rdf );
+            Inkscape::GC::release(rdf);
     }
     
     return rdf;
@@ -719,10 +717,10 @@ rdf_get_xml_repr( SPDocument * doc, gchar const * name, bool build )
         xml = sp_repr_new( name );
         g_return_val_if_fail (xml != NULL, NULL);
 
-        sp_repr_set_attr ( xml, "rdf:about", "" );
+        xml->setAttribute("rdf:about", "" );
 
         rdf->appendChild(xml);
-        sp_repr_unref(xml);
+        Inkscape::GC::release(xml);
     }
 
     return xml;
@@ -747,7 +745,7 @@ rdf_get_work_repr( SPDocument * doc, gchar const * name, bool build )
         g_return_val_if_fail (item != NULL, NULL);
 
         work->appendChild(item);
-        sp_repr_unref(item);
+        Inkscape::GC::release(item);
     }
 
     return item;
@@ -925,11 +923,11 @@ rdf_get_license(SPDocument * document)
 /**
  *  \brief   Stores an RDF/License XML in the document XML
  *  \param   document  Which document to update
- *  \param   license   The desired RDF/License structure to store
+ *  \param   license   The desired RDF/License structure to store; NULL drops old license, so can be used for proprietary license. 
  *  
  */
 void
-rdf_set_license(SPDocument * document, struct rdf_license_t * license)
+rdf_set_license(SPDocument * document, struct rdf_license_t const * license)
 {
     // drop old license section
     Inkscape::XML::Node * repr = rdf_get_xml_repr ( document, XML_TAG_NAME_LICENSE, FALSE );
@@ -941,16 +939,16 @@ rdf_set_license(SPDocument * document, struct rdf_license_t * license)
     repr = rdf_get_xml_repr ( document, XML_TAG_NAME_LICENSE, TRUE );
     g_assert ( repr );
 
-    sp_repr_set_attr ( repr, "rdf:about", license->uri );
+    repr->setAttribute("rdf:about", license->uri );
 
     for (struct rdf_double_t * detail = license->details;
          detail->name; detail++) {
         Inkscape::XML::Node * child = sp_repr_new( detail->name );
         g_assert ( child != NULL );
 
-        sp_repr_set_attr ( child, "rdf:resource", detail->resource );
+        child->setAttribute("rdf:resource", detail->resource );
         repr->appendChild(child);
-        sp_repr_unref ( child );
+        Inkscape::GC::release(child);
     }
 }
 
@@ -975,9 +973,9 @@ rdf_set_defaults ( SPDocument * document )
         // create repr
         Inkscape::XML::Node * rnew = sp_repr_new (XML_TAG_NAME_METADATA);
         // insert into the document
-        sp_repr_add_child (document->rroot, rnew, NULL);
+        document->rroot->addChild(rnew, NULL);
         // clean up
-        sp_repr_unref (rnew);
+        Inkscape::GC::release(rnew);
     }
 
     /* install defaults */
