@@ -16,8 +16,6 @@
 # include "config.h"
 #endif
 
-#include <string.h>
-#include <gtk/gtksignal.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
 #include "xml/repr.h"
@@ -123,7 +121,7 @@ sp_attribute_widget_destroy (GtkObject *object)
     } else {
     
         if (spaw->src.repr) {
-            spaw->src.repr = sp_repr_unref (spaw->src.repr);
+            spaw->src.repr = Inkscape::GC::release(spaw->src.repr);
         }
     } // end of if()
     
@@ -235,7 +233,7 @@ sp_attribute_widget_set_object ( SPAttributeWidget *spaw,
     } else {
         
         if (spaw->src.repr) {
-            spaw->src.repr = sp_repr_unref (spaw->src.repr);
+            spaw->src.repr = Inkscape::GC::release(spaw->src.repr);
         }
     }
 
@@ -290,7 +288,7 @@ sp_attribute_widget_set_repr ( SPAttributeWidget *spaw,
     } else {
         
         if (spaw->src.repr) {
-            spaw->src.repr = sp_repr_unref (spaw->src.repr);
+            spaw->src.repr = Inkscape::GC::release(spaw->src.repr);
         }
     }
 
@@ -300,7 +298,7 @@ sp_attribute_widget_set_repr ( SPAttributeWidget *spaw,
         const gchar *val;
 
         spaw->blocked = TRUE;
-        spaw->src.repr = sp_repr_ref (repr);
+        spaw->src.repr = Inkscape::GC::anchor(repr);
         spaw->attribute = g_strdup (attribute);
 
         val = repr->attribute(attribute);
@@ -442,7 +440,7 @@ sp_attribute_table_destroy ( GtkObject *object )
         }
     } else {
         if (spat->src.repr) {
-            spat->src.repr = sp_repr_unref (spat->src.repr);
+            spat->src.repr = Inkscape::GC::release(spat->src.repr);
         }
     } // end of if()
 
@@ -546,7 +544,7 @@ sp_attribute_table_set_object ( SPAttributeTable *spat,
         }
     } else {
         if (spat->src.repr) {
-            spat->src.repr = sp_repr_unref (spat->src.repr);
+            spat->src.repr = Inkscape::GC::release(spat->src.repr);
         }
     }
 
@@ -648,7 +646,7 @@ sp_attribute_table_set_repr ( SPAttributeTable *spat,
         }
     } else {
         if (spat->src.repr) {
-            spat->src.repr = sp_repr_unref (spat->src.repr);
+            spat->src.repr = Inkscape::GC::release(spat->src.repr);
         }
     }
 
@@ -660,7 +658,7 @@ sp_attribute_table_set_repr ( SPAttributeTable *spat,
         spat->blocked = TRUE;
 
         /* Set up repr */
-        spat->src.repr = sp_repr_ref (repr);
+        spat->src.repr = Inkscape::GC::anchor(repr);
         spat->num_attr = num_attr;
         /* Create table */
         spat->table = gtk_table_new (num_attr, 2, FALSE);
@@ -796,9 +794,9 @@ sp_attribute_table_entry_changed ( GtkEditable *editable,
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
