@@ -21,47 +21,33 @@
 # include "config.h"
 #endif
 
-#include <string.h>
-#include <glib.h>
 
-#include <libnr/nr-values.h>
-#include <libnr/nr-matrix.h>
-#include <libnr/nr-matrix-fns.h>
 
+#include <glib/gmem.h>
 #include <gtk/gtk.h>
 
 #include <glibmm/i18n.h>
 #include "helper/unit-menu.h"
 #include "helper/units.h"
-#include "svg/svg.h"
 #include "svg/css-ostringstream.h"
 #include "widgets/sp-widget.h"
 #include "widgets/spw-utilities.h"
-#include "sp-gradient.h"
 #include "sp-linear-gradient.h"
 #include "sp-radial-gradient.h"
-#include <sp-use.h>
 #include "sp-marker.h"
 #include <sp-pattern.h>
 #include <widgets/paint-selector.h>
 #include <widgets/dash-selector.h>
-#include "enums.h"
 #include "style.h"
 #include "gradient-chemistry.h"
-#include "document.h"
 #include "sp-namedview.h"
 #include "desktop-handles.h"
 #include "desktop-style.h"
-#include "marker-status.h"
 #include "selection.h"
-#include "sp-item.h"
 #include "inkscape.h"
 #include "inkscape-stock.h"
 #include "dialogs/dialog-events.h"
-#include "sp-root.h"
-#include "sp-defs.h"
 #include "sp-text.h"
-#include "sp-shape.h"
 #include "sp-rect.h"
 #include "document-private.h"
 #include "display/nr-arena.h"
@@ -70,7 +56,6 @@
 #include "widgets/icon.h"
 #include "helper/stock-items.h"
 #include "io/sys.h"
-#include <file.h>
 
 #include "dialogs/stroke-style.h"
 
@@ -276,7 +261,7 @@ sp_stroke_style_paint_dragged(SPPaintSelector *psel, SPWidget *spw)
         case SP_PAINT_SELECTOR_MODE_COLOR_CMYK:
         {
             sp_paint_selector_set_flat_color (psel, SP_ACTIVE_DESKTOP, "stroke", "stroke-opacity");
-            sp_document_maybe_done (SP_DT_DOCUMENT(SP_ACTIVE_DESKTOP), undo_label);
+            sp_document_maybe_done (sp_desktop_document(SP_ACTIVE_DESKTOP), undo_label);
             break;
         }
 
@@ -296,8 +281,8 @@ sp_stroke_style_paint_changed(SPPaintSelector *psel, SPWidget *spw)
     g_object_set_data (G_OBJECT (spw), "update", GINT_TO_POINTER (TRUE));
 
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
-    SPDocument *document = SP_DT_DOCUMENT (desktop);
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    SPDocument *document = sp_desktop_document (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     GSList const *items = selection->itemList();
 
@@ -329,7 +314,7 @@ sp_stroke_style_paint_changed(SPPaintSelector *psel, SPWidget *spw)
         case SP_PAINT_SELECTOR_MODE_COLOR_CMYK:
         {
             sp_paint_selector_set_flat_color (psel, desktop, "stroke", "stroke-opacity");
-            sp_document_maybe_done (SP_DT_DOCUMENT(desktop), undo_label);
+            sp_document_maybe_done (sp_desktop_document(desktop), undo_label);
 
             // on release, toggle undo_label so that the next drag will not be lumped with this one
             if (undo_label == undo_label_1)
@@ -513,7 +498,7 @@ sp_stroke_radio_button(GtkWidget *tb, char const *icon,
     gtk_signal_connect(GTK_OBJECT(tb), "toggled",
                        GTK_SIGNAL_FUNC(sp_stroke_style_any_toggled),
                        spw);
-    GtkWidget *px = sp_icon_new(GTK_ICON_SIZE_LARGE_TOOLBAR, icon);
+    GtkWidget *px = sp_icon_new(Inkscape::ICON_SIZE_LARGE_TOOLBAR, icon);
     g_assert(px != NULL);
     gtk_widget_show(px);
     gtk_container_add(GTK_CONTAINER(tb), px);
@@ -534,7 +519,7 @@ sp_marker_prev_new(unsigned size, gchar const *mname,
 
     // the repr of the marker; make a copy with id="sample"
     Inkscape::XML::Node *mrepr = SP_OBJECT_REPR (marker)->duplicate();
-    sp_repr_set_attr (mrepr, "id", "sample");
+    mrepr->setAttribute("id", "sample");
 
     // replace the old sample in the sandbox by the new one
     Inkscape::XML::Node *defsrepr = SP_OBJECT_REPR (sandbox->getObjectById("defs"));
@@ -542,7 +527,7 @@ sp_marker_prev_new(unsigned size, gchar const *mname,
     if (oldmarker)
         oldmarker->deleteObject(false);
     defsrepr->appendChild(mrepr);
-    sp_repr_unref (mrepr);
+    Inkscape::GC::release(mrepr);
 
 // Uncomment this to get the sandbox documents saved (useful for debugging)
     //FILE *fp = fopen (g_strconcat(mname, ".svg", NULL), "w");
@@ -560,11 +545,11 @@ sp_marker_prev_new(unsigned size, gchar const *mname,
     // Find object's bbox in document
     NR::Matrix const i2doc(sp_item_i2doc_affine(SP_ITEM(object)));
 
-    NRRect dbox;
-    sp_item_invoke_bbox(SP_ITEM(object), &dbox, i2doc, TRUE);
+    NR::Rect const dbox = SP_ITEM(object)->invokeBbox(i2doc);
 
-    if (nr_rect_d_test_empty(&dbox))
+    if (dbox.isEmpty()) {
         return NULL;
+    }
 
     /* Update to renderable state */
     NRMatrix t;
@@ -579,10 +564,10 @@ sp_marker_prev_new(unsigned size, gchar const *mname,
 
     /* Item integer bbox in points */
     NRRectL ibox;
-    ibox.x0 = (int) floor(sf * dbox.x0 + 0.5);
-    ibox.y0 = (int) floor(sf * dbox.y0 + 0.5);
-    ibox.x1 = (int) floor(sf * dbox.x1 + 0.5);
-    ibox.y1 = (int) floor(sf * dbox.y1 + 0.5);
+    ibox.x0 = (int) floor(sf * dbox.min()[NR::X] + 0.5);
+    ibox.y0 = (int) floor(sf * dbox.min()[NR::Y] + 0.5);
+    ibox.x1 = (int) floor(sf * dbox.max()[NR::X] + 0.5);
+    ibox.y1 = (int) floor(sf * dbox.max()[NR::Y] + 0.5);
 
     /* Find visible area */
     int width = ibox.x1 - ibox.x0;
@@ -606,7 +591,7 @@ sp_marker_prev_new(unsigned size, gchar const *mname,
     ua.y1 = MIN(ibox.y1, area.y1);
 
     /* Set up pixblock */
-    guchar *px = nr_new(guchar, 4 * size * size);
+    guchar *px = g_new(guchar, 4 * size * size);
     memset(px, 0x00, 4 * size * size);
 
     /* Render */
@@ -625,7 +610,7 @@ sp_marker_prev_new(unsigned size, gchar const *mname,
                               GDK_COLORSPACE_RGB,
                               TRUE,
                               8, size, size, size * 4,
-                              (GdkPixbufDestroyNotify)nr_free,
+                              (GdkPixbufDestroyNotify)g_free,
                               NULL));
     return pb;
 }
@@ -761,7 +746,7 @@ static GtkWidget *
 ink_marker_menu( GtkWidget *tbl, gchar *menu_id, SPDocument *sandbox)
 {
     SPDesktop *desktop = inkscape_active_desktop();
-    SPDocument *doc = SP_DT_DOCUMENT(desktop);
+    SPDocument *doc = sp_desktop_document(desktop);
     GtkWidget *mnu = gtk_option_menu_new();
 
     /* Create new menu widget */
@@ -845,7 +830,7 @@ sp_marker_select(GtkOptionMenu *mnu, GtkWidget *spw)
     }
 
     SPDesktop *desktop = inkscape_active_desktop();
-    SPDocument *document = SP_DT_DOCUMENT(desktop);
+    SPDocument *document = sp_desktop_document(desktop);
     if (!document) {
         return;
     }
@@ -878,7 +863,7 @@ sp_marker_select(GtkOptionMenu *mnu, GtkWidget *spw)
     gchar *menu_id = (gchar *) g_object_get_data(G_OBJECT(mnu), "menu_id");
     sp_repr_css_set_property(css, menu_id, marker);
 
-     Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+     Inkscape::Selection *selection = sp_desktop_selection(desktop);
      GSList const *items = selection->itemList();
      for (; items != NULL; items = items->next) {
          SPItem *item = (SPItem *) items->data;
@@ -908,7 +893,7 @@ static gboolean stroke_width_set_unit(SPUnitSelector *,
         return FALSE;
     }
 
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     if (selection->isEmpty())
         return FALSE;
@@ -986,6 +971,13 @@ sp_stroke_style_line_widget_new(void)
 
     hb = spw_hbox(t, 3, 1, i);
 
+// TODO: when this is gtkmmified, use an Inkscape::UI::Widget::ScalarUnit instead of the separate
+// spinbutton and unit selector for stroke width. In sp_stroke_style_line_update, use
+// setHundredPercent to remember the aeraged width corresponding to 100%. Then the
+// stroke_width_set_unit will be removed (because ScalarUnit takes care of conversions itself), and
+// with it, the two remaining calls of stroke_average_width, allowing us to get rid of that
+// function in desktop-style.
+
     a = gtk_adjustment_new(1.0, 0.0, 1000.0, 0.1, 10.0, 10.0);
     gtk_object_set_data(GTK_OBJECT(spw), "width", a);
     sb = gtk_spin_button_new(GTK_ADJUSTMENT(a), 0.1, 3);
@@ -998,7 +990,7 @@ sp_stroke_style_line_widget_new(void)
     us = sp_unit_selector_new(SP_UNIT_ABSOLUTE | SP_UNIT_DEVICE);
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
     if (desktop)
-        sp_unit_selector_set_unit (SP_UNIT_SELECTOR(us), SP_DT_NAMEDVIEW(desktop)->doc_units);
+        sp_unit_selector_set_unit (SP_UNIT_SELECTOR(us), sp_desktop_namedview(desktop)->doc_units);
     sp_unit_selector_add_unit(SP_UNIT_SELECTOR(us), &sp_unit_get_by_id(SP_UNIT_PERCENT), 0);
     g_signal_connect ( G_OBJECT (us), "set_unit", G_CALLBACK (stroke_width_set_unit), spw );
     gtk_widget_show(us);
@@ -1167,7 +1159,7 @@ sp_stroke_style_line_widget_new(void)
                         GTK_SIGNAL_FUNC(sp_stroke_style_line_selection_changed),
                         NULL );
 
-    sp_stroke_style_line_update( SP_WIDGET(spw), desktop ? SP_DT_SELECTION(desktop) : NULL);
+    sp_stroke_style_line_update( SP_WIDGET(spw), desktop ? sp_desktop_selection(desktop) : NULL);
 
     return spw;
 }
@@ -1185,7 +1177,7 @@ sp_stroke_style_line_construct(SPWidget *spw, gpointer data)
     if (spw->inkscape) {
         sp_stroke_style_line_update(spw,
                                     ( SP_ACTIVE_DESKTOP
-                                      ? SP_DT_SELECTION(SP_ACTIVE_DESKTOP)
+                                      ? sp_desktop_selection(SP_ACTIVE_DESKTOP)
                                       : NULL ));
     } 
 }
@@ -1287,87 +1279,70 @@ sp_stroke_style_line_update(SPWidget *spw, Inkscape::Selection *sel)
     GtkWidget *us = GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(spw), "units"));
     GtkWidget *dsel = GTK_WIDGET(gtk_object_get_data(GTK_OBJECT(spw), "dash"));
 
-    if ( !sel || sel->isEmpty() ) {
-        /* No objects, set empty */
-        gtk_widget_set_sensitive(sset, FALSE);
-        gtk_object_set_data( GTK_OBJECT(spw), "update",
-                             GINT_TO_POINTER(FALSE) );
-        return;
-    }
+    // create temporary style
+    SPStyle *query = sp_style_new ();
+    // query into it
+    int result_sw = sp_desktop_query_style (SP_ACTIVE_DESKTOP, query, QUERY_STYLE_PROPERTY_STROKEWIDTH); 
+    int result_ml = sp_desktop_query_style (SP_ACTIVE_DESKTOP, query, QUERY_STYLE_PROPERTY_STROKEMITERLIMIT); 
+    int result_cap = sp_desktop_query_style (SP_ACTIVE_DESKTOP, query, QUERY_STYLE_PROPERTY_STROKECAP); 
+    int result_join = sp_desktop_query_style (SP_ACTIVE_DESKTOP, query, QUERY_STYLE_PROPERTY_STROKEJOIN); 
 
-    GSList const *objects = sel->itemList();
-
-    gdouble avgwidth = stroke_average_width (objects);
-    gdouble avgml = stroke_average_miterlimit (objects);
-
-    if (avgwidth != NR_HUGE) {
-        gtk_widget_set_sensitive(sset, TRUE);
-    } else {
+    if (result_sw == QUERY_STYLE_NOTHING) {
         /* No objects stroked, set insensitive */
         gtk_widget_set_sensitive(sset, FALSE);
 
         gtk_object_set_data(GTK_OBJECT(spw), "update", GINT_TO_POINTER(FALSE));
         return;
-    }
-
-    SPUnit const *unit = sp_unit_selector_get_unit(SP_UNIT_SELECTOR(us));
-
-    if (stroke_width_varying (objects)) {
-        sp_unit_selector_set_unit(SP_UNIT_SELECTOR(us), &sp_unit_get_by_id(SP_UNIT_PERCENT));
     } else {
-        // only one object; no sense to keep percent, switch to absolute
-        if (unit->base != SP_UNIT_ABSOLUTE && unit->base != SP_UNIT_DEVICE) {
-            // FIXME: use some other default absolute unit
-            sp_unit_selector_set_unit(SP_UNIT_SELECTOR(us), &sp_unit_get_by_id(SP_UNIT_PT));
+        gtk_widget_set_sensitive(sset, TRUE);
+
+        SPUnit const *unit = sp_unit_selector_get_unit(SP_UNIT_SELECTOR(us));
+
+        if (result_sw == QUERY_STYLE_MULTIPLE_AVERAGED) {
+            sp_unit_selector_set_unit(SP_UNIT_SELECTOR(us), &sp_unit_get_by_id(SP_UNIT_PERCENT));
+        } else {
+            // same width, or only one object; no sense to keep percent, switch to absolute
+            if (unit->base != SP_UNIT_ABSOLUTE && unit->base != SP_UNIT_DEVICE) {
+                sp_unit_selector_set_unit(SP_UNIT_SELECTOR(us), sp_desktop_namedview(SP_ACTIVE_DESKTOP)->doc_units);
+            }
+        }
+
+        unit = sp_unit_selector_get_unit (SP_UNIT_SELECTOR (us));
+
+        if (unit->base == SP_UNIT_ABSOLUTE || unit->base == SP_UNIT_DEVICE) {
+            double avgwidth = sp_pixels_get_units (query->stroke_width.computed, *unit);
+            gtk_adjustment_set_value(GTK_ADJUSTMENT(width), avgwidth);
+        } else {
+            gtk_adjustment_set_value(GTK_ADJUSTMENT(width), 100);
         }
     }
 
-    unit = sp_unit_selector_get_unit (SP_UNIT_SELECTOR (us));
+    if (result_ml != QUERY_STYLE_NOTHING)
+        gtk_adjustment_set_value(GTK_ADJUSTMENT(ml), query->stroke_miterlimit.value); // TODO: reflect averagedness?
 
-    if (unit->base == SP_UNIT_ABSOLUTE || unit->base == SP_UNIT_DEVICE) {
-        avgwidth = sp_pixels_get_units (avgwidth, *unit);
-        gtk_adjustment_set_value(GTK_ADJUSTMENT(width), avgwidth);
-    } else {
-        gtk_adjustment_set_value(GTK_ADJUSTMENT(width), 100);
-    }
-
-    gtk_adjustment_set_value(GTK_ADJUSTMENT(ml), avgml);
-
-    /* Join & Cap */
-    SPObject * const object = SP_OBJECT(objects->data);
-    SPStyle * const style = SP_OBJECT_STYLE(object);
-    unsigned const jointype = object->style->stroke_linejoin.value;
-    unsigned const captype = object->style->stroke_linecap.value;
-
-    bool joinValid = true;
-    bool capValid = true;
-    for (GSList const *l = objects->next; l != NULL; l = l->next) {
-        SPObject *o = SP_OBJECT(l->data);
-        if ( o->style->stroke_linejoin.value != jointype ) {
-            joinValid = false;
-        }
-        if ( o->style->stroke_linecap.value != captype ) {
-            capValid = false;
-        }
-    }
-
-    if (joinValid) {
-        sp_jointype_set (spw, jointype);
+    if (result_join != QUERY_STYLE_MULTIPLE_DIFFERENT) {
+        sp_jointype_set (spw, query->stroke_linejoin.value);
     } else {
         sp_stroke_style_set_join_buttons(spw, NULL);
     }
 
-    if (capValid) {
-        sp_captype_set (spw, captype);
+    if (result_cap != QUERY_STYLE_MULTIPLE_DIFFERENT) {
+        sp_captype_set (spw, query->stroke_linecap.value);
     } else {
         sp_stroke_style_set_cap_buttons(spw, NULL);
     }
 
+    g_free (query);
+
+    GSList const *objects = sel->itemList();
+    SPObject * const object = SP_OBJECT(objects->data);
+    SPStyle * const style = SP_OBJECT_STYLE(object);
+
     /* Markers */
-    sp_stroke_style_update_marker_menus(spw, objects);
+    sp_stroke_style_update_marker_menus(spw, objects); // FIXME: make this desktop query too
 
     /* Dash */
-    sp_dash_selector_set_from_style (dsel, style);
+    sp_dash_selector_set_from_style (dsel, style); // FIXME: make this desktop query too
 
     gtk_widget_set_sensitive(sset, TRUE);
 
@@ -1414,8 +1389,8 @@ sp_stroke_style_scale_line(SPWidget *spw)
     GtkAdjustment *ml = GTK_ADJUSTMENT(gtk_object_get_data(GTK_OBJECT(spw), "miterlimit"));
 
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
-    SPDocument *document = SP_DT_DOCUMENT (desktop);
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    SPDocument *document = sp_desktop_document (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     GSList const *items = selection->itemList();
 
@@ -1562,7 +1537,7 @@ sp_stroke_style_any_toggled(GtkToggleButton *tb, SPWidget *spw)
 
         sp_repr_css_attr_unref(css);
 
-        sp_document_done(SP_DT_DOCUMENT(desktop));
+        sp_document_done(sp_desktop_document(desktop));
     }
 }
 
@@ -1734,7 +1709,7 @@ ink_extract_marker_name(gchar const *n)
 
 
     SPDesktop *desktop = inkscape_active_desktop();
-    SPDocument *doc = SP_DT_DOCUMENT(desktop);
+    SPDocument *doc = sp_desktop_document(desktop);
     SPObject *marker = doc->getObjectById(b);
     return marker;
 }
