@@ -17,16 +17,13 @@
 # include "config.h"
 #endif
 
-#include <string.h>
-#include <libnrtype/FontFactory.h>
 #include <libnrtype/font-instance.h>
 
-#include <glib.h>
 #include <gtk/gtk.h>
 
 #ifdef WITH_GTKSPELL
 extern "C" {
-#include <gtkspell/gtkspell.h>
+# include <gtkspell/gtkspell.h>
 }
 #endif
 
@@ -34,7 +31,6 @@ extern "C" {
 #include <glibmm/i18n.h>
 #include "helper/window.h"
 #include "../widgets/font-selector.h"
-#include "../forward.h"
 #include "../inkscape.h"
 #include "../document.h"
 #include "../desktop-style.h"
@@ -55,8 +51,6 @@ extern "C" {
 #include "widgets/icon.h"
 #include <xml/repr.h>
 
-#include "text-edit.h"
-
 #define VB_MARGIN 4
 
 static void sp_text_edit_dialog_selection_modified (Inkscape::Application *inkscape, Inkscape::Selection *sel, guint flags, GtkWidget *dlg);
@@ -83,7 +77,7 @@ static const gchar *spacings[] = {"50%", "80%", "90%", "100%", "110%", "120%", "
 static GtkWidget *dlg = NULL;
 static win_data wd;
 // impossible original values to make sure they are read from prefs
-static gint x = -1000, y = -1000, w = 0, h = 0; 
+static gint x = -1000, y = -1000, w = 0, h = 0;
 static gchar const *prefs_path = "dialogs.textandfont";
 
 
@@ -105,6 +99,9 @@ sp_text_edit_dialog_delete (GtkObject *object, GdkEvent *event, gpointer data)
     gtk_window_get_position ((GtkWindow *) dlg, &x, &y);
     gtk_window_get_size ((GtkWindow *) dlg, &w, &h);
 
+    if (x<0) x=0;
+    if (y<0) y=0;
+
     prefs_set_int_attribute (prefs_path, "x", x);
     prefs_set_int_attribute (prefs_path, "y", y);
     prefs_set_int_attribute (prefs_path, "w", w);
@@ -139,9 +136,8 @@ text_view_focus_out (GtkWidget *w, GdkEventKey *event, gpointer data)
 void
 sp_text_edit_dialog (void)
 {
-
     if (!dlg) {
-    
+
         gchar title[500];
         sp_ui_dialog_title_string (Inkscape::Verb::get(SP_VERB_DIALOG_TEXT), title);
 
@@ -150,32 +146,35 @@ sp_text_edit_dialog (void)
             x = prefs_get_int_attribute (prefs_path, "x", 0);
             y = prefs_get_int_attribute (prefs_path, "y", 0);
         }
-        
+
         if (w ==0 || h == 0) {
             w = prefs_get_int_attribute (prefs_path, "w", 0);
             h = prefs_get_int_attribute (prefs_path, "h", 0);
         }
-        
+
+        if (x<0) x=0;
+        if (y<0) y=0;
+
         if (x != 0 || y != 0) {
             gtk_window_move ((GtkWindow *) dlg, x, y);
         } else {
             gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
         }
-        
-        if (w && h) 
+
+        if (w && h)
             gtk_window_resize ((GtkWindow *) dlg, w, h);
-        
+
         sp_transientize (dlg);
         wd.win = dlg;
         wd.stop = 0;
         g_signal_connect ( G_OBJECT (INKSCAPE), "activate_desktop", G_CALLBACK (sp_transientize_callback), &wd );
-                           
+
         gtk_signal_connect ( GTK_OBJECT (dlg), "event", GTK_SIGNAL_FUNC (sp_dialog_event_handler), dlg );
-                             
+
         gtk_signal_connect ( GTK_OBJECT (dlg), "destroy", G_CALLBACK (sp_text_edit_dialog_destroy), dlg );
         gtk_signal_connect ( GTK_OBJECT (dlg), "delete_event", G_CALLBACK (sp_text_edit_dialog_delete), dlg );
         g_signal_connect ( G_OBJECT (INKSCAPE), "shut_down", G_CALLBACK (sp_text_edit_dialog_delete), dlg );
-                           
+
         g_signal_connect ( G_OBJECT (INKSCAPE), "dialogs_hide", G_CALLBACK (sp_dialog_hide), dlg );
         g_signal_connect ( G_OBJECT (INKSCAPE), "dialogs_unhide", G_CALLBACK (sp_dialog_unhide), dlg );
 
@@ -208,6 +207,12 @@ sp_text_edit_dialog (void)
             // font and style selector
             GtkWidget *fontsel = sp_font_selector_new ();
             g_signal_connect ( G_OBJECT (fontsel), "font_set", G_CALLBACK (sp_text_edit_dialog_font_changed), dlg );
+
+            g_signal_connect_swapped ( G_OBJECT (g_object_get_data (G_OBJECT(fontsel), "family-treeview")),
+                                      "row-activated",
+                                      G_CALLBACK (gtk_window_activate_default),
+                                      dlg);
+
             gtk_box_pack_start (GTK_BOX (hb), fontsel, TRUE, TRUE, 0);
             g_object_set_data (G_OBJECT (dlg), "fontsel", fontsel);
 
@@ -224,6 +229,7 @@ sp_text_edit_dialog (void)
 
                     // align left
                     {
+                        // TODO - replace with Inkscape-specific call
                         GtkWidget *px = gtk_image_new_from_stock ( GTK_STOCK_JUSTIFY_LEFT, GTK_ICON_SIZE_LARGE_TOOLBAR );
                         GtkWidget *b = group = gtk_radio_button_new (NULL);
                         gtk_tooltips_set_tip (tt, b, _("Align lines left"), NULL);
@@ -237,6 +243,7 @@ sp_text_edit_dialog (void)
 
                     // align center
                     {
+                        // TODO - replace with Inkscape-specific call
                         GtkWidget *px = gtk_image_new_from_stock ( GTK_STOCK_JUSTIFY_CENTER, GTK_ICON_SIZE_LARGE_TOOLBAR );
                         GtkWidget *b = gtk_radio_button_new (gtk_radio_button_group (GTK_RADIO_BUTTON (group)));
                         /* TRANSLATORS: `Center' here is a verb. */
@@ -251,6 +258,7 @@ sp_text_edit_dialog (void)
 
                     // align right
                     {
+                        // TODO - replace with Inkscape-specific call
                         GtkWidget *px = gtk_image_new_from_stock ( GTK_STOCK_JUSTIFY_RIGHT, GTK_ICON_SIZE_LARGE_TOOLBAR );
                         GtkWidget *b = gtk_radio_button_new (gtk_radio_button_group (GTK_RADIO_BUTTON (group)));
                         gtk_tooltips_set_tip (tt, b, _("Align lines right"), NULL);
@@ -272,7 +280,7 @@ sp_text_edit_dialog (void)
 
                     // horizontal
                     {
-                        GtkWidget *px = sp_icon_new( GTK_ICON_SIZE_LARGE_TOOLBAR,
+                        GtkWidget *px = sp_icon_new( Inkscape::ICON_SIZE_LARGE_TOOLBAR,
                                                       INKSCAPE_STOCK_WRITING_MODE_LR );
                         GtkWidget *b = group = gtk_radio_button_new (NULL);
                         gtk_tooltips_set_tip (tt, b, _("Horizontal text"), NULL);
@@ -286,7 +294,7 @@ sp_text_edit_dialog (void)
 
                     // vertical
                     {
-                        GtkWidget *px = sp_icon_new( GTK_ICON_SIZE_LARGE_TOOLBAR,
+                        GtkWidget *px = sp_icon_new( Inkscape::ICON_SIZE_LARGE_TOOLBAR,
                                                       INKSCAPE_STOCK_WRITING_MODE_TB );
                         GtkWidget *b = gtk_radio_button_new (gtk_radio_button_group (GTK_RADIO_BUTTON (group)));
                         gtk_tooltips_set_tip (tt, b, _("Vertical text"), NULL);
@@ -330,8 +338,8 @@ sp_text_edit_dialog (void)
                         g_list_free (sl);
                     }
 
-                    g_signal_connect ( (GObject *) ((GtkCombo *) c)->entry, 
-                                       "changed", 
+                    g_signal_connect ( (GObject *) ((GtkCombo *) c)->entry,
+                                       "changed",
                                        (GCallback) sp_text_edit_dialog_line_spacing_changed,
                                        dlg );
                     gtk_box_pack_start (GTK_BOX (row), c, FALSE, FALSE, VB_MARGIN);
@@ -383,7 +391,7 @@ sp_text_edit_dialog (void)
             gtk_text_view_set_editable (GTK_TEXT_VIEW (txt), TRUE);
             gtk_container_add (GTK_CONTAINER (scroller), txt);
             gtk_box_pack_start (GTK_BOX (vb), scroller, TRUE, TRUE, 0);
-            g_signal_connect ( G_OBJECT (tb), "changed", 
+            g_signal_connect ( G_OBJECT (tb), "changed",
                                G_CALLBACK (sp_text_edit_dialog_text_changed), dlg );
             g_signal_connect (G_OBJECT (txt), "focus-in-event", G_CALLBACK (text_view_focus_in), dlg);
             g_signal_connect (G_OBJECT (txt), "focus-out-event", G_CALLBACK (text_view_focus_out), dlg);
@@ -398,8 +406,8 @@ sp_text_edit_dialog (void)
 
         {
             GtkWidget *b = gtk_button_new_with_label (_("Set as default"));
-            g_signal_connect ( G_OBJECT (b), "clicked", 
-                               G_CALLBACK (sp_text_edit_dialog_set_default), 
+            g_signal_connect ( G_OBJECT (b), "clicked",
+                               G_CALLBACK (sp_text_edit_dialog_set_default),
                                dlg );
             gtk_box_pack_start (GTK_BOX (hb), b, FALSE, FALSE, 0);
             g_object_set_data (G_OBJECT (dlg), "default", b);
@@ -414,6 +422,7 @@ sp_text_edit_dialog (void)
 
         {
             GtkWidget *b = gtk_button_new_from_stock (GTK_STOCK_APPLY);
+            GTK_WIDGET_SET_FLAGS (b, GTK_CAN_DEFAULT | GTK_HAS_DEFAULT);
             g_signal_connect ( G_OBJECT (b), "clicked", 
                                G_CALLBACK (sp_text_edit_dialog_apply), dlg );
             gtk_box_pack_end ( GTK_BOX (hb), b, FALSE, FALSE, 0 );
@@ -486,7 +495,7 @@ sp_text_edit_dialog_update_object_text ( SPItem *text )
             gtk_text_buffer_get_bounds (tb, &start, &end);
             str = gtk_text_buffer_get_text (tb, &start, &end, TRUE);
             sp_te_set_repr_text_multiline (text, str);
-            g_free (str);    
+            g_free (str);
             gtk_text_buffer_set_modified (tb, FALSE);
         }
 }
@@ -543,9 +552,9 @@ sp_get_text_dialog_style ()
                 sp_repr_css_set_property (css, "text-align", "end");
             }
         }
-        
+
         b = (GtkWidget*)g_object_get_data (G_OBJECT (dlg), INKSCAPE_STOCK_WRITING_MODE_LR );
-        
+
         if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (b))) {
             sp_repr_css_set_property (css, "writing-mode", "lr");
         } else {
@@ -590,18 +599,16 @@ sp_text_edit_dialog_apply (GtkButton *button, GtkWidget *dlg)
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
 
     unsigned items = 0;
-    const GSList *item_list = SP_DT_SELECTION(desktop)->itemList();
-
+    const GSList *item_list = sp_desktop_selection(desktop)->itemList();
     SPCSSAttr *css = sp_get_text_dialog_style ();
-
     sp_desktop_set_style(desktop, css, true);
 
-    for (; item_list != NULL; item_list = item_list->next) { 
+    for (; item_list != NULL; item_list = item_list->next) {
         // apply style to the reprs of all text objects in the selection
         if (SP_IS_TEXT (item_list->data)) {
 
             // backwards compatibility:
-            sp_repr_set_attr (SP_OBJECT_REPR(item_list->data), "sodipodi:linespacing", sp_repr_css_property (css, "line-height", NULL));
+            SP_OBJECT_REPR(item_list->data)->setAttribute("sodipodi:linespacing", sp_repr_css_property (css, "line-height", NULL));
 
             ++items;
         }
@@ -609,31 +616,26 @@ sp_text_edit_dialog_apply (GtkButton *button, GtkWidget *dlg)
             // no need to set sodipodi:linespacing, because Inkscape never supported it on flowtext
             ++items;
     }
-    
-    if (items == 0) { 
+
+    if (items == 0) {
         // no text objects; apply style to prefs for new objects
         sp_repr_css_change (inkscape_get_repr (INKSCAPE, "tools.text"), css, "style");
         gtk_widget_set_sensitive (def, FALSE);
     } else if (items == 1) {
         /* exactly one text object; now set its text, too */
-        SPItem *item = SP_DT_SELECTION(SP_ACTIVE_DESKTOP)->singleItem();
+        SPItem *item = sp_desktop_selection(SP_ACTIVE_DESKTOP)->singleItem();
         if (SP_IS_TEXT (item) || SP_IS_FLOWTEXT(item)) {
             sp_text_edit_dialog_update_object_text (item);
         }
-    } 
+    }
 
     // complete the transaction
-    sp_document_done (SP_DT_DOCUMENT (SP_ACTIVE_DESKTOP));
-
+    sp_document_done (sp_desktop_document (SP_ACTIVE_DESKTOP));
     gtk_widget_set_sensitive (apply, FALSE);
-
     sp_repr_css_attr_unref (css);
-
     g_object_set_data (G_OBJECT (dlg), "blocked", GINT_TO_POINTER (FALSE));
 }
 
-
-
 static void
 sp_text_edit_dialog_close (GtkButton *button, GtkWidget *dlg)
 {
@@ -641,13 +643,13 @@ sp_text_edit_dialog_close (GtkButton *button, GtkWidget *dlg)
 }
 
 static void
-sp_text_edit_dialog_read_selection ( GtkWidget *dlg, 
-                                     gboolean dostyle, 
+sp_text_edit_dialog_read_selection ( GtkWidget *dlg,
+                                     gboolean dostyle,
                                      gboolean docontent )
 {
-    if (g_object_get_data (G_OBJECT (dlg), "blocked")) 
+    if (g_object_get_data (G_OBJECT (dlg), "blocked"))
         return;
-    
+
     g_object_set_data (G_OBJECT (dlg), "blocked", GINT_TO_POINTER (TRUE));
 
     GtkWidget *notebook = (GtkWidget*)g_object_get_data (G_OBJECT (dlg), "notebook");
@@ -694,7 +696,7 @@ sp_text_edit_dialog_read_selection ( GtkWidget *dlg,
             }
         } // end of if (docontent)
         repr = SP_OBJECT_REPR (text);
-        
+
     } else {
         gtk_widget_set_sensitive (textw, FALSE);
         gtk_widget_set_sensitive (apply, FALSE);
@@ -772,7 +774,7 @@ sp_text_edit_dialog_text_changed (GtkTextBuffer *tb, GtkWidget *dlg)
     GtkTextIter start, end;
     gchar *str;
 
-    if (g_object_get_data (G_OBJECT (dlg), "blocked")) 
+    if (g_object_get_data (G_OBJECT (dlg), "blocked"))
         return;
 
     SPItem *text = sp_ted_get_selected_text_item ();
@@ -799,16 +801,23 @@ sp_text_edit_dialog_text_changed (GtkTextBuffer *tb, GtkWidget *dlg)
 
 } // end of sp_text_edit_dialog_text_changed()
 
-
+void
+sp_text_edit_dialog_default_set_insensitive ()
+{
+    if (!dlg) return;
+    gpointer data = g_object_get_data (G_OBJECT (dlg), "default");
+    if (!data) return;
+    gtk_widget_set_sensitive (GTK_WIDGET (data), FALSE);
+}
 
 static void
-sp_text_edit_dialog_font_changed ( SPFontSelector *fsel, 
-                                   font_instance *font, 
+sp_text_edit_dialog_font_changed ( SPFontSelector *fsel,
+                                   font_instance *font,
                                    GtkWidget *dlg )
 {
     GtkWidget *preview, *apply, *def;
 
-    if (g_object_get_data (G_OBJECT (dlg), "blocked")) 
+    if (g_object_get_data (G_OBJECT (dlg), "blocked"))
         return;
 
     SPItem *text = sp_ted_get_selected_text_item ();
@@ -819,7 +828,8 @@ sp_text_edit_dialog_font_changed ( SPFontSelector *fsel,
 
     sp_font_preview_set_font (SP_FONT_PREVIEW (preview), font, SP_FONT_SELECTOR(fsel));
 
-    if (text) {
+    if (text)
+    {
         gtk_widget_set_sensitive (apply, TRUE);
     }
     gtk_widget_set_sensitive (def, TRUE);
@@ -854,7 +864,7 @@ sp_text_edit_dialog_line_spacing_changed (GtkEditable *editable, GtkWidget *dlg)
 {
     GtkWidget *apply, *def;
 
-    if (g_object_get_data ((GObject *) dlg, "blocked")) 
+    if (g_object_get_data ((GObject *) dlg, "blocked"))
         return;
 
     SPItem *text = sp_ted_get_selected_text_item ();
@@ -876,7 +886,7 @@ sp_ted_get_selected_text_item (void)
     if (!SP_ACTIVE_DESKTOP)
         return NULL;
 
-    for (const GSList *item = SP_DT_SELECTION(SP_ACTIVE_DESKTOP)->itemList();
+    for (const GSList *item = sp_desktop_selection(SP_ACTIVE_DESKTOP)->itemList();
          item != NULL;
          item = item->next)
     {
@@ -892,12 +902,12 @@ sp_ted_get_selected_text_item (void)
 static unsigned
 sp_ted_get_selected_text_count (void)
 {
-    if (!SP_ACTIVE_DESKTOP) 
+    if (!SP_ACTIVE_DESKTOP)
         return 0;
 
     unsigned int items = 0;
 
-    for (const GSList *item = SP_DT_SELECTION(SP_ACTIVE_DESKTOP)->itemList();
+    for (const GSList *item = sp_desktop_selection(SP_ACTIVE_DESKTOP)->itemList();
          item != NULL;
          item = item->next)
     {
@@ -912,9 +922,9 @@ sp_ted_get_selected_text_count (void)
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
