@@ -17,28 +17,24 @@
 # include <config.h>
 #endif
 
-#include "tiledialog.h"
 
-#include <dialogs/dialog-events.h>
 #include <gtk/gtkdialog.h> //for GTK_RESPONSE* types
+#include <gtk/gtksizegroup.h>
 #include <glibmm/i18n.h>
-#include "interface.h"
+#include <gtkmm/stock.h>
+
+#include "libnr/nr-matrix-ops.h"
 #include "verbs.h"
 #include "prefs-utils.h"
 #include "inkscape.h"
-#include "macros.h"
 #include "desktop-handles.h"
 #include "selection.h"
-#include "xml/repr.h"
 #include "document.h"
 #include "sp-item.h"
+#include "widgets/icon.h"
+#include "tiledialog.h"
 
 
-#include "libnr/nr-matrix.h"
-#include "libnr/nr-matrix-fns.h"
-#include "libnr/nr-matrix-ops.h"
-
-#include <glib.h>
 
 /*
  *    Sort items by their x co-ordinates, taking account of y (keeps rows intact)
@@ -50,22 +46,35 @@
 int
 sp_compare_x_position(SPItem *first, SPItem *second)
 {
-    NRRect a;
-    sp_item_invoke_bbox(first, &a, sp_item_i2doc_affine(first), TRUE);
-    double a_height = fabs (a.y1 - a.y0);
+    using NR::X;
+    using NR::Y;
 
-    NRRect b;
-    sp_item_invoke_bbox(second, &b, sp_item_i2doc_affine(second), TRUE);
-    double b_height = fabs (b.y1 - b.y0);
-    bool a_in_b_vert = FALSE;
-    if ((a.y0 < b.y0+0.1) && (a.y0 > b.y0 - b_height)) a_in_b_vert = TRUE;
-    else if ((b.y0 < a.y0+0.1) && (b.y0 > a.y0 - a_height)) a_in_b_vert = TRUE;
-    else if (b.y0 == a.y0) a_in_b_vert = TRUE;
-    else a_in_b_vert = FALSE;
+    NR::Rect const a = first->invokeBbox(sp_item_i2doc_affine(first));
+    double const a_height = a.dimensions()[Y];
 
-    if (!a_in_b_vert) return -1;
-    if (a_in_b_vert && (a.x0 > b.x0)) return 1;
-    if (a_in_b_vert && (a.x0 < b.x0)) return -1;
+    NR::Rect const b = second->invokeBbox(sp_item_i2doc_affine(second));
+    double const b_height = b.dimensions()[Y];
+    
+    bool a_in_b_vert = false;
+    if ((a.min()[Y] < b.min()[Y] + 0.1) && (a.min()[Y] > b.min()[Y] - b_height)) {
+        a_in_b_vert = true;
+    } else if ((b.min()[Y] < a.min()[Y] + 0.1) && (b.min()[Y] > a.min()[Y] - a_height)) {
+        a_in_b_vert = true;
+    } else if (b.min()[Y] == a.min()[Y]) {
+        a_in_b_vert = true;
+    } else {
+        a_in_b_vert = false;
+    }
+
+    if (!a_in_b_vert) {
+        return -1;
+    }
+    if (a_in_b_vert && a.min()[X] > b.min()[X]) {
+        return 1;
+    }
+    if (a_in_b_vert && a.min()[X] < b.min()[X]) {
+        return -1;
+    }
     return 0;
 }
 
@@ -75,13 +84,16 @@ sp_compare_x_position(SPItem *first, SPItem *second)
 int
 sp_compare_y_position(SPItem *first, SPItem *second)
 {
-    NRRect a;
-    sp_item_invoke_bbox(first, &a, sp_item_i2doc_affine(first), TRUE);
-    NRRect b;
-    sp_item_invoke_bbox(second, &b, sp_item_i2doc_affine(second), TRUE);
+    NR::Rect const a = first->invokeBbox(sp_item_i2doc_affine(first));
+    NR::Rect const b = second->invokeBbox(sp_item_i2doc_affine(second));
 
-    if (a.y0 > b.y0) return 1;
-    if (a.y0 < b.y0) return -1;
+    if (a.min()[NR::Y] > b.min()[NR::Y]) {
+        return 1;
+    }
+    if (a.min()[NR::Y] < b.min()[NR::Y]) {
+        return -1;
+    }
+    
     return 0;
 }
 
@@ -111,6 +123,9 @@ void TileDialog::Grid_Arrange ()
     total_col_width=0;
     total_row_height=0;
 
+    // check for correct numbers in the row- and col-spinners
+    on_col_spinbutton_changed();
+    on_row_spinbutton_changed();
 
     // set padding to manual values
     paddingx = XPadSpinner.get_value();
@@ -137,23 +152,31 @@ void TileDialog::Grid_Arrange ()
     grid_top = 99999;
 
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
+    sp_document_ensure_up_to_date(sp_desktop_document(desktop));
 
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
     const GSList *items = selection->itemList();
     cnt=0;
     for (; items != NULL; items = items->next) {
-        NRRect b;
-        SPItem *item=SP_ITEM(items->data);
-        sp_item_invoke_bbox(item, &b, sp_item_i2doc_affine(item), TRUE);
-        width = fabs (b.x1 - b.x0);
-        height = fabs (b.y1 - b.y0);
-        cx = (b.x1 + b.x0)/2;
-        cy = (b.y1 + b.y0)/2;
+        SPItem *item = SP_ITEM(items->data);
+        NR::Rect const b = item->invokeBbox(sp_item_i2doc_affine(item));
+        width = b.dimensions()[NR::X];
+        height = b.dimensions()[NR::Y];
+        cx = b.midpoint()[NR::X];
+        cy = b.midpoint()[NR::Y];
 
-        if (b.x0 < grid_left) grid_left = b.x0;
-        if (b.y0 < grid_top) grid_top = b.y0;
-        if (width > col_width) col_width = width;
-        if (height > row_height) row_height = height;
+        if (b.min()[NR::X] < grid_left) {
+            grid_left = b.min()[NR::X];
+        }
+        if (b.min()[NR::Y] < grid_top) {
+            grid_top = b.min()[NR::Y];
+        }
+        if (width > col_width) {
+            col_width = width;
+        }
+        if (height > row_height) {
+            row_height = height;
+        }
     }
 
 
@@ -172,13 +195,16 @@ void TileDialog::Grid_Arrange ()
         cnt=0;
         const GSList *sizes = sorted;
         for (; sizes != NULL; sizes = sizes->next) {
-            NRRect b;
-            SPItem *item=SP_ITEM(sizes->data);
-            sp_item_invoke_bbox(item, &b, sp_item_i2doc_affine(item), TRUE);
-            width = fabs (b.x1 - b.x0);
-            height = fabs (b.y1 - b.y0);
-            if (width > col_widths[(cnt % NoOfCols)]) col_widths[(cnt % NoOfCols)] = width;
-            if (height > row_heights[(cnt / NoOfCols)]) row_heights[(cnt / NoOfCols)] = height;
+            SPItem *item = SP_ITEM(sizes->data);
+            NR::Rect const b = item->invokeBbox(sp_item_i2doc_affine(item));
+            width = b.dimensions()[NR::X];
+            height = b.dimensions()[NR::Y];
+            if (width > col_widths[(cnt % NoOfCols)]) {
+                col_widths[(cnt % NoOfCols)] = width;
+            }
+            if (height > row_heights[(cnt / NoOfCols)]) {
+                row_heights[(cnt / NoOfCols)] = height;
+            }
             cnt++;
         }
 
@@ -226,13 +252,12 @@ void TileDialog::Grid_Arrange ()
 
     // Fit to bbox, calculate padding between rows accordingly.
     if (!SpaceManualRadioButton.get_active()){
-        NRRect b;
-        selection->bounds(&b);
-        #ifdef DEBUG_GRID_ARRANGE
-        g_print("\n row = %f     col = %f selection x= %f selection y = %f", total_row_height,total_col_width,fabs (b.x1 - b.x0),fabs (b.y1 - b.y0));
-        #endif
-        paddingx = (fabs (b.x1 - b.x0) - total_col_width) / (NoOfCols -1);
-        paddingy = (fabs (b.y1 - b.y0) - total_row_height) / (NoOfRows -1);
+        NR::Rect b = selection->bounds();
+#ifdef DEBUG_GRID_ARRANGE
+g_print("\n row = %f     col = %f selection x= %f selection y = %f", total_row_height,total_col_width, b.extent(NR::X), b.extent(NR::Y));
+#endif
+        paddingx = (b.extent(NR::X) - total_col_width) / (NoOfCols -1);
+        paddingy = (b.extent(NR::Y) - total_row_height) / (NoOfRows -1);
     }
 
 /*
@@ -275,10 +300,9 @@ void TileDialog::Grid_Arrange ()
              for (; current_row != NULL; current_row = current_row->next) {
                  SPItem *item=SP_ITEM(current_row->data);
                  Inkscape::XML::Node *repr = SP_OBJECT_REPR(item);
-                 NRRect b;
-                 sp_item_invoke_bbox(item, &b, sp_item_i2doc_affine(item), TRUE);
-                 width = b.x1 - b.x0;
-                 height = b.y1 - b.y0;
+                 NR::Rect const b = item->invokeBbox(sp_item_i2doc_affine(item));
+                 width = b.dimensions()[NR::X];
+                 height = b.dimensions()[NR::Y];
                  row = cnt / NoOfCols;
                  col = cnt % NoOfCols;
 
@@ -289,7 +313,7 @@ void TileDialog::Grid_Arrange ()
                  new_x = grid_left + (((col_widths[col] - width)/2)*HorizAlign) + col_xs[col];
                  new_y = grid_top + (((row_heights[row] - height)/2)*VertAlign) + row_ys[row];
 
-                 NR::Point move = NR::Point(new_x-b.x0, b.y0 - new_y); // why are the two args the opposite ways round???
+                 NR::Point move = NR::Point(new_x - b.min()[NR::X], b.min()[NR::Y] - new_y); // why are the two args the opposite ways round???
                  NR::Matrix const &affine = NR::Matrix(NR::translate(move));
                  sp_item_set_i2d_affine(item, sp_item_i2d_affine(item) * affine);
                  sp_item_write_transform(item, repr, item->transform,  NULL);
@@ -302,7 +326,7 @@ void TileDialog::Grid_Arrange ()
     NRRect b;
             selection->bounds(&b);
 
-    sp_document_done (SP_DT_DOCUMENT (desktop));
+    sp_document_done (sp_desktop_document (desktop));
 
 }
 
@@ -312,24 +336,9 @@ void TileDialog::Grid_Arrange ()
 //#########################################################################
 
 
-/**
- * Default response from the dialog.  Let's intercept it
- */
-void TileDialog::responseCallback(int response_id)
+void TileDialog::_apply()
 {
-
-    if (response_id == GTK_RESPONSE_OK)
-        {
-        Grid_Arrange();
-        }
-    else if (response_id == GTK_RESPONSE_CANCEL)
-        {
-        }
-    else
-        {
-        hide();
-        return;
-        }
+	Grid_Arrange();
 }
 
 
@@ -347,7 +356,7 @@ void TileDialog::on_row_spinbutton_changed()
     updating = true;
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
 
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     GSList const *items = selection->itemList();
     int selcount = g_slist_length((GSList *)items);
@@ -371,7 +380,7 @@ void TileDialog::on_col_spinbutton_changed()
     // in turn, prevent listener from responding
     updating = true;
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     GSList const *items = selection->itemList();
     int selcount = g_slist_length((GSList *)items);
@@ -533,7 +542,7 @@ void TileDialog::updateSelection()
     // in turn, prevent listener from responding
     updating = true;
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
     const GSList *items = selection->itemList();
     int selcount = g_slist_length((GSList *)items);
 
@@ -585,6 +594,11 @@ TileDialog::TileDialog()
      // bool used by spin button callbacks to stop loops where they change each other.
     updating = false;
 
+    // could not do this in gtkmm - there's no Gtk::SizeGroup public constructor (!)
+    GtkSizeGroup *_col1 = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
+    GtkSizeGroup *_col2 = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
+    GtkSizeGroup *_col3 = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
+
     {
         // Selection Change signal
         g_signal_connect ( G_OBJECT (INKSCAPE), "change_selection", G_CALLBACK (updateSelectionCallback), this);
@@ -598,11 +612,11 @@ TileDialog::TileDialog()
 
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
 
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
     int selcount = 1;
     if (!selection->isEmpty()) {
         GSList const *items = selection->itemList();
-        selcount =g_slist_length((GSList *)items);
+        selcount = g_slist_length((GSList *)items);
     }
 
 
@@ -623,11 +637,9 @@ TileDialog::TileDialog()
     NoOfRowsSpinner.set_range(1.0, 100.0);
     NoOfRowsSpinner.set_value(PerCol);
     NoOfRowsSpinner.signal_changed().connect(sigc::mem_fun(*this, &TileDialog::on_col_spinbutton_changed));
-
-    NoOfRowsBox.pack_start(NoOfRowsSpinner, false, false, MARGIN);
     tips.set_tip(NoOfRowsSpinner, _("Number of rows"));
-
-
+    NoOfRowsBox.pack_start(NoOfRowsSpinner, false, false, MARGIN);
+    gtk_size_group_add_widget(_col1, (GtkWidget *) NoOfRowsBox.gobj());
 
     RowHeightButton.set_label(_("Equal height"));
     double AutoRow = prefs_get_double_attribute ("dialogs.gridtiler", "AutoRowSize", 15);
@@ -642,11 +654,7 @@ TileDialog::TileDialog()
     tips.set_tip(RowHeightButton, _("If not set, each row has the height of the tallest object in it"));
     RowHeightButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::on_RowSize_checkbutton_changed));
 
-
-
-
  {
-
         /*#### Radio buttons to control vertical alignment ####*/
 
         VertAlignLabel.set_label(_("Align:"));
@@ -654,15 +662,15 @@ TileDialog::TileDialog()
 
         VertTopRadioButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::VertAlign_changed));
         VertAlignGroup = VertTopRadioButton.get_group();
-        VertAlignVBox.pack_start(VertTopRadioButton, false, false, MARGIN);
+        VertAlignVBox.pack_start(VertTopRadioButton, false, false, 0);
 
         VertCentreRadioButton.set_group(VertAlignGroup);
         VertCentreRadioButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::VertAlign_changed));
-        VertAlignVBox.pack_start(VertCentreRadioButton, false, false, MARGIN);
+        VertAlignVBox.pack_start(VertCentreRadioButton, false, false, 0);
 
         VertBotRadioButton.set_group(VertAlignGroup);
         VertBotRadioButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::VertAlign_changed));
-        VertAlignVBox.pack_start(VertBotRadioButton, false, false, MARGIN);
+        VertAlignVBox.pack_start(VertBotRadioButton, false, false, 0);
 
         VertAlign = prefs_get_double_attribute ("dialogs.gridtiler", "VertAlign", 1);
         if (VertAlign == 0) {
@@ -682,11 +690,12 @@ TileDialog::TileDialog()
 
 
     /*#### Label for X ####*/
-    padXByYLabel.set_label("   ");
+    padXByYLabel.set_label(" ");
     XByYLabelVBox.pack_start(padXByYLabel, false, false, MARGIN);
-    XByYLabel.set_label(_(" X "));
+    XByYLabel.set_markup(" &#215; ");
     XByYLabelVBox.pack_start(XByYLabel, false, false, MARGIN);
     SpinsHBox.pack_start(XByYLabelVBox, false, false, MARGIN);
+    gtk_size_group_add_widget(_col2, (GtkWidget *) XByYLabelVBox.gobj());
 
     /*#### Number of columns ####*/
 
@@ -698,11 +707,9 @@ TileDialog::TileDialog()
     NoOfColsSpinner.set_range(1.0, 100.0);
     NoOfColsSpinner.set_value(PerRow);
     NoOfColsSpinner.signal_changed().connect(sigc::mem_fun(*this, &TileDialog::on_row_spinbutton_changed));
-
-    NoOfColsBox.pack_start(NoOfColsSpinner, false, false, MARGIN);
     tips.set_tip(NoOfColsSpinner, _("Number of columns"));
-
-
+    NoOfColsBox.pack_start(NoOfColsSpinner, false, false, MARGIN);
+    gtk_size_group_add_widget(_col3, (GtkWidget *) NoOfColsBox.gobj());
 
     ColumnWidthButton.set_label(_("Equal width"));
     double AutoCol = prefs_get_double_attribute ("dialogs.gridtiler", "AutoColSize", 15);
@@ -723,17 +730,21 @@ TileDialog::TileDialog()
         HorizAlignLabel.set_label(_("Align:"));
         HorizAlignVBox.pack_start(HorizAlignLabel, false, false, MARGIN);
 
+        HorizAlignHBox.pack_start(*(new Gtk::HBox()), true, true, 0); // centering strut
+
         HorizLeftRadioButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::HorizAlign_changed));
         HorizAlignGroup = HorizLeftRadioButton.get_group();
-        HorizAlignHBox.pack_start(HorizLeftRadioButton, false, false, MARGIN);
+        HorizAlignHBox.pack_start(HorizLeftRadioButton, false, false, 0);
 
         HorizCentreRadioButton.set_group(HorizAlignGroup);
         HorizCentreRadioButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::HorizAlign_changed));
-        HorizAlignHBox.pack_start(HorizCentreRadioButton, false, false, MARGIN);
+        HorizAlignHBox.pack_start(HorizCentreRadioButton, false, false, 0);
 
         HorizRightRadioButton.set_group(HorizAlignGroup);
         HorizRightRadioButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::HorizAlign_changed));
-        HorizAlignHBox.pack_start(HorizRightRadioButton, false, false, MARGIN);
+        HorizAlignHBox.pack_start(HorizRightRadioButton, false, false, 0);
+
+        HorizAlignHBox.pack_start(*(new Gtk::HBox()), true, true, 0); // centering strut
 
         HorizAlign = prefs_get_double_attribute ("dialogs.gridtiler", "HorizAlign", 1);
         if (HorizAlign == 0) {
@@ -753,16 +764,12 @@ TileDialog::TileDialog()
 
     TileBox.pack_start(SpinsHBox, false, false, MARGIN);
 
-
-
-
     {
         /*#### Radio buttons to control spacing manually or to fit selection bbox ####*/
         SpaceByBBoxRadioButton.set_label(_("Fit into selection box"));
         SpaceByBBoxRadioButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::Spacing_button_changed));
         SpacingGroup = SpaceByBBoxRadioButton.get_group();
 
-
         SpacingVBox.pack_start(SpaceByBBoxRadioButton, false, false, MARGIN);
 
         SpaceManualRadioButton.set_label(_("Set spacing:"));
@@ -770,74 +777,73 @@ TileDialog::TileDialog()
         SpaceManualRadioButton.signal_toggled().connect(sigc::mem_fun(*this, &TileDialog::Spacing_button_changed));
         SpacingVBox.pack_start(SpaceManualRadioButton, false, false, MARGIN);
 
-        double SpacingType = prefs_get_double_attribute ("dialogs.gridtiler", "SpacingType", 15);
-        if (SpacingType>0) {
-            ManualSpacing=true;
-            SpaceManualRadioButton.set_active(ManualSpacing);
-            SpaceByBBoxRadioButton.set_active(!ManualSpacing);
-        }
-        else {
-            ManualSpacing=false;
-            SpaceManualRadioButton.set_active(ManualSpacing);
-            SpaceByBBoxRadioButton.set_active(!ManualSpacing);
-        }
-
         TileBox.pack_start(SpacingVBox, false, false, MARGIN);
-
     }
 
     {
         /*#### Y Padding ####*/
 
-        YPadLabel.set_label(_("Row spacing:   "));
-        YPadBox.pack_start(YPadLabel, false, false, MARGIN);
+        GtkWidget *i = sp_icon_new (Inkscape::ICON_SIZE_MENU, "clonetiler_per_row");
+        YPadBox.pack_start (*(Glib::wrap(i)), false, false, MARGIN);
 
         YPadSpinner.set_digits(1);
         YPadSpinner.set_increments(0.2, 2);
-        YPadSpinner.set_range(0.0, 999.0);
+        YPadSpinner.set_range(-10000, 10000);
         double YPad = prefs_get_double_attribute ("dialogs.gridtiler", "YPad", 15);
         YPadSpinner.set_value(YPad);
-        YPadBox.pack_start(YPadSpinner, false, false, MARGIN);
-        tips.set_tip(YPadSpinner, _("Vertical spacing between rows"));
+        YPadBox.pack_start(YPadSpinner, true, true, MARGIN);
+        tips.set_tip(YPadSpinner, _("Vertical spacing between rows (px units)"));
         YPadSpinner.signal_changed().connect(sigc::mem_fun(*this, &TileDialog::on_ypad_spinbutton_changed));
+        gtk_size_group_add_widget(_col1, (GtkWidget *) YPadBox.gobj());
 
         SizesHBox.pack_start(YPadBox, false, false, MARGIN);
     }
 
+    {
+    Gtk::HBox *spacer = new Gtk::HBox;
+    SizesHBox.pack_start(*spacer, false, false, 0);
+    gtk_size_group_add_widget(_col2, (GtkWidget *) spacer->gobj());
+    }
+
     {
         /*#### X padding ####*/
 
-        XPadLabel.set_label(_("Column spacing:"));
-        XPadBox.pack_start(XPadLabel, false, false, MARGIN);
+        GtkWidget *i = sp_icon_new (Inkscape::ICON_SIZE_MENU, "clonetiler_per_column");
+        XPadBox.pack_start (*(Glib::wrap(i)), false, false, MARGIN);
 
         XPadSpinner.set_digits(1);
         XPadSpinner.set_increments(0.2, 2);
-        XPadSpinner.set_range(0.0, 999.0);
+        XPadSpinner.set_range(-10000, 10000);
         double XPad = prefs_get_double_attribute ("dialogs.gridtiler", "XPad", 15);
         XPadSpinner.set_value(XPad);
-        XPadBox.pack_start(XPadSpinner, false, false, MARGIN);
-        tips.set_tip(XPadSpinner, _("Horizontal spacing between columns"));
+        XPadBox.pack_start(XPadSpinner, true, true, MARGIN);
+        tips.set_tip(XPadSpinner, _("Horizontal spacing between columns (px units)"));
         XPadSpinner.signal_changed().connect(sigc::mem_fun(*this, &TileDialog::on_xpad_spinbutton_changed));
+        gtk_size_group_add_widget(_col3, (GtkWidget *) XPadBox.gobj());
 
         SizesHBox.pack_start(XPadBox, false, false, MARGIN);
     }
 
 
-
     TileBox.pack_start(SizesHBox, false, false, MARGIN);
 
     mainVBox->pack_start(TileBox);
 
+    double SpacingType = prefs_get_double_attribute ("dialogs.gridtiler", "SpacingType", 15);
+    if (SpacingType>0) {
+        ManualSpacing=true;
+    } else {
+        ManualSpacing=false;
+    }
+    SpaceManualRadioButton.set_active(ManualSpacing);
+    SpaceByBBoxRadioButton.set_active(!ManualSpacing);
+    SizesHBox.set_sensitive (ManualSpacing);
+
     //## The OK button
-    TileOkButton     = add_button(Gtk::Stock::OK,   GTK_RESPONSE_OK);
-    tips.set_tip((*TileOkButton), _("Arrange Objects"));
+    TileOkButton     = add_button(Gtk::Stock::APPLY,   GTK_RESPONSE_APPLY);
+    tips.set_tip((*TileOkButton), _("Arrange selected objects"));
 
     show_all_children();
-
-    //## Connect the signal
-    signal_response().connect(
-    sigc::mem_fun(*this, &TileDialog::responseCallback) );
-
 }
 
 
@@ -854,4 +860,16 @@ TileDialog::TileDialog()
 //#########################################################################
 
 
+/*
+  Local Variables:
+  mode:c++
+  c-file-style:"stroustrup"
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
+  indent-tabs-mode:nil
+  fill-column:99
+  End:
+*/
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+
+
 
