@@ -11,14 +11,11 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <math.h>
 
-#include <libnr/nr-matrix.h>
 #include <libnr/nr-pixops.h>
-
+#include "display-forward.h"
 #include "sp-canvas-util.h"
 #include "guideline.h"
-#include <libnr/nr-matrix-fns.h>
 
 static void sp_guideline_class_init(SPGuideLineClass *c);
 static void sp_guideline_init(SPGuideLine *guideline);
@@ -84,8 +81,7 @@ static void sp_guideline_render(SPCanvasItem *item, SPCanvasBuf *buf)
 {
     SPGuideLine const *gl = SP_GUIDELINE (item);
     
-    sp_canvas_buf_ensure_buf(buf);
-    buf->is_bg = FALSE;
+    sp_canvas_prepare_buffer(buf);
     
     unsigned int const r = NR_RGBA32_R (gl->rgba);
     unsigned int const g = NR_RGBA32_G (gl->rgba);
@@ -154,9 +150,9 @@ static double sp_guideline_point(SPCanvasItem *item, NR::Point p, SPCanvasItem *
     *actual_item = item;
 
     if (gl->vertical) {
-        return fabs(gl->position - p[NR::X]);
+        return MAX(fabs(gl->position - p[NR::X])-1, 0);
     } else {
-        return fabs(gl->position - p[NR::Y]);
+        return MAX(fabs(gl->position - p[NR::Y])-1, 0);
     }
 }
 
