@@ -19,20 +19,25 @@
 
 #include "nr-arena-item.h"
 
-struct _NRArenaGroup {
-	NRArenaItem item;
+NRType nr_arena_group_get_type (void);
+
+struct NRArenaGroup : public NRArenaItem{
 	unsigned int transparent : 1;
 	NRArenaItem *children;
 	NRArenaItem *last;
 	NRMatrix child_transform;
+
+	static NRArenaGroup *create(NRArena *arena) {
+		NRArenaGroup *obj=reinterpret_cast<NRArenaGroup *>(nr_object_new(NR_TYPE_ARENA_GROUP));
+		obj->init(arena);
+		return obj;
+	}
 };
 
-struct _NRArenaGroupClass {
+struct NRArenaGroupClass {
 	NRArenaItemClass parent_class;
 };
 
-NRType nr_arena_group_get_type (void);
-
 void nr_arena_group_set_transparent (NRArenaGroup *group, unsigned int transparent);
 
 void nr_arena_group_set_child_transform(NRArenaGroup *group, NR::Matrix const &t);
