@@ -20,9 +20,9 @@
 #include <libnr/nr-matrix.h>
 #include "nr-arena-item.h"
 
-struct _NRArenaImage {
-	NRArenaItem item;
+NRType nr_arena_image_get_type (void);
 
+struct NRArenaImage : public NRArenaItem {
 	unsigned char *px;
 	unsigned int pxw;
 	unsigned int pxh;
@@ -32,15 +32,19 @@ struct _NRArenaImage {
 	double width, height;
 
 	/* From GRID to PIXELS */
-	NRMatrix grid2px;
+	NR::Matrix grid2px;
+
+	static NRArenaImage *create(NRArena *arena) {
+		NRArenaImage *obj=reinterpret_cast<NRArenaImage *>(nr_object_new(NR_TYPE_ARENA_IMAGE));
+		obj->init(arena);
+		return obj;
+	}
 };
 
-struct _NRArenaImageClass {
+struct NRArenaImageClass {
 	NRArenaItemClass parent_class;
 };
 
-NRType nr_arena_image_get_type (void);
-
 void nr_arena_image_set_pixels (NRArenaImage *image, const unsigned char *px, unsigned int pxw, unsigned int pxh, unsigned int pxrs);
 void nr_arena_image_set_geometry (NRArenaImage *image, double x, double y, double width, double height);
 
