@@ -17,10 +17,6 @@
  * Here is GPL code, unlike other libnr wihich is public domain
  */
 
-#include <glib.h>
-
-
-
 #include <libnr/nr-gradient.h>
 
 /* Linear */
@@ -29,8 +25,8 @@ struct NRLGradientRenderer {
 	NRRenderer renderer;
 	const unsigned char *vector;
 	unsigned int spread;
-	int x0, y0;
-	float dx, dy;
+	double x0, y0;
+	double dx, dy;
 };
 
 NRRenderer *nr_lgradient_renderer_setup (NRLGradientRenderer *lgr,
