@@ -18,7 +18,7 @@
 /** \class SPDocument
  * SPDocument serves as the container of both model trees (agnostic XML
  * and typed object tree), and implements all of the document-level
- * functionality used by the program. Many document level operations, like 
+ * functionality used by the program. Many document level operations, like
  * load, save, print, export and so on, use SPDocument as their basic datatype.
  *
  * SPDocument implements undo and redo stacks and an id-based object
@@ -37,29 +37,24 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-#include <glib.h>
-#include <string.h>
 #include <gtk/gtkmain.h>
+#include "application/application.h"
+#include "application/editor.h"
 #include "libnr/nr-matrix-fns.h"
 #include "xml/repr.h"
-#include "xml/event-fns.h"
-#include "helper/sp-marshal.h"
 #include "helper/units.h"
-#include <glibmm/i18n.h>
 #include "inkscape-private.h"
 #include "inkscape_version.h"
 #include "sp-object-repr.h"
-#include "sp-item-group.h"
-#include "sp-root.h"
-#include "sp-namedview.h"
 #include "document-private.h"
-#include "version.h"
 #include "dir-util.h"
 #include "unit-constants.h"
+#include "prefs-utils.h"
+#include "libavoid/router.h"
+#include "libnr/nr-rect.h"
+#include "sp-item-group.h"
 
 #include "display/nr-arena-item.h"
-#include "display/nr-arena.h"
-#include "display/canvas-arena.h"
 
 #include "dialogs/rdf.h"
 
@@ -68,8 +63,6 @@
 
 #define SP_DOCUMENT_UPDATE_PRIORITY (G_PRIORITY_HIGH_IDLE - 1)
 
-#include <locale>
-#include <sstream>
 
 static gint sp_document_idle_handler(gpointer data);
 
@@ -96,6 +89,9 @@ SPDocument::SPDocument() {
 
     _collection_queue = NULL;
 
+    // Initialise instance of connector router.
+    router = new Avoid::Router();
+
     p = new SPDocumentPrivate();
 
     p->iddef = g_hash_table_new(g_direct_hash, g_direct_equal);
@@ -128,7 +124,7 @@ SPDocument::~SPDocument() {
 
         if (root) {
             sp_object_invoke_release(root);
-            g_object_unref(G_OBJECT(root));
+            sp_object_unref(root);
             root = NULL;
         }
 
@@ -166,11 +162,19 @@ SPDocument::~SPDocument() {
         modified_id = 0;
     }
 
+    _selection_changed_connection.disconnect();
+    _desktop_activated_connection.disconnect();
+
     if (keepalive) {
         inkscape_unref();
         keepalive = FALSE;
     }
 
+    if (router) {
+        delete router;
+        router = NULL;
+    }
+
     //delete this->_whiteboard_session_manager;
 }
 
@@ -195,6 +199,11 @@ void SPDocument::collectOrphans() {
     }
 }
 
+void SPDocument::reset_key (void *dummy)
+{
+    actionkey = NULL;
+}
+
 static SPDocument *
 sp_document_create(Inkscape::XML::Document *rdoc,
                    gchar const *uri,
@@ -236,31 +245,23 @@ sp_document_create(Inkscape::XML::Document *rdoc,
     sodipodi_version = SP_ROOT(document->root)->version.sodipodi;
 
     /* fixme: Not sure about this, but lets assume ::build updates */
-    sp_repr_set_attr(rroot, "sodipodi:version", SODIPODI_VERSION);
-    sp_repr_set_attr(rroot, "inkscape:version", INKSCAPE_VERSION);
+    rroot->setAttribute("sodipodi:version", SODIPODI_VERSION);
+    rroot->setAttribute("inkscape:version", INKSCAPE_VERSION);
     /* fixme: Again, I moved these here to allow version determining in ::build (Lauris) */
 
     /* Quick hack 2 - get default image size into document */
-    if (!rroot->attribute("width")) sp_repr_set_attr(rroot, "width", A4_WIDTH_STR);
-    if (!rroot->attribute("height")) sp_repr_set_attr(rroot, "height", A4_HEIGHT_STR);
+    if (!rroot->attribute("width")) rroot->setAttribute("width", A4_WIDTH_STR);
+    if (!rroot->attribute("height")) rroot->setAttribute("height", A4_HEIGHT_STR);
     /* End of quick hack 2 */
 
     /* Quick hack 3 - Set uri attributes */
     if (uri) {
         /* fixme: Think, what this means for images (Lauris) */
-        sp_repr_set_attr(rroot, "sodipodi:docname", uri);
+        rroot->setAttribute("sodipodi:docname", uri);
         if (document->base)
-            sp_repr_set_attr(rroot, "sodipodi:docbase", document->base);
+            rroot->setAttribute("sodipodi:docbase", document->base);
     }
     /* End of quick hack 3 */
-    /* between 0 and 0.25 */
-    if (sp_version_inside_range(sodipodi_version, 0, 0, 0, 25)) {
-        /* Clear ancient spec violating attributes */
-        sp_repr_set_attr(rroot, "SP-DOCNAME", NULL);
-        sp_repr_set_attr(rroot, "SP-DOCBASE", NULL);
-        sp_repr_set_attr(rroot, "docname", NULL);
-        sp_repr_set_attr(rroot, "docbase", NULL);
-    }
 
     // creating namedview
     if (!sp_item_group_get_child_by_name((SPGroup *) document->root, NULL, "sodipodi:namedview")) {
@@ -272,23 +273,23 @@ sp_document_create(Inkscape::XML::Document *rdoc,
         if (!r) {
             // if there's none, create an empty element
             rnew = sp_repr_new("sodipodi:namedview");
-            sp_repr_set_attr(rnew, "id", "base");
+            rnew->setAttribute("id", "base");
         } else {
             // otherwise, take from preferences
             rnew = r->duplicate();
         }
         // insert into the document
-        sp_repr_add_child(rroot, rnew, NULL);
+        rroot->addChild(rnew, NULL);
         // clean up
-        sp_repr_unref(rnew);
+        Inkscape::GC::release(rnew);
     }
 
     /* Defs */
     if (!SP_ROOT(document->root)->defs) {
         Inkscape::XML::Node *r;
         r = sp_repr_new("svg:defs");
-        sp_repr_add_child(rroot, r, NULL);
-        sp_repr_unref(r);
+        rroot->addChild(r, NULL);
+        Inkscape::GC::release(r);
         g_assert(SP_ROOT(document->root)->defs);
     }
 
@@ -302,11 +303,14 @@ sp_document_create(Inkscape::XML::Document *rdoc,
     sp_document_set_undo_sensitive(document, TRUE);
 
     // reset undo key when selection changes, so that same-key actions on different objects are not coalesced
-    if (INKSCAPE != NULL) {
+    if (!Inkscape::NSApplication::Application::getNewGui()) {
         g_signal_connect(G_OBJECT(INKSCAPE), "change_selection",
                          G_CALLBACK(sp_document_reset_key), document);
         g_signal_connect(G_OBJECT(INKSCAPE), "activate_desktop",
                          G_CALLBACK(sp_document_reset_key), document);
+    } else {
+        document->_selection_changed_connection = Inkscape::NSApplication::Editor::connectSelectionChanged (sigc::mem_fun (*document, &SPDocument::reset_key));
+        document->_desktop_activated_connection = Inkscape::NSApplication::Editor::connectDesktopActivated (sigc::mem_fun (*document, &SPDocument::reset_key));
     }
     inkscape_add_document(document);
 
@@ -314,7 +318,7 @@ sp_document_create(Inkscape::XML::Document *rdoc,
 }
 
 /**
- * Fetches document from URI, or creates new, if NULL; public document 
+ * Fetches document from URI, or creates new, if NULL; public document
  * appears in document list.
  */
 SPDocument *
@@ -429,7 +433,7 @@ sp_document_set_width (SPDocument *document, gdouble width, const SPUnit *unit)
 {
     SPRoot *root = SP_ROOT(document->root);
 
-    if (root->width.unit == SP_SVG_UNIT_PERCENT && root->viewBox_set) { // set to viewBox=
+    if (root->width.unit == SVGLength::PERCENT && root->viewBox_set) { // set to viewBox=
         root->viewBox.x1 = root->viewBox.x0 + sp_units_get_pixels (width, *unit);
     } else { // set to width=
         root->width.computed = sp_units_get_pixels (width, *unit);
@@ -437,10 +441,10 @@ sp_document_set_width (SPDocument *document, gdouble width, const SPUnit *unit)
          * cm when writing */
         if (!strcmp(unit->abbr, "m")) {
             root->width.value = 100*width;
-            root->width.unit = SP_SVG_UNIT_CM;
+            root->width.unit = SVGLength::CM;
         } else {
             root->width.value = width;
-            root->width.unit = (SPSVGLengthUnit) sp_unit_get_svg_unit(unit);
+            root->width.unit = (SVGLength::Unit) sp_unit_get_svg_unit(unit);
         }
     }
 
@@ -451,7 +455,7 @@ void sp_document_set_height (SPDocument * document, gdouble height, const SPUnit
 {
     SPRoot *root = SP_ROOT(document->root);
 
-    if (root->height.unit == SP_SVG_UNIT_PERCENT && root->viewBox_set) { // set to viewBox=
+    if (root->height.unit == SVGLength::PERCENT && root->viewBox_set) { // set to viewBox=
         root->viewBox.y1 = root->viewBox.y0 + sp_units_get_pixels (height, *unit);
     } else { // set to height=
         root->height.computed = sp_units_get_pixels (height, *unit);
@@ -459,10 +463,10 @@ void sp_document_set_height (SPDocument * document, gdouble height, const SPUnit
          * cm when writing */
         if (!strcmp(unit->abbr, "m")) {
             root->height.value = 100*height;
-            root->height.unit = SP_SVG_UNIT_CM;
+            root->height.unit = SVGLength::CM;
         } else {
             root->height.value = height;
-            root->height.unit = (SPSVGLengthUnit) sp_unit_get_svg_unit(unit);
+            root->height.unit = (SVGLength::Unit) sp_unit_get_svg_unit(unit);
         }
     }
 
@@ -478,6 +482,26 @@ gdouble sp_document_height(SPDocument *document)
     return SP_ROOT(document->root)->height.computed;
 }
 
+/**
+ * Given an NRRect that may, for example, correspond to the bbox of an object
+ * this function fits the canvas to that rect by resizing the canvas
+ * and translating the document root into position.
+ */
+void SPDocument::fitToRect(NRRect const & rect)
+{
+    g_return_if_fail(!empty(rect));
+    
+    gdouble w = rect.x1 - rect.x0;
+    gdouble h = rect.y1 - rect.y0;
+    gdouble old_height = sp_document_height(this);
+    SPUnit unit = sp_unit_get_by_id(SP_UNIT_PX);
+    sp_document_set_width(this, w, &unit);
+    sp_document_set_height(this, h, &unit);
+
+    NR::translate tr = NR::translate::translate(-rect.x0,-(rect.y0 + (h - old_height)));
+    static_cast<SPGroup *>(root)->translateChildItems(tr);
+}
+
 void sp_document_set_uri(SPDocument *document, gchar const *uri)
 {
     g_return_if_fail(document != NULL);
@@ -520,9 +544,9 @@ void sp_document_set_uri(SPDocument *document, gchar const *uri)
     gboolean saved = sp_document_get_undo_sensitive(document);
     sp_document_set_undo_sensitive(document, FALSE);
     if (document->base)
-        sp_repr_set_attr(repr, "sodipodi:docbase", document->base);
+        repr->setAttribute("sodipodi:docbase", document->base);
 
-    sp_repr_set_attr(repr, "sodipodi:docname", document->name);
+    repr->setAttribute("sodipodi:docname", document->name);
     sp_document_set_undo_sensitive(document, saved);
 
     document->priv->uri_set_signal.emit(document->uri);
@@ -649,6 +673,35 @@ SPObject *SPDocument::getObjectByRepr(Inkscape::XML::Node *repr) {
     return (SPObject*)g_hash_table_lookup(priv->reprdef, repr);
 }
 
+Glib::ustring SPDocument::getLanguage() {
+    gchar const *document_language = rdf_get_work_entity(this, rdf_find_entity("language"));
+    if (document_language) {
+        while (isspace(*document_language))
+            document_language++;
+    }
+    if ( !document_language || 0 == *document_language) {
+        // retrieve system language
+        document_language = getenv("LC_ALL");
+        if ( NULL == document_language || *document_language == 0 ) {
+            document_language = getenv ("LC_MESSAGES");
+        }
+        if ( NULL == document_language || *document_language == 0 ) {
+            document_language = getenv ("LANG");
+        }
+        
+        if ( NULL != document_language ) {
+            gchar *pos = strchr(document_language, '_');
+            if ( NULL != pos ) {
+                return Glib::ustring(document_language, pos - document_language);
+            }
+        }
+    }
+
+    if ( NULL == document_language )
+        return Glib::ustring();
+    return document_language;
+}
+
 /* Object modification root handler */
 
 void
@@ -744,54 +797,31 @@ sp_document_idle_handler(gpointer data)
     return repeat;
 }
 
-static int
-is_within(NRRect const *area, NRRect const *box)
+static bool is_within(NR::Rect const &area, NR::Rect const &box)
 {
-    if (box->x0 > box->x1 || box->y0 > box->y1) // invalid (=empty) bbox, may happen e.g. with a whitespace-only text object
-        return false;
-
-    return (box->x0 > area->x0) && (box->x1 < area->x1)
-        && (box->y0 > area->y0) && (box->y1 < area->y1);
+    return area.contains(box);
 }
 
-static int
-overlaps(NRRect const *area, NRRect const *box)
+static bool overlaps(NR::Rect const &area, NR::Rect const &box)
 {
-    if (box->x0 > box->x1 || box->y0 > box->y1) // invalid (=empty) bbox, may happen e.g. with a whitespace-only text object
-        return false;
-
-    /* FIXME: The below looks suspicious: it tests whether area's border overlaps box rather than
-     * whether area's inside overlaps box's inside.  E.g. if box fits entirely within area then it
-     * returns false.
-     *
-     * If this is the intended behaviour, then it should be documented (both here and in the
-     * caller).
-     *
-     * Otherwise, consider replacing this function body with a call to nr_rect_d_test_intersect.
-     */
-    return (((area->x0 > box->x0) && (area->x0 < box->x1)) ||
-            ((area->x1 > box->x0) && (area->x1 < box->x1))   ) &&
-           (((area->y0 > box->y0) && (area->y0 < box->y1)) ||
-            ((area->y1 > box->y0) && (area->y1 < box->y1))   );
+    return area.intersects(box);
 }
 
-static GSList *
-find_items_in_area(GSList *s, SPGroup *group, unsigned int dkey, NRRect const *area,
-                   int (*test)(NRRect const *, NRRect const *), bool take_insensitive = false)
+static GSList *find_items_in_area(GSList *s, SPGroup *group, unsigned int dkey, NR::Rect const &area,
+                                  bool (*test)(NR::Rect const &, NR::Rect const &), bool take_insensitive = false)
 {
     g_return_val_if_fail(SP_IS_GROUP(group), s);
 
     for (SPObject *o = sp_object_first_child(SP_OBJECT(group)) ; o != NULL ; o = SP_OBJECT_NEXT(o) ) {
-        if (!SP_IS_ITEM(o)) continue;
-        if (SP_IS_GROUP(o) &&
-            SP_GROUP(o)->effectiveLayerMode(dkey) == SPGroup::LAYER )
-        {
+        if (!SP_IS_ITEM(o)) {
+            continue;
+        }
+        if (SP_IS_GROUP(o) && SP_GROUP(o)->effectiveLayerMode(dkey) == SPGroup::LAYER ) {
             s = find_items_in_area(s, SP_GROUP(o), dkey, area, test);
         } else {
             SPItem *child = SP_ITEM(o);
-            NRRect box;
-            sp_item_bbox_desktop(child, &box);
-            if (test(area, &box) && (take_insensitive || child->isVisibleAndUnlocked(dkey))) {
+            NR::Rect box = sp_item_bbox_desktop(child);
+            if (test(area, box) && (take_insensitive || child->isVisibleAndUnlocked(dkey))) {
                 s = g_slist_append(s, child);
             }
         }
@@ -800,8 +830,6 @@ find_items_in_area(GSList *s, SPGroup *group, unsigned int dkey, NRRect const *a
     return s;
 }
 
-extern gdouble nr_arena_global_delta;
-
 /**
 Returns true if an item is among the descendants of group (recursively).
  */
@@ -827,13 +855,15 @@ sp_document_item_from_list_at_point_bottom(unsigned int dkey, SPGroup *group, GS
 {
     g_return_val_if_fail(group, NULL);
 
+    gdouble delta = prefs_get_double_attribute ("options.cursortolerance", "value", 1.0);
+
     for (SPObject *o = sp_object_first_child(SP_OBJECT(group)) ; o != NULL ; o = SP_OBJECT_NEXT(o) ) {
 
         if (!SP_IS_ITEM(o)) continue;
 
         SPItem *item = SP_ITEM(o);
         NRArenaItem *arenaitem = sp_item_get_arenaitem(item, dkey);
-        if (nr_arena_item_invoke_pick(arenaitem, p, nr_arena_global_delta, 1) != NULL
+        if (arenaitem && nr_arena_item_invoke_pick(arenaitem, p, delta, 1) != NULL
             && (take_insensitive || item->isVisibleAndUnlocked(dkey))) {
             if (g_slist_find((GSList *) list, item) != NULL)
                 return item;
@@ -862,6 +892,8 @@ find_item_at_point(unsigned int dkey, SPGroup *group, NR::Point const p, gboolea
 {
     SPItem *seen = NULL, *newseen = NULL;
 
+    gdouble delta = prefs_get_double_attribute ("options.cursortolerance", "value", 1.0);
+
     for (SPObject *o = sp_object_first_child(SP_OBJECT(group)) ; o != NULL ; o = SP_OBJECT_NEXT(o) ) {
         if (!SP_IS_ITEM(o)) continue;
 
@@ -884,7 +916,7 @@ find_item_at_point(unsigned int dkey, SPGroup *group, NR::Point const p, gboolea
             NRArenaItem *arenaitem = sp_item_get_arenaitem(child, dkey);
 
             // seen remembers the last (topmost) of items pickable at this point
-            if (nr_arena_item_invoke_pick(arenaitem, p, nr_arena_global_delta, 1) != NULL
+            if (arenaitem && nr_arena_item_invoke_pick(arenaitem, p, delta, 1) != NULL
                 && (take_insensitive || child->isVisibleAndUnlocked(dkey))) {
                 seen = child;
             }
@@ -902,6 +934,8 @@ find_group_at_point(unsigned int dkey, SPGroup *group, NR::Point const p)
 {
     SPItem *seen = NULL;
 
+    gdouble delta = prefs_get_double_attribute ("options.cursortolerance", "value", 1.0);
+
     for (SPObject *o = sp_object_first_child(SP_OBJECT(group)) ; o != NULL ; o = SP_OBJECT_NEXT(o) ) {
         if (!SP_IS_ITEM(o)) continue;
         if (SP_IS_GROUP(o) && SP_GROUP(o)->effectiveLayerMode(dkey) == SPGroup::LAYER) {
@@ -915,7 +949,7 @@ find_group_at_point(unsigned int dkey, SPGroup *group, NR::Point const p)
             NRArenaItem *arenaitem = sp_item_get_arenaitem(child, dkey);
 
             // seen remembers the last (topmost) of groups pickable at this point
-            if (nr_arena_item_invoke_pick(arenaitem, p, nr_arena_global_delta, 1) != NULL) {
+            if (arenaitem && nr_arena_item_invoke_pick(arenaitem, p, delta, 1) != NULL) {
                 seen = child;
             }
         }
@@ -930,15 +964,12 @@ find_group_at_point(unsigned int dkey, SPGroup *group, NR::Point const p)
  *
  */
 
-GSList *
-sp_document_items_in_box(SPDocument *document, unsigned int dkey, NRRect const *box)
+GSList *sp_document_items_in_box(SPDocument *document, unsigned int dkey, NR::Rect const &box)
 {
     g_return_val_if_fail(document != NULL, NULL);
     g_return_val_if_fail(document->priv != NULL, NULL);
-    g_return_val_if_fail(box != NULL, NULL);
 
-    return find_items_in_area(NULL, SP_GROUP(document->root),
-                              dkey, box, is_within);
+    return find_items_in_area(NULL, SP_GROUP(document->root), dkey, box, is_within);
 }
 
 /*
@@ -948,15 +979,12 @@ sp_document_items_in_box(SPDocument *document, unsigned int dkey, NRRect const *
  *
  */
 
-GSList *
-sp_document_partial_items_in_box(SPDocument *document, unsigned int dkey, NRRect const *box)
+GSList *sp_document_partial_items_in_box(SPDocument *document, unsigned int dkey, NR::Rect const &box)
 {
     g_return_val_if_fail(document != NULL, NULL);
     g_return_val_if_fail(document->priv != NULL, NULL);
-    g_return_val_if_fail(box != NULL, NULL);
 
-    return find_items_in_area(NULL, SP_GROUP(document->root),
-                              dkey, box, overlaps);
+    return find_items_in_area(NULL, SP_GROUP(document->root), dkey, box, overlaps);
 }
 
 SPItem *
@@ -1018,6 +1046,9 @@ sp_document_remove_resource(SPDocument *document, gchar const *key, SPObject *ob
     g_return_val_if_fail(object != NULL, FALSE);
     g_return_val_if_fail(SP_IS_OBJECT(object), FALSE);
 
+    if (SP_OBJECT_IS_CLONED(object))
+        return FALSE;
+
     rlist = (GSList*)g_hash_table_lookup(document->priv->resources, key);
     g_return_val_if_fail(rlist != NULL, FALSE);
     g_return_val_if_fail(g_slist_find(rlist, object), FALSE);
