@@ -862,7 +862,7 @@ void NodeImpl::setNodeName(const DOMString &qualifiedName)
             }
         else
             {
-            localName.push_back(ch);
+            localName.push_back((XMLCh)ch);
             }
         }
 }
@@ -927,12 +927,30 @@ DOMString NodeImpl::lookupNamespacePrefix(const DOMString &theNamespaceURI,
 /**
  *
  */
-NodeImpl::NodeImpl()
+NodeImpl::NodeImpl() : Node()
 {
     init();
 }
 
 
+/**
+ *
+ */
+NodeImpl::NodeImpl(const NodeImpl &other) : Node()
+{
+    init();
+    assign(other);
+}
+
+/**
+ *
+ */
+NodeImpl &NodeImpl::operator=(const NodeImpl &other)
+{
+    init();
+    assign(other);
+    return *this;
+}
 
 
 /**
