@@ -34,7 +34,7 @@
 #include "events.h"
 #include "traversal.h"
 
-#include "domstream.h"
+#include "io/domstream.h"
 
 namespace org
 {
@@ -52,10 +52,10 @@ namespace ls
 //use our own class which is designed to be a bit similar to
 //java.io streams
 
-typedef dom::InputStream  LSInputStream;
-typedef dom::OutputStream LSOutputStream;
-typedef dom::Reader       LSReader;
-typedef dom::Writer       LSWriter;
+typedef dom::io::InputStream  LSInputStream;
+typedef dom::io::OutputStream LSOutputStream;
+typedef dom::io::Reader       LSReader;
+typedef dom::io::Writer       LSWriter;
 
 
 //local definitions
