@@ -1,4 +1,4 @@
-/** \file 
+/** \file
  * Anchors implementation.
  */
 
@@ -12,17 +12,12 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <gtk/gtktypeutils.h>
 
 #include "draw-anchor.h"
-#include "desktop-affine.h"
+#include "desktop.h"
 #include "desktop-handles.h"
 #include "event-context.h"
 #include "display/sodipodi-ctrl.h"
-#include "display/sp-canvas.h"
-#include <glibmm/i18n.h>
-#include "libnr/nr-point-fns.h"
-#include "libnr/nr-point-ops.h"
 
 /**
  * Creates an anchor object and initializes it.
@@ -39,7 +34,7 @@ sp_draw_anchor_new(SPDrawContext *dc, SPCurve *curve, gboolean start, NR::Point
     a->start = start;
     a->active = FALSE;
     a->dp = delta;
-    a->ctrl = sp_canvas_item_new(SP_DT_CONTROLS(dt), SP_TYPE_CTRL,
+    a->ctrl = sp_canvas_item_new(sp_desktop_controls(dt), SP_TYPE_CTRL,
                                  "size", 6.0,
                                  "filled", 0,
                                  "fill_color", 0xff00007f,
@@ -68,7 +63,7 @@ sp_draw_anchor_destroy(SPDrawAnchor *anchor)
 #define A_SNAP 4.0
 
 /**
- * Test if point is near anchor, if so fill anchor on canvas and return 
+ * Test if point is near anchor, if so fill anchor on canvas and return
  * pointer to it or NULL.
  */
 SPDrawAnchor *
@@ -76,7 +71,7 @@ sp_draw_anchor_test(SPDrawAnchor *anchor, NR::Point w, gboolean activate)
 {
     SPDesktop *dt = SP_EVENT_CONTEXT_DESKTOP(anchor->dc);
 
-    if ( activate && ( NR::LInfty( w - sp_desktop_d2w_xy_point(dt, anchor->dp) ) <= A_SNAP ) ) {
+    if ( activate && ( NR::LInfty( w - dt->d2w(anchor->dp) ) <= A_SNAP ) ) {
         if (!anchor->active) {
             sp_canvas_item_set((GtkObject *) anchor->ctrl, "filled", TRUE, NULL);
             anchor->active = TRUE;
