@@ -18,14 +18,9 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-#include <math.h>
-#include <string.h>
-#include <glib.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtksignal.h>
 
 #include "display/canvas-bpath.h"
-#include "display/sp-canvas.h"
 #include "xml/repr.h"
 #include "svg/svg.h"
 #include <glibmm/i18n.h>
@@ -36,7 +31,6 @@
 #include "desktop-style.h"
 #include "document.h"
 #include "draw-anchor.h"
-#include "draw-context.h"
 #include "macros.h"
 #include "message-stack.h"
 #include "pen-context.h"
@@ -45,7 +39,7 @@
 #include "selection-chemistry.h"
 #include "snap.h"
 #include "sp-path.h"
-
+#include "sp-namedview.h"
 
 static void sp_draw_context_class_init(SPDrawContextClass *klass);
 static void sp_draw_context_init(SPDrawContext *dc);
@@ -156,7 +150,7 @@ sp_draw_context_setup(SPEventContext *ec)
         ((SPEventContextClass *) draw_parent_class)->setup(ec);
     }
 
-    dc->selection = SP_DT_SELECTION(dt);
+    dc->selection = sp_desktop_selection(dt);
 
     /* Connect signals to track selection changes */
     dc->sel_changed_connection = dc->selection->connectChanged(
@@ -167,13 +161,13 @@ sp_draw_context_setup(SPEventContext *ec)
     );
 
     /* Create red bpath */
-    dc->red_bpath = sp_canvas_bpath_new(SP_DT_SKETCH(ec->desktop), NULL);
+    dc->red_bpath = sp_canvas_bpath_new(sp_desktop_sketch(ec->desktop), NULL);
     sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(dc->red_bpath), dc->red_color, 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
     /* Create red curve */
     dc->red_curve = sp_curve_new_sized(4);
 
     /* Create blue bpath */
-    dc->blue_bpath = sp_canvas_bpath_new(SP_DT_SKETCH(ec->desktop), NULL);
+    dc->blue_bpath = sp_canvas_bpath_new(sp_desktop_sketch(ec->desktop), NULL);
     sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(dc->blue_bpath), dc->blue_color, 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
     /* Create blue curve */
     dc->blue_curve = sp_curve_new_sized(8);
@@ -224,7 +218,7 @@ sp_draw_context_root_handler(SPEventContext *ec, GdkEvent *event)
         case GDK_KEY_PRESS:
             switch (get_group0_keyval (&event->key)) {
                 case GDK_Escape:
-                    SP_DT_SELECTION(desktop)->clear();
+                    sp_desktop_selection(desktop)->clear();
                     ret = TRUE;
                     break;
                 case GDK_Tab: // Tab - cycle selection forward
@@ -307,14 +301,14 @@ spdc_attach_selection(SPDrawContext *dc, Inkscape::Selection *sel)
         SPCurve *norm = sp_shape_get_curve(SP_SHAPE(item));
         sp_curve_transform(norm, sp_item_i2d_affine(dc->white_item));
         g_return_if_fail( norm != NULL );
-        dc->white_curves = sp_curve_split(norm);
+        dc->white_curves = g_slist_reverse(sp_curve_split(norm));
         sp_curve_unref(norm);
         /* Anchor list */
         for (GSList *l = dc->white_curves; l != NULL; l = l->next) {
             SPCurve *c;
             c = (SPCurve*)l->data;
             g_return_if_fail( c->end > 1 );
-            if ( c->bpath->code == NR_MOVETO_OPEN ) {
+            if ( SP_CURVE_BPATH(c)->code == NR_MOVETO_OPEN ) {
                 NArtBpath *s, *e;
                 SPDrawAnchor *a;
                 s = sp_curve_first_bpath(c);
@@ -331,58 +325,72 @@ spdc_attach_selection(SPDrawContext *dc, Inkscape::Selection *sel)
 
 
 /**
-\brief  Snaps node or handle to PI/rotationsnapsperpi degree increments
-\param dc  draw context
-\param p  cursor point (to be changed by snapping)
-\param o  origin point
-\param state  keyboard state to check if ctrl was pressed
+ *  Snaps node or handle to PI/rotationsnapsperpi degree increments.
+ *
+ *  \param dc draw context
+ *  \param p cursor point (to be changed by snapping)
+ *  \param o origin point
+ *  \param state  keyboard state to check if ctrl was pressed
 */
-void
-spdc_endpoint_snap_internal(SPEventContext const *const ec, NR::Point &p, NR::Point const o, guint const state)
+
+void spdc_endpoint_snap_rotation(SPEventContext const *const ec, NR::Point &p, NR::Point const o,
+                                 guint state)
 {
-    if ( state & GDK_CONTROL_MASK ) {
-        /* Constrained motion */
+    /* Control must be down for this snap to work */
+    if ((state & GDK_CONTROL_MASK) == 0) {
+        return;
+    }
 
-        unsigned snaps = abs(prefs_get_int_attribute("options.rotationsnapsperpi", "value", 12));
-        /* 0 means no snapping. */
+    unsigned const snaps = abs(prefs_get_int_attribute("options.rotationsnapsperpi", "value", 12));
+    /* 0 means no snapping. */
 
-        /* mirrored by fabs, so this corresponds to 15 degrees */
-        NR::Point best; /* best solution */
-        double bn = 1e18; /* best normal */
-        double bdot = 0;
-        NR::Point v = NR::Point(0, 1);
-        double const r00 = cos( M_PI / snaps ), r01 = sin( M_PI / snaps );
-        double const r10 = -r01, r11 = r00;
+    /* mirrored by fabs, so this corresponds to 15 degrees */
+    NR::Point best; /* best solution */
+    double bn = NR_HUGE; /* best normal */
+    double bdot = 0;
+    NR::Point v = NR::Point(0, 1);
+    double const r00 = cos(M_PI / snaps), r01 = sin(M_PI / snaps);
+    double const r10 = -r01, r11 = r00;
 
-        NR::Point delta = p - o;
+    NR::Point delta = p - o;
 
-        for (unsigned i = 0; i < snaps; i++) {
-            double const ndot = fabs(dot(v,NR::rot90(delta)));
-            NR::Point t(r00*v[NR::X] + r01*v[NR::Y],
-                        r10*v[NR::X] + r11*v[NR::Y]);
-            if ( ndot < bn ) {
-                /* I think it is better numerically to use the normal, rather than the dot product
-                 * to assess solutions, but I haven't proven it. */
-                bn = ndot;
-                best = v;
-                bdot = dot(v, delta);
-            }
-            v = t;
+    for (unsigned i = 0; i < snaps; i++) {
+        double const ndot = fabs(dot(v,NR::rot90(delta)));
+        NR::Point t(r00*v[NR::X] + r01*v[NR::Y],
+                    r10*v[NR::X] + r11*v[NR::Y]);
+        if (ndot < bn) {
+            /* I think it is better numerically to use the normal, rather than the dot product
+             * to assess solutions, but I haven't proven it. */
+            bn = ndot;
+            best = v;
+            bdot = dot(v, delta);
         }
+        v = t;
+    }
 
-        if ( fabs(bdot) > 0 ) {
-            p = o + bdot * best;
+    if (fabs(bdot) > 0) {
+        p = o + bdot * best;
 
-            /* Snap it along best vector */
-            namedview_vector_snap_all_types(SP_EVENT_CONTEXT_DESKTOP(ec)->namedview, p, best);
-        }
-    } else if ((state & GDK_SHIFT_MASK) == 0) {
-        /* Free */
-        namedview_free_snap_all_types(SP_EVENT_CONTEXT_DESKTOP(ec)->namedview, p);
+        /* Snap it along best vector */
+        SnapManager const &m = SP_EVENT_CONTEXT_DESKTOP(ec)->namedview->snap_manager;
+        p = m.constrainedSnap(Inkscape::Snapper::SNAP_POINT | Inkscape::Snapper::BBOX_POINT,
+                              p, Inkscape::Snapper::ConstraintLine(best), NULL).getPoint();
     }
 }
 
 
+void spdc_endpoint_snap_free(SPEventContext const * const ec, NR::Point& p, guint const state)
+{
+    /* Shift disables this snap */
+    if (state & GDK_SHIFT_MASK) {
+        return;
+    }
+
+    /* FIXME: this should be doing bbox snap as well */
+    SnapManager const &m = SP_EVENT_CONTEXT_DESKTOP(ec)->namedview->snap_manager;
+    p = m.freeSnap(Inkscape::Snapper::BBOX_POINT | Inkscape::Snapper::SNAP_POINT, p, NULL).getPoint();
+}
+
 static SPCurve *
 reverse_then_unref(SPCurve *orig)
 {
@@ -517,11 +525,11 @@ spdc_flush_white(SPDrawContext *dc, SPCurve *gc)
 
     /* Now we have to go back to item coordinates at last */
     sp_curve_transform(c, ( dc->white_item
-                            ? sp_item_dt2i_affine(dc->white_item, SP_EVENT_CONTEXT_DESKTOP(dc))
+                            ? sp_item_dt2i_affine(dc->white_item)
                             : sp_desktop_dt2root_affine(SP_EVENT_CONTEXT_DESKTOP(dc)) ));
 
     SPDesktop *desktop = SP_EVENT_CONTEXT_DESKTOP(dc);
-    SPDocument *doc = SP_DT_DOCUMENT(desktop);
+    SPDocument *doc = sp_desktop_document(desktop);
 
     if ( c && !sp_curve_empty(c) ) {
         /* We actually have something to write */
@@ -537,14 +545,14 @@ spdc_flush_white(SPDrawContext *dc, SPCurve *gc)
 
         gchar *str = sp_svg_write_path(SP_CURVE_BPATH(c));
         g_assert( str != NULL );
-        sp_repr_set_attr(repr, "d", str);
+        repr->setAttribute("d", str);
         g_free(str);
 
         if (!dc->white_item) {
             /* Attach repr */
             SPItem *item = SP_ITEM(desktop->currentLayer()->appendChildRepr(repr));
             dc->selection->set(repr);
-            sp_repr_unref(repr);
+            Inkscape::GC::release(repr);
             item->transform = i2i_affine(desktop->currentRoot(), desktop->currentLayer());
             item->updateRepr();
         }
