@@ -30,6 +30,10 @@
 #define SP_IS_DRAW_CONTEXT_CLASS(k) (GTK_CHECK_CLASS_TYPE((k), SP_TYPE_DRAW_CONTEXT))
 
 struct SPDrawAnchor;
+namespace Inkscape
+{
+  class Selection;
+}
 
 struct SPDrawContext : public SPEventContext{
     Inkscape::Selection *selection;
@@ -78,7 +82,8 @@ struct SPDrawContextClass : public SPEventContextClass{};
 GType sp_draw_context_get_type(void);
 SPDrawAnchor *spdc_test_inside(SPDrawContext *dc, NR::Point p);
 void spdc_concat_colors_and_flush(SPDrawContext *dc, gboolean forceclosed);
-void spdc_endpoint_snap_internal(SPEventContext const *ec, NR::Point &p, NR::Point const o, guint state);
+void spdc_endpoint_snap_rotation(SPEventContext const *const ec, NR::Point &p, NR::Point const o, guint state);
+void spdc_endpoint_snap_free(SPEventContext const *ec, NR::Point &p, guint state);
 
 
 #endif
