@@ -18,34 +18,19 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-/*
- * TODO: Tue Oct  2 22:57:15 2001
- *  - Decide control point behavior when use_calligraphic==1.
- *  - Decide to use NORMALIZED_COORDINATE or not.
- *  - Bug fix.
- */
-
 #define noDYNA_DRAW_VERBOSE
 
 #include "config.h"
 
-#include <math.h>
-#include <string.h>
-#include <glib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "svg/svg.h"
-#include <glibmm/i18n.h>
-#include "display/curve.h"
 #include "display/canvas-bpath.h"
-#include "display/sodipodi-ctrl.h"
 #include "display/bezier-utils.h"
 
+#include <glib/gmem.h>
 #include "macros.h"
-#include "enums.h"
-#include "mod360.h"
-#include "inkscape.h"
 #include "document.h"
 #include "selection.h"
 #include "desktop.h"
@@ -54,17 +39,17 @@
 #include "desktop-affine.h"
 #include "desktop-style.h"
 #include "message-context.h"
-#include "snap.h"
 #include "pixmaps/cursor-calligraphy.xpm"
-#include "widgets/desktop-widget.h"
 #include "dyna-draw-context.h"
-#include "widgets/spw-utilities.h"
 #include "libnr/n-art-bpath.h"
-#include "libnr/nr-point-fns.h"
+#include "libnr/nr-path.h"
 #include "xml/repr.h"
+#include "context-fns.h"
+#include "sp-item.h"
+#include "inkscape.h"
+#include "color.h"
 
 #define DDC_RED_RGBA 0xff0000ff
-#define DDC_GREEN_RGBA 0x000000ff
 
 #define SAMPLE_TIMEOUT 10
 #define TOLERANCE_LINE 1.0
@@ -87,17 +72,14 @@ static gint sp_dyna_draw_context_root_handler(SPEventContext *ec, GdkEvent *even
 
 static void clear_current(SPDynaDrawContext *dc);
 static void set_to_accumulated(SPDynaDrawContext *dc);
-static void concat_current_line(SPDynaDrawContext *dc);
 static void accumulate_calligraphic(SPDynaDrawContext *dc);
 
 static void fit_and_split(SPDynaDrawContext *ddc, gboolean release);
-static void fit_and_split_line(SPDynaDrawContext *ddc, gboolean release);
 static void fit_and_split_calligraphics(SPDynaDrawContext *ddc, gboolean release);
 
 static void sp_dyna_draw_reset(SPDynaDrawContext *ddc, NR::Point p);
 static NR::Point sp_dyna_draw_get_npoint(SPDynaDrawContext const *ddc, NR::Point v);
 static NR::Point sp_dyna_draw_get_vpoint(SPDynaDrawContext const *ddc, NR::Point n);
-static NR::Point sp_dyna_draw_get_curr_vpoint(SPDynaDrawContext const *ddc);
 static void draw_temporary_box(SPDynaDrawContext *dc);
 
 
@@ -146,7 +128,7 @@ sp_dyna_draw_context_init(SPDynaDrawContext *ddc)
     event_context->cursor_shape = cursor_calligraphy_xpm;
     event_context->hot_x = 4;
     event_context->hot_y = 4;
-    
+
     ddc->accumulated = NULL;
     ddc->segments = NULL;
     ddc->currentcurve = NULL;
@@ -165,11 +147,7 @@ sp_dyna_draw_context_init(SPDynaDrawContext *ddc)
     ddc->del = NR::Point(0,0);
 
     /* attributes */
-    ddc->use_timeout = FALSE;
-    ddc->use_calligraphic = TRUE;
-    ddc->timer_id = 0;
     ddc->dragging = FALSE;
-    ddc->dynahand = FALSE;
 
     ddc->mass = 0.3;
     ddc->drag = DRAG_DEFAULT;
@@ -178,6 +156,9 @@ sp_dyna_draw_context_init(SPDynaDrawContext *ddc)
 
     ddc->vel_thin = 0.1;
     ddc->flatness = 0.9;
+
+    ddc->abs_width = false;
+    ddc->keep_selected = true;
 }
 
 static void
@@ -224,8 +205,7 @@ sp_dyna_draw_context_setup(SPEventContext *ec)
     ddc->cal1 = sp_curve_new_sized(32);
     ddc->cal2 = sp_curve_new_sized(32);
 
-    /* style should be changed when dc->use_calligraphc is touched */
-    ddc->currentshape = sp_canvas_item_new(SP_DT_SKETCH(ec->desktop), SP_TYPE_CANVAS_BPATH, NULL);
+    ddc->currentshape = sp_canvas_item_new(sp_desktop_sketch(ec->desktop), SP_TYPE_CANVAS_BPATH, NULL);
     sp_canvas_bpath_set_fill(SP_CANVAS_BPATH(ddc->currentshape), DDC_RED_RGBA, SP_WIND_RULE_EVENODD);
     sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(ddc->currentshape), 0x00000000, 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
     /* fixme: Cannot we cascade it to root more clearly? */
@@ -236,9 +216,12 @@ sp_dyna_draw_context_setup(SPEventContext *ec)
     sp_event_context_read(ec, "angle");
     sp_event_context_read(ec, "width");
     sp_event_context_read(ec, "thinning");
+    sp_event_context_read(ec, "tremor");
     sp_event_context_read(ec, "flatness");
     sp_event_context_read(ec, "usepressure");
     sp_event_context_read(ec, "usetilt");
+    sp_event_context_read(ec, "abs_width");
+    sp_event_context_read(ec, "keep_selected");
 
     ddc->is_drawing = false;
 
@@ -265,6 +248,9 @@ sp_dyna_draw_context_set(SPEventContext *ec, gchar const *key, gchar const *val)
     } else if (!strcmp(key, "thinning")) {
         double const dval = ( val ? g_ascii_strtod (val, NULL) : 0.1 );
         ddc->vel_thin = CLAMP(dval, -1.0, 1.0);
+    } else if (!strcmp(key, "tremor")) {
+        double const dval = ( val ? g_ascii_strtod (val, NULL) : 0.0 );
+        ddc->tremor = CLAMP(dval, 0.0, 1.0);
     } else if (!strcmp(key, "flatness")) {
         double const dval = ( val ? g_ascii_strtod (val, NULL) : 1.0 );
         ddc->flatness = CLAMP(dval, 0, 1.0);
@@ -272,6 +258,10 @@ sp_dyna_draw_context_set(SPEventContext *ec, gchar const *key, gchar const *val)
         ddc->usepressure = (val && strcmp(val, "0"));
     } else if (!strcmp(key, "usetilt")) {
         ddc->usetilt = (val && strcmp(val, "0"));
+    } else if (!strcmp(key, "abs_width")) {
+        ddc->abs_width = (val && strcmp(val, "0"));
+    } else if (!strcmp(key, "keep_selected")) {
+        ddc->keep_selected = (val && strcmp(val, "0"));
     }
 
     //g_print("DDC: %g %g %g %g\n", ddc->mass, ddc->drag, ddc->angle, ddc->width);
@@ -287,29 +277,18 @@ flerp(double f0, double f1, double p)
 static NR::Point
 sp_dyna_draw_get_npoint(SPDynaDrawContext const *dc, NR::Point v)
 {
-    NRRect drect;
-    SP_EVENT_CONTEXT(dc)->desktop->get_display_area(&drect);
-    double max = MAX (( drect.x1 - drect.x0 ), ( drect.y1 - drect.y0 ));
-    return NR::Point(( v[NR::X] - drect.x0 ) / max,  ( v[NR::Y] - drect.y0 ) / max);
+    NR::Rect drect = SP_EVENT_CONTEXT(dc)->desktop->get_display_area();
+    double const max = MAX ( drect.dimensions()[NR::X], drect.dimensions()[NR::Y] );
+    return NR::Point(( v[NR::X] - drect.min()[NR::X] ) / max,  ( v[NR::Y] - drect.min()[NR::Y] ) / max);
 }
 
 /* Get view point */
 static NR::Point
 sp_dyna_draw_get_vpoint(SPDynaDrawContext const *dc, NR::Point n)
 {
-    NRRect drect;
-    SP_EVENT_CONTEXT(dc)->desktop->get_display_area(&drect);
-    double max = MAX (( drect.x1 - drect.x0 ), ( drect.y1 - drect.y0 ));
-    return NR::Point(n[NR::X] * max + drect.x0, n[NR::Y] * max + drect.y0);
-}
-
-/* Get current view point */
-static NR::Point sp_dyna_draw_get_curr_vpoint(SPDynaDrawContext const *dc)
-{
-    NRRect drect;
-    SP_EVENT_CONTEXT(dc)->desktop->get_display_area(&drect);
-    double max = MAX (( drect.x1 - drect.x0 ), ( drect.y1 - drect.y0 ));
-    return NR::Point(dc->cur[NR::X] * max + drect.x0, dc->cur[NR::Y] * max + drect.y0);
+    NR::Rect drect = SP_EVENT_CONTEXT(dc)->desktop->get_display_area();
+    double const max = MAX ( drect.dimensions()[NR::X], drect.dimensions()[NR::Y] );
+    return NR::Point(n[NR::X] * max + drect.min()[NR::X], n[NR::Y] * max + drect.min()[NR::Y]);
 }
 
 static void
@@ -425,71 +404,63 @@ sp_dyna_draw_brush(SPDynaDrawContext *dc)
 {
     g_assert( dc->npoints >= 0 && dc->npoints < SAMPLING_SIZE );
 
-    if (dc->use_calligraphic) {
-        /* calligraphics */
+    // How much velocity thins strokestyle
+    double vel_thin = flerp (0, 160, dc->vel_thin);
 
-        // How much velocity thins strokestyle
-        double vel_thin = flerp (0, 160, dc->vel_thin);
+    // Influence of pressure on thickness
+    double pressure_thick = (dc->usepressure ? dc->pressure : 1.0);
 
-        // Influence of pressure on thickness
-        double pressure_thick = (dc->usepressure ? dc->pressure : 1.0);
+    double width = ( pressure_thick - vel_thin * NR::L2(dc->vel) ) * dc->width;
 
-        double width = ( pressure_thick - vel_thin * NR::L2(dc->vel) ) * dc->width;
-        if ( width < 0.02 * dc->width ) {
-            width = 0.02 * dc->width;
-        }
+    double tremble_left = 0, tremble_right = 0;
+    if (dc->tremor > 0) {
+        // obtain two normally distributed random variables, using polar Box-Muller transform
+        double x1, x2, w, y1, y2;
+        do {
+            x1 = 2.0 * g_random_double_range(0,1) - 1.0;
+            x2 = 2.0 * g_random_double_range(0,1) - 1.0;
+            w = x1 * x1 + x2 * x2;
+        } while ( w >= 1.0 );
+        w = sqrt( (-2.0 * log( w ) ) / w );
+        y1 = x1 * w;
+        y2 = x2 * w;
 
-        NR::Point del = 0.05 * width * dc->ang;
-
-        dc->point1[dc->npoints] = sp_dyna_draw_get_vpoint(dc, dc->cur + del);
-        dc->point2[dc->npoints] = sp_dyna_draw_get_vpoint(dc, dc->cur - del);
-
-        dc->del = del;
-    } else {
-        dc->point1[dc->npoints] = sp_dyna_draw_get_curr_vpoint(dc);
+        // deflect both left and right edges randomly and independently, so that:
+        // (1) dc->tremor=1 corresponds to sigma=1, decreasing dc->tremor narrows the bell curve;
+        // (2) deflection depends on width, but is upped for small widths for better visual uniformity across widths;
+        // (3) deflection somewhat depends on speed, to prevent fast strokes looking
+        // comparatively smooth and slow ones excessively jittery
+        tremble_left  = (y1)*dc->tremor * (0.15 + 0.8*width) * (0.35 + 14*NR::L2(dc->vel));
+        tremble_right = (y2)*dc->tremor * (0.15 + 0.8*width) * (0.35 + 14*NR::L2(dc->vel));
     }
 
+    if ( width < 0.02 * dc->width ) {
+        width = 0.02 * dc->width;
+    }
+
+    double dezoomify_factor = 0.05 * 1000;
+    if (!dc->abs_width) {
+        dezoomify_factor /= SP_EVENT_CONTEXT(dc)->desktop->current_zoom();
+    }
+
+    NR::Point del_left = dezoomify_factor * (width + tremble_left) * dc->ang;
+    NR::Point del_right = dezoomify_factor * (width + tremble_right) * dc->ang;
+
+    NR::Point abs_middle = sp_dyna_draw_get_vpoint(dc, dc->cur);
+
+    dc->point1[dc->npoints] = abs_middle + del_left;
+    dc->point2[dc->npoints] = abs_middle - del_right;
+
+    dc->del = 0.5*(del_left + del_right);
+
     dc->npoints++;
 }
 
-static gint
-sp_dyna_draw_timeout_handler(gpointer data)
-{
-    SPDynaDrawContext *dc = SP_DYNA_DRAW_CONTEXT(data);
-    SPDesktop *desktop = SP_EVENT_CONTEXT(dc)->desktop;
-    SPCanvas *canvas = SP_CANVAS(SP_DT_CANVAS(desktop));
-
-    dc->dragging = TRUE;
-    dc->dynahand = TRUE;
-
-    int x, y;
-    gtk_widget_get_pointer(GTK_WIDGET(canvas), &x, &y);
-    NR::Point p = sp_canvas_window_to_world(canvas, NR::Point(x, y));
-    p = sp_desktop_w2d_xy_point(desktop, p);
-    if (! sp_dyna_draw_apply(dc, p)) {
-        return TRUE;
-    }
-    p = sp_dyna_draw_get_curr_vpoint(dc);
-    namedview_free_snap(desktop->namedview, Snapper::SNAP_POINT, p);
-    // something's not right here
-    if ( dc->cur != dc->last ) {
-        sp_dyna_draw_brush(dc);
-        g_assert( dc->npoints > 0 );
-        fit_and_split(dc, FALSE);
-    }
-
-    return TRUE;
-}
-
 void
 sp_ddc_update_toolbox (SPDesktop *desktop, const gchar *id, double value)
 {
-    gpointer hb = sp_search_by_data_recursive (desktop->owner->aux_toolbox, (gpointer) id);
-    if (hb && GTK_IS_WIDGET(hb) && GTK_IS_SPIN_BUTTON(hb)) {
-        GtkAdjustment *a = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON(hb));
-        gtk_adjustment_set_value (a, value);
-    }
- }
+    desktop->setToolboxAdjustmentValue (id, value);
+}
 
 gint
 sp_dyna_draw_context_root_handler(SPEventContext *event_context,
@@ -505,26 +476,17 @@ sp_dyna_draw_context_root_handler(SPEventContext *event_context,
         if ( event->button.button == 1 ) {
 
             SPDesktop *desktop = SP_EVENT_CONTEXT_DESKTOP(dc);
-            SPItem *layer=SP_ITEM(desktop->currentLayer());
-            if ( !layer || desktop->itemIsHidden(layer)) {
-                dc->_message_context->flash(Inkscape::WARNING_MESSAGE, _("<b>Current layer is hidden</b>. Unhide it to be able to draw on it."));
-                return TRUE;
-            }
-            if ( !layer || layer->isLocked()) {
-                dc->_message_context->flash(Inkscape::WARNING_MESSAGE, _("<b>Current layer is locked</b>. Unlock it to be able to draw on it."));
+
+            if (Inkscape::have_viable_layer(desktop, dc->_message_context) == false) {
                 return TRUE;
             }
 
             NR::Point const button_w(event->button.x,
                                      event->button.y);
-            NR::Point const button_dt(sp_desktop_w2d_xy_point(desktop, button_w));
+            NR::Point const button_dt(desktop->w2d(button_w));
             sp_dyna_draw_reset(dc, button_dt);
             sp_dyna_draw_extinput(dc, event);
             sp_dyna_draw_apply(dc, button_dt);
-            NR::Point p = sp_dyna_draw_get_curr_vpoint(dc);
-            namedview_free_snap(desktop->namedview, Snapper::SNAP_POINT, p);
-            /* TODO: p isn't subsequently used; we should probably get rid of the last
-               1-2 statements (or use p).  Same for MOTION_NOTIFY below. */
             sp_curve_reset(dc->accumulated);
             if (dc->repr) {
                 dc->repr = NULL;
@@ -534,42 +496,31 @@ sp_dyna_draw_context_root_handler(SPEventContext *event_context,
             dc->npoints = 0;
 
             sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
-                                ( dc->use_timeout
-                                  ? ( GDK_KEY_PRESS_MASK |
-                                      GDK_BUTTON_RELEASE_MASK |
-                                      GDK_BUTTON_PRESS_MASK    )
-                                  : ( GDK_KEY_PRESS_MASK | 
-                                      GDK_BUTTON_RELEASE_MASK |
-                                      GDK_POINTER_MOTION_MASK |
-                                      GDK_BUTTON_PRESS_MASK    ) ),
+                                ( GDK_KEY_PRESS_MASK |
+                                  GDK_BUTTON_RELEASE_MASK |
+                                  GDK_POINTER_MOTION_MASK |
+                                  GDK_BUTTON_PRESS_MASK ),
                                 NULL,
                                 event->button.time);
 
-            if ( dc->use_timeout && !dc->timer_id ) {
-                dc->timer_id = gtk_timeout_add(SAMPLE_TIMEOUT, sp_dyna_draw_timeout_handler, dc);
-            }
             ret = TRUE;
 
             dc->is_drawing = true;
         }
         break;
     case GDK_MOTION_NOTIFY:
-        if ( dc->is_drawing && !dc->use_timeout && ( event->motion.state & GDK_BUTTON1_MASK ) ) {
+        if ( dc->is_drawing && ( event->motion.state & GDK_BUTTON1_MASK ) ) {
             dc->dragging = TRUE;
-            dc->dynahand = TRUE;
 
             NR::Point const motion_w(event->motion.x,
                                      event->motion.y);
-            NR::Point const motion_dt(sp_desktop_w2d_xy_point(desktop, motion_w));
+            NR::Point const motion_dt(desktop->w2d(motion_w));
 
             sp_dyna_draw_extinput(dc, event);
             if (!sp_dyna_draw_apply(dc, motion_dt)) {
                 ret = TRUE;
                 break;
             }
-            NR::Point p = sp_dyna_draw_get_curr_vpoint(dc);
-            namedview_free_snap(desktop->namedview, Snapper::SNAP_POINT, p);
-            /* p unused; see comments above in BUTTON_PRESS. */
 
             if ( dc->cur != dc->last ) {
                 sp_dyna_draw_brush(dc);
@@ -583,40 +534,23 @@ sp_dyna_draw_context_root_handler(SPEventContext *event_context,
     case GDK_BUTTON_RELEASE:
         sp_canvas_item_ungrab(SP_CANVAS_ITEM(desktop->acetate), event->button.time);
         dc->is_drawing = false;
-        if ( event->button.button == 1
-             && dc->use_timeout
-             && dc->timer_id != 0 )
-        {
-            gtk_timeout_remove(dc->timer_id);
-            dc->timer_id = 0;
-        }
         if ( dc->dragging && event->button.button == 1 ) {
             dc->dragging = FALSE;
 
-            /* release */
-            if (dc->dynahand) {
-                dc->dynahand = FALSE;
-                /* Remove all temporary line segments */
-                while (dc->segments) {
-                    gtk_object_destroy(GTK_OBJECT(dc->segments->data));
-                    dc->segments = g_slist_remove(dc->segments, dc->segments->data);
-                }
-                /* Create object */
-                fit_and_split(dc, TRUE);
-                if (dc->use_calligraphic) {
-                    accumulate_calligraphic(dc);
-                } else {
-                    concat_current_line(dc);
-                }
-                set_to_accumulated(dc); /* temporal implementation */
-                if (dc->use_calligraphic /* || dc->cinside*/) {
-                    /* reset accumulated curve */
-                    sp_curve_reset(dc->accumulated);
-                    clear_current(dc);
-                    if (dc->repr) {
-                        dc->repr = NULL;
-                    }
-                }
+            /* Remove all temporary line segments */
+            while (dc->segments) {
+                gtk_object_destroy(GTK_OBJECT(dc->segments->data));
+                dc->segments = g_slist_remove(dc->segments, dc->segments->data);
+            }
+            /* Create object */
+            fit_and_split(dc, TRUE);
+            accumulate_calligraphic(dc);
+            set_to_accumulated(dc); /* temporal implementation */
+            /* reset accumulated curve */
+            sp_curve_reset(dc->accumulated);
+            clear_current(dc);
+            if (dc->repr) {
+                dc->repr = NULL;
             }
             ret = TRUE;
         }
@@ -627,7 +561,7 @@ sp_dyna_draw_context_root_handler(SPEventContext *event_context,
         case GDK_KP_Up:
             if (!MOD__CTRL_ONLY) {
                 dc->angle += 5.0;
-                if (dc->angle > 90.0) 
+                if (dc->angle > 90.0)
                     dc->angle = 90.0;
                 sp_ddc_update_toolbox (desktop, "calligraphy-angle", dc->angle);
                 ret = TRUE;
@@ -637,7 +571,7 @@ sp_dyna_draw_context_root_handler(SPEventContext *event_context,
         case GDK_KP_Down:
             if (!MOD__CTRL_ONLY) {
                 dc->angle -= 5.0;
-                if (dc->angle < -90.0) 
+                if (dc->angle < -90.0)
                     dc->angle = -90.0;
                 sp_ddc_update_toolbox (desktop, "calligraphy-angle", dc->angle);
                 ret = TRUE;
@@ -647,9 +581,9 @@ sp_dyna_draw_context_root_handler(SPEventContext *event_context,
         case GDK_KP_Right:
             if (!MOD__CTRL_ONLY) {
                 dc->width += 0.01;
-                if (dc->width > 1.0) 
+                if (dc->width > 1.0)
                     dc->width = 1.0;
-                sp_ddc_update_toolbox (desktop, "altx-calligraphy", dc->width); // the same spinbutton is for alt+x
+                sp_ddc_update_toolbox (desktop, "altx-calligraphy", dc->width * 100); // the same spinbutton is for alt+x
                 ret = TRUE;
             }
             break;
@@ -657,22 +591,22 @@ sp_dyna_draw_context_root_handler(SPEventContext *event_context,
         case GDK_KP_Left:
             if (!MOD__CTRL_ONLY) {
                 dc->width -= 0.01;
-                if (dc->width < 0.01) 
+                if (dc->width < 0.01)
                     dc->width = 0.01;
-                sp_ddc_update_toolbox (desktop, "altx-calligraphy", dc->width); 
+                sp_ddc_update_toolbox (desktop, "altx-calligraphy", dc->width * 100);
                 ret = TRUE;
             }
             break;
         case GDK_x:
         case GDK_X:
             if (MOD__ALT_ONLY) {
-                gpointer hb = sp_search_by_data_recursive (desktop->owner->aux_toolbox, (gpointer) "altx-calligraphy");
-                if (hb && GTK_IS_WIDGET(hb)) {
-                    gtk_widget_grab_focus (GTK_WIDGET (hb));
-                }
+                desktop->setToolboxFocusTo ("altx-calligraphy");
                 ret = TRUE;
             }
             break;
+        case GDK_Escape:
+            sp_desktop_selection(desktop)->clear();
+            break;
 
         default:
             break;
@@ -723,16 +657,20 @@ set_to_accumulated(SPDynaDrawContext *dc)
             dc->repr = repr;
 
             SPItem *item=SP_ITEM(desktop->currentLayer()->appendChildRepr(dc->repr));
-            sp_repr_unref(dc->repr);
+            Inkscape::GC::release(dc->repr);
             item->transform = SP_ITEM(desktop->currentRoot())->getRelativeTransform(desktop->currentLayer());
             item->updateRepr();
-            SP_DT_SELECTION(desktop)->set(dc->repr);
+            if (dc->keep_selected) {
+                sp_desktop_selection(desktop)->set(dc->repr);
+            } else {
+                sp_desktop_selection(desktop)->clear();
+            }
         }
         abp = nr_artpath_affine(sp_curve_first_bpath(dc->accumulated), sp_desktop_dt2root_affine(desktop));
         str = sp_svg_write_path(abp);
         g_assert( str != NULL );
-        nr_free(abp);
-        sp_repr_set_attr(dc->repr, "d", str);
+        g_free(abp);
+        dc->repr->setAttribute("d", str);
         g_free(str);
     } else {
         if (dc->repr) {
@@ -741,31 +679,7 @@ set_to_accumulated(SPDynaDrawContext *dc)
         dc->repr = NULL;
     }
 
-    sp_document_done(SP_DT_DOCUMENT(desktop));
-}
-
-static void
-concat_current_line(SPDynaDrawContext *dc)
-{
-    if (!sp_curve_empty(dc->currentcurve)) {
-        NArtBpath *bpath;
-        if (sp_curve_empty(dc->accumulated)) {
-            bpath = sp_curve_first_bpath(dc->currentcurve);
-            g_assert( bpath->code == NR_MOVETO_OPEN );
-            sp_curve_moveto(dc->accumulated, bpath->x3, bpath->y3);
-        }
-        bpath = sp_curve_last_bpath(dc->currentcurve);
-        if ( bpath->code == NR_CURVETO ) {
-            sp_curve_curveto(dc->accumulated,
-                             bpath->x1, bpath->y1,
-                             bpath->x2, bpath->y2,
-                             bpath->x3, bpath->y3);
-        } else if ( bpath->code == NR_LINETO ) {
-            sp_curve_lineto(dc->accumulated, bpath->x3, bpath->y3);
-        } else {
-            g_assert_not_reached();
-        }
-    }
+    sp_document_done(sp_desktop_document(desktop));
 }
 
 static void
@@ -789,11 +703,7 @@ static void
 fit_and_split(SPDynaDrawContext *dc,
               gboolean release)
 {
-    if (dc->use_calligraphic) {
-        fit_and_split_calligraphics(dc, release);
-    } else {
-        fit_and_split_line(dc, release);
-    }
+    fit_and_split_calligraphics(dc, release);
 }
 
 static double square(double const x)
@@ -801,55 +711,10 @@ static double square(double const x)
     return x * x;
 }
 
-static void
-fit_and_split_line(SPDynaDrawContext *dc,
-                   gboolean release)
-{
-    double const tolerance_sq = square( NR::expansion(SP_EVENT_CONTEXT(dc)->desktop->w2d) * TOLERANCE_LINE );
-
-    NR::Point b[4];
-    double const n_segs = sp_bezier_fit_cubic(b, dc->point1, dc->npoints, tolerance_sq);
-    if ( n_segs > 0
-         && dc->npoints < SAMPLING_SIZE )
-    {
-        /* Fit and draw and reset state */
-#ifdef DYNA_DRAW_VERBOSE
-        g_print("%d", dc->npoints);
-#endif
-        sp_curve_reset(dc->currentcurve);
-        sp_curve_moveto(dc->currentcurve, b[0]);
-        sp_curve_curveto(dc->currentcurve, b[1], b[2], b[3]);
-        sp_canvas_bpath_set_bpath(SP_CANVAS_BPATH(dc->currentshape), dc->currentcurve);
-    } else {
-        /* Fit and draw and copy last point */
-#ifdef DYNA_DRAW_VERBOSE
-        g_print("[%d]Yup\n", dc->npoints);
-#endif
-        g_assert(!sp_curve_empty(dc->currentcurve));
-        concat_current_line(dc);
-
-        SPCanvasItem *cbp = sp_canvas_item_new(SP_DT_SKETCH(SP_EVENT_CONTEXT(dc)->desktop),
-                                               SP_TYPE_CANVAS_BPATH,
-                                               NULL);
-        SPCurve *curve = sp_curve_copy(dc->currentcurve);
-        sp_canvas_bpath_set_bpath(SP_CANVAS_BPATH(cbp), curve);
-        sp_curve_unref(curve);
-        /* fixme: We have to parse style color somehow */
-        sp_canvas_bpath_set_fill(SP_CANVAS_BPATH(cbp), DDC_GREEN_RGBA, SP_WIND_RULE_EVENODD);
-        sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(cbp), 0x000000ff, 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
-        /* fixme: Cannot we cascade it to root more clearly? */
-        g_signal_connect(G_OBJECT(cbp), "event", G_CALLBACK(sp_desktop_root_handler), SP_EVENT_CONTEXT(dc)->desktop);
-
-        dc->segments = g_slist_prepend(dc->segments, cbp);
-        dc->point1[0] = dc->point1[dc->npoints - 2];
-        dc->npoints = 1;
-    }
-}
-
 static void
 fit_and_split_calligraphics(SPDynaDrawContext *dc, gboolean release)
 {
-    double const tolerance_sq = square( NR::expansion(SP_EVENT_CONTEXT(dc)->desktop->w2d) * TOLERANCE_CALLIGRAPHIC );
+    double const tolerance_sq = square( NR::expansion(SP_EVENT_CONTEXT(dc)->desktop->w2d()) * TOLERANCE_CALLIGRAPHIC );
 
 #ifdef DYNA_DRAW_VERBOSE
     g_print("[F&S:R=%c]", release?'T':'F');
@@ -940,13 +805,21 @@ fit_and_split_calligraphics(SPDynaDrawContext *dc, gboolean release)
         if (!release) {
             g_assert(!sp_curve_empty(dc->currentcurve));
 
-            SPCanvasItem *cbp = sp_canvas_item_new(SP_DT_SKETCH(SP_EVENT_CONTEXT(dc)->desktop),
+            SPCanvasItem *cbp = sp_canvas_item_new(sp_desktop_sketch(SP_EVENT_CONTEXT(dc)->desktop),
                                                    SP_TYPE_CANVAS_BPATH,
                                                    NULL);
             SPCurve *curve = sp_curve_copy(dc->currentcurve);
             sp_canvas_bpath_set_bpath(SP_CANVAS_BPATH (cbp), curve);
             sp_curve_unref(curve);
-            sp_canvas_bpath_set_fill(SP_CANVAS_BPATH(cbp), 0x000000ff, SP_WIND_RULE_EVENODD);
+
+            guint32 fillColor = sp_desktop_get_color_tool (SP_ACTIVE_DESKTOP, "tools.calligraphic", true);
+            //guint32 strokeColor = sp_desktop_get_color_tool (SP_ACTIVE_DESKTOP, "tools.calligraphic", false);
+            double opacity = sp_desktop_get_master_opacity_tool (SP_ACTIVE_DESKTOP, "tools.calligraphic");
+            double fillOpacity = sp_desktop_get_opacity_tool (SP_ACTIVE_DESKTOP, "tools.calligraphic", true);
+            //double strokeOpacity = sp_desktop_get_opacity_tool (SP_ACTIVE_DESKTOP, "tools.calligraphic", false);
+            sp_canvas_bpath_set_fill(SP_CANVAS_BPATH(cbp), ((fillColor & 0xffffff00) | SP_COLOR_F_TO_U(opacity*fillOpacity)), SP_WIND_RULE_EVENODD);
+            //on second thougtht don't do stroke yet because we don't have stoke-width yet and because stoke appears between segments while drawing
+            //sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(cbp), ((strokeColor & 0xffffff00) | SP_COLOR_F_TO_U(opacity*strokeOpacity)), 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
             sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(cbp), 0x00000000, 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
             /* fixme: Cannot we cascade it to root more clearly? */
             g_signal_connect(G_OBJECT(cbp), "event", G_CALLBACK(sp_desktop_root_handler), SP_EVENT_CONTEXT(dc)->desktop);
@@ -981,9 +854,9 @@ draw_temporary_box(SPDynaDrawContext *dc)
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
