@@ -32,7 +32,7 @@
 class SPDynaDrawContext;
 class SPDynaDrawContextClass;
 
-#define SAMPLING_SIZE 16        /* fixme: ?? */
+#define SAMPLING_SIZE 8        /* fixme: ?? */
 
 #define DDC_MIN_PRESSURE      0.0
 #define DDC_MAX_PRESSURE      1.0
@@ -46,24 +46,32 @@ struct SPDynaDrawContext
 {
     SPEventContext event_context;
 
+    /** accumulated shape which ultimately goes in svg:path */
     SPCurve *accumulated;
+
+    /** canvas items for "comitted" segments */
     GSList *segments;
-    /* current shape and curves */
+
+    /** canvas item for red "leading" segment */
     SPCanvasItem *currentshape;
+    /** shape of red "leading" segment */
     SPCurve *currentcurve;
+
+    /** left edge of the stroke; combined to get accumulated */
     SPCurve *cal1;
+    /** right edge of the stroke; combined to get accumulated */
     SPCurve *cal2;
-    /* temporary work area */
+
+    /** left edge points for this segment */
     NR::Point point1[SAMPLING_SIZE];
+    /** right edge points for this segment */
     NR::Point point2[SAMPLING_SIZE];
+    /** number of edge points for this segment */
     gint npoints;
 
     /* repr */
     Inkscape::XML::Node *repr;
 
-    /* time_id if use timeout */
-    gint timer_id;
-
     /* DynaDraw */
     NR::Point cur;
     NR::Point vel;
@@ -76,23 +84,26 @@ struct SPDynaDrawContext
     gdouble xtilt;
     gdouble ytilt;
     /* attributes */
-    /* fixme: shuld be merge dragging and dynahand ?? */
     guint dragging : 1;           /* mouse state: mouse is dragging */
-    guint dynahand : 1;           /* mouse state: mouse is in draw */
-    guint use_timeout : 1;
-    guint use_calligraphic : 1;
+    guint usepressure : 1;
+    guint usetilt : 1;
     double mass, drag;
     double angle;
     double width;
-    guint usepressure : 1;
-    guint usetilt : 1;
 
     double vel_thin;
     double flatness;
+    double tremor;
 
     Inkscape::MessageContext *_message_context;
 
     bool is_drawing;
+
+    /** uses absolute width independent of zoom */
+    bool abs_width;
+
+    /** newly created object remain selected */
+    bool keep_selected;
 };
 
 struct SPDynaDrawContextClass
@@ -108,9 +119,9 @@ GtkType sp_dyna_draw_context_get_type(void);
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
