@@ -30,34 +30,25 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
 
 #include "display/sp-canvas.h"
 #include "xml/node-event-vector.h"
-#include "xml/repr.h"
 #include "sp-cursor.h"
 #include "shortcuts.h"
 #include "desktop.h"
 #include "desktop-handles.h"
-#include "desktop-affine.h"
 #include "selection.h"
-#include "sp-item.h"
-#include "zoom-context.h"
-#include "select-context.h"
 #include "file.h"
 #include "interface.h"
-#include <glibmm/i18n.h>
-#include "selection-chemistry.h"
-#include "dialogs/desktop-properties.h"
 #include "macros.h"
 #include "tools-switch.h"
 #include "prefs-utils.h"
 #include "message-context.h"
-#include "widgets/spw-utilities.h"
 #include "gradient-drag.h"
-#include "knotholder.h"
 #include "object-edit.h"
 #include "attributes.h"
+#include "rubberband.h"
+#include "selcue.h"
 
 #include "event-context.h"
 
@@ -166,7 +157,7 @@ sp_event_context_dispose(GObject *object)
 
     if (ec->prefs_repr) {
         sp_repr_remove_listener_by_data(ec->prefs_repr, ec);
-        sp_repr_unref(ec->prefs_repr);
+        Inkscape::GC::release(ec->prefs_repr);
         ec->prefs_repr = NULL;
     }
 
@@ -179,7 +170,7 @@ sp_event_context_dispose(GObject *object)
 void
 sp_event_context_update_cursor(SPEventContext *ec)
 {
-    GtkWidget *w = GTK_WIDGET(SP_DT_CANVAS(ec->desktop));
+    GtkWidget *w = GTK_WIDGET(sp_desktop_canvas(ec->desktop));
     if (w->window) {
         /* fixme: */
         if (ec->cursor_shape) {
@@ -190,7 +181,7 @@ sp_event_context_update_cursor(SPEventContext *ec)
                 if (ec->cursor)
                     gdk_cursor_unref (ec->cursor);
                 ec->cursor = gdk_cursor_new_from_pixmap(bitmap, mask,
-                                                        &w->style->black, 
+                                                        &w->style->black,
                                                         &w->style->white,
                                                         ec->hot_x, ec->hot_y);
                 g_object_unref (bitmap);
@@ -222,7 +213,7 @@ gint gobble_key_events(guint keyval, gint mask)
     event_next = gdk_event_get();
     // while the next event is also a key notify with the same keyval and mask,
     while (event_next && event_next->type == GDK_KEY_PRESS
-           && event_next->key.keyval == keyval 
+           && event_next->key.keyval == keyval
            && (event_next->key.state & mask)) {
         // kill it
         gdk_event_free(event_next);
@@ -264,7 +255,7 @@ gint gobble_motion_events(gint mask)
  * Toggles current tool between active tool and selector tool.
  * Subroutine of sp_event_context_private_root_handler().
  */
-static void 
+static void
 sp_toggle_selector(SPDesktop *dt)
 {
     if (!dt->event_context) return;
@@ -303,16 +294,16 @@ static gdouble accelerate_scroll(GdkEvent *event, gdouble acceleration)
 }
 
 // This is a hack that is necessary because when middle-clicking too fast,
-// button_press events come for all clicks but there's button_release only 
-// for the first one. So after a release, we must prohibit the next grab for 
-// some time, or the grab will be stuck.  Perhaps this is caused by some 
-// wrong handling of events among contexts and not by a GDK bug; 
+// button_press events come for all clicks but there's button_release only
+// for the first one. So after a release, we must prohibit the next grab for
+// some time, or the grab will be stuck.  Perhaps this is caused by some
+// wrong handling of events among contexts and not by a GDK bug;
 // if someone can fix this properly this would be great.
 static gint dontgrab = 0;
-static bool 
-grab_allow_again() 
+static bool
+grab_allow_again()
 {
-    dontgrab--; 
+    dontgrab--;
     if (dontgrab < 0) dontgrab = 0;
     return FALSE; // so that it is only called once
 }
@@ -324,6 +315,7 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
 {
     static NR::Point button_w;
     static unsigned int panning = 0;
+    static unsigned int zoom_rb = 0;
 
     SPDesktop *desktop = event_context->desktop;
 
@@ -344,7 +336,7 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
         case GDK_2BUTTON_PRESS:
             if (panning) {
                 panning = 0;
-                sp_canvas_item_ungrab(SP_CANVAS_ITEM(desktop->acetate), 
+                sp_canvas_item_ungrab(SP_CANVAS_ITEM(desktop->acetate),
                         event->button.time);
                 ret = TRUE;
             } else {
@@ -354,38 +346,42 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
         case GDK_BUTTON_PRESS:
 
             // save drag origin
-            xp = (gint) event->button.x; 
+            xp = (gint) event->button.x;
             yp = (gint) event->button.y;
             within_tolerance = true;
 
             switch (event->button.button) {
                 case 2:
 
-                    if (dontgrab) 
-                        // double-click, still not permitted to grab; 
+                    if (dontgrab)
+                        // double-click, still not permitted to grab;
                         // increase the counter to guard against triple click
                     {
-                        dontgrab ++; 
+                        dontgrab ++;
                         gtk_timeout_add(250, (GtkFunction) grab_allow_again, NULL);
                         break;
                     }
 
                     button_w = NR::Point(event->button.x,
                                          event->button.y);
-                    panning = 2;
-                    sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
-                            GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK,
+                    if (event->button.state == GDK_SHIFT_MASK) {
+                        zoom_rb = 2;
+                    } else {
+                        panning = 2;
+                        sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
+                            GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK,
                             NULL, event->button.time-1);
+                    }
                     ret = TRUE;
                     break;
                 case 3:
-                    if (event->button.state & GDK_SHIFT_MASK 
+                    if (event->button.state & GDK_SHIFT_MASK
                             || event->button.state & GDK_CONTROL_MASK) {
                         button_w = NR::Point(event->button.x,
                                              event->button.y);
                         panning = 3;
                         sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
-                                GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK,
+                                GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK,
                                 NULL, event->button.time);
                         ret = TRUE;
                     } else {
@@ -398,12 +394,12 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
             break;
         case GDK_MOTION_NOTIFY:
             if (panning) {
-                if ((panning == 2 && !(event->motion.state & GDK_BUTTON2_MASK)) 
+                if ((panning == 2 && !(event->motion.state & GDK_BUTTON2_MASK))
                         || (panning == 3 && !(event->motion.state & GDK_BUTTON3_MASK))) {
                     /* Gdk seems to lose button release for us sometimes :-( */
                     panning = 0;
                     dontgrab = 0;
-                    sp_canvas_item_ungrab(SP_CANVAS_ITEM(desktop->acetate), 
+                    sp_canvas_item_ungrab(SP_CANVAS_ITEM(desktop->acetate),
                             event->button.time);
                     ret = TRUE;
                 } else {
@@ -412,17 +408,17 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                          && ( abs( (gint) event->motion.y - yp ) < tolerance ))
                     {
                         // do not drag if we're within tolerance from origin
-                        break; 
+                        break;
                     }
-                    // Once the user has moved farther than tolerance from 
-                    // the original location (indicating they intend to move 
-                    // the object, not click), then always process the motion 
+                    // Once the user has moved farther than tolerance from
+                    // the original location (indicating they intend to move
+                    // the object, not click), then always process the motion
                     // notify coordinates as given (no snapping back to origin)
-                    within_tolerance = false; 
+                    within_tolerance = false;
 
-                    // gobble subsequent motion events to prevent "sticking" 
+                    // gobble subsequent motion events to prevent "sticking"
                     // when scrolling is slow
-                    gobble_motion_events(panning == 2 ? 
+                    gobble_motion_events(panning == 2 ?
                             GDK_BUTTON2_MASK : GDK_BUTTON3_MASK);
 
                     NR::Point const motion_w(event->motion.x,
@@ -431,27 +427,53 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                     event_context->desktop->scroll_world(moved_w);
                     ret = TRUE;
                 }
+            } else if (zoom_rb) {
+                NR::Point const motion_w(event->motion.x, event->motion.y);
+                NR::Point const motion_dt(desktop->w2d(motion_w));
+
+                if ( within_tolerance
+                     && ( abs( (gint) event->motion.x - xp ) < tolerance )
+                     && ( abs( (gint) event->motion.y - yp ) < tolerance ) ) {
+                    break; // do not drag if we're within tolerance from origin
+                }
+
+                if (within_tolerance) {
+                    Inkscape::Rubberband::get()->start(desktop, motion_dt);
+                } else {
+                    Inkscape::Rubberband::get()->move(motion_dt);
+                }
+
+                // Once the user has moved farther than tolerance from the original location
+                // (indicating they intend to move the object, not click), then always process the
+                // motion notify coordinates as given (no snapping back to origin)
+                within_tolerance = false;
             }
             break;
         case GDK_BUTTON_RELEASE:
+            if (within_tolerance && (panning || zoom_rb)) {
+                dontgrab ++;
+                NR::Point const event_w(event->button.x, event->button.y);
+                NR::Point const event_dt(desktop->w2d(event_w));
+                double const zoom_power = ( (event->button.state & GDK_SHIFT_MASK)
+                                            ? -dontgrab : dontgrab );
+                desktop->zoom_relative_keep_point(event_dt,
+                                                  pow(zoom_inc, zoom_power));
+                gtk_timeout_add(250, (GtkFunction) grab_allow_again, NULL);
+            }
             if (panning == event->button.button) {
                 panning = 0;
-                sp_canvas_item_ungrab(SP_CANVAS_ITEM(desktop->acetate), 
-                        event->button.time);
-                if (within_tolerance) {
-                    dontgrab ++;
-                    NR::Point const event_w(event->button.x, event->button.y);
-                    NR::Point const event_dt(sp_desktop_w2d_xy_point(desktop, event_w));
-                    double const zoom_power = ( (event->button.state & GDK_SHIFT_MASK)
-                            ? -dontgrab : dontgrab );
-                    desktop->zoom_relative_keep_point(event_dt,
-                            pow(zoom_inc, zoom_power));
-                    gtk_timeout_add(250, (GtkFunction) grab_allow_again, NULL);
-                }
-
+                sp_canvas_item_ungrab(SP_CANVAS_ITEM(desktop->acetate),
+                                      event->button.time);
                 ret = TRUE;
-            } 
-            xp = yp = 0; 
+            } else if (zoom_rb == event->button.button) {
+                zoom_rb = 0;
+                NR::Maybe<NR::Rect> const b = Inkscape::Rubberband::get()->getRectangle();
+                if (b != NR::Nothing() && !within_tolerance) {
+                    desktop->set_display_area(b.assume(), 10);
+                }
+                Inkscape::Rubberband::get()->stop();
+            }
+            xp = yp = 0;
             break;
         case GDK_KEY_PRESS:
             switch (get_group0_keyval(&event->key)) {
@@ -459,14 +481,15 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                 case GDK_F1:
                     /* Grab it away from Gtk */
                     shortcut = get_group0_keyval(&event->key);
-                    if (event->key.state & GDK_SHIFT_MASK) 
+                    if (event->key.state & GDK_SHIFT_MASK)
                         shortcut |= SP_SHORTCUT_SHIFT_MASK;
-                    if (event->key.state & GDK_CONTROL_MASK) 
+                    if (event->key.state & GDK_CONTROL_MASK)
                         shortcut |= SP_SHORTCUT_CONTROL_MASK;
-                    if (event->key.state & GDK_MOD1_MASK) 
+                    if (event->key.state & GDK_MOD1_MASK)
                         shortcut |= SP_SHORTCUT_ALT_MASK;
-                    ret = sp_shortcut_invoke(shortcut, 
-                            SP_EVENT_CONTEXT_DESKTOP(event_context));
+                    ret = sp_shortcut_invoke(shortcut, desktop);
+                    break;
+
                 case GDK_Tab: // disable tab/shift-tab which cycle widget focus
                 case GDK_ISO_Left_Tab: // they will get different functions
                     if (!(MOD__CTRL_ONLY || (MOD__CTRL && MOD__SHIFT))) {
@@ -474,14 +497,13 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                     } else {
                         /* Grab it away from Gtk */
                         shortcut = get_group0_keyval(&event->key);
-                        if (event->key.state & GDK_SHIFT_MASK) 
+                        if (event->key.state & GDK_SHIFT_MASK)
                             shortcut |= SP_SHORTCUT_SHIFT_MASK;
-                        if (event->key.state & GDK_CONTROL_MASK) 
+                        if (event->key.state & GDK_CONTROL_MASK)
                             shortcut |= SP_SHORTCUT_CONTROL_MASK;
-                        if (event->key.state & GDK_MOD1_MASK) 
+                        if (event->key.state & GDK_MOD1_MASK)
                             shortcut |= SP_SHORTCUT_ALT_MASK;
-                        ret = sp_shortcut_invoke(shortcut,
-                                SP_EVENT_CONTEXT_DESKTOP(event_context));
+                        ret = sp_shortcut_invoke(shortcut, desktop);
                     }
                     break;
                 case GDK_W:
@@ -493,19 +515,12 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                         ret = TRUE;
                     }
                     break;
-                    // FIXME: make import a verb
-                case GDK_i: // Ctrl i - import file
-                    if (MOD__CTRL_ONLY) {
-                        sp_file_import(NULL);
-                        ret = TRUE;
-                    }
-                    break;
-                case GDK_Left: // Ctrl Left 
+                case GDK_Left: // Ctrl Left
                 case GDK_KP_Left:
                 case GDK_KP_4:
                     if (MOD__CTRL_ONLY) {
                         int i = (int) floor(key_scroll * accelerate_scroll(event, acceleration));
-                        gobble_key_events(get_group0_keyval(&event->key), 
+                        gobble_key_events(get_group0_keyval(&event->key),
                                 GDK_CONTROL_MASK);
                         event_context->desktop->scroll_world(i, 0);
                         ret = TRUE;
@@ -516,7 +531,7 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                 case GDK_KP_8:
                     if (MOD__CTRL_ONLY) {
                         int i = (int) floor(key_scroll * accelerate_scroll(event, acceleration));
-                        gobble_key_events(get_group0_keyval(&event->key), 
+                        gobble_key_events(get_group0_keyval(&event->key),
                                 GDK_CONTROL_MASK);
                         event_context->desktop->scroll_world(0, i);
                         ret = TRUE;
@@ -527,7 +542,7 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                 case GDK_KP_6:
                     if (MOD__CTRL_ONLY) {
                         int i = (int) floor(key_scroll * accelerate_scroll(event, acceleration));
-                        gobble_key_events(get_group0_keyval(&event->key), 
+                        gobble_key_events(get_group0_keyval(&event->key),
                                 GDK_CONTROL_MASK);
                         event_context->desktop->scroll_world(-i, 0);
                         ret = TRUE;
@@ -538,7 +553,7 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                 case GDK_KP_2:
                     if (MOD__CTRL_ONLY) {
                         int i = (int) floor(key_scroll * accelerate_scroll(event, acceleration));
-                        gobble_key_events(get_group0_keyval(&event->key), 
+                        gobble_key_events(get_group0_keyval(&event->key),
                                 GDK_CONTROL_MASK);
                         event_context->desktop->scroll_world(0, -i);
                         ret = TRUE;
@@ -548,7 +563,7 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                     if (MOD__SHIFT_ONLY) {
                         sp_event_root_menu_popup(desktop, NULL, event);
                         ret= TRUE;
-                    } 
+                    }
                     break;
                 case GDK_space:
                     sp_toggle_selector(desktop);
@@ -557,10 +572,7 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
                 case GDK_z:
                 case GDK_Z:
                     if (MOD__ALT_ONLY) {
-                        gpointer hb = gtk_object_get_data(GTK_OBJECT(desktop->owner), "altz");
-                        if (hb && GTK_IS_WIDGET(hb)) {
-                            gtk_widget_grab_focus(GTK_WIDGET(hb));
-                        }
+                        desktop->zoom_grab_focus();
                         ret = TRUE;
                     }
                     break;
@@ -586,13 +598,13 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
             } else if (event->scroll.state & GDK_CONTROL_MASK) {
                 double rel_zoom;
                 switch (event->scroll.direction) {
-                    case GDK_SCROLL_UP:   
+                    case GDK_SCROLL_UP:
                         rel_zoom = zoom_inc;
                         break;
-                    case GDK_SCROLL_DOWN: 
+                    case GDK_SCROLL_DOWN:
                         rel_zoom = 1 / zoom_inc;
                         break;
-                    default:              
+                    default:
                         rel_zoom = 0.0;
                         break;
                 }
@@ -627,7 +639,7 @@ static gint sp_event_context_private_root_handler(SPEventContext *event_context,
 }
 
 /**
- * Handles item specific events. Gets called from Gdk. 
+ * Handles item specific events. Gets called from Gdk.
  *
  * Only reacts to right mouse button at the moment.
  * \todo Fixme: do context sensitive popup menu on items.
@@ -639,7 +651,7 @@ sp_event_context_private_item_handler(SPEventContext *ec, SPItem *item, GdkEvent
 
     switch (event->type) {
         case GDK_BUTTON_PRESS:
-            if ((event->button.button == 3) 
+            if ((event->button.button == 3)
                     && !(event->button.state & GDK_SHIFT_MASK || event->button.state & GDK_CONTROL_MASK)) {
                 sp_event_root_menu_popup(ec->desktop, item, event);
                 ret = TRUE;
@@ -692,7 +704,7 @@ sp_event_context_new(GType type, SPDesktop *desktop, Inkscape::XML::Node *prefs_
     ec->key = key;
     ec->prefs_repr = prefs_repr;
     if (ec->prefs_repr) {
-        sp_repr_ref(ec->prefs_repr);
+        Inkscape::GC::anchor(ec->prefs_repr);
         sp_repr_add_listener(ec->prefs_repr, &sp_ec_event_vector, ec);
     }
 
@@ -724,18 +736,16 @@ sp_event_context_finish(SPEventContext *ec)
 //-------------------------------member functions
 
 /**
- * Enables/disables the SPEventContext's SPSelCue.
+ * Enables/disables the SPEventContext's SelCue.
  */
 void SPEventContext::enableSelectionCue(bool enable) {
     if (enable) {
         if (!_selcue) {
-            _selcue = new SPSelCue(desktop);
+            _selcue = new Inkscape::SelCue(desktop);
         }
     } else {
-        if (_selcue) {
-            delete _selcue;
-            _selcue = NULL;
-        }
+        delete _selcue;
+        _selcue = NULL;
     }
 }
 
@@ -842,9 +852,9 @@ static void set_event_location(SPDesktop *desktop, GdkEvent *event)
     }
 
     NR::Point const button_w(event->button.x, event->button.y);
-    NR::Point const button_dt(sp_desktop_w2d_xy_point(desktop, button_w));
+    NR::Point const button_dt(desktop->w2d(button_w));
     desktop-> setPosition (button_dt);
-    desktop->set_coordinate_status(button_dt, 0);
+    desktop->set_coordinate_status(button_dt);
 }
 
 //-------------------------------------------------------------------
@@ -858,7 +868,7 @@ sp_event_root_menu_popup(SPDesktop *desktop, SPItem *item, GdkEvent *event)
 
     /* fixme: This is not what I want but works for now (Lauris) */
     if (event->type == GDK_KEY_PRESS) {
-        item = SP_DT_SELECTION(desktop)->singleItem();
+        item = sp_desktop_selection(desktop)->singleItem();
     }
     menu = sp_ui_context_menu(desktop, item);
     gtk_widget_show(menu);
@@ -879,25 +889,25 @@ sp_event_root_menu_popup(SPDesktop *desktop, SPItem *item, GdkEvent *event)
  * Show tool context specific modifier tip.
  */
 void
-sp_event_show_modifier_tip(Inkscape::MessageContext *message_context, 
-        GdkEvent *event, gchar const *ctrl_tip, gchar const *shift_tip, 
+sp_event_show_modifier_tip(Inkscape::MessageContext *message_context,
+        GdkEvent *event, gchar const *ctrl_tip, gchar const *shift_tip,
         gchar const *alt_tip)
 {
     guint keyval = get_group0_keyval(&event->key);
-    
-    bool ctrl = ctrl_tip && (MOD__CTRL 
-            || (keyval == GDK_Control_L) 
+
+    bool ctrl = ctrl_tip && (MOD__CTRL
+            || (keyval == GDK_Control_L)
             || (keyval == GDK_Control_R));
-    bool shift = shift_tip 
+    bool shift = shift_tip
         && (MOD__SHIFT || (keyval == GDK_Shift_L) || (keyval == GDK_Shift_R));
-    bool alt = alt_tip 
-        && (MOD__ALT 
-                || (keyval == GDK_Alt_L) 
-                || (keyval == GDK_Alt_R) 
-                || (keyval == GDK_Meta_L) 
+    bool alt = alt_tip
+        && (MOD__ALT
+                || (keyval == GDK_Alt_L)
+                || (keyval == GDK_Alt_R)
+                || (keyval == GDK_Meta_L)
                 || (keyval == GDK_Meta_R));
 
-    gchar *tip = g_strdup_printf("%s%s%s%s%s", 
+    gchar *tip = g_strdup_printf("%s%s%s%s%s",
                                  ( ctrl ? ctrl_tip : "" ),
                                  ( ctrl && (shift || alt) ? "; " : "" ),
                                  ( shift ? shift_tip : "" ),
@@ -912,20 +922,20 @@ sp_event_show_modifier_tip(Inkscape::MessageContext *message_context,
 }
 
 /**
- * Return the keyval corresponding to the key event in group 0, i.e., 
- * in the main (English) layout.  
+ * Return the keyval corresponding to the key event in group 0, i.e.,
+ * in the main (English) layout.
  *
- * Use this instead of simply event->keyval, so that your keyboard shortcuts 
+ * Use this instead of simply event->keyval, so that your keyboard shortcuts
  * work regardless of layouts (e.g., in Cyrillic).
  */
 guint
-get_group0_keyval(GdkEventKey *event) 
+get_group0_keyval(GdkEventKey *event)
 {
     guint keyval = 0;
     gdk_keymap_translate_keyboard_state(
             gdk_keymap_get_for_display(gdk_display_get_default()),
-            event->hardware_keycode, 
-            (GdkModifierType) event->state, 
+            event->hardware_keycode,
+            (GdkModifierType) event->state,
             0   /*event->key.group*/,
             &keyval, NULL, NULL, NULL);
     return keyval;
@@ -934,23 +944,23 @@ get_group0_keyval(GdkEventKey *event)
 /**
  * Returns item at point p in desktop.
  *
- * If state includes alt key mask, cyclically selects under; honors 
+ * If state includes alt key mask, cyclically selects under; honors
  * into_groups.
  */
 SPItem *
-sp_event_context_find_item (SPDesktop *desktop, NR::Point const p, 
+sp_event_context_find_item (SPDesktop *desktop, NR::Point const p,
         bool select_under, bool into_groups)
 {
     SPItem *item;
 
     if (select_under) {
-        SPItem *selected_at_point = 
+        SPItem *selected_at_point =
             desktop->item_from_list_at_point_bottom (desktop->selection->itemList(), p);
         item = desktop->item_at_point(p, into_groups, selected_at_point);
         if (item == NULL) { // we may have reached bottom, flip over to the top
             item = desktop->item_at_point(p, into_groups, NULL);
         }
-    } else 
+    } else
         item = desktop->item_at_point(p, into_groups, NULL);
 
     return item;
@@ -975,13 +985,13 @@ sp_event_context_over_item (SPDesktop *desktop, SPItem *item, NR::Point const p)
 /**
  * Called when SPEventContext subclass node attribute changed.
  */
-void 
-ec_shape_event_attr_changed(Inkscape::XML::Node *shape_repr, gchar const *name, 
+void
+ec_shape_event_attr_changed(Inkscape::XML::Node *shape_repr, gchar const *name,
         gchar const *old_value, gchar const *new_value,
         bool const is_interactive, gpointer const data)
 {
-    if (!name 
-            || !strcmp(name, "style") 
+    if (!name
+            || !strcmp(name, "style")
             || SP_ATTRIBUTE_IS_CSS(sp_attribute_lookup(name))) {
         // no need to regenrate knotholder if only style changed
         return;
@@ -996,7 +1006,7 @@ ec_shape_event_attr_changed(Inkscape::XML::Node *shape_repr, gchar const *name,
 
     SPDesktop *desktop = ec->desktop;
 
-    SPItem *item = SP_DT_SELECTION(desktop)->singleItem();
+    SPItem *item = sp_desktop_selection(desktop)->singleItem();
 
     if (item) {
         ec->shape_knot_holder = sp_item_knot_holder(item, desktop);
