@@ -20,6 +20,7 @@
 #include "extension/extension-forward.h"
 #include "libnr/nr-forward.h"
 #include "libnr/nr-point.h"
+#include "xml/node.h"
 
 namespace Inkscape {
 namespace Extension {
@@ -107,6 +108,7 @@ public:
                           char const *text,
                           NR::Point p,
                           SPStyle const *style);
+    virtual void     processPath(Inkscape::XML::Node * node);
 };
 
 }  /* namespace Implementation */
