@@ -55,23 +55,26 @@ Input::Input (Inkscape::XML::Node * in_repr, Implementation::Implementation * in
             if (!strcmp(child_repr->name(), "input")) {
                 child_repr = sp_repr_children(child_repr);
                 while (child_repr != NULL) {
-                    if (!strcmp(child_repr->name(), "extension")) {
+                    char const * chname = child_repr->name();
+                    if (chname[0] == '_') /* Allow _ for translation of tags */
+                        chname++;
+                    if (!strcmp(chname, "extension")) {
                         g_free (extension);
                         extension = g_strdup(sp_repr_children(child_repr)->content());
                     }
-                    if (!strcmp(child_repr->name(), "mimetype")) {
+                    if (!strcmp(chname, "mimetype")) {
                         g_free (mimetype);
                         mimetype = g_strdup(sp_repr_children(child_repr)->content());
                     }
-                    if (!strcmp(child_repr->name(), "filetypename")) {
+                    if (!strcmp(chname, "filetypename")) {
                         g_free (filetypename);
                         filetypename = g_strdup(sp_repr_children(child_repr)->content());
                     }
-                    if (!strcmp(child_repr->name(), "filetypetooltip")) {
+                    if (!strcmp(chname, "filetypetooltip")) {
                         g_free (filetypetooltip);
                         filetypetooltip = g_strdup(sp_repr_children(child_repr)->content());
                     }
-                    if (!strcmp(child_repr->name(), "output_extension")) {
+                    if (!strcmp(chname, "output_extension")) {
                         g_free (output_extension);
                         output_extension = g_strdup(sp_repr_children(child_repr)->content());
                     }
@@ -164,7 +167,7 @@ Input::open (const gchar *uri)
         Inkscape::XML::Node * repr = sp_document_repr_root(doc);
         gboolean saved = sp_document_get_undo_sensitive(doc);
         sp_document_set_undo_sensitive (doc, FALSE);
-        sp_repr_set_attr(repr, "inkscape:output_extension", output_extension);
+        repr->setAttribute("inkscape:output_extension", output_extension);
         sp_document_set_undo_sensitive (doc, saved);
     }
 
@@ -234,7 +237,7 @@ Input::prefs (const gchar *uri)
         return true;
     }
 
-    PrefDialog * dialog = new PrefDialog(this->get_name(), controls);
+    PrefDialog * dialog = new PrefDialog(this->get_name(), this->get_help(), controls);
     int response = dialog->run();
     dialog->hide();
 
