@@ -239,7 +239,7 @@ PrintGNOME::fill(Inkscape::Extension::Print *mod,
 	dpbox.y0 = pbox->y0;
 	dpbox.x1 = pbox->x1;
 	dpbox.y1 = pbox->y1;
-	painter = sp_paint_server_painter_new(SP_STYLE_FILL_SERVER(style), 
+	painter = sp_paint_server_painter_new(SP_STYLE_FILL_SERVER(style),
 						// FIXME: the second matrix below must be the parent (context) transform.
 						// I don't know what it must be for gnome-print. --bb
 						ctm, NR::identity(),
@@ -388,15 +388,17 @@ PrintGNOME::image (Inkscape::Extension::Print *mod, unsigned char *px, unsigned
     return 0;
 }
 
+#include "clear-n_.h"
+
 void
 PrintGNOME::init (void)
 {
 	Inkscape::Extension::Extension * ext;
-	
+
 	/* SVG in */
     ext = Inkscape::Extension::build_from_mem(
 		"<inkscape-extension>\n"
-			"<name>GNOME Print</name>\n"
+			"<name>" N_("GNOME Print") "</name>\n"
 			"<id>" SP_MODULE_KEY_PRINT_GNOME "</id>\n"
 			"<print/>\n"
 		"</inkscape-extension>", new PrintGNOME());
@@ -421,7 +423,7 @@ nr_artpath_to_art_bpath(NArtBpath const *s)
 	i = 0;
 	while (s[i].code != NR_END) i += 1;
 
-	ArtBpath* d = nr_new (ArtBpath, i + 1);
+	ArtBpath* d = g_new (ArtBpath, i + 1);
 
 	i = 0;
 	while (s[i].code != NR_END) {
