@@ -11,37 +11,17 @@
 # include <config.h>
 #endif
 #include "latex-pstricks-out.h"
-#include "latex-pstricks.h"
-#include "inkscape.h"
 #include "sp-path.h"
-#include "style.h"
-#include "color.h"
-#include "display/curve.h"
-#include "libnr/n-art-bpath.h"
-#include "libnr/nr-point-matrix-ops.h"
-#include <gtk/gtk.h>
 #include <print.h>
-#include <glibmm/i18n.h>
-#include "extension/extension.h"
 #include "extension/system.h"
 #include "extension/print.h"
 #include "extension/db.h"
-#include "extension/output.h"
-#include "document.h"
 #include "display/nr-arena.h"
 #include "display/nr-arena-item.h"
 
-#include <libnr/nr-rect.h>
-#include <libnr/nr-matrix.h>
-#include <libnr/nr-pixblock.h>
 
-#include <stdio.h>
-#include <string.h>
 
-#include <vector>
-#include <string>
 
-#include "io/sys.h"
 
 namespace Inkscape {
 namespace Extension {
@@ -109,6 +89,8 @@ LatexOutput::save (Inkscape::Extension::Output *mod2, SPDocument *doc, const gch
     return;
 }
 
+#include "clear-n_.h"
+
 /**
     \brief   A function allocate a copy of this function.
 
@@ -121,13 +103,13 @@ LatexOutput::init (void)
 {
     Inkscape::Extension::build_from_mem(
         "<inkscape-extension>\n"
-            "<name>LaTeX Output</name>\n"
+            "<name>" N_("LaTeX Output") "</name>\n"
             "<id>org.inkscape.output.latex</id>\n"
             "<output>\n"
                 "<extension>.tex</extension>\n"
                 "<mimetype>text/plain</mimetype>\n"
-                "<filetypename>LaTeX With PSTricks macros (*.tex)</filetypename>\n"
-                "<filetypetooltip>LaTeX PSTricks File</filetypetooltip>\n"
+                "<filetypename>" N_("LaTeX With PSTricks macros (*.tex)") "</filetypename>\n"
+                "<filetypetooltip>" N_("LaTeX PSTricks File") "</filetypetooltip>\n"
             "</output>\n"
         "</inkscape-extension>", new LatexOutput());
 
