@@ -1,9 +1,10 @@
 #define __SP_PS_C__
 
+/** \file
+ * PostScript printing.
+ */
 /*
- * PostScript printing
- *
- * Author:
+ * Authors:
  *   Lauris Kaplinski <lauris@kaplinski.com>
  *   bulia byak <buliabyak@users.sf.net>
  *
@@ -26,24 +27,14 @@
 # include "config.h"
 #endif
 
-#include <string.h>
-#include <ctype.h>
-#include <stdlib.h>
 #include <signal.h>
 #include <errno.h>
-#include <math.h>
 
 #include <libnr/n-art-bpath.h>
-#include <libnr/nr-macros.h>
-#include <libnr/nr-matrix.h>
-#include <libnr/nr-matrix-ops.h>
-#include <libnr/nr-point-matrix-ops.h>
 
-#include <glib.h>
+#include <glib/gmem.h>
 #include <gtk/gtkstock.h>
-#include <gtk/gtkdialog.h>
 #include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
 #include <gtk/gtkframe.h>
 #include <gtk/gtkradiobutton.h>
 #include <gtk/gtkcombo.h>
@@ -54,21 +45,11 @@
 #include <glibmm/i18n.h>
 #include "display/nr-arena-item.h"
 #include "display/canvas-bpath.h"
-#include "enums.h"
-#include "document.h"
-#include "desktop-handles.h"
-#include "widgets/desktop-widget.h"
-#include "inkscape.h"
 #include "sp-item.h"
 #include "style.h"
-#include "inkscape_version.h"
-#include "sp-gradient.h"
-#include "sp-gradient-vector.h"
 #include "sp-linear-gradient.h"
-#include "sp-pattern.h"
 #include "sp-radial-gradient.h"
 
-#include "libnrtype/FontFactory.h"
 #include "libnrtype/font-instance.h"
 #include "libnrtype/font-style-to-pos.h"
 
@@ -76,7 +57,6 @@
 
 #include "ps.h"
 #include "extension/system.h"
-#include "extension/extension.h"
 #include "extension/print.h"
 
 #include "io/sys.h"
@@ -108,31 +88,22 @@ PrintPS::~PrintPS(void)
 unsigned int
 PrintPS::setup(Inkscape::Extension::Print * mod)
 {
-    static const gchar *pdr[] = {"72", "75", "100", "144", "150", "200", "300", "360", "600", "1200", "2400", NULL};
-    GtkWidget *dlg, *vbox, *f, *vb, *rb, *hb, *combo, *l, *e;
-    GtkTooltips *tt;
-    GList *sl;
-    int i;
-    int response;
-    unsigned int ret;
-#ifdef TED
-    Inkscape::XML::Node *repr;
-#endif
-    bool p2bm;
+    static gchar const *const pdr[] = {"72", "75", "100", "144", "150", "200", "300", "360", "600", "1200", "2400", NULL};
 
 #ifdef TED
-    repr = ((SPModule *) mod)->repr;
+    Inkscape::XML::Node *repr = ((SPModule *) mod)->repr;
 #endif
 
-    ret = FALSE;
+    unsigned int ret = FALSE;
 
     /* Create dialog */
-    tt = gtk_tooltips_new();
+    GtkTooltips *tt = gtk_tooltips_new();
     g_object_ref((GObject *) tt);
     gtk_object_sink((GtkObject *) tt);
 
-    dlg = gtk_dialog_new_with_buttons(_("Print Destination"),
-            SP_DT_WIDGET(SP_ACTIVE_DESKTOP)->window,
+    GtkWidget *dlg = gtk_dialog_new_with_buttons(_("Print Destination"),
+//            SP_DT_WIDGET(SP_ACTIVE_DESKTOP)->window,
+            NULL,
             (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR | GTK_DIALOG_DESTROY_WITH_PARENT),
             GTK_STOCK_CANCEL,
             GTK_RESPONSE_CANCEL,
@@ -142,17 +113,17 @@ PrintPS::setup(Inkscape::Extension::Print * mod)
 
     gtk_dialog_set_default_response(GTK_DIALOG(dlg), GTK_RESPONSE_OK);
 
-    vbox = GTK_DIALOG(dlg)->vbox;
+    GtkWidget *vbox = GTK_DIALOG(dlg)->vbox;
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
     /* Print properties frame */
-    f = gtk_frame_new(_("Print properties"));
+    GtkWidget *f = gtk_frame_new(_("Print properties"));
     gtk_box_pack_start(GTK_BOX(vbox), f, FALSE, FALSE, 4);
-    vb = gtk_vbox_new(FALSE, 4);
+    GtkWidget *vb = gtk_vbox_new(FALSE, 4);
     gtk_container_add(GTK_CONTAINER(f), vb);
     gtk_container_set_border_width(GTK_CONTAINER(vb), 4);
     /* Print type */
-    p2bm = mod->get_param_bool("bitmap");
-    rb = gtk_radio_button_new_with_label(NULL, _("Print using PostScript operators"));
+    bool const p2bm = mod->get_param_bool("bitmap");
+    GtkWidget *rb = gtk_radio_button_new_with_label(NULL, _("Print using PostScript operators"));
     gtk_tooltips_set_tip((GtkTooltips *) tt, rb,
                          _("Use PostScript vector operators. The resulting image is usually smaller "
                            "in file size and can be arbitrarily scaled, but alpha transparency "
@@ -167,9 +138,9 @@ PrintPS::setup(Inkscape::Extension::Print * mod)
     if (p2bm) gtk_toggle_button_set_active((GtkToggleButton *) rb, TRUE);
     gtk_box_pack_start(GTK_BOX(vb), rb, FALSE, FALSE, 0);
     /* Resolution */
-    hb = gtk_hbox_new(FALSE, 4);
+    GtkWidget *hb = gtk_hbox_new(FALSE, 4);
     gtk_box_pack_start(GTK_BOX(vb), hb, FALSE, FALSE, 0);
-    combo = gtk_combo_new();
+    GtkWidget *combo = gtk_combo_new();
     gtk_combo_set_value_in_list(GTK_COMBO(combo), FALSE, FALSE);
     gtk_combo_set_use_arrows(GTK_COMBO(combo), TRUE);
     gtk_combo_set_use_arrows_always(GTK_COMBO(combo), TRUE);
@@ -177,20 +148,19 @@ PrintPS::setup(Inkscape::Extension::Print * mod)
     gtk_tooltips_set_tip((GtkTooltips *) tt, GTK_COMBO(combo)->entry,
                          _("Preferred resolution (dots per inch) of bitmap"), NULL);
     /* Setup strings */
-    sl = NULL;
-    for (i = 0; pdr[i] != NULL; i++) {
+    GList *sl = NULL;
+    for (unsigned i = 0; pdr[i] != NULL; i++) {
         sl = g_list_prepend(sl, (gpointer) pdr[i]);
     }
     sl = g_list_reverse(sl);
     gtk_combo_set_popdown_strings(GTK_COMBO(combo), sl);
     g_list_free(sl);
     if (1) {
-        const gchar * val = NULL;
-        val = mod->get_param_string("resolution");
+        gchar const *val = mod->get_param_string("resolution");
         gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry), val);
     }
     gtk_box_pack_end(GTK_BOX(hb), combo, FALSE, FALSE, 0);
-    l = gtk_label_new(_("Resolution:"));
+    GtkWidget *l = gtk_label_new(_("Resolution:"));
     gtk_box_pack_end(GTK_BOX(hb), l, FALSE, FALSE, 0);
 
     /* Print destination frame */
@@ -200,15 +170,18 @@ PrintPS::setup(Inkscape::Extension::Print * mod)
     gtk_container_add(GTK_CONTAINER(f), vb);
     gtk_container_set_border_width(GTK_CONTAINER(vb), 4);
 
-    l = gtk_label_new(_("Use '> filename' to print to file.\n"
+    l = gtk_label_new(_("Printer name (as given by lpstat -p);\n"
+                        "leave empty to use the system default printer.\n"
+                        "Use '> filename' to print to file.\n"
                         "Use '| prog arg...' to pipe to a program."));
     gtk_box_pack_start(GTK_BOX(vb), l, FALSE, FALSE, 0);
 
-    e = gtk_entry_new();
+    GtkWidget *e = gtk_entry_new();
     if (1) {
-        const gchar *val;
-        val = mod->get_param_string("destination");
-        gtk_entry_set_text(GTK_ENTRY(e), val);
+        gchar const *val = mod->get_param_string("destination");
+        gtk_entry_set_text(GTK_ENTRY(e), ( val != NULL
+                                           ? val
+                                           : "" ));
     }
     gtk_box_pack_start(GTK_BOX(vb), e, FALSE, FALSE, 0);
 
@@ -217,13 +190,13 @@ PrintPS::setup(Inkscape::Extension::Print * mod)
 
     gtk_widget_show_all(vbox);
 
-    response = gtk_dialog_run(GTK_DIALOG(dlg));
+    int const response = gtk_dialog_run(GTK_DIALOG(dlg));
 
     g_object_unref((GObject *) tt);
 
     if (response == GTK_RESPONSE_OK) {
-        const gchar *fn;
-        const char *sstr;
+        gchar const *fn;
+        char const *sstr;
 
         _bitmap = gtk_toggle_button_get_active((GtkToggleButton *) rb);
         sstr = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry));
@@ -248,26 +221,21 @@ PrintPS::setup(Inkscape::Extension::Print * mod)
 unsigned int
 PrintPS::begin(Inkscape::Extension::Print *mod, SPDocument *doc)
 {
-    Inkscape::SVGOStringStream os;
-    int res;
-    FILE *osf, *osp;
-    const gchar * fn;
-    gboolean epsexport=false;
+    gboolean epsexport = false;
 
     _latin1_encoded_fonts.clear();
     _newlatin1font_proc_defined = false;
 
-    fn = mod->get_param_string("destination");
-
-    osf = NULL;
-    osp = NULL;
+    FILE *osf = NULL;
+    FILE *osp = NULL;
 
     gsize bytesRead = 0;
     gsize bytesWritten = 0;
-    GError* error = NULL;
-    gchar* local_fn = g_filename_from_utf8( fn,
+    GError *error = NULL;
+    gchar const *utf8_fn = mod->get_param_string("destination");
+    gchar *local_fn = g_filename_from_utf8( utf8_fn,
                                             -1,  &bytesRead,  &bytesWritten, &error);
-    fn = local_fn;
+    gchar const *fn = local_fn;
 
     /* TODO: Replace the below fprintf's with something that does the right thing whether in
      * gui or batch mode (e.g. --print=blah).  Consider throwing an exception: currently one of
@@ -302,10 +270,10 @@ PrintPS::begin(Inkscape::Extension::Print *mod, SPDocument *doc)
             }
             _stream = osf;
         } else {
-            gchar *qn;
             /* put cwd stuff in here */
-            /* FIXME: quote fn */
-            qn = g_strdup_printf("lpr -P %s", fn);
+            gchar *qn = ( *fn
+                          ? g_strdup_printf("lpr -P %s", fn)  /* FIXME: quote fn */
+                          : g_strdup("lpr") );
 #ifndef WIN32
             osp = popen(qn, "w");
 #else
@@ -330,10 +298,9 @@ PrintPS::begin(Inkscape::Extension::Print *mod, SPDocument *doc)
 #endif
     }
 
-    if (epsexport)
-        res = fprintf(_stream, "%%!PS-Adobe-3.0 EPSF-3.0\n");
-    else
-        res = fprintf(_stream, "%%!PS-Adobe-3.0\n");
+    int const res = fprintf(_stream, ( epsexport
+                                       ? "%%!PS-Adobe-3.0 EPSF-3.0\n"
+                                       : "%%!PS-Adobe-3.0\n" ));
     /* flush this to test output stream as early as possible */
     if (fflush(_stream)) {
         /*g_print("caught error in sp_module_print_plain_begin\n");*/
@@ -372,6 +339,7 @@ PrintPS::begin(Inkscape::Extension::Print *mod, SPDocument *doc)
         d.y1 *= PT_PER_PX;
     }
 
+    Inkscape::SVGOStringStream os;
     if (res >= 0) {
 
         os << "%%Creator: " << PACKAGE_STRING << "\n";
@@ -450,80 +418,79 @@ PrintPS::begin(Inkscape::Extension::Print *mod, SPDocument *doc)
         }
     }
 
+    /* FIXME: This function is declared to return unsigned, whereas fprintf returns a signed int *
+     * that can be zero if the first fprintf failed (os is empty) or "negative" (i.e. very positive
+     * in unsigned int interpretation) if the first fprintf failed but this one succeeds, or
+     * positive if both succeed. */
     return fprintf(_stream, "%s", os.str().c_str());
 }
 
 unsigned int
 PrintPS::finish(Inkscape::Extension::Print *mod)
 {
-    int res;
-
     if (!_stream) return 0;
 
     if (_bitmap) {
-        double x0, y0, x1, y1;
-        int width, height;
-        float scale;
+        double const dots_per_pt = _dpi / PT_PER_IN;
+
+        double const x0 = 0.0;
+        double const y0 = 0.0;
+        double const x1 = x0 + _width;
+        double const y1 = y0 + _height;
+
+        /* Bitmap width/height in bitmap dots. */
+        int const width = (int) (_width * dots_per_pt + 0.5);
+        int const height = (int) (_height * dots_per_pt + 0.5);
+
         NRMatrix affine;
-        guchar *px;
-        int y;
-
-        scale = _dpi / 72.0;
-
-        y0 = 0.0;
-        x0 = 0.0;
-        x1 = _width;
-        y1 = _height;
-
-        width = (int) (_width * scale + 0.5);
-        height = (int) (_height * scale + 0.5);
-
-        affine.c[0] = width / (x1 - x0);
+        affine.c[0] = width / ((x1 - x0) * PX_PER_PT);
         affine.c[1] = 0.0;
         affine.c[2] = 0.0;
-        affine.c[3] = height / (y1 - y0);
+        affine.c[3] = height / ((y1 - y0) * PX_PER_PT);
         affine.c[4] = -affine.c[0] * x0;
         affine.c[5] = -affine.c[3] * y0;
 
         nr_arena_item_set_transform(mod->root, &affine);
 
-        px = nr_new(guchar, 4 * width * 64);
+        guchar *const px = g_new(guchar, 4 * width * 64);
 
-        for (y = 0; y < height; y += 64) {
+        for (int y = 0; y < height; y += 64) {
+            /* Set area of interest. */
             NRRectL bbox;
-            NRGC gc(NULL);
-            NRMatrix imgt;
-            NRPixBlock pb;
-            /* Set area of interest */
             bbox.x0 = 0;
             bbox.y0 = y;
             bbox.x1 = width;
             bbox.y1 = MIN(height, y + 64);
-            /* Update to renderable state */
+
+            /* Update to renderable state. */
+            NRGC gc(NULL);
             nr_matrix_set_identity(&gc.transform);
             nr_arena_item_invoke_update(mod->root, &bbox, &gc, NR_ARENA_ITEM_STATE_ALL, NR_ARENA_ITEM_STATE_NONE);
             /* Render */
             /* This should take guchar* instead of unsigned char*) */
+            NRPixBlock pb;
             nr_pixblock_setup_extern(&pb, NR_PIXBLOCK_MODE_R8G8B8A8N,
                                      bbox.x0, bbox.y0, bbox.x1, bbox.y1,
                                      (guchar*)px, 4 * width, FALSE, FALSE);
             memset(px, 0xff, 4 * width * 64);
             nr_arena_item_invoke_render(mod->root, &bbox, &pb, 0);
             /* Blitter goes here */
-            imgt.c[0] = (bbox.x1 - bbox.x0) / scale;
+            NRMatrix imgt;
+            imgt.c[0] = (bbox.x1 - bbox.x0) / dots_per_pt;
             imgt.c[1] = 0.0;
             imgt.c[2] = 0.0;
-            imgt.c[3] = (bbox.y1 - bbox.y0) / scale;
+            imgt.c[3] = (bbox.y1 - bbox.y0) / dots_per_pt;
             imgt.c[4] = 0.0;
-            imgt.c[5] = _height - y / scale - (bbox.y1 - bbox.y0) / scale;
+            imgt.c[5] = _height - y / dots_per_pt - (bbox.y1 - bbox.y0) / dots_per_pt;
 
             print_image(_stream, px, bbox.x1 - bbox.x0, bbox.y1 - bbox.y0, 4 * width, &imgt);
         }
 
-        nr_free(px);
+        g_free(px);
     }
 
-    res = fprintf(_stream, "showpage\n");
+    fprintf(_stream, "showpage\n");
+    int const res = fprintf(_stream, "%%%%EOF\n");
 
     /* Flush stream to be sure. */
     (void) fflush(_stream);
@@ -537,7 +504,7 @@ PrintPS::finish(Inkscape::Extension::Print *mod)
 }
 
 unsigned int
-PrintPS::bind(Inkscape::Extension::Print *mod, const NRMatrix *transform, float opacity)
+PrintPS::bind(Inkscape::Extension::Print *mod, NRMatrix const *transform, float opacity)
 {
     if (!_stream) return 0;  // XXX: fixme, returning -1 as unsigned.
     if (_bitmap) return 0;
@@ -563,7 +530,7 @@ PrintPS::release(Inkscape::Extension::Print *mod)
 }
 
 unsigned int
-PrintPS::comment(Inkscape::Extension::Print *mod, const char * comment)
+PrintPS::comment(Inkscape::Extension::Print *mod, char const *comment)
 {
     if (!_stream) return 0; // XXX: fixme, returning -1 as unsigned.
     if (_bitmap) return 0;
@@ -577,7 +544,7 @@ PrintPS::print_fill_style(SVGOStringStream &os, SPStyle const *const style, NRRe
     g_return_if_fail( style->fill.type == SP_PAINT_TYPE_COLOR
                       || ( style->fill.type == SP_PAINT_TYPE_PAINTSERVER
                            && SP_IS_GRADIENT(SP_STYLE_FILL_SERVER(style)) ) );
-    
+
     if (style->fill.type == SP_PAINT_TYPE_COLOR) {
         float rgb[3];
         sp_color_get_rgb_floatv(&style->fill.value.color, rgb);
@@ -588,9 +555,9 @@ PrintPS::print_fill_style(SVGOStringStream &os, SPStyle const *const style, NRRe
         g_assert( style->fill.type == SP_PAINT_TYPE_PAINTSERVER
                   && SP_IS_GRADIENT(SP_STYLE_FILL_SERVER(style)) );
 
-        if (SP_IS_LINEARGRADIENT (SP_STYLE_FILL_SERVER (style))) {
+        if (SP_IS_LINEARGRADIENT(SP_STYLE_FILL_SERVER(style))) {
 
-            SPLinearGradient *lg=SP_LINEARGRADIENT(SP_STYLE_FILL_SERVER (style));
+            SPLinearGradient *lg = SP_LINEARGRADIENT(SP_STYLE_FILL_SERVER(style));
             NR::Point p1 (lg->x1.computed, lg->y1.computed);
             NR::Point p2 (lg->x2.computed, lg->y2.computed);
             if (pbox && SP_GRADIENT(lg)->units == SP_GRADIENT_UNITS_OBJECTBOUNDINGBOX) {
@@ -607,7 +574,7 @@ PrintPS::print_fill_style(SVGOStringStream &os, SPStyle const *const style, NRRe
             os << "/Function <<\n/FunctionType 3\n/Functions\n[\n";
 
             sp_gradient_ensure_vector(SP_GRADIENT(lg)); // when exporting from commandline, vector is not built
-            for (gint i = 0; unsigned(i) < lg->vector.stops.size() - 1; i++) {
+            for (unsigned i = 0; i + 1 < lg->vector.stops.size(); i++) {
                 float rgb[3];
                 sp_color_get_rgb_floatv(&lg->vector.stops[i].color, rgb);
                 os << "<<\n/FunctionType 2\n/Domain [0 1]\n";
@@ -618,26 +585,28 @@ PrintPS::print_fill_style(SVGOStringStream &os, SPStyle const *const style, NRRe
             }
             os << "]\n/Domain [0 1]\n";
             os << "/Bounds [ ";
-            for (gint i=0;unsigned(i)<lg->vector.stops.size()-2;i++) {
+            for (unsigned i = 0; i + 2 < lg->vector.stops.size(); i++) {
                 os << lg->vector.stops[i+1].offset <<" ";
             }
             os << "]\n";
             os << "/Encode [ ";
-            for (gint i=0;unsigned(i)<lg->vector.stops.size()-1;i++) {
+            for (unsigned i = 0; i + 1 < lg->vector.stops.size(); i++) {
                 os << "0 1 ";
             }
             os << "]\n";
             os << ">>\n>>\n";
 
-        } else if (SP_IS_RADIALGRADIENT (SP_STYLE_FILL_SERVER (style))) {
+        } else if (SP_IS_RADIALGRADIENT(SP_STYLE_FILL_SERVER(style))) {
 
-            SPRadialGradient *rg=SP_RADIALGRADIENT(SP_STYLE_FILL_SERVER (style));
-            NR::Point c (rg->cx.computed, rg->cy.computed);
-            NR::Point f (rg->fx.computed, rg->fy.computed);
+            SPRadialGradient *rg = SP_RADIALGRADIENT(SP_STYLE_FILL_SERVER(style));
+            NR::Point c(rg->cx.computed, rg->cy.computed);
+            NR::Point f(rg->fx.computed, rg->fy.computed);
             double r = rg->r.computed;
             if (pbox && SP_GRADIENT(rg)->units == SP_GRADIENT_UNITS_OBJECTBOUNDINGBOX) {
                 // convert to userspace
-                NR::Matrix bbox2user(pbox->x1 - pbox->x0, 0, 0, pbox->y1 - pbox->y0, pbox->x0, pbox->y0);
+                NR::Matrix const bbox2user(pbox->x1 - pbox->x0, 0,
+                                           0, pbox->y1 - pbox->y0,
+                                           pbox->x0, pbox->y0);
                 c *= bbox2user;
                 f *= bbox2user;
                 r *= bbox2user.expansion();
@@ -650,7 +619,7 @@ PrintPS::print_fill_style(SVGOStringStream &os, SPStyle const *const style, NRRe
             os << "/Function <<\n/FunctionType 3\n/Functions\n[\n";
 
             sp_gradient_ensure_vector(SP_GRADIENT(rg)); // when exporting from commandline, vector is not built
-            for (gint i = 0; unsigned(i) < rg->vector.stops.size() - 1; i++) {
+            for (unsigned i = 0; i + 1 < rg->vector.stops.size(); i++) {
                 float rgb[3];
                 sp_color_get_rgb_floatv(&rg->vector.stops[i].color, rgb);
                 os << "<<\n/FunctionType 2\n/Domain [0 1]\n";
@@ -661,12 +630,12 @@ PrintPS::print_fill_style(SVGOStringStream &os, SPStyle const *const style, NRRe
             }
             os << "]\n/Domain [0 1]\n";
             os << "/Bounds [ ";
-            for (gint i=0;unsigned(i)<rg->vector.stops.size()-2;i++) {
-                os << rg->vector.stops[i+1].offset <<" ";
+            for (unsigned i = 0; i + 2 < rg->vector.stops.size(); i++) {
+                os << rg->vector.stops[i+1].offset << " ";
             }
             os << "]\n";
             os << "/Encode [ ";
-            for (gint i=0;unsigned(i)<rg->vector.stops.size()-1;i++) {
+            for (unsigned i = 0; i + 1 < rg->vector.stops.size(); i++) {
                 os << "0 1 ";
             }
             os << "]\n";
@@ -676,25 +645,26 @@ PrintPS::print_fill_style(SVGOStringStream &os, SPStyle const *const style, NRRe
 }
 
 void
-PrintPS::print_stroke_style(SVGOStringStream &os, const SPStyle *style)
+PrintPS::print_stroke_style(SVGOStringStream &os, SPStyle const *style)
 {
     float rgb[3];
     sp_color_get_rgb_floatv(&style->stroke.value.color, rgb);
 
     os << rgb[0] << " " << rgb[1] << " " << rgb[2] << " setrgbcolor\n";
 
-    // There are rare cases in which for a solid line stroke_dasharray_set is true. To avoid 
+    // There are rare cases in which for a solid line stroke_dasharray_set is true. To avoid
     // invalid PS-lines such as "[0.0000000 0.0000000] 0.0000000 setdash", which should be "[] 0 setdash",
     // we first check if all components of stroke_dash.dash are 0.
     bool LineSolid = true;
     if (style->stroke_dasharray_set &&
-        style->stroke_dash.n_dash &&
-        style->stroke_dash.dash ) {
+        style->stroke_dash.n_dash   &&
+        style->stroke_dash.dash       )
+    {
         int i = 0;
         while (LineSolid && (i < style->stroke_dash.n_dash)) {
-                i++;
                 if (style->stroke_dash.dash[i] > 0.00000001)
                     LineSolid = false;
+                i++;
         }
         if (!LineSolid) {
             os << "[";
@@ -746,9 +716,9 @@ PrintPS::fill(Inkscape::Extension::Print *mod, NRBPath const *bpath, NRMatrix co
                 SPGradient const *g = SP_GRADIENT(SP_STYLE_FILL_SERVER(style));
                 os << "eoclip\n";
                 if (g->gradientTransform_set) {
-                    os << "gsave [" << g->gradientTransform[0] << " " << g->gradientTransform[1] 
-                        << " " << g->gradientTransform[2] << " " << g->gradientTransform[3] 
-                        << " " << g->gradientTransform[4] << " " << g->gradientTransform[5] << "] concat\n"; 
+                    os << "gsave [" << g->gradientTransform[0] << " " << g->gradientTransform[1]
+                        << " " << g->gradientTransform[2] << " " << g->gradientTransform[3]
+                        << " " << g->gradientTransform[4] << " " << g->gradientTransform[5] << "] concat\n";
                 }
                 os << "shfill\n";
                 if (g->gradientTransform_set) {
@@ -764,9 +734,9 @@ PrintPS::fill(Inkscape::Extension::Print *mod, NRBPath const *bpath, NRMatrix co
                 SPGradient const *g = SP_GRADIENT(SP_STYLE_FILL_SERVER(style));
                 os << "clip\n";
                 if (g->gradientTransform_set) {
-                    os << "gsave [" << g->gradientTransform[0] << " " << g->gradientTransform[1] 
-                        << " " << g->gradientTransform[2] << " " << g->gradientTransform[3] 
-                        << " " << g->gradientTransform[4] << " " << g->gradientTransform[5] << "] concat\n"; 
+                    os << "gsave [" << g->gradientTransform[0] << " " << g->gradientTransform[1]
+                        << " " << g->gradientTransform[2] << " " << g->gradientTransform[3]
+                        << " " << g->gradientTransform[4] << " " << g->gradientTransform[5] << "] concat\n";
                 }
                 os << "shfill\n";
                 if (g->gradientTransform_set) {
@@ -778,15 +748,15 @@ PrintPS::fill(Inkscape::Extension::Print *mod, NRBPath const *bpath, NRMatrix co
         os << "grestore\n";
 
         fprintf(_stream, "%s", os.str().c_str());
-    }        
+    }
 
     return 0;
 }
 
 
 unsigned int
-PrintPS::stroke(Inkscape::Extension::Print *mod, const NRBPath *bpath, const NRMatrix *ctm, const SPStyle *style,
-                const NRRect *pbox, const NRRect *dbox, const NRRect *bbox)
+PrintPS::stroke(Inkscape::Extension::Print *mod, NRBPath const *bpath, NRMatrix const *ctm, SPStyle const *style,
+                NRRect const *pbox, NRRect const *dbox, NRRect const *bbox)
 {
     if (!_stream) return 0; // XXX: fixme, returning -1 as unsigned.
     if (_bitmap) return 0;
@@ -808,7 +778,7 @@ PrintPS::stroke(Inkscape::Extension::Print *mod, const NRBPath *bpath, const NRM
 
 unsigned int
 PrintPS::image(Inkscape::Extension::Print *mod, guchar *px, unsigned int w, unsigned int h, unsigned int rs,
-               const NRMatrix *transform, const SPStyle *style)
+               NRMatrix const *transform, SPStyle const *style)
 {
     if (!_stream) return 0; // XXX: fixme, returning -1 as unsigned.
     if (_bitmap) return 0;
@@ -835,7 +805,7 @@ PrintPS::image(Inkscape::Extension::Print *mod, guchar *px, unsigned int w, unsi
         for (c0 = 0; c0 < w; c0 += 24) {
             c1 = MIN(w, c0 + 24);
             for (c = c0; c < c1; c++) {
-                static const char xtab[] = {'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'};
+                static char const xtab[] = {'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'};
                 fputc(xtab[s[0] >> 4], _stream);
                 fputc(xtab[s[0] & 0xf], _stream);
                 fputc(xtab[s[1] >> 4], _stream);
@@ -854,8 +824,8 @@ PrintPS::image(Inkscape::Extension::Print *mod, guchar *px, unsigned int w, unsi
 #endif
 }
 
-const char *
-PrintPS::PSFontName(const SPStyle *style)
+char const *
+PrintPS::PSFontName(SPStyle const *style)
 {
     font_instance *tf = (font_factory::Default())->Face(style->text->font_family.value, font_style_to_pos(*style));
 
@@ -896,8 +866,8 @@ PrintPS::text(Inkscape::Extension::Print *mod, char const *text, NR::Point p,
     // Escape chars
     Inkscape::SVGOStringStream escaped_text;
     escaped_text << std::oct;
-    for (const gchar *p_text = text ; *p_text ; p_text = g_utf8_next_char(p_text)) {
-        gunichar c = g_utf8_get_char(p_text);
+    for (gchar const *p_text = text ; *p_text ; p_text = g_utf8_next_char(p_text)) {
+        gunichar const c = g_utf8_get_char(p_text);
         if (c == '\\' || c == ')' || c == '(')
             escaped_text << '\\' << static_cast<char>(c);
         else if (c >= 0x80)
@@ -909,7 +879,7 @@ PrintPS::text(Inkscape::Extension::Print *mod, char const *text, NR::Point p,
     os << "gsave\n";
 
     // set font
-    const char *fn = PSFontName(style);
+    char const *fn = PSFontName(style);
     if (_latin1_encoded_fonts.find(fn) == _latin1_encoded_fonts.end()) {
         if (!_newlatin1font_proc_defined) {
             // input: newfontname, existingfontname
@@ -933,7 +903,7 @@ PrintPS::text(Inkscape::Extension::Print *mod, char const *text, NR::Point p,
               && SP_IS_GRADIENT(SP_STYLE_FILL_SERVER(style)) ) )
     {
         // set fill style
-        print_fill_style(os, style, NULL); 
+        print_fill_style(os, style, NULL);
         // FIXME: we don't know the pbox of text, so have to pass NULL. This means gradients with
         // bbox units won't work with text. However userspace gradients don't work with text either
         // (text is black) for some reason.
@@ -966,26 +936,24 @@ PrintPS::text(Inkscape::Extension::Print *mod, char const *text, NR::Point p,
 /* PostScript helpers */
 
 void
-PrintPS::print_bpath(SVGOStringStream &os, const NArtBpath *bp)
+PrintPS::print_bpath(SVGOStringStream &os, NArtBpath const *bp)
 {
-    unsigned int closed;
-
     os << "newpath\n";
-    closed = FALSE;
+    bool closed = false;
     while (bp->code != NR_END) {
         switch (bp->code) {
             case NR_MOVETO:
                 if (closed) {
                     os << "closepath\n";
                 }
-                closed = TRUE;
+                closed = true;
                 os << bp->x3 << " " << bp->y3 << " moveto\n";
                 break;
             case NR_MOVETO_OPEN:
                 if (closed) {
                     os << "closepath\n";
                 }
-                closed = FALSE;
+                closed = false;
                 os << bp->x3 << " " << bp->y3 << " moveto\n";
                 break;
             case NR_LINETO:
@@ -1104,11 +1072,10 @@ void
 PrintPS::ascii85_flush(SVGOStringStream &os)
 {
     char c[5];
-    int i;
-    gboolean zero_case = (ascii85_buf == 0);
-    static int max_linewidth = 75;
+    bool const zero_case = (ascii85_buf == 0);
+    static int const max_linewidth = 75;
 
-    for (i=4; i >= 0; i--) {
+    for (int i = 4; i >= 0; i--) {
         c[i] = (ascii85_buf % 85) + '!';
         ascii85_buf /= 85;
     }
@@ -1122,7 +1089,7 @@ PrintPS::ascii85_flush(SVGOStringStream &os)
         os << 'z';
         ascii85_linewidth++;
     } else {
-        for (i=0; i < ascii85_len+1; i++) {
+        for (int i = 0; i < ascii85_len+1; i++) {
             if ((ascii85_linewidth >= max_linewidth) && (c[i] != '%')) {
                 os << '\n';
                 ascii85_linewidth = 0;
@@ -1170,11 +1137,8 @@ PrintPS::ascii85_done(SVGOStringStream &os)
 
 unsigned int
 PrintPS::print_image(FILE *ofp, guchar *px, unsigned int width, unsigned int height, unsigned int rs,
-                     const NRMatrix *transform)
+                     NRMatrix const *transform)
 {
-    unsigned int i, j;
-    /* gchar *data, *src; */
-    guchar *packb = NULL, *plane = NULL;
     Inkscape::SVGOStringStream os;
 
     os << "gsave\n";
@@ -1199,34 +1163,33 @@ PrintPS::print_image(FILE *ofp, guchar *px, unsigned int width, unsigned int hei
     os << "true 3\n";
 
     /* Allocate buffer for packbits data. Worst case: Less than 1% increase */
-    packb = (guchar *)g_malloc((width * 105)/100+2);
-    plane = (guchar *)g_malloc(width);
+    guchar *const packb = (guchar *)g_malloc((width * 105)/100+2);
+    guchar *const plane = (guchar *)g_malloc(width);
 
     /* ps_begin_data(ofp); */
     os << "colorimage\n";
 
-#define GET_RGB_TILE(begin) \
-  {int scan_lines; \
-    scan_lines = (i+tile_height-1 < height) ? tile_height : (height-i); \
-    gimp_pixel_rgn_get_rect(&pixel_rgn, begin, 0, i, width, scan_lines); \
-    src = begin; }
+/*#define GET_RGB_TILE(begin)                   \
+ *  {int scan_lines;                                                    \
+ *    scan_lines = (i+tile_height-1 < height) ? tile_height : (height-i); \
+ *    gimp_pixel_rgn_get_rect(&pixel_rgn, begin, 0, i, width, scan_lines); \
+ *    src = begin; }
+ */
 
-    for (i = 0; i < height; i++) {
+    for (unsigned i = 0; i < height; i++) {
         /* if ((i % tile_height) == 0) GET_RGB_TILE(data); */ /* Get more data */
-        guchar *plane_ptr, *src_ptr;
-        int rgb, nout;
-        guchar *src;
-
-        src = px + i * rs;
+        guchar const *const src = px + i * rs;
 
         /* Iterate over RGB */
-        for (rgb = 0; rgb < 3; rgb++) {
-            src_ptr = src + rgb;
-            plane_ptr = plane;
-            for (j = 0; j < width; j++) {
+        for (int rgb = 0; rgb < 3; rgb++) {
+            guchar const *src_ptr = src + rgb;
+            guchar *plane_ptr = plane;
+            for (unsigned j = 0; j < width; j++) {
                 *(plane_ptr++) = *src_ptr;
                 src_ptr += 4;
             }
+
+            int nout;
             compress_packbits(width, plane, &nout, packb);
 
             ascii85_init();
@@ -1257,7 +1220,7 @@ PrintPS::print_image(FILE *ofp, guchar *px, unsigned int width, unsigned int hei
     fprintf(ofp, "%s", os.str().c_str());
 
     return 0;
-#undef GET_RGB_TILE
+//#undef GET_RGB_TILE
 }
 
 bool
@@ -1266,25 +1229,23 @@ PrintPS::textToPath(Inkscape::Extension::Print * ext)
     return ext->get_param_bool("textToPath");
 }
 
+#include "clear-n_.h"
+
 void
 PrintPS::init(void)
 {
-    Inkscape::Extension::Extension * ext;
-
     /* SVG in */
-    ext = Inkscape::Extension::build_from_mem(
+    (void) Inkscape::Extension::build_from_mem(
         "<inkscape-extension>\n"
-        "<name>Postscript Print</name>\n"
+        "<name>" N_("Postscript Print") "</name>\n"
         "<id>" SP_MODULE_KEY_PRINT_PS "</id>\n"
         "<param name=\"bitmap\" type=\"boolean\">FALSE</param>\n"
         "<param name=\"resolution\" type=\"string\">72</param>\n"
-        "<param name=\"destination\" type=\"string\">lp</param>\n"
+        "<param name=\"destination\" type=\"string\">| lp</param>\n"
         "<param name=\"pageBoundingBox\" type=\"boolean\">TRUE</param>\n"
         "<param name=\"textToPath\" type=\"boolean\">TRUE</param>\n"
         "<print/>\n"
         "</inkscape-extension>", new PrintPS());
-
-    return;
 }
 
 
