@@ -13,6 +13,7 @@
 # include "config.h"
 #endif
 
+#include <glib/gmem.h>
 #include <libnr/nr-macros.h>
 #include <libnr/nr-matrix.h>
 
@@ -23,6 +24,7 @@
 #include "win32.h"
 #include "system.h"
 #include "extension/print.h"
+#include <gtk/gtk.h>
 
 /* Initialization */
 
@@ -254,7 +256,7 @@ PrintWin32::finish (Inkscape::Extension::Print *mod)
 	int sheight, row;
 	BITMAPINFO bmInfo = {
 		{
-			sizeof (BITMAPINFOHEADER), // bV4Size 
+			sizeof (BITMAPINFOHEADER), // bV4Size
 			64,      // biWidth
 			64,      // biHeight
 			1,       // biPlanes
@@ -277,14 +279,14 @@ PrintWin32::finish (Inkscape::Extension::Print *mod)
 	dpiX = (int) GetDeviceCaps (_hDC, LOGPIXELSX);
 	dpiY = (int) GetDeviceCaps (_hDC, LOGPIXELSY);
 	// Size in pixels of the printable area
-	pPhysicalWidth = GetDeviceCaps (_hDC, PHYSICALWIDTH); 
-	pPhysicalHeight = GetDeviceCaps (_hDC, PHYSICALHEIGHT); 
+	pPhysicalWidth = GetDeviceCaps (_hDC, PHYSICALWIDTH);
+	pPhysicalHeight = GetDeviceCaps (_hDC, PHYSICALHEIGHT);
 	// Top left corner of prontable area
-	pPhysicalOffsetX = GetDeviceCaps (_hDC, PHYSICALOFFSETX); 
-	pPhysicalOffsetY = GetDeviceCaps (_hDC, PHYSICALOFFSETY); 
+	pPhysicalOffsetX = GetDeviceCaps (_hDC, PHYSICALOFFSETX);
+	pPhysicalOffsetY = GetDeviceCaps (_hDC, PHYSICALOFFSETY);
 	// Size in pixels of the printable area
-	pPrintableWidth = GetDeviceCaps (_hDC, HORZRES); 
-	pPrintableHeight = GetDeviceCaps (_hDC, VERTRES); 
+	pPrintableWidth = GetDeviceCaps (_hDC, HORZRES);
+	pPrintableHeight = GetDeviceCaps (_hDC, VERTRES);
 
 	// Scaling from document to device
 	scalex = dpiX / 72.0;
@@ -311,7 +313,7 @@ PrintWin32::finish (Inkscape::Extension::Print *mod)
 	width = x1 - x0;
 	height = y1 - y0;
 
-	px = nr_new (unsigned char, 4 * 64 * width);
+	px = g_new (unsigned char, 4 * 64 * width);
 	sheight = 64;
 
 	/* Printing goes here */
@@ -367,7 +369,7 @@ PrintWin32::finish (Inkscape::Extension::Print *mod)
 		nr_pixblock_release (&pb);
 	}
 
-	nr_free (px);
+	g_free (px);
 
 	res = EndPage (_hDC);
 	res = EndDoc (_hDC);
@@ -476,15 +478,17 @@ PrintWin32::get_save_filename (unsigned char *dir, unsigned int *spns)
 	return g_strdup (fnbuf);
 }
 
+#include "clear-n_.h"
+
 void
 PrintWin32::init (void)
 {
 	Inkscape::Extension::Extension * ext;
-	
+
 	/* SVG in */
     ext = Inkscape::Extension::build_from_mem(
 		"<inkscape-extension>\n"
-			"<name>Windows 32-bit Print</name>\n"
+			"<name>" N_("Windows 32-bit Print") "</name>\n"
 			"<id>" SP_MODULE_KEY_PRINT_WIN32 "</id>\n"
 			"<param name=\"textToPath\" type=\"boolean\">TRUE</param>\n"
 			"<print/>\n"
