@@ -12,9 +12,9 @@
 
 #include "extension.h"
 
-#include <libnr/nr-path.h>
-#include <display/nr-arena-forward.h>
-#include <forward.h>
+#include "libnr/nr-path.h"
+#include "display/nr-arena-forward.h"
+#include "forward.h"
 
 namespace Inkscape {
 namespace Extension {
