@@ -15,22 +15,17 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#include <string.h>
 
 #include <interface.h>
-#include <glibmm/i18n.h>
-#include "xml/repr.h"
-#include "document.h"
-#include "inkscape.h"
 
-#include "extension/extension.h"
-#include "system.h"
 #include "db.h"
 #include "input.h"
 #include "output.h"
 #include "effect.h"
+#include "patheffect.h"
 #include "print.h"
 #include "implementation/script.h"
+#include "implementation/xslt.h"
 /* #include "implementation/plugin.h" */
 
 namespace Inkscape {
@@ -110,7 +105,7 @@ open(Extension *key, gchar const *filename)
     Inkscape::XML::Node *repr = sp_document_repr_root(doc);
     gboolean saved = sp_document_get_undo_sensitive(doc);
     sp_document_set_undo_sensitive(doc, FALSE);
-    sp_repr_set_attr(repr, "sodipodi:modified", NULL);
+    repr->setAttribute("sodipodi:modified", NULL);
     sp_document_set_undo_sensitive(doc, saved);
 
     sp_document_set_uri(doc, filename);
@@ -332,6 +327,7 @@ build_from_reprdoc(Inkscape::XML::Document *doc, Implementation::Implementation
 {
     enum {
         MODULE_EXTENSION,
+        MODULE_XSLT,
         /* MODULE_PLUGIN, */
         MODULE_UNKNOWN_IMP
     } module_implementation_type = MODULE_UNKNOWN_IMP;
@@ -340,6 +336,7 @@ build_from_reprdoc(Inkscape::XML::Document *doc, Implementation::Implementation
         MODULE_OUTPUT,
         MODULE_FILTER,
         MODULE_PRINT,
+        MODULE_PATH_EFFECT,
         MODULE_UNKNOWN_FUNC
     } module_functional_type = MODULE_UNKNOWN_FUNC;
 
@@ -366,8 +363,12 @@ build_from_reprdoc(Inkscape::XML::Document *doc, Implementation::Implementation
             module_functional_type = MODULE_FILTER;
         } else if (!strcmp(element_name, "print")) {
             module_functional_type = MODULE_PRINT;
+        } else if (!strcmp(element_name, "path-effect")) {
+            module_functional_type = MODULE_PATH_EFFECT;
         } else if (!strcmp(element_name, "script")) {
             module_implementation_type = MODULE_EXTENSION;
+        } else if (!strcmp(element_name, "xslt")) {
+            module_implementation_type = MODULE_XSLT;
 #if 0
         } else if (!strcmp(element_name, "plugin")) {
             module_implementation_type = MODULE_PLUGIN;
@@ -376,7 +377,7 @@ build_from_reprdoc(Inkscape::XML::Document *doc, Implementation::Implementation
 
         //Inkscape::XML::Node *old_repr = child_repr;
         child_repr = sp_repr_next(child_repr);
-        //sp_repr_unref(old_repr);
+        //Inkscape::GC::release(old_repr);
     }
 
     Implementation::Implementation *imp;
@@ -387,6 +388,11 @@ build_from_reprdoc(Inkscape::XML::Document *doc, Implementation::Implementation
                 imp = static_cast<Implementation::Implementation *>(script);
                 break;
             }
+            case MODULE_XSLT: {
+                Implementation::XSLT *xslt = new Implementation::XSLT();
+                imp = static_cast<Implementation::Implementation *>(xslt);
+                break;
+            }
 #if 0
             case MODULE_PLUGIN: {
                 Implementation::Plugin *plugin = new Implementation::Plugin();
@@ -421,6 +427,10 @@ build_from_reprdoc(Inkscape::XML::Document *doc, Implementation::Implementation
             module = new Print(repr, imp);
             break;
         }
+        case MODULE_PATH_EFFECT: {
+            module = new PathEffect(repr, imp);
+            break;
+        }
         default: {
             break;
         }
@@ -444,8 +454,9 @@ build_from_file(gchar const *filename)
        DTD in general for this stuff */
     Inkscape::XML::Document *doc = sp_repr_read_file(filename, NULL);
     Extension *ext = build_from_reprdoc(doc, NULL);
-    Inkscape::GC::release(doc);
-    if (ext == NULL)
+    if (ext != NULL)
+        Inkscape::GC::release(doc);
+    else
         g_warning("Unable to create extension from definition file %s.\n", filename);
     return ext;
 }
