@@ -25,16 +25,9 @@
 # include "config.h"
 #endif
 
-#include <string.h>
-#include <time.h>
+#include <glib/gmem.h>
 #include <libnr/nr-pixops.h>
-#include <glib.h>
 
-#include <gtkmm.h>
-
-#include "macros.h"
-#include "xml/node-fns.h"
-#include "document.h"
 #include "document-private.h"
 #include "selection-chemistry.h"
 #include "ui/view/view-widget.h"
@@ -45,14 +38,11 @@
 #include "inkscape.h"
 #include "desktop.h"
 #include "selection.h"
-#include "sp-image.h"
 #include "interface.h"
 #include "style.h"
 #include "print.h"
 #include "file.h"
-#include "dialogs/dialog-events.h"
 #include "message-stack.h"
-
 #include "dialogs/filedialog.h"
 #include "prefs-utils.h"
 #include "path-prefix.h"
@@ -61,14 +51,15 @@
 #include "desktop-handles.h"
 
 #include "extension/db.h"
-#include "extension/extension.h"
 #include "extension/input.h"
 #include "extension/output.h"
 /* #include "extension/menu.h"  */
 #include "extension/system.h"
 
 #include "io/sys.h"
-
+#include "application/application.h"
+#include "application/editor.h"
+#include "inkscape.h"
 #include "uri.h"
 
 #ifdef WITH_INKBOARD
@@ -106,29 +97,47 @@ sp_file_new(gchar const *templ)
     SPDocument *doc = sp_document_new(templ, TRUE, true);
     g_return_val_if_fail(doc != NULL, NULL);
 
-    SPViewWidget *dtw = sp_desktop_widget_new(sp_document_namedview(doc, NULL));
-    sp_document_unref(doc);
-    g_return_val_if_fail(dtw != NULL, NULL);
+    SPDesktop *dt;
+    if (Inkscape::NSApplication::Application::getNewGui())
+    {
+        dt = Inkscape::NSApplication::Editor::createDesktop (doc);
+    } else {
+        SPViewWidget *dtw = sp_desktop_widget_new(sp_document_namedview(doc, NULL));
+        g_return_val_if_fail(dtw != NULL, NULL);
+        sp_document_unref(doc);
 
-    sp_create_window(dtw, TRUE);
-    SPDesktop *dt = static_cast<SPDesktop*>(dtw->view);
-    sp_namedview_window_from_document(dt);
-	return dt;
+        sp_create_window(dtw, TRUE);
+        dt = static_cast<SPDesktop*>(dtw->view);
+        sp_namedview_window_from_document(dt);
+    }
+    return dt;
 }
 
 SPDesktop*
 sp_file_new_default()
 {
-    // TRANSLATORS: default.svg is localizable - this is the name of the default document
-    //  template. This way you can localize the default pagesize, translate the name of
-    //  the default layer, etc. If you wish to localize this file, please create a
-    //  localized share/templates/default.xx.svg file, where xx is your language code.
-    char *default_template = g_build_filename(INKSCAPE_TEMPLATESDIR, _("default.svg"), NULL);
-    if (Inkscape::IO::file_test(default_template, G_FILE_TEST_IS_REGULAR)) {
-        return sp_file_new(default_template);
-    } else {
-        return sp_file_new(NULL);
+    std::list<gchar *> sources;
+    sources.push_back( profile_path("templates") ); // first try user's local dir
+    sources.push_back( g_strdup(INKSCAPE_TEMPLATESDIR) ); // then the system templates dir
+
+    while (!sources.empty()) {
+        gchar *dirname = sources.front();
+        if ( Inkscape::IO::file_test( dirname, (GFileTest)(G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR) ) ) {
+
+            // TRANSLATORS: default.svg is localizable - this is the name of the default document
+            //  template. This way you can localize the default pagesize, translate the name of
+            //  the default layer, etc. If you wish to localize this file, please create a
+            //  localized share/templates/default.xx.svg file, where xx is your language code.
+            char *default_template = g_build_filename(dirname, _("default.svg"), NULL);
+            if (Inkscape::IO::file_test(default_template, G_FILE_TEST_IS_REGULAR)) {
+                return sp_file_new(default_template);
+            }
+        }
+        g_free(dirname);
+        sources.pop_front();
     }
+
+    return sp_file_new(NULL);
 }
 
 
@@ -171,18 +180,24 @@ sp_file_open(gchar const *uri, Inkscape::Extension::Extension *key, bool add_to_
 
     if (doc) {
         SPDesktop *desktop = SP_ACTIVE_DESKTOP;
-        SPDocument *existing = desktop ? SP_DT_DOCUMENT(desktop) : NULL;
-        
+        SPDocument *existing = desktop ? sp_desktop_document(desktop) : NULL;
+
         if (existing && existing->virgin && replace_empty) {
             // If the current desktop is empty, open the document there
+            sp_document_ensure_up_to_date (doc);
             desktop->change_document(doc);
+            sp_document_resized_signal_emit (doc, sp_document_width(doc), sp_document_height(doc));
         } else {
-            // create a whole new desktop and window
-            SPViewWidget *dtw = sp_desktop_widget_new(sp_document_namedview(doc, NULL));
-            sp_create_window(dtw, TRUE);
-            desktop = static_cast<SPDesktop*>(dtw->view);
+            if (!Inkscape::NSApplication::Application::getNewGui()) {
+                // create a whole new desktop and window
+                SPViewWidget *dtw = sp_desktop_widget_new(sp_document_namedview(doc, NULL));
+                sp_create_window(dtw, TRUE);
+                desktop = static_cast<SPDesktop*>(dtw->view);
+            } else {
+                desktop = Inkscape::NSApplication::Editor::createDesktop (doc);
+            }
         }
-        
+
         doc->virgin = FALSE;
         // everyone who cares now has a reference, get rid of ours
         sp_document_unref(doc);
@@ -218,7 +233,7 @@ sp_file_revert_dialog()
     SPDesktop  *desktop = SP_ACTIVE_DESKTOP;
     g_assert(desktop != NULL);
 
-    SPDocument *doc = SP_DT_DOCUMENT(desktop);
+    SPDocument *doc = sp_desktop_document(desktop);
     g_assert(doc != NULL);
 
     Inkscape::XML::Node     *repr = sp_document_repr_root(doc);
@@ -234,17 +249,10 @@ sp_file_revert_dialog()
     if (repr->attribute("sodipodi:modified") != NULL) {
         gchar *text = g_strdup_printf(_("Changes will be lost!  Are you sure you want to reload document %s?"), uri);
 
-        GtkWidget *dialog = gtk_message_dialog_new(
-                GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(desktop->owner))),
-                GTK_DIALOG_DESTROY_WITH_PARENT,
-                GTK_MESSAGE_WARNING,
-                GTK_BUTTONS_YES_NO,
-                text);
-        gint response = gtk_dialog_run(GTK_DIALOG(dialog));
-        gtk_widget_destroy(dialog);
+        bool response = desktop->warnDialog (text);
         g_free(text);
 
-        if (response != GTK_RESPONSE_YES) {
+        if (!response) {
             do_revert = false;
         }
     }
@@ -399,7 +407,7 @@ sp_file_open_dialog(gpointer object, gpointer data)
         {
 
 #ifdef INK_DUMP_FILENAME_CONV
-            g_message(" FileName: %s",(const char *)list->data);           
+            g_message(" FileName: %s",(const char *)list->data);
 #endif
 
             fileName=(gchar *)g_strdup((gchar *)list->data);
@@ -427,7 +435,7 @@ sp_file_open_dialog(gpointer object, gpointer data)
                     g_warning( "ERROR CONVERTING OPEN FILENAME TO UTF-8" );
                 }
 
-#ifdef INK_DUMP_FILENAME_CONV                
+#ifdef INK_DUMP_FILENAME_CONV
                 g_message("Opening File %s\n",fileName);
 #endif
 
@@ -438,7 +446,7 @@ sp_file_open_dialog(gpointer object, gpointer data)
             {
                 g_message("Cannot Open Directory %s\n",fileName);
             }
-            
+
             list=list->next;
         }
 
@@ -810,7 +818,7 @@ file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension
              child != NULL; child = SP_OBJECT_NEXT(child))
         {
             // FIXME: in case of id conflict, newly added thing will be re-ided and thus likely break a reference to it from imported stuff
-            sp_repr_add_child(SP_OBJECT_REPR(in_defs), SP_OBJECT_REPR(child)->duplicate(), last_def);
+            SP_OBJECT_REPR(in_defs)->addChild(SP_OBJECT_REPR(child)->duplicate(), last_def);
         }
 
         guint items_count = 0;
@@ -834,7 +842,7 @@ file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension
 
                     // convert layers to groups; FIXME: add "preserve layers" mode where each layer
                     // from impot is copied to the same-named layer in host
-                    sp_repr_set_attr (newchild, "inkscape:groupmode", NULL);
+                    newchild->setAttribute("inkscape:groupmode", NULL);
 
                     newgroup->appendChild(newchild);
                 }
@@ -849,13 +857,13 @@ file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension
                 new_obj = SP_DOCUMENT_ROOT(in_doc)->appendChildRepr(newgroup);
             }
 
-            sp_repr_unref(newgroup);
+            Inkscape::GC::release(newgroup);
         } else {
             // just add one item
             for (SPObject *child = sp_object_first_child(SP_DOCUMENT_ROOT(doc)); child != NULL; child = SP_OBJECT_NEXT(child) ) {
                 if (SP_IS_ITEM(child)) {
                     Inkscape::XML::Node *newitem = SP_OBJECT_REPR(child)->duplicate();
-                    sp_repr_set_attr (newitem, "inkscape:groupmode", NULL);
+                    newitem->setAttribute("inkscape:groupmode", NULL);
 
                     if (desktop) {
                         // Add it to the current layer
@@ -874,7 +882,7 @@ file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension
 
         // select and move the imported item
         if (new_obj && SP_IS_ITEM(new_obj)) {
-            Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+            Inkscape::Selection *selection = sp_desktop_selection(desktop);
             selection->set(SP_ITEM(new_obj));
 
             // To move the imported object, we must temporarily set the "transform pattern with
@@ -882,7 +890,7 @@ file_import(SPDocument *in_doc, gchar const *uri, Inkscape::Extension::Extension
             {
                 int const saved_pref = prefs_get_int_attribute("options.transform", "pattern", 1);
                 prefs_set_int_attribute("options.transform", "pattern", 1);
-                sp_document_ensure_up_to_date(SP_DT_DOCUMENT(desktop));
+                sp_document_ensure_up_to_date(sp_desktop_document(desktop));
                 NR::Point m( desktop->point() - selection->bounds().midpoint() );
                 sp_selection_move_relative(selection, m);
                 prefs_set_int_attribute("options.transform", "pattern", saved_pref);
@@ -1163,10 +1171,10 @@ sp_export_png_file(SPDocument *doc, gchar const *filename,
         write_status = sp_png_write_rgba_striped(filename, width, height, sp_export_get_rows, &ebp);
         nr_pixelstore_64K_free(ebp.px);
     } else {
-        ebp.px = nr_new(guchar, 4 * 64 * width);
+        ebp.px = g_new(guchar, 4 * 64 * width);
         ebp.sheight = 64;
         write_status = sp_png_write_rgba_striped(filename, width, height, sp_export_get_rows, &ebp);
-        nr_free(ebp.px);
+        g_free(ebp.px);
     }
 
     // Hide items
@@ -1312,7 +1320,7 @@ void Inkscape::IO::fixupHrefs( SPDocument *doc, const gchar *base, gboolean spns
         if (href && g_path_is_absolute(href)) {
             const gchar *relname = sp_relative_path_from_path(href, base);
             //g_message("     setting to [%s]", relname );
-            sp_repr_set_attr(ir, "xlink:href", relname);
+            ir->setAttribute("xlink:href", relname);
         }
 // TODO next refinement is to make the first choice keeping the relative path as-is if
 //      based on the new location it gives us a valid file.
