@@ -1,6 +1,3 @@
-#include <cmath>
-#include "fontsize-expansion.h"
-#include "libnr/nr-matrix.h"
 #include "libnr/nr-matrix-ops.h"
 
 /**
