@@ -13,30 +13,23 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <string.h>
-#include <ctype.h>
 
 #include "style.h"
 #include "document-private.h"
 #include "desktop-style.h"
 
-#include "sp-gradient.h"
 #include "sp-gradient-reference.h"
 #include "sp-linear-gradient.h"
 #include "sp-radial-gradient.h"
 #include "sp-stop.h"
 #include "widgets/gradient-vector.h"
 
-#include "sp-root.h"
+#include "sp-text.h"
 #include "sp-tspan.h"
-#include "gradient-chemistry.h"
-#include "libnr/nr-point-ops.h"
-#include <libnr/nr-rect.h>
-#include <libnr/nr-matrix.h>
 #include <libnr/nr-matrix-fns.h>
-#include <libnr/nr-point-matrix-ops.h>
 #include "xml/repr.h"
 #include "svg/svg.h"
+#include "svg/svg-color.h"
 
 
 // Terminology:
@@ -110,14 +103,14 @@ sp_gradient_get_private_normalized(SPDocument *document, SPGradient *vector, SPG
     }
 
     // privates are garbage-collectable
-    sp_repr_set_attr(repr, "inkscape:collect", "always");
+    repr->setAttribute("inkscape:collect", "always");
 
     // link to vector
     sp_gradient_repr_set_link(repr, vector);
 
     /* Append the new private gradient to defs */
     SP_OBJECT_REPR(defs)->appendChild(repr);
-    sp_repr_unref(repr);
+    Inkscape::GC::release(repr);
 
     // get corresponding object
     SPGradient *gr = (SPGradient *) document->getObjectByRepr(repr);
@@ -213,20 +206,20 @@ sp_gradient_fork_private_if_necessary(SPGradient *gr, SPGradient *vector,
         // copy all the attributes to it
         Inkscape::XML::Node *repr_new = SP_OBJECT_REPR(gr_new);
         Inkscape::XML::Node *repr = SP_OBJECT_REPR(gr);
-        sp_repr_set_attr(repr_new, "gradientUnits", repr->attribute("gradientUnits"));
-        sp_repr_set_attr(repr_new, "gradientTransform", repr->attribute("gradientTransform"));
-        sp_repr_set_attr(repr_new, "spreadMethod", repr->attribute("spreadMethod"));
+        repr_new->setAttribute("gradientUnits", repr->attribute("gradientUnits"));
+        repr_new->setAttribute("gradientTransform", repr->attribute("gradientTransform"));
+        repr_new->setAttribute("spreadMethod", repr->attribute("spreadMethod"));
         if (SP_IS_RADIALGRADIENT(gr)) {
-            sp_repr_set_attr(repr_new, "cx", repr->attribute("cx"));
-            sp_repr_set_attr(repr_new, "cy", repr->attribute("cy"));
-            sp_repr_set_attr(repr_new, "fx", repr->attribute("fx"));
-            sp_repr_set_attr(repr_new, "fy", repr->attribute("fy"));
-            sp_repr_set_attr(repr_new, "r", repr->attribute("r"));
+            repr_new->setAttribute("cx", repr->attribute("cx"));
+            repr_new->setAttribute("cy", repr->attribute("cy"));
+            repr_new->setAttribute("fx", repr->attribute("fx"));
+            repr_new->setAttribute("fy", repr->attribute("fy"));
+            repr_new->setAttribute("r", repr->attribute("r"));
         } else {
-            sp_repr_set_attr(repr_new, "x1", repr->attribute("x1"));
-            sp_repr_set_attr(repr_new, "y1", repr->attribute("y1"));
-            sp_repr_set_attr(repr_new, "x2", repr->attribute("x2"));
-            sp_repr_set_attr(repr_new, "y2", repr->attribute("y2"));
+            repr_new->setAttribute("x1", repr->attribute("x1"));
+            repr_new->setAttribute("y1", repr->attribute("y1"));
+            repr_new->setAttribute("x2", repr->attribute("x2"));
+            repr_new->setAttribute("y2", repr->attribute("y2"));
         }
 
         return gr_new;
@@ -242,10 +235,10 @@ sp_gradient_fork_vector_if_necessary (SPGradient *gr)
         SPDocument *document = SP_OBJECT_DOCUMENT(gr);
 
         Inkscape::XML::Node *repr = SP_OBJECT_REPR (gr)->duplicate();
-        sp_repr_add_child (SP_OBJECT_REPR (SP_DOCUMENT_DEFS (document)), repr, NULL);
+        SP_OBJECT_REPR (SP_DOCUMENT_DEFS (document))->addChild(repr, NULL);
         SPGradient *gr_new = (SPGradient *) document->getObjectByRepr(repr);
         gr_new = sp_gradient_ensure_vector_normalized (gr_new);
-        sp_repr_unref (repr);
+        Inkscape::GC::release(repr);
         return gr_new;
     }
     return gr;
@@ -253,7 +246,7 @@ sp_gradient_fork_vector_if_necessary (SPGradient *gr)
 
 /**
  * Convert an item's gradient to userspace _without_ preserving coords, setting them to defaults
- * instead. No forking or reapplying is done because this is only called for newly created privates.  
+ * instead. No forking or reapplying is done because this is only called for newly created privates.
  * @return The new gradient.
  */
 SPGradient *
@@ -262,15 +255,14 @@ sp_gradient_reset_to_userspace (SPGradient *gr, SPItem *item)
     Inkscape::XML::Node *repr = SP_OBJECT_REPR(gr);
 
     // calculate the bbox of the item
-    NRRect bbox;
     sp_document_ensure_up_to_date(SP_OBJECT_DOCUMENT(item));
-    sp_item_invoke_bbox(item, &bbox, NR::identity(), TRUE); // we need "true" bbox without item_i2d_affine
+    NR::Rect const bbox = item->invokeBbox(NR::identity()); // we need "true" bbox without item_i2d_affine
 
-    double width = bbox.x1 - bbox.x0;
-    double height = bbox.y1 - bbox.y0;
-    g_assert (height > 0 && width > 0);
+    NR::Coord const width = bbox.dimensions()[NR::X];
+    NR::Coord const height = bbox.dimensions()[NR::Y];
+    g_assert(width > 0 && height > 0);
 
-    NR::Point center = NR::Point (0.5 * (bbox.x1 + bbox.x0), 0.5 * (bbox.y1 + bbox.y0));
+    NR::Point const center = bbox.midpoint();
 
     if (SP_IS_RADIALGRADIENT(gr)) {
         sp_repr_set_svg_double(repr, "cx", center[NR::X]);
@@ -280,17 +272,17 @@ sp_gradient_reset_to_userspace (SPGradient *gr, SPItem *item)
         sp_repr_set_svg_double(repr, "r", width/2);
 
         // we want it to be elliptic, not circular
-        NR::Matrix squeeze = NR::Matrix (NR::translate (-center)) * 
-            NR::Matrix (NR::scale(1, height/width)) * 
+        NR::Matrix squeeze = NR::Matrix (NR::translate (-center)) *
+            NR::Matrix (NR::scale(1, height/width)) *
             NR::Matrix (NR::translate (center));
 
         gr->gradientTransform = squeeze;
         {
             gchar c[256];
             if (sp_svg_transform_write(c, 256, gr->gradientTransform)) {
-                sp_repr_set_attr(SP_OBJECT_REPR(gr), "gradientTransform", c);
+                SP_OBJECT_REPR(gr)->setAttribute("gradientTransform", c);
             } else {
-                sp_repr_set_attr(SP_OBJECT_REPR(gr), "gradientTransform", NULL);
+                SP_OBJECT_REPR(gr)->setAttribute("gradientTransform", NULL);
             }
         }
     } else {
@@ -301,7 +293,7 @@ sp_gradient_reset_to_userspace (SPGradient *gr, SPItem *item)
     }
 
     // set the gradientUnits
-    sp_repr_set_attr(repr, "gradientUnits", "userSpaceOnUse");
+    repr->setAttribute("gradientUnits", "userSpaceOnUse");
 
     return gr;
 }
@@ -324,10 +316,11 @@ sp_gradient_convert_to_userspace(SPGradient *gr, SPItem *item, gchar const *prop
         Inkscape::XML::Node *repr = SP_OBJECT_REPR(gr);
 
         // calculate the bbox of the item
-        NRRect bbox;
         sp_document_ensure_up_to_date(SP_OBJECT_DOCUMENT(item));
-        sp_item_invoke_bbox(item, &bbox, NR::identity(), TRUE); // we need "true" bbox without item_i2d_affine
-        NR::Matrix bbox2user(bbox.x1 - bbox.x0, 0, 0, bbox.y1 - bbox.y0, bbox.x0, bbox.y0);
+        NR::Rect const bbox = item->invokeBbox(NR::identity()); // we need "true" bbox without item_i2d_affine
+        NR::Matrix bbox2user(bbox.dimensions()[NR::X], 0,
+                             0, bbox.dimensions()[NR::Y],
+                             bbox.min()[NR::X], bbox.min()[NR::Y]);
 
         /* skew is the additional transform, defined by the proportions of the item, that we need
          * to apply to the gradient in order to work around this weird bit from SVG 1.1
@@ -357,9 +350,9 @@ sp_gradient_convert_to_userspace(SPGradient *gr, SPItem *item, gchar const *prop
         {
             gchar c[256];
             if (sp_svg_transform_write(c, 256, gr->gradientTransform)) {
-                sp_repr_set_attr(SP_OBJECT_REPR(gr), "gradientTransform", c);
+                SP_OBJECT_REPR(gr)->setAttribute("gradientTransform", c);
             } else {
-                sp_repr_set_attr(SP_OBJECT_REPR(gr), "gradientTransform", NULL);
+                SP_OBJECT_REPR(gr)->setAttribute("gradientTransform", NULL);
             }
         }
 
@@ -402,7 +395,7 @@ sp_gradient_convert_to_userspace(SPGradient *gr, SPItem *item, gchar const *prop
         }
 
         // set the gradientUnits
-        sp_repr_set_attr(repr, "gradientUnits", "userSpaceOnUse");
+        repr->setAttribute("gradientUnits", "userSpaceOnUse");
     }
 
     // apply the gradient to the item (may be necessary if we forked it); not recursive
@@ -430,9 +423,9 @@ sp_gradient_transform_multiply(SPGradient *gradient, NR::Matrix postmul, bool se
 
     gchar c[256];
     if (sp_svg_transform_write(c, 256, gradient->gradientTransform)) {
-        sp_repr_set_attr(SP_OBJECT_REPR(gradient), "gradientTransform", c);
+        SP_OBJECT_REPR(gradient)->setAttribute("gradientTransform", c);
     } else {
-        sp_repr_set_attr(SP_OBJECT_REPR(gradient), "gradientTransform", NULL);
+        SP_OBJECT_REPR(gradient)->setAttribute("gradientTransform", NULL);
     }
 }
 
@@ -457,7 +450,7 @@ sp_item_gradient (SPItem *item, bool fill_or_stroke)
             }
         }
     }
- 
+
    return gradient;
 }
 
@@ -475,7 +468,7 @@ sp_first_stop(SPGradient *gradient)
 SPStop*
 sp_prev_stop(SPStop *stop, SPGradient *gradient)
 {
-	if (sp_object_first_child(SP_OBJECT(gradient)) == SP_OBJECT(stop)) 
+	if (sp_object_first_child(SP_OBJECT(gradient)) == SP_OBJECT(stop))
 		return NULL;
 	SPObject *found = NULL;
 	for ( SPObject *ochild = sp_object_first_child(SP_OBJECT(gradient)) ; ochild != NULL ; ochild = SP_OBJECT_NEXT(ochild) ) {
@@ -608,7 +601,7 @@ sp_item_gradient_stop_set_style (SPItem *item, guint point_num, bool fill_or_str
         {
             SPStop *first = sp_first_stop (vector);
             if (first) {
-                sp_repr_css_set (SP_OBJECT_REPR (first), stop, "style");
+                sp_repr_css_change (SP_OBJECT_REPR (first), stop, "style");
             }
         }
         break;
@@ -619,7 +612,7 @@ sp_item_gradient_stop_set_style (SPItem *item, guint point_num, bool fill_or_str
         {
             SPStop *last = sp_last_stop (vector);
             if (last) {
-                sp_repr_css_set (SP_OBJECT_REPR (last), stop, "style");
+                sp_repr_css_change (SP_OBJECT_REPR (last), stop, "style");
             }
         }
         break;
@@ -628,6 +621,59 @@ sp_item_gradient_stop_set_style (SPItem *item, guint point_num, bool fill_or_str
     }
 }
 
+void
+sp_item_gradient_reverse_vector (SPItem *item, bool fill_or_stroke)
+{
+    SPGradient *gradient = sp_item_gradient (item, fill_or_stroke);
+    if (!gradient || !SP_IS_GRADIENT(gradient))
+        return;
+
+    SPGradient *vector = sp_gradient_get_vector (gradient, false);
+    if (!vector) // orphan!
+        return;
+
+    vector = sp_gradient_fork_vector_if_necessary (vector);
+    if ( gradient != vector && gradient->ref->getObject() != vector ) {
+        sp_gradient_repr_set_link(SP_OBJECT_REPR(gradient), vector);
+    }
+
+    GSList *child_reprs = NULL;
+    GSList *child_objects = NULL;
+    std::vector<double> offsets;
+    for (SPObject *child = sp_object_first_child(vector);
+         child != NULL; child = SP_OBJECT_NEXT(child)) {
+        child_reprs = g_slist_prepend (child_reprs, SP_OBJECT_REPR(child));
+        child_objects = g_slist_prepend (child_objects, child);
+        offsets.push_back(sp_repr_get_double_attribute(SP_OBJECT_REPR(child), "offset", 0));
+    }
+
+    GSList *child_copies = NULL;
+    for (GSList *i = child_reprs; i != NULL; i = i->next) {
+        Inkscape::XML::Node *repr = (Inkscape::XML::Node *) i->data;
+        child_copies = g_slist_append (child_copies, repr->duplicate());
+    }
+
+
+    for (GSList *i = child_objects; i != NULL; i = i->next) {
+        SPObject *child = SP_OBJECT (i->data);
+        child->deleteObject();
+    }
+
+    std::vector<double>::iterator iter = offsets.end() - 1;
+    for (GSList *i = child_copies; i != NULL; i = i->next) {
+        Inkscape::XML::Node *copy = (Inkscape::XML::Node *) i->data;
+        vector->appendChildRepr(copy);
+        sp_repr_set_svg_double (copy, "offset", 1 - *iter);
+        iter --;
+        Inkscape::GC::release(copy);
+    }
+
+    g_slist_free (child_reprs);
+    g_slist_free (child_copies);
+    g_slist_free (child_objects);
+}
+
+
 
 /**
 Set the position of point point_num of the gradient applied to item (either fill_or_stroke) to
@@ -657,7 +703,7 @@ sp_item_gradient_set_coords (SPItem *item, guint point_num, NR::Point p_w, bool
                 if (scale) {
                     lg->x2.computed += (lg->x1.computed - p[NR::X]);
                     lg->y2.computed += (lg->y1.computed - p[NR::Y]);
-                } 
+                }
                 lg->x1.computed = p[NR::X];
                 lg->y1.computed = p[NR::Y];
                 if (write_repr) {
@@ -675,7 +721,7 @@ sp_item_gradient_set_coords (SPItem *item, guint point_num, NR::Point p_w, bool
                 if (scale) {
                     lg->x1.computed += (lg->x2.computed - p[NR::X]);
                     lg->y1.computed += (lg->y2.computed - p[NR::Y]);
-                } 
+                }
                 lg->x2.computed = p[NR::X];
                 lg->y2.computed = p[NR::Y];
                 if (write_repr) {
@@ -737,13 +783,13 @@ sp_item_gradient_set_coords (SPItem *item, guint point_num, NR::Point p_w, bool
 				double move_stretch = NR::L2(p_w - c_w) / NR::L2(r1_w - c_w);
 
 				NR::Matrix move = NR::Matrix (NR::translate (-c_w)) *
-												 NR::Matrix (NR::rotate(-r1_angle)) * 
+												 NR::Matrix (NR::rotate(-r1_angle)) *
 												 NR::Matrix (NR::scale(move_stretch, scale? move_stretch : 1)) *
-												 NR::Matrix (NR::rotate(r1_angle)) * 
-												 NR::Matrix (NR::rotate(move_angle)) * 
+												 NR::Matrix (NR::rotate(r1_angle)) *
+												 NR::Matrix (NR::rotate(move_angle)) *
 												 NR::Matrix (NR::translate (c_w));
 
-				new_transform = gradient->gradientTransform * i2d * move * i2d.inverse(); 
+				new_transform = gradient->gradientTransform * i2d * move * i2d.inverse();
 				transform_set = true;
 
 				break;
@@ -756,13 +802,13 @@ sp_item_gradient_set_coords (SPItem *item, guint point_num, NR::Point p_w, bool
 				double move_stretch = NR::L2(p_w - c_w) / NR::L2(r2_w - c_w);
 
 				NR::Matrix move = NR::Matrix (NR::translate (-c_w)) *
-												 NR::Matrix (NR::rotate(-r2_angle)) * 
+												 NR::Matrix (NR::rotate(-r2_angle)) *
 												 NR::Matrix (NR::scale(move_stretch, scale? move_stretch : 1)) *
-												 NR::Matrix (NR::rotate(r2_angle)) * 
-												 NR::Matrix (NR::rotate(move_angle)) * 
+												 NR::Matrix (NR::rotate(r2_angle)) *
+												 NR::Matrix (NR::rotate(move_angle)) *
 												 NR::Matrix (NR::translate (c_w));
 
-				new_transform = gradient->gradientTransform * i2d * move * i2d.inverse(); 
+				new_transform = gradient->gradientTransform * i2d * move * i2d.inverse();
 				transform_set = true;
 
 				break;
@@ -770,14 +816,14 @@ sp_item_gradient_set_coords (SPItem *item, guint point_num, NR::Point p_w, bool
 		}
 
 		if (transform_set) {
-				gradient->gradientTransform = new_transform; 
+				gradient->gradientTransform = new_transform;
 				gradient->gradientTransform_set = TRUE;
 				if (write_repr) {
 					gchar s[256];
 					if (sp_svg_transform_write(s, 256, gradient->gradientTransform)) {
-						sp_repr_set_attr(SP_OBJECT_REPR(gradient), "gradientTransform", s);
+						SP_OBJECT_REPR(gradient)->setAttribute("gradientTransform", s);
 					} else {
-						sp_repr_set_attr(SP_OBJECT_REPR(gradient), "gradientTransform", NULL);
+						SP_OBJECT_REPR(gradient)->setAttribute("gradientTransform", NULL);
 					}
 				} else {
 					SP_OBJECT (gradient)->requestModified(SP_OBJECT_MODIFIED_FLAG);
@@ -796,7 +842,7 @@ sp_item_gradient_get_vector (SPItem *item, bool fill_or_stroke)
     return NULL;
 }
 
-SPGradientSpread 
+SPGradientSpread
 sp_item_gradient_get_spread (SPItem *item, bool fill_or_stroke)
 {
     SPGradient *gradient = sp_item_gradient (item, fill_or_stroke);
@@ -808,7 +854,7 @@ sp_item_gradient_get_spread (SPItem *item, bool fill_or_stroke)
 
 
 /**
-Returns the position of point point_num of the gradient applied to item (either fill_or_stroke), 
+Returns the position of point point_num of the gradient applied to item (either fill_or_stroke),
 in desktop coordinates.
 */
 
@@ -851,10 +897,11 @@ sp_item_gradient_get_coords (SPItem *item, guint point_num, bool fill_or_stroke)
     }
 
     if (SP_GRADIENT(gradient)->units == SP_GRADIENT_UNITS_OBJECTBOUNDINGBOX) {
-        NRRect bbox;
         sp_document_ensure_up_to_date(SP_OBJECT_DOCUMENT(item));
-        sp_item_invoke_bbox(item, &bbox, NR::identity(), TRUE); // we need "true" bbox without item_i2d_affine
-        p *= NR::Matrix(bbox.x1 - bbox.x0, 0, 0, bbox.y1 - bbox.y0, bbox.x0, bbox.y0);
+        NR::Rect const bbox = item->invokeBbox(NR::identity()); // we need "true" bbox without item_i2d_affine
+        p *= NR::Matrix(bbox.dimensions()[NR::X], 0,
+                        0, bbox.dimensions()[NR::Y],
+                        bbox.min()[NR::X], bbox.min()[NR::Y]);
     }
     p *= NR::Matrix(gradient->gradientTransform) * sp_item_i2d_affine(item);
     return p;
@@ -894,7 +941,7 @@ sp_item_set_gradient(SPItem *item, SPGradient *gr, SPGradientType type, bool is_
 
         //g_print("hrefcount %d   count %d\n", SP_OBJECT_HREFCOUNT(ig), count_gradient_hrefs(SP_OBJECT(item), ig));
 
-        if (SP_OBJECT_HREFCOUNT(current) == 1 || 
+        if (SP_OBJECT_HREFCOUNT(current) == 1 ||
             SP_OBJECT_HREFCOUNT(current) == count_gradient_hrefs(SP_OBJECT(item), current)) {
 
             // current is private and it's either used once, or all its uses are by children of item;
@@ -956,7 +1003,7 @@ sp_gradient_repr_set_link(Inkscape::XML::Node *repr, SPGradient *link)
         ref = NULL;
     }
 
-    sp_repr_set_attr(repr, "xlink:href", ref);
+    repr->setAttribute("xlink:href", ref);
 }
 
 static void
@@ -991,7 +1038,7 @@ sp_document_default_gradient_vector(SPDocument *document, guint32 color)
 
     Inkscape::XML::Node *repr = sp_repr_new("svg:linearGradient");
 
-    sp_repr_set_attr(repr, "inkscape:collect", "always");
+    repr->setAttribute("inkscape:collect", "always");
     // set here, but removed when it's edited in the gradient editor
     // to further reduce clutter, we could
     // (1) here, search gradients by color and return what is found without duplication
@@ -1004,30 +1051,30 @@ sp_document_default_gradient_vector(SPDocument *document, guint32 color)
 
     {
         gchar *t = g_strdup_printf("stop-color:%s;stop-opacity:1;", b);
-        sp_repr_set_attr(stop, "style", t);
+        stop->setAttribute("style", t);
         g_free(t);
     }
 
-    sp_repr_set_attr(stop, "offset", "0");
+    stop->setAttribute("offset", "0");
 
     repr->appendChild(stop);
-    sp_repr_unref(stop);
+    Inkscape::GC::release(stop);
 
     stop = sp_repr_new("svg:stop");
 
     {
         gchar *t = g_strdup_printf("stop-color:%s;stop-opacity:0;", b);
-        sp_repr_set_attr(stop, "style", t);
+        stop->setAttribute("style", t);
         g_free(t);
     }
 
-    sp_repr_set_attr(stop, "offset", "1");
+    stop->setAttribute("offset", "1");
 
     repr->appendChild(stop);
-    sp_repr_unref(stop);
+    Inkscape::GC::release(stop);
 
-    sp_repr_add_child(SP_OBJECT_REPR(defs), repr, NULL);
-    sp_repr_unref(repr);
+    SP_OBJECT_REPR(defs)->addChild(repr, NULL);
+    Inkscape::GC::release(repr);
 
     /* fixme: This does not look like nice */
     SPGradient *gr;
