@@ -11,37 +11,28 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 
-#include <math.h>
-#include <string.h>
-#include <glib.h>
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "macros.h"
-#include "display/sp-canvas.h"
-#include "inkscape.h"
 #include "document.h"
 #include "selection.h"
+#include "desktop.h"
 #include "desktop-handles.h"
-#include "desktop-affine.h"
-#include "snap.h"
-#include "desktop-style.h"
 #include "message-context.h"
 #include "message-stack.h"
 #include "pixmaps/cursor-gradient.xpm"
 #include "gradient-context.h"
-#include "widgets/desktop-widget.h"
-#include "sp-metrics.h"
 #include <glibmm/i18n.h>
 #include "prefs-utils.h"
-#include "widgets/spw-utilities.h"
-#include "selcue.h"
 #include "gradient-drag.h"
-#include "sp-gradient.h"
 #include "gradient-chemistry.h"
 #include "xml/repr.h"
+#include "sp-item.h"
 
 static void sp_gradient_context_class_init(SPGradientContextClass *klass);
 static void sp_gradient_context_init(SPGradientContext *gr_context);
@@ -130,7 +121,7 @@ static void sp_gradient_context_setup(SPEventContext *ec)
 
     ec->enableGrDrag();
 
-    rc->_message_context = new Inkscape::MessageContext(SP_DT_MSGSTACK(ec->desktop));
+    rc->_message_context = new Inkscape::MessageContext(sp_desktop_message_stack(ec->desktop));
 }
 
 static gint sp_gradient_context_root_handler(SPEventContext *event_context, GdkEvent *event)
@@ -138,8 +129,8 @@ static gint sp_gradient_context_root_handler(SPEventContext *event_context, GdkE
     static bool dragging;
 
     SPDesktop *desktop = event_context->desktop;
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
- 
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
+
     SPGradientContext *rc = SP_GRADIENT_CONTEXT(event_context);
 
     event_context->tolerance = prefs_get_int_attribute_limited("options.dragtolerance", "value", 0, 0, 100);
@@ -157,13 +148,13 @@ static gint sp_gradient_context_root_handler(SPEventContext *event_context, GdkE
                 SPGradientType new_type = (SPGradientType) prefs_get_int_attribute ("tools.gradient", "newgradient", SP_GRADIENT_TYPE_LINEAR);
                 guint new_fill = prefs_get_int_attribute ("tools.gradient", "newfillorstroke", 1);
 
-                SPGradient *vector = sp_gradient_vector_for_object(SP_DT_DOCUMENT(desktop), desktop,                                                                                   SP_OBJECT (item), new_fill);
+                SPGradient *vector = sp_gradient_vector_for_object(sp_desktop_document(desktop), desktop,                                                                                   SP_OBJECT (item), new_fill);
 
                 SPGradient *priv = sp_item_set_gradient(item, vector, new_type, new_fill);
                 sp_gradient_reset_to_userspace(priv, item);
             }
 
-            sp_document_done (SP_DT_DOCUMENT (desktop));
+            sp_document_done (sp_desktop_document (desktop));
 
             ret = TRUE;
         }
@@ -184,7 +175,7 @@ static gint sp_gradient_context_root_handler(SPEventContext *event_context, GdkE
 
             dragging = true;
             /* Position center */
-            NR::Point const button_dt(sp_desktop_w2d_xy_point(event_context->desktop, button_w));
+            NR::Point const button_dt = desktop->w2d(button_w);
             /* Snap center to nearest magnetic point */
 
             rc->origin = button_dt;
@@ -208,8 +199,8 @@ static gint sp_gradient_context_root_handler(SPEventContext *event_context, GdkE
 
             NR::Point const motion_w(event->motion.x,
                                      event->motion.y);
-            NR::Point const motion_dt(sp_desktop_w2d_xy_point(event_context->desktop, motion_w));
-            
+            NR::Point const motion_dt = event_context->desktop->w2d(motion_w);
+
             sp_gradient_drag(*rc, motion_dt, event->motion.state, event->motion.time);
 
             ret = TRUE;
@@ -267,10 +258,7 @@ static gint sp_gradient_context_root_handler(SPEventContext *event_context, GdkE
         case GDK_x:
         case GDK_X:
             if (MOD__ALT_ONLY) {
-                gpointer hb = sp_search_by_data_recursive (SP_DT_WIDGET(desktop)->aux_toolbox, (gpointer) "altx-grad");
-                if (hb && GTK_IS_WIDGET(hb)) {
-                    gtk_widget_grab_focus (GTK_WIDGET (hb));
-                }
+                desktop->setToolboxFocusTo ("altx-grad");
                 ret = TRUE;
             }
             break;
@@ -358,6 +346,23 @@ static gint sp_gradient_context_root_handler(SPEventContext *event_context, GdkE
                 ret = TRUE;
             }
             break;
+        case GDK_r:
+        case GDK_R:
+            if (MOD__SHIFT_ONLY) {
+                // First try selected dragger
+                if (drag && drag->selected) {
+                    drag->selected_reverse_vector();
+                } else { // If no drag or no dragger selected, act on selection (both fill and stroke gradients)
+                    for (GSList const* i = selection->itemList(); i != NULL; i = i->next) {
+                        sp_item_gradient_reverse_vector (SP_ITEM(i->data), true);
+                        sp_item_gradient_reverse_vector (SP_ITEM(i->data), false);
+                    }
+                }
+                // we did an undoable action
+                sp_document_done (sp_desktop_document (desktop));
+                ret = TRUE;
+            }
+            break;
         default:
             break;
         }
@@ -394,8 +399,8 @@ static gint sp_gradient_context_root_handler(SPEventContext *event_context, GdkE
 static void sp_gradient_drag(SPGradientContext &rc, NR::Point const pt, guint state, guint32 etime)
 {
     SPDesktop *desktop = SP_EVENT_CONTEXT(&rc)->desktop;
-    Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
-    SPDocument *document = SP_DT_DOCUMENT(desktop);
+    Inkscape::Selection *selection = sp_desktop_selection(desktop);
+    SPDocument *document = sp_desktop_document(desktop);
     SPEventContext *ec = SP_EVENT_CONTEXT(&rc);
 
     if (!selection->isEmpty()) {
@@ -436,17 +441,21 @@ static void sp_gradient_drag(SPGradientContext &rc, NR::Point const pt, guint st
             ec->_grdrag->local_change = true;
             // give the grab out-of-bounds values of xp/yp because we're already dragging
             // and therefore are already out of tolerance
-            ec->_grdrag->grabKnot (SP_ITEM(selection->itemList()->data), 
-                                   type == SP_GRADIENT_TYPE_LINEAR? POINT_LG_P2 : POINT_RG_R1, 
+            ec->_grdrag->grabKnot (SP_ITEM(selection->itemList()->data),
+                                   type == SP_GRADIENT_TYPE_LINEAR? POINT_LG_P2 : POINT_RG_R1,
                                    fill_or_stroke, 99999, 99999, etime);
         }
         // We did an undoable action, but sp_document_done will be called by the knot when released
 
         // status text; we do not track coords because this branch is run once, not all the time
         // during drag
-        rc._message_context->setF(Inkscape::NORMAL_MESSAGE, _("<b>Gradient</b> for %d objects; with <b>Ctrl</b> to snap angle"), g_slist_length((GSList *) selection->itemList()));
+        int n_objects = g_slist_length((GSList *) selection->itemList());
+        rc._message_context->setF(Inkscape::NORMAL_MESSAGE,
+                                  ngettext("<b>Gradient</b> for %d object; with <b>Ctrl</b> to snap angle",
+                                           "<b>Gradient</b> for %d objects; with <b>Ctrl</b> to snap angle", n_objects),
+                                  n_objects);
     } else {
-        SP_DT_MSGSTACK(desktop)->flash(Inkscape::WARNING_MESSAGE, _("Select <b>objects</b> on which to create gradient."));
+        sp_desktop_message_stack(desktop)->flash(Inkscape::WARNING_MESSAGE, _("Select <b>objects</b> on which to create gradient."));
     }
 }
 
@@ -455,9 +464,9 @@ static void sp_gradient_drag(SPGradientContext &rc, NR::Point const pt, guint st
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
