@@ -16,61 +16,44 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-#include "path-prefix.h"
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 
-#include "debug/logger.h"
 #include "debug/simple-event.h"
 #include "debug/event-tracker.h"
 
 #ifndef WIN32
-#include <unistd.h>
-#define HAS_PROC_SELF_EXE  //to get path of executable
+# define HAS_PROC_SELF_EXE  //to get path of executable
 #else
 
 // For now to get at is_os_wide().
-#include "extension/internal/win32.h"
+# include "extension/internal/win32.h"
 using Inkscape::Extension::Internal::PrintWin32;
 
-#include <direct.h>
 #define _WIN32_IE 0x0400
 //#define HAS_SHGetSpecialFolderPath
 #define HAS_SHGetSpecialFolderLocation
 #define HAS_GetModuleFileName
-#include <shlobj.h> //to get appdata path
+# include <shlobj.h>
 #endif
 
-#include <time.h>
-#include <fcntl.h>
 #include <signal.h>
-#include <ctype.h>
 
-#include <glib.h>
-#include <gdk/gdkkeysyms.h>
 #include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
 #include <gtk/gtkmessagedialog.h>
 
 #include <glibmm/i18n.h>
 #include "helper/sp-marshal.h"
 #include "dialogs/debugdialog.h"
-#include "dialogs/input.h"
-#include "widgets/desktop-widget.h"
+#include "application/application.h"
+#include "application/editor.h"
+#include "preferences.h"
 
-#include "shortcuts.h"
 
-#include "file.h"
 #include "document.h"
 #include "desktop.h"
 #include "desktop-handles.h"
 #include "selection.h"
 #include "event-context.h"
-#include "inkscape.h"
 #include "inkscape-private.h"
 #include "prefs-utils.h"
 #include "xml/repr.h"
@@ -81,7 +64,6 @@ using Inkscape::Extension::Internal::PrintWin32;
 static Inkscape::Application *inkscape = NULL;
 
 /* Backbones of configuration xml data */
-#include "preferences-skeleton.h"
 #include "menus-skeleton.h"
 
 enum {
@@ -116,7 +98,7 @@ static void inkscape_dispose (GObject *object);
 static void inkscape_activate_desktop_private (Inkscape::Application *inkscape, SPDesktop *desktop);
 static void inkscape_deactivate_desktop_private (Inkscape::Application *inkscape, SPDesktop *desktop);
 
-static bool inkscape_init_config (Inkscape::XML::Document *doc, const gchar *config_name, const gchar *skeleton, 
+static bool inkscape_init_config (Inkscape::XML::Document *doc, const gchar *config_name, const gchar *skeleton,
 				  unsigned int skel_size,
 				  const gchar *e_mkdir,
 				  const gchar *e_notdir,
@@ -126,8 +108,6 @@ static bool inkscape_init_config (Inkscape::XML::Document *doc, const gchar *con
 
 struct Inkscape::Application {
     GObject object;
-    Inkscape::XML::Document *preferences;
-    bool save_preferences;
     Inkscape::XML::Document *menus;
     GSList *documents;
     GSList *desktops;
@@ -167,13 +147,12 @@ static void (* segv_handler) (int) = NULL;
 #define INKSCAPE_PROFILE_DIR ".inkscape"
 #endif
 
-#define PREFERENCES_FILE "preferences.xml"
 #define MENUS_FILE "menus.xml"
 
 
 /**
  *  Retrieves the GType for the Inkscape Application object.
- */ 
+ */
 GType
 inkscape_get_type (void)
 {
@@ -309,7 +288,6 @@ inkscape_init (SPObject * object)
         g_assert_not_reached ();
     }
 
-    inkscape->preferences = sp_repr_read_mem (preferences_skeleton, PREFERENCES_SKELETON_SIZE, NULL);
     inkscape->menus = sp_repr_read_mem (_(menus_skeleton), MENUS_SKELETON_SIZE, NULL);
 
     inkscape->documents = NULL;
@@ -331,13 +309,7 @@ inkscape_dispose (GObject *object)
 
     g_assert (!inkscape->desktops);
 
-    if (inkscape->preferences && inkscape->save_preferences) {
-        /* fixme: This is not the best place */
-        inkscape_save_preferences (inkscape);
-        Inkscape::GC::release(inkscape->preferences);
-        inkscape->preferences = NULL;
-        inkscape->save_preferences = FALSE;
-    }
+    Inkscape::Preferences::save();
 
     if (inkscape->menus) {
         /* fixme: This is not the best place */
@@ -354,14 +326,16 @@ inkscape_dispose (GObject *object)
 void
 inkscape_ref (void)
 {
-    g_object_ref (G_OBJECT (inkscape));
+    if (inkscape)
+        g_object_ref (G_OBJECT (inkscape));
 }
 
 
 void
 inkscape_unref (void)
 {
-    g_object_unref (G_OBJECT (inkscape));
+    if (inkscape)
+        g_object_unref (G_OBJECT (inkscape));
 }
 
 
@@ -491,9 +465,7 @@ inkscape_segv_handler (int signum)
         }
     }
 
-    if (inkscape->preferences && inkscape->save_preferences) {
-        inkscape_save_preferences (inkscape);
-    }
+    Inkscape::Preferences::save();
 
     fprintf (stderr, "Emergency save completed. Inkscape will close now.\n");
     fprintf (stderr, "If you can reproduce this crash, please file a bug at www.inkscape.org\n");
@@ -501,9 +473,9 @@ inkscape_segv_handler (int signum)
 
     /* Show nice dialog box */
 
-    char const *istr = N_("Inkscape encountered an internal error and will close now.\n");
-    char const *sstr = N_("Automatic backups of unsaved documents were done to the following locations:\n");
-    char const *fstr = N_("Automatic backup of the following documents failed:\n");
+    char const *istr = _("Inkscape encountered an internal error and will close now.\n");
+    char const *sstr = _("Automatic backups of unsaved documents were done to the following locations:\n");
+    char const *fstr = _("Automatic backup of the following documents failed:\n");
     gint nllen = strlen ("\n");
     gint len = strlen (istr) + strlen (sstr) + strlen (fstr);
     for (GSList *l = savednames; l != NULL; l = l->next) {
@@ -572,13 +544,13 @@ inkscape_application_init (const gchar *argv0, gboolean use_gui)
 {
     inkscape = (Inkscape::Application *)g_object_new (SP_TYPE_INKSCAPE, NULL);
     /* fixme: load application defaults */
-  
+
     segv_handler = signal (SIGSEGV, inkscape_segv_handler);
     signal (SIGFPE,  inkscape_segv_handler);
     signal (SIGILL,  inkscape_segv_handler);
-#ifndef WIN32    
+#ifndef WIN32
     signal (SIGBUS,  inkscape_segv_handler);
-#endif    
+#endif
     signal (SIGABRT, inkscape_segv_handler);
 
     inkscape->use_gui = use_gui;
@@ -586,19 +558,21 @@ inkscape_application_init (const gchar *argv0, gboolean use_gui)
 
     /* Attempt to load the preferences, and set the save_preferences flag to TRUE
        if we could, or FALSE if we couldn't */
-    inkscape->save_preferences = inkscape_load_preferences(inkscape);
+    Inkscape::Preferences::load();
     inkscape_load_menus(inkscape);
 
-    /* DebugDialog redirection.  On Linux, default to OFF, on Win32, default to ON */
+    /* DebugDialog redirection.  On Linux, default to OFF, on Win32, default to ON.
+	 * Use only if use_gui is enabled 
+	 */
 #ifdef WIN32
 #define DEFAULT_LOG_REDIRECT true
 #else
 #define DEFAULT_LOG_REDIRECT false
 #endif
 
-    if (prefs_get_int_attribute("dialogs.debug", "redirect", DEFAULT_LOG_REDIRECT))
+    if (use_gui == TRUE && prefs_get_int_attribute("dialogs.debug", "redirect", DEFAULT_LOG_REDIRECT))
     {
-        Inkscape::UI::Dialogs::DebugDialog::getInstance()->captureLogMessages();
+		Inkscape::UI::Dialogs::DebugDialog::getInstance()->captureLogMessages();
     }
 
     /* Initialize the extensions */
@@ -624,24 +598,24 @@ gboolean inkscape_app_use_gui( Inkscape::Application const * app )
 /**
  * Preference management
  * We use '.' as separator
- * 
+ *
  * Returns TRUE if the config file was successfully loaded, FALSE if not.
  */
-static bool
-inkscape_load_config (const gchar *filename, Inkscape::XML::Document *config, const gchar *skeleton, 
-		      unsigned int skel_size, const gchar *e_notreg, const gchar *e_notxml, 
+bool
+inkscape_load_config (const gchar *filename, Inkscape::XML::Document *config, const gchar *skeleton,
+		      unsigned int skel_size, const gchar *e_notreg, const gchar *e_notxml,
 		      const gchar *e_notsp, const gchar *warn)
 {
     gchar *fn = profile_path(filename);
     if (!Inkscape::IO::file_test(fn, G_FILE_TEST_EXISTS)) {
         bool result;
         /* No such file */
-        result = inkscape_init_config (config, filename, skeleton, 
+        result = inkscape_init_config (config, filename, skeleton,
                                        skel_size,
                                        _("Cannot create directory %s.\n%s"),
                                        _("%s is not a valid directory.\n%s"),
                                        _("Cannot create file %s.\n%s"),
-                                       _("Cannot write file %s.\n%s"), 
+                                       _("Cannot write file %s.\n%s"),
                                        _("Although Inkscape will run, it will use default settings,\n"
                                          "and any changes made in preferences will not be saved."));
         g_free (fn);
@@ -686,7 +660,8 @@ inkscape_load_config (const gchar *filename, Inkscape::XML::Document *config, co
     /** \todo this is a hack, need to figure out how to get
      *        a reasonable merge working with the menus.xml file */
     if (skel_size == MENUS_SKELETON_SIZE) {
-        INKSCAPE->menus = doc;
+        if (INKSCAPE)
+            INKSCAPE->menus = doc;
         doc = config;
     } else {
         config->root()->mergeFrom(doc->root(), "id");
@@ -697,50 +672,9 @@ inkscape_load_config (const gchar *filename, Inkscape::XML::Document *config, co
     return true;
 }
 
-/**
- *  Preferences management
- * 
- *  Attempts to load the preferences file indicated by the global PREFERENCES_FILE
- *  parameter.  If it cannot load it, the defailt preferences_skeleton will be used
- *  instead.
- */
-bool
-inkscape_load_preferences (Inkscape::Application *inkscape)
-{
-    if (inkscape_load_config (PREFERENCES_FILE, 
-                              inkscape->preferences, 
-                              preferences_skeleton, 
-                              PREFERENCES_SKELETON_SIZE,
-                              _("%s is not a regular file.\n%s"),
-                              _("%s not a valid XML file, or\n"
-                                "you don't have read permissions on it.\n%s"),
-                              _("%s is not a valid preferences file.\n%s"),
-                              _("Inkscape will run with default settings.\n"
-                                "New settings will not be saved.")))
-    {
-        sp_input_load_from_preferences();
-        return true;
-    } else
-        return false;
-}
-
-
-/*
- *  Returns true if file was successfully saved, false if not
- */
-bool
-inkscape_save_preferences (Inkscape::Application * inkscape)
-{
-    gchar *fn = profile_path(PREFERENCES_FILE);
-    bool retval = sp_repr_save_file (inkscape->preferences, fn);
-
-    g_free (fn);
-    return retval;
-}
-
 /**
  *  Menus management
- * 
+ *
  */
 bool
 inkscape_load_menus (Inkscape::Application *inkscape)
@@ -748,9 +682,9 @@ inkscape_load_menus (Inkscape::Application *inkscape)
     gchar *fn = profile_path(MENUS_FILE);
     bool retval = false;
     if (Inkscape::IO::file_test(fn, G_FILE_TEST_EXISTS)) {
-        retval = inkscape_load_config (MENUS_FILE, 
-				 inkscape->menus, 
-				 menus_skeleton, 
+        retval = inkscape_load_config (MENUS_FILE,
+				 inkscape->menus,
+				 menus_skeleton,
 				 MENUS_SKELETON_SIZE,
 				 _("%s is not a regular file.\n%s"),
 				 _("%s not a valid XML file, or\n"
@@ -769,6 +703,7 @@ inkscape_load_menus (Inkscape::Application *inkscape)
 
 /**
  * We use '.' as separator
+ * \param inkscape Unused
  */
 Inkscape::XML::Node *
 inkscape_get_repr (Inkscape::Application *inkscape, const gchar *key)
@@ -777,7 +712,7 @@ inkscape_get_repr (Inkscape::Application *inkscape, const gchar *key)
         return NULL;
     }
 
-    Inkscape::XML::Node *repr = sp_repr_document_root (inkscape->preferences);
+    Inkscape::XML::Node *repr = sp_repr_document_root (Inkscape::Preferences::get());
     g_assert (!(strcmp (repr->name(), "inkscape")));
 
     gchar const *s = key;
@@ -791,7 +726,7 @@ inkscape_get_repr (Inkscape::Application *inkscape, const gchar *key)
         } else {
             len = strlen (s);
         }
-        
+
         Inkscape::XML::Node* child;
         for (child = repr->firstChild(); child != NULL; child = child->next()) {
             gchar const *id = child->attribute("id");
@@ -815,7 +750,10 @@ inkscape_get_repr (Inkscape::Application *inkscape, const gchar *key)
 void
 inkscape_selection_modified (Inkscape::Selection *selection, guint flags)
 {
-    g_return_if_fail (inkscape != NULL);
+    if (Inkscape::NSApplication::Application::getNewGui()) {
+        Inkscape::NSApplication::Editor::selectionModified (selection, flags);
+        return;
+    }
     g_return_if_fail (selection != NULL);
 
     if (DESKTOP_IS_ACTIVE (selection->desktop())) {
@@ -827,7 +765,10 @@ inkscape_selection_modified (Inkscape::Selection *selection, guint flags)
 void
 inkscape_selection_changed (Inkscape::Selection * selection)
 {
-    g_return_if_fail (inkscape != NULL);
+    if (Inkscape::NSApplication::Application::getNewGui()) {
+        Inkscape::NSApplication::Editor::selectionChanged (selection);
+        return;
+    }
     g_return_if_fail (selection != NULL);
 
     if (DESKTOP_IS_ACTIVE (selection->desktop())) {
@@ -838,7 +779,11 @@ inkscape_selection_changed (Inkscape::Selection * selection)
 void
 inkscape_subselection_changed (SPDesktop *desktop)
 {
-    g_return_if_fail (inkscape != NULL);
+    if (Inkscape::NSApplication::Application::getNewGui()) {
+        Inkscape::NSApplication::Editor::subSelectionChanged (desktop);
+        return;
+    }
+    g_return_if_fail (desktop != NULL);
 
     if (DESKTOP_IS_ACTIVE (desktop)) {
         g_signal_emit (G_OBJECT (inkscape), inkscape_signals[CHANGE_SUBSELECTION], 0, desktop);
@@ -849,7 +794,10 @@ inkscape_subselection_changed (SPDesktop *desktop)
 void
 inkscape_selection_set (Inkscape::Selection * selection)
 {
-    g_return_if_fail (inkscape != NULL);
+    if (Inkscape::NSApplication::Application::getNewGui()) {
+        Inkscape::NSApplication::Editor::selectionSet (selection);
+        return;
+    }
     g_return_if_fail (selection != NULL);
 
     if (DESKTOP_IS_ACTIVE (selection->desktop())) {
@@ -862,7 +810,10 @@ inkscape_selection_set (Inkscape::Selection * selection)
 void
 inkscape_eventcontext_set (SPEventContext * eventcontext)
 {
-    g_return_if_fail (inkscape != NULL);
+    if (Inkscape::NSApplication::Application::getNewGui()) {
+        Inkscape::NSApplication::Editor::eventContextSet (eventcontext);
+        return;
+    }
     g_return_if_fail (eventcontext != NULL);
     g_return_if_fail (SP_IS_EVENT_CONTEXT (eventcontext));
 
@@ -875,18 +826,24 @@ inkscape_eventcontext_set (SPEventContext * eventcontext)
 void
 inkscape_add_desktop (SPDesktop * desktop)
 {
-    g_return_if_fail (inkscape != NULL);
     g_return_if_fail (desktop != NULL);
 
+    if (Inkscape::NSApplication::Application::getNewGui())
+    {
+        Inkscape::NSApplication::Editor::addDesktop (desktop);
+        return;
+    }
+    g_return_if_fail (inkscape != NULL);
+
     g_assert (!g_slist_find (inkscape->desktops, desktop));
 
     inkscape->desktops = g_slist_append (inkscape->desktops, desktop);
 
     if (DESKTOP_IS_ACTIVE (desktop)) {
         g_signal_emit (G_OBJECT (inkscape), inkscape_signals[ACTIVATE_DESKTOP], 0, desktop);
-        g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_EVENTCONTEXT], 0, SP_DT_EVENTCONTEXT (desktop));
-        g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_SELECTION], 0, SP_DT_SELECTION (desktop));
-        g_signal_emit (G_OBJECT (inkscape), inkscape_signals[CHANGE_SELECTION], 0, SP_DT_SELECTION (desktop));
+        g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_EVENTCONTEXT], 0, sp_desktop_event_context (desktop));
+        g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_SELECTION], 0, sp_desktop_selection (desktop));
+        g_signal_emit (G_OBJECT (inkscape), inkscape_signals[CHANGE_SELECTION], 0, sp_desktop_selection (desktop));
     }
 }
 
@@ -895,8 +852,13 @@ inkscape_add_desktop (SPDesktop * desktop)
 void
 inkscape_remove_desktop (SPDesktop * desktop)
 {
-    g_return_if_fail (inkscape != NULL);
     g_return_if_fail (desktop != NULL);
+    if (Inkscape::NSApplication::Application::getNewGui())
+    {
+        Inkscape::NSApplication::Editor::removeDesktop (desktop);
+        return;
+    }
+    g_return_if_fail (inkscape != NULL);
 
     g_assert (g_slist_find (inkscape->desktops, desktop));
 
@@ -907,13 +869,13 @@ inkscape_remove_desktop (SPDesktop * desktop)
             inkscape->desktops = g_slist_remove (inkscape->desktops, new_desktop);
             inkscape->desktops = g_slist_prepend (inkscape->desktops, new_desktop);
             g_signal_emit (G_OBJECT (inkscape), inkscape_signals[ACTIVATE_DESKTOP], 0, new_desktop);
-            g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_EVENTCONTEXT], 0, SP_DT_EVENTCONTEXT (new_desktop));
-            g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_SELECTION], 0, SP_DT_SELECTION (new_desktop));
-            g_signal_emit (G_OBJECT (inkscape), inkscape_signals[CHANGE_SELECTION], 0, SP_DT_SELECTION (new_desktop));
+            g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_EVENTCONTEXT], 0, sp_desktop_event_context (new_desktop));
+            g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_SELECTION], 0, sp_desktop_selection (new_desktop));
+            g_signal_emit (G_OBJECT (inkscape), inkscape_signals[CHANGE_SELECTION], 0, sp_desktop_selection (new_desktop));
         } else {
             g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_EVENTCONTEXT], 0, NULL);
-            if (SP_DT_SELECTION(desktop))
-                SP_DT_SELECTION(desktop)->clear();
+            if (sp_desktop_selection(desktop))
+                sp_desktop_selection(desktop)->clear();
         }
     }
 
@@ -930,8 +892,13 @@ inkscape_remove_desktop (SPDesktop * desktop)
 void
 inkscape_activate_desktop (SPDesktop * desktop)
 {
-    g_return_if_fail (inkscape != NULL);
     g_return_if_fail (desktop != NULL);
+    if (Inkscape::NSApplication::Application::getNewGui())
+    {
+        Inkscape::NSApplication::Editor::activateDesktop (desktop);
+        return;
+    }
+    g_return_if_fail (inkscape != NULL);
 
     if (DESKTOP_IS_ACTIVE (desktop)) {
         return;
@@ -947,9 +914,9 @@ inkscape_activate_desktop (SPDesktop * desktop)
     inkscape->desktops = g_slist_prepend (inkscape->desktops, desktop);
 
     g_signal_emit (G_OBJECT (inkscape), inkscape_signals[ACTIVATE_DESKTOP], 0, desktop);
-    g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_EVENTCONTEXT], 0, SP_DT_EVENTCONTEXT (desktop));
-    g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_SELECTION], 0, SP_DT_SELECTION (desktop));
-    g_signal_emit (G_OBJECT (inkscape), inkscape_signals[CHANGE_SELECTION], 0, SP_DT_SELECTION (desktop));
+    g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_EVENTCONTEXT], 0, sp_desktop_event_context (desktop));
+    g_signal_emit (G_OBJECT (inkscape), inkscape_signals[SET_SELECTION], 0, sp_desktop_selection (desktop));
+    g_signal_emit (G_OBJECT (inkscape), inkscape_signals[CHANGE_SELECTION], 0, sp_desktop_selection (desktop));
 }
 
 
@@ -959,8 +926,13 @@ inkscape_activate_desktop (SPDesktop * desktop)
 void
 inkscape_reactivate_desktop (SPDesktop * desktop)
 {
-    g_return_if_fail (inkscape != NULL);
     g_return_if_fail (desktop != NULL);
+    if (Inkscape::NSApplication::Application::getNewGui())
+    {
+        Inkscape::NSApplication::Editor::reactivateDesktop (desktop);
+        return;
+    }
+    g_return_if_fail (inkscape != NULL);
 
     if (DESKTOP_IS_ACTIVE (desktop))
         g_signal_emit (G_OBJECT (inkscape), inkscape_signals[ACTIVATE_DESKTOP], 0, desktop);
@@ -1057,8 +1029,7 @@ inkscape_prev_desktop ()
 void
 inkscape_switch_desktops_next ()
 {
-    GtkWindow *w = SP_DT_WIDGET(inkscape_next_desktop ())->window;
-    gtk_window_present (w);
+    inkscape_next_desktop()->presentWindow();
 }
 
 
@@ -1066,8 +1037,7 @@ inkscape_switch_desktops_next ()
 void
 inkscape_switch_desktops_prev ()
 {
-    GtkWindow *w = SP_DT_WIDGET(inkscape_prev_desktop ())->window;
-    gtk_window_present (w);
+    inkscape_prev_desktop()->presentWindow();
 }
 
 
@@ -1075,10 +1045,13 @@ inkscape_switch_desktops_prev ()
 void
 inkscape_dialogs_hide ()
 {
-    g_return_if_fail (inkscape != NULL);
-
-    g_signal_emit (G_OBJECT (inkscape), inkscape_signals[DIALOGS_HIDE], 0);
-    inkscape->dialogs_toggle = FALSE;
+    if (Inkscape::NSApplication::Application::getNewGui())
+        Inkscape::NSApplication::Editor::hideDialogs();
+    else
+    {
+        g_signal_emit (G_OBJECT (inkscape), inkscape_signals[DIALOGS_HIDE], 0);
+        inkscape->dialogs_toggle = FALSE;
+    }
 }
 
 
@@ -1086,10 +1059,13 @@ inkscape_dialogs_hide ()
 void
 inkscape_dialogs_unhide ()
 {
-    g_return_if_fail (inkscape != NULL);
-
-    g_signal_emit (G_OBJECT (inkscape), inkscape_signals[DIALOGS_UNHIDE], 0);
-    inkscape->dialogs_toggle = TRUE;
+    if (Inkscape::NSApplication::Application::getNewGui())
+        Inkscape::NSApplication::Editor::unhideDialogs();
+    else
+    {
+        g_signal_emit (G_OBJECT (inkscape), inkscape_signals[DIALOGS_UNHIDE], 0);
+        inkscape->dialogs_toggle = TRUE;
+    }
 }
 
 
@@ -1118,12 +1094,17 @@ inkscape_external_change ()
 void
 inkscape_add_document (SPDocument *document)
 {
-    g_return_if_fail (inkscape != NULL);
     g_return_if_fail (document != NULL);
 
-    g_assert (!g_slist_find (inkscape->documents, document));
-
-    inkscape->documents = g_slist_append (inkscape->documents, document);
+    if (!Inkscape::NSApplication::Application::getNewGui())
+    {
+        g_assert (!g_slist_find (inkscape->documents, document));
+        inkscape->documents = g_slist_append (inkscape->documents, document);
+    }
+    else
+    {
+        Inkscape::NSApplication::Editor::addDocument (document);
+    }
 }
 
 
@@ -1131,12 +1112,17 @@ inkscape_add_document (SPDocument *document)
 void
 inkscape_remove_document (SPDocument *document)
 {
-    g_return_if_fail (inkscape != NULL);
     g_return_if_fail (document != NULL);
 
-    g_assert (g_slist_find (inkscape->documents, document));
-
-    inkscape->documents = g_slist_remove (inkscape->documents, document);
+    if (!Inkscape::NSApplication::Application::getNewGui())
+    {
+        g_assert (g_slist_find (inkscape->documents, document));
+        inkscape->documents = g_slist_remove (inkscape->documents, document);
+    }
+    else
+    {
+        Inkscape::NSApplication::Editor::removeDocument (document);
+    }
 
     return;
 }
@@ -1144,6 +1130,9 @@ inkscape_remove_document (SPDocument *document)
 SPDesktop *
 inkscape_active_desktop (void)
 {
+    if (Inkscape::NSApplication::Application::getNewGui())
+        return Inkscape::NSApplication::Editor::getActiveDesktop();
+
     if (inkscape->desktops == NULL) {
         return NULL;
     }
@@ -1154,8 +1143,11 @@ inkscape_active_desktop (void)
 SPDocument *
 inkscape_active_document (void)
 {
+    if (Inkscape::NSApplication::Application::getNewGui())
+        return Inkscape::NSApplication::Editor::getActiveDocument();
+
     if (SP_ACTIVE_DESKTOP) {
-        return SP_DT_DOCUMENT (SP_ACTIVE_DESKTOP);
+        return sp_desktop_document (SP_ACTIVE_DESKTOP);
     }
 
     return NULL;
@@ -1180,7 +1172,7 @@ SPEventContext *
 inkscape_active_event_context (void)
 {
     if (SP_ACTIVE_DESKTOP) {
-        return SP_DT_EVENTCONTEXT (SP_ACTIVE_DESKTOP);
+        return sp_desktop_event_context (SP_ACTIVE_DESKTOP);
     }
 
     return NULL;
@@ -1193,19 +1185,20 @@ inkscape_active_event_context (void)
 #####################*/
 
 static bool
-inkscape_init_config (Inkscape::XML::Document *doc, const gchar *config_name, const gchar *skeleton, 
+inkscape_init_config (Inkscape::XML::Document *doc, const gchar *config_name, const gchar *skeleton,
 		      unsigned int skel_size,
-		      const gchar *e_mkdir, 
-		      const gchar *e_notdir, 
-		      const gchar *e_ccf, 
-		      const gchar *e_cwf, 
+		      const gchar *e_mkdir,
+		      const gchar *e_notdir,
+		      const gchar *e_ccf,
+		      const gchar *e_cwf,
 		      const gchar *warn)
 {
     gchar *dn = profile_path(NULL);
+    bool use_gui = (Inkscape::NSApplication::Application::getNewGui())? Inkscape::NSApplication::Application::getUseGui() : inkscape->use_gui;
     if (!Inkscape::IO::file_test(dn, G_FILE_TEST_EXISTS)) {
         if (Inkscape::IO::mkdir_utf8name(dn))
         {
-            if (inkscape->use_gui) {
+            if (use_gui) {
                 // Cannot create directory
                 gchar *safeDn = Inkscape::IO::sanitizeString(dn);
                 GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_mkdir, safeDn, warn);
@@ -1221,7 +1214,7 @@ inkscape_init_config (Inkscape::XML::Document *doc, const gchar *config_name, co
             }
         }
     } else if (!Inkscape::IO::file_test(dn, G_FILE_TEST_IS_DIR)) {
-        if (inkscape->use_gui) {
+        if (use_gui) {
             // Not a directory
             gchar *safeDn = Inkscape::IO::sanitizeString(dn);
             GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_notdir, safeDn, warn);
@@ -1243,7 +1236,7 @@ inkscape_init_config (Inkscape::XML::Document *doc, const gchar *config_name, co
     Inkscape::IO::dump_fopen_call(fn, "H");
     FILE *fh = Inkscape::IO::fopen_utf8name(fn, "w");
     if (!fh) {
-        if (inkscape->use_gui) {
+        if (use_gui) {
             /* Cannot create file */
             gchar *safeFn = Inkscape::IO::sanitizeString(fn);
             GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_ccf, safeFn, warn);
@@ -1259,7 +1252,7 @@ inkscape_init_config (Inkscape::XML::Document *doc, const gchar *config_name, co
         }
     }
     if ( fwrite(skeleton, 1, skel_size, fh) != skel_size ) {
-        if (inkscape->use_gui) {
+        if (use_gui) {
             /* Cannot create file */
             gchar *safeFn = Inkscape::IO::sanitizeString(fn);
             GtkWidget *w = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, e_cwf, safeFn, warn);
@@ -1299,13 +1292,11 @@ void
 inkscape_exit (Inkscape::Application *inkscape)
 {
     g_assert (INKSCAPE);
-        
+
     //emit shutdown signal so that dialogs could remember layout
     g_signal_emit (G_OBJECT (INKSCAPE), inkscape_signals[SHUTDOWN_SIGNAL], 0);
 
-    if (inkscape->preferences && inkscape->save_preferences) {
-        inkscape_save_preferences (INKSCAPE);
-    }
+    Inkscape::Preferences::save();
     gtk_main_quit ();
 }
 
