@@ -12,22 +12,25 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "forward.h"
+#include <glib/gtypes.h>
+
+struct SPDesktop;
+struct SPDocument;
+struct SPEventContext;
 
 namespace Inkscape {
-namespace XML {
-class Node;
+    struct Application;
+    namespace XML {
+        class Node;
+        class Document;
+        }
 }
-}
-
 
 #define INKSCAPE inkscape_get_instance()
 
 void inkscape_application_init (const gchar *argv0, gboolean use_gui);
 
-/* Preference management */
-bool inkscape_load_preferences (Inkscape::Application * inkscape);
-bool inkscape_save_preferences (Inkscape::Application * inkscape);
+bool inkscape_load_config (const gchar *filename, Inkscape::XML::Document *config, const gchar *skeleton, unsigned int skel_size, const gchar *e_notreg, const gchar *e_notxml, const gchar *e_notsp, const gchar *warn);
 Inkscape::XML::Node *inkscape_get_repr (Inkscape::Application *inkscape, const gchar *key);
 
 /* Menus */
@@ -79,9 +82,9 @@ void inkscape_exit (Inkscape::Application *inkscape);
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
