@@ -17,12 +17,12 @@
  *
  * Copyright (C) 1999-2002 authors
  * Copyright (C) 2001-2002 Ximian, Inc.
- * 
+ *
  * Inkscape authors:
  *   Johan Ceuppens
- * 
+ *
  * Copyright (C) 2004 Inkscape authors
- * 
+ *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
@@ -35,6 +35,7 @@
 #include <sys/stat.h>
 #include <locale.h>
 
+#include <glib/gmem.h>
 #include <libnr/nr-macros.h>
 
 #include <libxml/tree.h>
@@ -46,6 +47,7 @@
 #include <gtk/gtkbutton.h>
 
 #include "gc-core.h"
+#include "preferences.h"
 
 #include <glibmm/i18n.h>
 #include "document.h"
@@ -94,6 +96,9 @@ static void usage();
 
 static GtkWidget *ctrlwin = NULL;
 
+/// Dummy functions to keep linker happy
+int sp_main_gui (int, char const**) { return 0; }
+int sp_main_console (int, char const**) { return 0; }
 
 static int
 sp_svgview_main_delete (GtkWidget *widget, GdkEvent *event, struct SPSlideShow *ss)
@@ -157,9 +162,9 @@ main (int argc, const char **argv)
     if (argc == 1) {
 	usage();
     }
-    
-    struct SPSlideShow ss; 
-	
+
+    struct SPSlideShow ss;
+
     GtkWidget *w;
     int i;
 
@@ -168,8 +173,9 @@ main (int argc, const char **argv)
     textdomain (GETTEXT_PACKAGE);
 
     LIBXML_TEST_VERSION
-    
+
     Inkscape::GC::init();
+    Inkscape::Preferences::loadSkeleton();
 
     gtk_init (&argc, (char ***) &argv);
 
@@ -186,18 +192,19 @@ main (int argc, const char **argv)
     ss.size = 32;
     ss.length = 0;
     ss.current = 0;
-    ss.slides = nr_new (char *, ss.size);
+    ss.slides = g_new (char *, ss.size);
     ss.current = 0;
     ss.doc = NULL;
     ss.view = NULL;
     ss.fullscreen = false;
 
     inkscape = (Inkscape::Application *)g_object_new (SP_TYPE_INKSCAPE, NULL);
+    Inkscape::Preferences::load();
 
     for (i = 1; i < argc; i++) {
 	struct stat st;
-	if (stat (argv[i], &st) 
-	      || !S_ISREG (st.st_mode) 
+	if (stat (argv[i], &st)
+	      || !S_ISREG (st.st_mode)
 	      || (st.st_size < 64)) {
 		fprintf(stderr, "could not open file %s\n", argv[i]);
 	} else {
@@ -224,10 +231,10 @@ main (int argc, const char **argv)
 			if (ss.length >= ss.size) {
 			    /* Expand */
 			    ss.size <<= 1;
-			    ss.slides = nr_renew (ss.slides, char *, ss.size);
+			    ss.slides = g_renew (char *, ss.slides, ss.size);
 			}
-			
-			ss.doc = sp_document_new_from_mem ((const gchar *)gba->data, 
+
+			ss.doc = sp_document_new_from_mem ((const gchar *)gba->data,
 							   gba->len,
 							   TRUE);
 			gchar *last_filename = jar_file_reader.get_last_filename();
@@ -246,13 +253,13 @@ main (int argc, const char **argv)
 		if (ss.length >= ss.size) {
 		    /* Expand */
 		    ss.size <<= 1;
-		    ss.slides = nr_renew (ss.slides, char *, ss.size);
-		    
+		    ss.slides = g_renew (char *, ss.slides, ss.size);
+
 		}
-		
+
 		ss.slides[ss.length++] = strdup (argv[i]);
 		ss.doc = sp_document_new (ss.slides[ss.current], TRUE, false);
-		
+
 		if (!ss.doc && ++ss.current >= ss.length) {
 		    /* No loadable documents */
 		    return 1;
@@ -262,7 +269,7 @@ main (int argc, const char **argv)
 #endif
 	}
     }
-    
+
     if(!ss.doc)
        return 1; /* none of the slides loadable */
 
@@ -307,29 +314,29 @@ sp_svgview_control_show (struct SPSlideShow *ss)
 	t = gtk_table_new (1, 4, TRUE);
 	gtk_container_add ((GtkContainer *) ctrlwin, t);
 	b = gtk_button_new_from_stock (GTK_STOCK_GOTO_FIRST);
-	gtk_table_attach ((GtkTable *) t, b, 0, 1, 0, 1, 
-			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 
-			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 
+	gtk_table_attach ((GtkTable *) t, b, 0, 1, 0, 1,
+			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
+			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
 			  0, 0);
-	g_signal_connect ((GObject *) b, "clicked", (GCallback) sp_svgview_goto_first_cb, ss); 
+	g_signal_connect ((GObject *) b, "clicked", (GCallback) sp_svgview_goto_first_cb, ss);
 	b = gtk_button_new_from_stock (GTK_STOCK_GO_BACK);
 	gtk_table_attach ((GtkTable *) t, b, 1, 2, 0, 1,
-			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 
-			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 
+			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
+			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
 			  0, 0);
-	g_signal_connect (G_OBJECT(b), "clicked", (GCallback) sp_svgview_show_prev_cb, ss); 
+	g_signal_connect (G_OBJECT(b), "clicked", (GCallback) sp_svgview_show_prev_cb, ss);
 	b = gtk_button_new_from_stock (GTK_STOCK_GO_FORWARD);
 	gtk_table_attach ((GtkTable *) t, b, 2, 3, 0, 1,
-			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 
-			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 
+			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
+			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
 			  0, 0);
-	g_signal_connect (G_OBJECT(b), "clicked", (GCallback) sp_svgview_show_next_cb, ss); 
+	g_signal_connect (G_OBJECT(b), "clicked", (GCallback) sp_svgview_show_next_cb, ss);
 	b = gtk_button_new_from_stock (GTK_STOCK_GOTO_LAST);
 	gtk_table_attach ((GtkTable *) t, b, 3, 4, 0, 1,
-			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 
-			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 
+			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
+			  (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
 			  0, 0);
-	g_signal_connect (G_OBJECT(b), "clicked", (GCallback) sp_svgview_goto_last_cb, ss); 
+	g_signal_connect (G_OBJECT(b), "clicked", (GCallback) sp_svgview_goto_last_cb, ss);
 	gtk_widget_show_all (ctrlwin);
     } else {
 	gtk_window_present ((GtkWindow *) ctrlwin);
@@ -338,28 +345,28 @@ sp_svgview_control_show (struct SPSlideShow *ss)
     return NULL;
 }
 
-static int 
+static int
 sp_svgview_show_next_cb (GtkWidget *widget, void *data)
 {
     sp_svgview_show_next(static_cast<struct SPSlideShow *>(data));
     return FALSE;
 }
 
-static int 
+static int
 sp_svgview_show_prev_cb (GtkWidget *widget, void *data)
 {
     sp_svgview_show_prev(static_cast<struct SPSlideShow *>(data));
     return FALSE;
 }
 
-static int 
+static int
 sp_svgview_goto_first_cb (GtkWidget *widget, void *data)
 {
     sp_svgview_goto_first(static_cast<struct SPSlideShow *>(data));
     return FALSE;
 }
 
-static int 
+static int
 sp_svgview_goto_last_cb (GtkWidget *widget, void *data)
 {
     sp_svgview_goto_last(static_cast<struct SPSlideShow *>(data));
@@ -377,7 +384,7 @@ sp_svgview_show_next (struct SPSlideShow *ss)
 	doc = sp_document_new (ss->slides[++current], TRUE, false);
     }
     if (doc) {
-	(SP_VIEW_WIDGET_VIEW (ss->view))->setDocument (doc);
+	reinterpret_cast<SPSVGView*>(SP_VIEW_WIDGET_VIEW (ss->view))->setDocument (doc);
 	sp_document_ensure_up_to_date (doc);
 	ss->doc = doc;
 	ss->current = current;
@@ -395,7 +402,7 @@ sp_svgview_show_prev (struct SPSlideShow *ss)
 	doc = sp_document_new (ss->slides[--current], TRUE, false);
     }
     if (doc) {
-	(SP_VIEW_WIDGET_VIEW (ss->view))->setDocument (doc);
+	reinterpret_cast<SPSVGView*>(SP_VIEW_WIDGET_VIEW (ss->view))->setDocument (doc);
 	sp_document_ensure_up_to_date (doc);
 	ss->doc = doc;
 	ss->current = current;
@@ -411,7 +418,7 @@ sp_svgview_goto_first (struct SPSlideShow *ss)
 	doc = sp_document_new (ss->slides[current], TRUE, false);
     }
     if (doc) {
-	(SP_VIEW_WIDGET_VIEW (ss->view))->setDocument (doc);
+	reinterpret_cast<SPSVGView*>(SP_VIEW_WIDGET_VIEW (ss->view))->setDocument (doc);
 	sp_document_ensure_up_to_date (doc);
 	ss->doc = doc;
 	ss->current = current;
@@ -427,7 +434,7 @@ sp_svgview_goto_last (struct SPSlideShow *ss)
 	doc = sp_document_new (ss->slides[current], TRUE, false);
     }
     if (doc) {
-	(SP_VIEW_WIDGET_VIEW (ss->view))->setDocument (doc);
+	reinterpret_cast<SPSVGView*>(SP_VIEW_WIDGET_VIEW (ss->view))->setDocument (doc);
 	sp_document_ensure_up_to_date (doc);
 	ss->doc = doc;
 	ss->current = current;
@@ -452,7 +459,7 @@ is_jar(char const *filename)
 
 static void usage()
 {
-    fprintf(stderr, 
+    fprintf(stderr,
 	    "Usage: inkview [FILES ...]\n"
 	    "\twhere FILES are SVG (.svg or .svgz)"
 #ifdef WITH_INKJAR
