@@ -13,10 +13,12 @@
 #ifndef __WHITEBOARD_INVITATION_CONFIRM_DIALOG_H__
 #define __WHITEBOARD_INVITATION_CONFIRM_DIALOG_H__
 
-#include <gtkmm.h>
-#include <glibmm.h>
+#include <gtkmm/messagedialog.h>
+#include <gtkmm/checkbutton.h>
+#include <gtkmm/entry.h>
+
+#include "jabber_whiteboard/session-file-selector.h"
 
-#include "session-file-selector.h"
 
 namespace Inkscape {
 
@@ -59,9 +61,9 @@ private:
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
