@@ -12,8 +12,10 @@
 #ifndef __WHITEBOARD_SESSION_FILE_SELECTOR_BOX_H__
 #define __WHITEBOARD_SESSION_FILE_SELECTOR_BOX_H__
 
-#include <glibmm.h>
-#include <gtkmm.h>
+#include <glibmm/ustring.h>
+#include <gtkmm/checkbutton.h>
+#include <gtkmm/entry.h>
+#include <gtkmm/box.h>
 
 namespace Inkscape {
 
@@ -51,9 +53,9 @@ private:
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
