@@ -2,7 +2,7 @@
  * vim: ts=4 sw=4 et tw=0 wm=0
  *
  * libavoid - Fast, Incremental, Object-avoiding Line Router
- * Copyright (C) 2004-2005  Michael Wybrow <mjwybrow@users.sourceforge.net>
+ * Copyright (C) 2004-2006  Michael Wybrow <mjwybrow@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,13 +24,7 @@
 #define AVOID_DEBUG_H
 
 
-
-#ifndef NDEBUG
-  //#define DBPRINTF_DEBUG
-#endif
-
-
-#ifdef DBPRINTF_DEBUG
+#ifdef LIBAVOID_DEBUG
 
 #include <stdarg.h>
 #include <iostream>
@@ -39,7 +33,7 @@
 
 namespace Avoid {
 
-#ifdef DBPRINTF_DEBUG
+#ifdef LIBAVOID_DEBUG
 inline void db_printf(const char *fmt, ...)
 {
     va_list ap;
