@@ -19,7 +19,8 @@
 
 #include <glib/gmessages.h>
 
-#include <libnr/nr-macros.h>
+#include "libnr/nr-coord.h"
+#include "libnr/nr-values.h"
 #include <libnr/nr-rotate.h>
 #include <libnr/nr-scale.h>
 #include <libnr/nr-translate.h>
@@ -395,14 +396,18 @@ class Matrix {
     }
 
 
-
-
     private:
 
 
     NR::Coord _c[6];
 };
 
+/** A function to print out the Matrix (for debugging) */
+inline std::ostream &operator<< (std::ostream &out_file, const NR::Matrix &m) {
+    out_file << "A: " << m[0] << "  C: " << m[2] << "  E: " << m[4] << "\n";
+    out_file << "B: " << m[1] << "  D: " << m[3] << "  F: " << m[5] << "\n";
+    return out_file;
+}
 
 extern void assert_close(Matrix const &a, Matrix const &b);
 
