@@ -5,15 +5,15 @@
  * Cartesian point class.
  */
 
-#include <math.h>
-#include <stdexcept>
+//#include <math.h>
+//#include <stdexcept>
 #include <iostream>
-#include <iomanip>
+//#include <iomanip>
 
 #include <libnr/nr-coord.h>
 #include <libnr/nr-dim2.h>
 
-#include "round.h"
+//#include "round.h"
 #include "decimal-round.h"
 
 /// A NRPoint consists of x and y coodinates.
@@ -151,9 +151,9 @@ inline std::ostream &operator<< (std::ostream &out_file, const NR::Point &in_pnt
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
