@@ -12,12 +12,10 @@
 
 /* Sorted vector paths */
 
+#include <glib/gtypes.h>
 #include <libnr/nr-coord.h>
-#include <libnr/nr-forward.h>
-#include <libnr/nr-rect.h>
-#include <libnr/nr-path.h>
 
-#include <glib.h>
+struct NRPoint;
 
 struct NRSVPSegment {
     gint16 wind;
@@ -59,9 +57,9 @@ struct NRVertex {
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
