@@ -1,12 +1,6 @@
 #define __NR_VALUES_C__
 
-#include "nr-values.h"
-#include <math.h>
-#include "nr-macros.h"
-#include <libnr/nr-matrix.h>
-#include <libnr/nr-rect.h>
 #include <libnr/nr-rect-l.h>
-#include <libnr/nr-point.h>
 
 
 /*
