@@ -11,36 +11,26 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#include "FontFactory.h"
 #include <libnr/nr-rect.h>
 #include <libnrtype/font-glyph.h>
 #include <libnrtype/font-instance.h>
 
-/* #include <layout/LEGlyphStorage.h> */
-
 #include <livarot/Path.h>
-#include <livarot/Shape.h>
 
 #include "RasterFont.h"
 
 /* Freetype 2 */
-# include <freetype/ftoutln.h>
-# include <freetype/ftbbox.h>
-# include <freetype/internal/tttypes.h>
-# include <freetype/internal/ftstream.h>
-# include <freetype/tttags.h>
+# include <ft2build.h>
+# include FT_OUTLINE_H
+# include FT_BBOX_H
+# include FT_TRUETYPE_TAGS_H
+# include FT_TRUETYPE_TABLES_H
 # include <pango/pangoft2.h>
 
 
-#include <glib.h>
 
 size_t  font_style_hash::operator()(const font_style &x) const {
 	int      h=0,n;
-	for (int i=0;i<6;i++) {
-		n=(int)floor(100*x.transform[i]);
-		h*=12186;
-		h+=n;			
-	}
 	n=(int)floor(100*x.stroke_width);
 	h*=12186;
 	h+=n;
@@ -69,16 +59,9 @@ size_t  font_style_hash::operator()(const font_style &x) const {
 }
 
 bool  font_style_equal::operator()(const font_style &a,const font_style &b) {
-	NR::Matrix  diff=a.transform.inverse();
-	diff*=b.transform;
-	if ( diff.is_translation(0.01) ) {
-		if ( fabs(diff[4]) < 0.01 && fabs(diff[5]) < 0.01 ) {
-		} else {
-			return false;
-		}
-	} else {
-		return false;
-	}
+    for (int i=0;i<6;i++) {
+        if ( (int)(100*a.transform[i]) != (int)(100*b.transform[i]) ) return false;
+    }
 	if ( a.vertical && b.vertical == false ) return false;
 	if ( a.vertical == false && b.vertical ) return false;
 	if ( a.stroke_width > 0.01 && b.stroke_width <= 0.01 ) return false;
@@ -87,19 +70,17 @@ bool  font_style_equal::operator()(const font_style &a,const font_style &b) {
 	
 	if ( a.stroke_cap != b.stroke_cap ) return false;
 	if ( a.stroke_join != b.stroke_join ) return false;
-    if ( fabs(a.stroke_miter_limit-b.stroke_miter_limit) > 0.01) return false;
+    if ( (int)(a.stroke_miter_limit*100) != (int)(b.stroke_miter_limit*100) ) return false;
 	if ( a.nbDash != b.nbDash ) return false;
 	if ( a.nbDash <= 0 ) return true;
-	if ( fabs(a.dash_offset-b.dash_offset) < 0.01 ) {
-		for (int i=0;i<a.nbDash;i++) {
-			if ( fabs(a.dashes[i]-b.dashes[i]) >= 0.01 ) return false;
-		}
-	} else {
-		return false;
+	if ( (int)floor(100*a.dash_offset) != (int)floor(100*b.dash_offset) ) return false;
+	for (int i=0;i<a.nbDash;i++) {
+		if ( (int)floor(100*a.dashes[i]) != (int)floor(100*b.dashes[i]) ) return false;
 	}
 	return true;
 }
 
+#ifndef USE_PANGO_WIN32
 /*
  * Outline extraction
  */
@@ -109,9 +90,20 @@ typedef struct ft2_to_liv {
 	NR::Point    last;
 } ft2_to_liv;
 
+// Note: Freetype 2.2.1 redefined function signatures for functions to be placed in an
+// FT_Outline_Funcs structure.  This is needed to keep backwards compatibility with the
+// 2.1.x series.
+
+/* *** BEGIN #if HACK *** */
+#if FREETYPE_MAJOR == 2 && FREETYPE_MINOR >= 2
+typedef FT_Vector const FREETYPE_VECTOR;
+#else
+typedef FT_Vector FREETYPE_VECTOR;
+#endif
+
 // outline as returned by freetype -> livarot Path
 // see nr-type-ft2.cpp for the freetype -> artBPath on which this code is based
-static int ft2_move_to (FT_Vector * to, void * i_user) {
+static int ft2_move_to(FREETYPE_VECTOR *to, void * i_user) {
 	ft2_to_liv* user=(ft2_to_liv*)i_user;
 	NR::Point   p(user->scale*to->x,user->scale*to->y);
 	//	printf("m  t=%f %f\n",p[0],p[1]);
@@ -120,7 +112,7 @@ static int ft2_move_to (FT_Vector * to, void * i_user) {
 	return 0;
 }
 
-static int ft2_line_to (FT_Vector * to, void * i_user)
+static int ft2_line_to(FREETYPE_VECTOR *to, void *i_user)
 {
 	ft2_to_liv* user=(ft2_to_liv*)i_user;
 	NR::Point   p(user->scale*to->x,user->scale*to->y);
@@ -130,7 +122,7 @@ static int ft2_line_to (FT_Vector * to, void * i_user)
 	return 0;
 }
 
-static int ft2_conic_to (FT_Vector * control, FT_Vector * to, void * i_user)
+static int ft2_conic_to(FREETYPE_VECTOR *control, FREETYPE_VECTOR *to, void *i_user)
 {
 	ft2_to_liv* user=(ft2_to_liv*)i_user;
 	NR::Point   p(user->scale*to->x,user->scale*to->y),c(user->scale*control->x,user->scale*control->y);  
@@ -142,7 +134,7 @@ static int ft2_conic_to (FT_Vector * control, FT_Vector * to, void * i_user)
 	return 0;
 }
 
-static int ft2_cubic_to (FT_Vector * control1, FT_Vector * control2, FT_Vector * to, void * i_user)
+static int ft2_cubic_to(FREETYPE_VECTOR *control1, FREETYPE_VECTOR *control2, FREETYPE_VECTOR *to, void *i_user)
 {
 	ft2_to_liv* user=(ft2_to_liv*)i_user;
 	NR::Point   p(user->scale*to->x,user->scale*to->y),
@@ -153,7 +145,9 @@ static int ft2_cubic_to (FT_Vector * control1, FT_Vector * control2, FT_Vector *
 	user->last=p;
 	return 0;
 }
+#endif
 
+/* *** END #if HACK *** */
 
 /*
  *
@@ -243,7 +237,9 @@ unsigned int font_instance::Attribute(const gchar *key, gchar *str, unsigned int
 		pango_font_description_free(td);
 		free_res=true;
 	} else if ( strcmp(key,"psname") == 0 ) {
+#ifndef USE_PANGO_WIN32
          res = (char *) FT_Get_Postscript_Name (theFace); // that's the main method, seems to always work
+#endif
          free_res=false;
          if (res == NULL) { // a very limited workaround, only bold, italic, and oblique will work
              PangoStyle style=pango_font_description_get_style(descr);
@@ -334,27 +330,45 @@ unsigned int font_instance::Attribute(const gchar *key, gchar *str, unsigned int
 	return 0;
 }
 
+void font_instance::InitTheFace()
+{
+#ifdef USE_PANGO_WIN32
+    if ( !theFace ) {
+        LOGFONT *lf=pango_win32_font_logfont(pFont);
+        g_assert(lf != NULL);
+        theFace=pango_win32_font_cache_load(daddy->pangoFontCache,lf);
+        g_free(lf);
+    }
+    XFORM identity = {1.0, 0.0, 0.0, 1.0, 0.0, 0.0};
+    SetWorldTransform(daddy->hScreenDC, &identity);
+    SetGraphicsMode(daddy->hScreenDC, GM_COMPATIBLE);
+    SelectObject(daddy->hScreenDC,theFace);
+#else
+	theFace=pango_ft2_font_get_face(pFont);
+    if ( theFace )
+        FT_Select_Charmap(theFace,ft_encoding_unicode) && FT_Select_Charmap(theFace,ft_encoding_symbol);
+#endif
+}
+
+void font_instance::FreeTheFace()
+{
+#ifdef USE_PANGO_WIN32
+    SelectObject(daddy->hScreenDC,GetStockObject(SYSTEM_FONT));
+    pango_win32_font_cache_unload(daddy->pangoFontCache,theFace);
+#endif
+    theFace=NULL;
+}
+
 void font_instance::InstallFace(PangoFont* iFace)
 {
         if ( !iFace )
             return;
 	pFont=iFace;
 
-	theFace=pango_ft2_font_get_face(pFont);
-	FT_Error ftresult=FT_Select_Charmap(theFace,ft_encoding_unicode);
-	if ( ftresult ) {
-		//g_print("failed to load unicode charmap\n");
-		ftresult=FT_Select_Charmap(theFace,ft_encoding_symbol);
-		if ( ftresult ) {
-			//g_print("and failed to load symbol charmap\n");
-			if ( pFont ) g_object_unref(pFont);
-			pFont=NULL;
-			theFace=NULL;
-		}
-	}
+    InitTheFace();
 
 	if ( pFont && IsOutlineFont() == false ) {
-		theFace=NULL;
+        FreeTheFace();
 		if ( pFont ) g_object_unref(pFont);
 		pFont=NULL;
 	}
@@ -363,19 +377,21 @@ void font_instance::InstallFace(PangoFont* iFace)
 bool	font_instance::IsOutlineFont(void)
 {
 	if ( pFont == NULL ) return false;
-	theFace=pango_ft2_font_get_face(pFont);
+    InitTheFace();
+#ifdef USE_PANGO_WIN32
+    TEXTMETRIC tm;
+    return GetTextMetrics(daddy->hScreenDC,&tm) && tm.tmPitchAndFamily&(TMPF_TRUETYPE|TMPF_DEVICE);
+#else
 	return FT_IS_SCALABLE(theFace);
-}
-
-void font_instance::SelectUnicodeCharmap()
-{
-	theFace=pango_ft2_font_get_face(pFont);
-	FT_Select_Charmap(theFace,ft_encoding_unicode) && FT_Select_Charmap(theFace,ft_encoding_symbol);
+#endif
 }
 
 int font_instance::MapUnicodeChar(gunichar c)
 {
 	if ( pFont == NULL ) return 0;
+#ifdef USE_PANGO_WIN32
+    return pango_win32_font_get_glyph_index(pFont,c);
+#else
 	int res=0;
 	theFace=pango_ft2_font_get_face(pFont);
 	if ( c > 0xf0000 ) {
@@ -384,16 +400,25 @@ int font_instance::MapUnicodeChar(gunichar c)
 		res=FT_Get_Char_Index(theFace, c);
 	}
 	return res;
+#endif
 }
 
 
-
+#ifdef USE_PANGO_WIN32
+static inline NR::Point pointfx_to_nrpoint(const POINTFX &p, double scale)
+{
+    return NR::Point(*(long*)&p.x / 65536.0 * scale,
+                     *(long*)&p.y / 65536.0 * scale);
+}
+#endif
 
 void font_instance::LoadGlyph(int glyph_id)
 {
 	if ( pFont == NULL ) return;
-	theFace=pango_ft2_font_get_face(pFont);
-	if ( theFace->units_per_EM == 0 ) return; // bitmap font
+    InitTheFace();
+#ifndef USE_PANGO_WIN32
+	if ( !FT_IS_SCALABLE(theFace) ) return; // bitmap font
+#endif
 
 	if ( id_to_no.find(glyph_id) == id_to_no.end() ) {
 		if ( nbGlyph >= maxGlyph ) {
@@ -406,6 +431,87 @@ void font_instance::LoadGlyph(int glyph_id)
 		n_g.bbox[0]=n_g.bbox[1]=n_g.bbox[2]=n_g.bbox[3]=0;
 		bool   doAdd=false;
 
+#ifdef USE_PANGO_WIN32
+        MAT2 identity = {{0,1},{0,0},{0,0},{0,1}};
+        OUTLINETEXTMETRIC otm;
+        GetOutlineTextMetrics(daddy->hScreenDC, sizeof(otm), &otm);
+        GLYPHMETRICS metrics;
+        DWORD bufferSize=GetGlyphOutline (daddy->hScreenDC, glyph_id, GGO_GLYPH_INDEX | GGO_NATIVE | GGO_UNHINTED, &metrics, 0, NULL, &identity);
+        double scale=1.0/daddy->fontSize;
+        n_g.h_advance=metrics.gmCellIncX*scale;
+        n_g.v_advance=otm.otmTextMetrics.tmHeight*scale;
+        n_g.h_width=metrics.gmBlackBoxX*scale;
+        n_g.v_width=metrics.gmBlackBoxY*scale;
+        n_g.outline=NULL;
+        if ( bufferSize == GDI_ERROR) {
+            // shit happened
+        } else if ( bufferSize == 0) {
+            // character has no visual representation, but is valid (eg whitespace)
+            doAdd=true;
+        } else {
+            std::auto_ptr<char> buffer(new char[bufferSize]);
+            if ( GetGlyphOutline (daddy->hScreenDC, glyph_id, GGO_GLYPH_INDEX | GGO_NATIVE | GGO_UNHINTED, &metrics, bufferSize, buffer.get(), &identity) <= 0 ) {
+                // shit happened
+            } else {
+                // Platform SDK is rubbish, read KB87115 instead
+                n_g.outline=new Path;
+                DWORD polyOffset=0;
+                while ( polyOffset < bufferSize ) {
+                    TTPOLYGONHEADER const *polyHeader=(TTPOLYGONHEADER const *)(buffer.get()+polyOffset);
+                    if (polyOffset+polyHeader->cb > bufferSize) break;
+
+                    if (polyHeader->dwType == TT_POLYGON_TYPE) {
+                        n_g.outline->MoveTo(pointfx_to_nrpoint(polyHeader->pfxStart, scale));
+                        DWORD curveOffset=polyOffset+sizeof(TTPOLYGONHEADER);
+
+                        while ( curveOffset < polyOffset+polyHeader->cb ) {
+                            TTPOLYCURVE const *polyCurve=(TTPOLYCURVE const *)(buffer.get()+curveOffset);
+                            POINTFX const *p=polyCurve->apfx;
+                            POINTFX const *endp=p+polyCurve->cpfx;
+
+                            switch (polyCurve->wType) {
+                                case TT_PRIM_LINE:
+                                    while ( p != endp )
+                                        n_g.outline->LineTo(pointfx_to_nrpoint(*p++, scale));
+                                    break;
+
+                                case TT_PRIM_QSPLINE:
+                                {
+                                    g_assert(polyCurve->cpfx >= 2);
+                                    endp -= 2;
+                                    NR::Point this_mid=pointfx_to_nrpoint(p[0], scale);
+                                    while ( p != endp ) {
+                                        NR::Point next_mid=pointfx_to_nrpoint(p[1], scale);
+	                                    n_g.outline->BezierTo((next_mid+this_mid)/2);
+	                                    n_g.outline->IntermBezierTo(this_mid);
+	                                    n_g.outline->EndBezierTo();
+                                        ++p;
+                                        this_mid=next_mid;
+                                    }
+	                                n_g.outline->BezierTo(pointfx_to_nrpoint(p[1], scale));
+	                                n_g.outline->IntermBezierTo(this_mid);
+	                                n_g.outline->EndBezierTo();
+                                    break;
+                                }
+
+                                case 3:  // TT_PRIM_CSPLINE
+                                    g_assert(polyCurve->cpfx % 3 == 0);
+                                    while ( p != endp ) {
+                                        n_g.outline->CubicTo(pointfx_to_nrpoint(p[2], scale), pointfx_to_nrpoint(p[0], scale), pointfx_to_nrpoint(p[1], scale));
+                                        p += 3;
+                                    }
+                                    break;
+                            }
+                            curveOffset += sizeof(TTPOLYCURVE)+sizeof(POINTFX)*(polyCurve->cpfx-1);
+                        }
+                        n_g.outline->Close();
+                    }
+                    polyOffset += polyHeader->cb;
+                }
+                doAdd=true;
+            }
+        }
+#else
 		if (FT_Load_Glyph (theFace, glyph_id, FT_LOAD_NO_SCALE | FT_LOAD_NO_HINTING | FT_LOAD_NO_BITMAP)) {
 			// shit happened
 		} else {
@@ -438,6 +544,7 @@ void font_instance::LoadGlyph(int glyph_id)
 			}
 			doAdd=true;
 		}
+#endif
 
 		if ( doAdd ) {
 			if ( n_g.outline ) {
@@ -454,16 +561,23 @@ void font_instance::LoadGlyph(int glyph_id)
 
 bool font_instance::FontMetrics(double &ascent,double &descent,double &leading)
 {
-	theFace=pango_ft2_font_get_face(pFont);
-	if ( theFace->units_per_EM == 0 ) return false; // bitmap font
-	
 	if ( pFont == NULL ) return false;
-	
+    InitTheFace();
 	if ( theFace == NULL ) return false;
+#ifdef USE_PANGO_WIN32
+    OUTLINETEXTMETRIC otm;
+    if ( !GetOutlineTextMetrics(daddy->hScreenDC,sizeof(otm),&otm) ) return false;
+    double scale=1.0/daddy->fontSize;
+    ascent=fabs(otm.otmAscent*scale);
+    descent=fabs(otm.otmDescent*scale);
+    leading=fabs(otm.otmLineGap*scale);
+#else
+	if ( theFace->units_per_EM == 0 ) return false; // bitmap font
 	ascent=fabs(((double)theFace->ascender)/((double)theFace->units_per_EM));
 	descent=fabs(((double)theFace->descender)/((double)theFace->units_per_EM));
 	leading=fabs(((double)theFace->height)/((double)theFace->units_per_EM));
 	leading-=ascent+descent;
+#endif
 	return true;
 }
 
@@ -472,18 +586,23 @@ bool font_instance::FontSlope(double &run, double &rise)
     run = 0.0;
     rise = 1.0;
 
-    theFace=pango_ft2_font_get_face(pFont);
-
-	if ( theFace->units_per_EM == 0 ) return false; // bitmap font
-	
 	if ( pFont == NULL ) return false;
-	
+    InitTheFace();
 	if ( theFace == NULL ) return false;
 
+#ifdef USE_PANGO_WIN32
+    OUTLINETEXTMETRIC otm;
+    if ( !GetOutlineTextMetrics(daddy->hScreenDC,sizeof(otm),&otm) ) return false;
+    run=otm.otmsCharSlopeRun;
+    rise=otm.otmsCharSlopeRise;
+#else
+	if ( !FT_IS_SCALABLE(theFace) ) return false; // bitmap font
+	
     TT_HoriHeader *hhea = (TT_HoriHeader*)FT_Get_Sfnt_Table(theFace, ft_sfnt_hhea);
     if (hhea == NULL) return false;
     run = hhea->caret_Slope_Run;
     rise = hhea->caret_Slope_Rise;
+#endif
 	return true;
 }
 
