@@ -8,24 +8,20 @@
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
-#include <algorithm>
 #include "Layout-TNG.h"
 #include "style.h"
 #include "font-instance.h"
-#include "svg/svg-types.h"
+#include "svg/svg-length.h"
 #include "sp-object.h"
 #include "Layout-TNG-Scanline-Maker.h"
-#include "FontFactory.h"
-#include <pango/pango.h>
-#include <map>
 
 namespace Inkscape {
 namespace Text {
 
-//#define IFDEBUG(...)     __VA_ARGS__
-#define IFDEBUG(...)
-
-#define TRACE(format, ...) IFDEBUG(g_print(format, ## __VA_ARGS__),g_print("\n"))
+//#define IFTRACE(_code) _code
+//#define TRACE(_args) g_print _args
+#define IFTRACE(_code)
+#define TRACE(_args)
 
 // ******* enum conversion tables
 static Layout::EnumConversionItem const enum_convert_spstyle_direction_to_pango_direction[] = {
@@ -125,7 +121,7 @@ class Layout::Calculator
         double line_height_multiplier;  /// calculated from the font-height css property
         unsigned text_bytes;
         unsigned char_index_in_para;    /// the index of the first character in this span in the paragraph, for looking up char_attributes
-        SPSVGLength x, y, dx, dy, rotate;  // these are reoriented copies of the <tspan> attributes. We change span when we encounter one.
+        SVGLength x, y, dx, dy, rotate;  // these are reoriented copies of the <tspan> attributes. We change span when we encounter one.
 
         UnbrokenSpan() : glyph_string(NULL) {}
         void free() {if (glyph_string) pango_glyph_string_free(glyph_string); glyph_string = NULL;}
@@ -238,7 +234,7 @@ class Layout::Calculator
     {
         span->setZero();
 
-        if (span->start.iter_span->dx.set && span->start.char_byte == 0)
+        if (span->start.iter_span->dx._set && span->start.char_byte == 0)
             span->width += span->start.iter_span->dx.computed;
 
         if (span->start.iter_span->pango_item_index == -1) {
@@ -257,7 +253,7 @@ class Layout::Calculator
             if (control_code->code == ARBITRARY_GAP) {
                 if (span->width + control_code->width > maximum_width)
                     return false;
-                TRACE("fitted control code, width = %f", control_code->width);
+                TRACE(("fitted control code, width = %f\n", control_code->width));
                 span->width += control_code->width;
                 span->end.increment();
             }
@@ -282,7 +278,7 @@ class Layout::Calculator
         double soft_hyphen_glyph_width = 0.0;
         bool soft_hyphen_in_word = false;
         bool is_soft_hyphen = false;
-        IFDEBUG(int char_count = 0);
+        IFTRACE(int char_count = 0);
 
         // if we're not at the start of the span we need to pre-init glyph_index
         span->start_glyph_index = 0;
@@ -297,7 +293,7 @@ class Layout::Calculator
 
             if (char_attributes.is_mandatory_break) {
                 *last_emergency_break_span = *last_break_span = *span;
-                TRACE("span %d end of para; width = %f chars = %d", span->start.iter_span - para.unbroken_spans.begin(), span->width, char_count);
+                TRACE(("span %d end of para; width = %f chars = %d\n", span->start.iter_span - para.unbroken_spans.begin(), span->width, char_count));
                 return false;
             }
 
@@ -330,7 +326,7 @@ class Layout::Calculator
             if (char_attributes.is_white)
                 char_width += text_source->style->word_spacing.computed;
             span->width += char_width;
-            IFDEBUG(char_count++);
+            IFTRACE(char_count++);
 
             if (char_attributes.is_white) {
                 span->whitespace_count++;
@@ -345,12 +341,12 @@ class Layout::Calculator
             span->end.increment();
 
             if (span->width > maximum_width && !char_attributes.is_white) {       // whitespaces don't matter, we can put as many as we want at eol
-                TRACE("span %d exceeded scanrun; width = %f chars = %d", span->start.iter_span - para.unbroken_spans.begin(), span->width, char_count);
+                TRACE(("span %d exceeded scanrun; width = %f chars = %d\n", span->start.iter_span - para.unbroken_spans.begin(), span->width, char_count));
                 return false;
             }
 
         } while (span->end.char_byte != 0);  // while we haven't wrapped to the next span
-        TRACE("fitted span %d width = %f chars = %d", span->start.iter_span - para.unbroken_spans.begin(), span->width, char_count);
+        TRACE(("fitted span %d width = %f chars = %d\n", span->start.iter_span - para.unbroken_spans.begin(), span->width, char_count));
         return true;
     }
 
@@ -404,12 +400,12 @@ class Layout::Calculator
     void _outputLine(ParagraphInfo const &para, LineHeight const &line_height, std::vector<ChunkInfo> const &chunk_info)
     {
         if (chunk_info.empty()) {
-            TRACE("line too short to fit anything on it, go to next");
+            TRACE(("line too short to fit anything on it, go to next\n"));
             return;
         }
 
         // we've finished fiddling about with ascents and descents: create the output
-        TRACE("found line fit; creating output");
+        TRACE(("found line fit; creating output\n"));
         Layout::Line new_line;
         new_line.in_paragraph = _flow._paragraphs.size() - 1;
         new_line.baseline_y = _scanline_maker->yCoordinate() + line_height.ascent;
@@ -426,7 +422,7 @@ class Layout::Calculator
             // we may also have y move orders to deal with here (dx, dy and rotate are done per span)
             if (!it_chunk->broken_spans.empty()    // this one only happens for empty paragraphs
                 && it_chunk->broken_spans.front().start.char_byte == 0
-                && it_chunk->broken_spans.front().start.iter_span->y.set) {
+                && it_chunk->broken_spans.front().start.iter_span->y._set) {
                 // if this is the start of a line, we should change the baseline rather than each glyph individually
                 if (_flow._characters.empty() || _flow._characters.back().chunk(&_flow).in_line != _flow._lines.size() - 1) {
                     new_line.baseline_y = it_chunk->broken_spans.front().start.iter_span->y.computed;
@@ -460,9 +456,9 @@ class Layout::Calculator
 
                 if (it_span->start.char_byte == 0) {
                     // start of an unbroken span, we might have dx, dy or rotate still to process (x and y are done per chunk)
-                    if (unbroken_span.dx.set) x += unbroken_span.dx.computed;
-                    if (unbroken_span.dy.set) _y_offset += unbroken_span.dy.computed;
-                    if (unbroken_span.rotate.set) glyph_rotate = unbroken_span.rotate.computed * (M_PI/180);
+                    if (unbroken_span.dx._set) x += unbroken_span.dx.computed;
+                    if (unbroken_span.dy._set) _y_offset += unbroken_span.dy.computed;
+                    if (unbroken_span.rotate._set) glyph_rotate = unbroken_span.rotate.computed * (M_PI/180);
                 }
 
                 if (_flow._input_stream[unbroken_span.input_index]->Type() == TEXT_SOURCE
@@ -528,7 +524,6 @@ class Layout::Calculator
 
                         if (unbroken_span.glyph_string->log_clusters[glyph_index] < (int)unbroken_span.text_bytes
                             && *iter_source_text == UNICODE_SOFT_HYPHEN
-                            && it_span + 1 != it_chunk->broken_spans.end()
                             && glyph_index + 1 != it_span->end_glyph_index) {
                             // if we're looking at a soft hyphen and it's not the last glyph in the
                             // chunk we don't draw the glyph but we still need to add to _characters
@@ -542,7 +537,6 @@ class Layout::Calculator
                             while (glyph_index < (unsigned)unbroken_span.glyph_string->num_glyphs
                                    && unbroken_span.glyph_string->log_clusters[glyph_index] == (int)char_byte)
                                 glyph_index++;
-                            glyph_rotate = 0.0;
                             glyph_index--;
                             continue;
                         }
@@ -644,7 +638,7 @@ class Layout::Calculator
             }
             // end adding spans to the list, on to the next chunk...
         }
-        TRACE("output done");
+        TRACE(("output done\n"));
     }
 
 /* *********************************************************************************************************/
@@ -664,11 +658,11 @@ class Layout::Calculator
             if (!text_source->y.empty())
                 initial_y = text_source->y.front().computed;
             _scanline_maker = new InfiniteScanlineMaker(initial_x, initial_y, _block_progression);
-            TRACE("  wrapping disabled");
+            TRACE(("  wrapping disabled\n"));
         }
         else {
             _scanline_maker = new ShapeScanlineMaker(_flow._input_wrap_shapes[_current_shape_index].shape, _block_progression);
-            TRACE("  begin wrap shape 0");
+            TRACE(("  begin wrap shape 0\n"));
         }
     }
 
@@ -824,7 +818,7 @@ void Layout::Calculator::_buildPangoItemizationForPara(ParagraphInfo *para) cons
     para->free_sequence(para->pango_items);
     para->char_attributes.clear();
 
-    TRACE("itemizing para, first input %d", para->first_input_index);
+    TRACE(("itemizing para, first input %d\n", para->first_input_index));
 
     attributes_list = pango_attr_list_new();
     for(input_index = para->first_input_index ; input_index < _flow._input_stream.size() ; input_index++) {
@@ -838,12 +832,10 @@ void Layout::Calculator::_buildPangoItemizationForPara(ParagraphInfo *para) cons
         } else if (_flow._input_stream[input_index]->Type() == TEXT_SOURCE) {
             Layout::InputStreamTextSource *text_source = static_cast<Layout::InputStreamTextSource *>(_flow._input_stream[input_index]);
 
-            // create the font_instance
-            font_instance *font = text_source->styleGetFontInstance();
-            if (font == NULL)
-                continue;  // bad news: we'll have to ignore all this text because we know of no font to render it
+            PangoFontDescription *temp_descr = text_source->styleGetFontDescription();
+            PangoAttribute *attribute_font_description = pango_attr_font_desc_new(temp_descr);
+            pango_font_description_free(temp_descr);
 
-            PangoAttribute *attribute_font_description = pango_attr_font_desc_new(font->descr);
             attribute_font_description->start_index = para_text.bytes();
             para_text.append(&*text_source->text_begin.base(), text_source->text_length);     // build the combined text
             attribute_font_description->end_index = para_text.bytes();
@@ -852,8 +844,8 @@ void Layout::Calculator::_buildPangoItemizationForPara(ParagraphInfo *para) cons
         }
     }
 
-    TRACE("whole para: \"%s\"", para_text.data());
-    TRACE("%d input sources used", input_index - para->first_input_index);
+    TRACE(("whole para: \"%s\"\n", para_text.data()));
+    TRACE(("%d input sources used\n", input_index - para->first_input_index));
 
     // do the pango_itemize()
     GList *pango_items_glist = NULL;
@@ -877,7 +869,7 @@ void Layout::Calculator::_buildPangoItemizationForPara(ParagraphInfo *para) cons
 
     // convert the GList to our vector<> and make the font_instance for each PangoItem at the same time
     para->pango_items.reserve(g_list_length(pango_items_glist));
-    TRACE("para itemizes to %d sections", g_list_length(pango_items_glist));
+    TRACE(("para itemizes to %d sections\n", g_list_length(pango_items_glist)));
     for (GList *current_pango_item = pango_items_glist ; current_pango_item != NULL ; current_pango_item = current_pango_item->next) {
         PangoItemInfo new_item;
         new_item.item = (PangoItem*)current_pango_item->data;
@@ -892,7 +884,7 @@ void Layout::Calculator::_buildPangoItemizationForPara(ParagraphInfo *para) cons
     para->char_attributes.resize(para_text.length() + 1);
     pango_get_log_attrs(para_text.data(), para_text.bytes(), -1, NULL, &*para->char_attributes.begin(), para->char_attributes.size());
 
-    TRACE("end para itemize, direction = %d", para->direction);
+    TRACE(("end para itemize, direction = %d\n", para->direction));
 }
 
 /**
@@ -956,7 +948,7 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
     unsigned byte_index_in_para = 0;
     unsigned input_index;
 
-    TRACE("build spans");
+    TRACE(("build spans\n"));
     para->free_sequence(para->unbroken_spans);
 
     for(input_index = para->first_input_index ; input_index < _flow._input_stream.size() ; input_index++) {
@@ -975,7 +967,7 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
                 new_span.text_bytes = 0;
                 new_span.char_index_in_para = char_index_in_para;
                 para->unbroken_spans.push_back(new_span);
-                TRACE("add gap span %d", para->unbroken_spans.size() - 1);
+                TRACE(("add gap span %d\n", para->unbroken_spans.size() - 1));
             }
         } else if (_flow._input_stream[input_index]->Type() == TEXT_SOURCE && pango_item_index < para->pango_items.size()) {
             Layout::InputStreamTextSource const *text_source = static_cast<Layout::InputStreamTextSource const *>(_flow._input_stream[input_index]);
@@ -1002,11 +994,11 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
                 new_span.input_index = input_index;
 
                 // cut at <tspan> attribute changes as well
-                new_span.x.set = false;
-                new_span.y.set = false;
-                new_span.dx.set = false;
-                new_span.dy.set = false;
-                new_span.rotate.set = false;
+                new_span.x._set = false;
+                new_span.y._set = false;
+                new_span.dx._set = false;
+                new_span.dy._set = false;
+                new_span.rotate._set = false;
                 if (_block_progression == TOP_TO_BOTTOM || _block_progression == BOTTOM_TO_TOP) {
                     if (text_source->x.size()  > char_index_in_source) new_span.x  = text_source->x[char_index_in_source];
                     if (text_source->y.size()  > char_index_in_source) new_span.y  = text_source->y[char_index_in_source];
@@ -1019,7 +1011,7 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
                     if (text_source->dy.size() > char_index_in_source) new_span.dx = text_source->dy[char_index_in_source];
                 }
                 if (text_source->rotate.size() > char_index_in_source) new_span.rotate = text_source->rotate[char_index_in_source];
-                if (input_index == 0 && para->unbroken_spans.empty() && !new_span.y.set && _flow._input_wrap_shapes.empty()) {
+                if (input_index == 0 && para->unbroken_spans.empty() && !new_span.y._set && _flow._input_wrap_shapes.empty()) {
                     // if we don't set an explicit y some of the automatic wrapping code takes over and moves the text vertically
                     // so that the top of the letters is at zero, not the baseline
                     new_span.y = 0.0;
@@ -1030,13 +1022,14 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
                     if (iter_text >= text_source->text_end) break;
                     if (iter_text.base() - new_span.input_stream_first_character.base() >= (int)new_span.text_bytes) break;
                     if (   i >= text_source->x.size() && i >= text_source->y.size()
-                           && i >= text_source->dx.size() && i >= text_source->dy.size()
-                           && i >= text_source->rotate.size()) break;
-                    if (   (text_source->x.size()  > i && text_source->x[i].set)
-                           || (text_source->y.size()  > i && text_source->y[i].set)
-                           || (text_source->dx.size() > i && text_source->dx[i].set && text_source->dx[i].computed != 0.0)
-                           || (text_source->dy.size() > i && text_source->dy[i].set && text_source->dy[i].computed != 0.0)
-                           || (text_source->rotate.size() > i && text_source->rotate[i].set && text_source->rotate[i].computed != 0.0)) {
+                        && i >= text_source->dx.size() && i >= text_source->dy.size()
+                        && i >= text_source->rotate.size()) break;
+                    if (   (text_source->x.size()  > i && text_source->x[i]._set)
+                        || (text_source->y.size()  > i && text_source->y[i]._set)
+                        || (text_source->dx.size() > i && text_source->dx[i]._set && text_source->dx[i].computed != 0.0)
+                        || (text_source->dy.size() > i && text_source->dy[i]._set && text_source->dy[i].computed != 0.0)
+                        || (text_source->rotate.size() > i && text_source->rotate[i]._set
+                            && (i == 0 || text_source->rotate[i].computed != text_source->rotate[i - 1].computed))) {
                         new_span.text_bytes = iter_text.base() - new_span.input_stream_first_character.base();
                         break;
                     }
@@ -1045,7 +1038,7 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
                 // now we know the length, do some final calculations and add the UnbrokenSpan to the list
                 new_span.font_size = text_source->styleComputeFontSize();
                 if (new_span.text_bytes) {
-                    int original_bidi_level = para->pango_items[pango_item_index].item->analysis.level;
+                    int const original_bidi_level = para->pango_items[pango_item_index].item->analysis.level;
                     para->pango_items[pango_item_index].item->analysis.level = 0;
                     // pango_shape() will reorder glyphs in rtl sections which messes us up because
                     // the svg spec requires us to draw glyphs in character order
@@ -1064,8 +1057,8 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
                     new_span.pango_item_index = pango_item_index;
                     _computeFontLineHeight(para->pango_items[pango_item_index].font, new_span.font_size, text_source->style, &new_span.line_height, &new_span.line_height_multiplier);
                     // TODO: metrics for vertical text
-                    TRACE("add text span %d \"%s\"", para->unbroken_spans.size(), text_source->text->raw().substr(span_start_byte_in_source, new_span.text_bytes).c_str());
-                    TRACE("  %d glyphs", new_span.glyph_string->num_glyphs);
+                    TRACE(("add text span %d \"%s\"\n", para->unbroken_spans.size(), text_source->text->raw().substr(span_start_byte_in_source, new_span.text_bytes).c_str()));
+                    TRACE(("  %d glyphs\n", new_span.glyph_string->num_glyphs));
                 } else {
                     // if there's no text we still need to initialise the styles
                     new_span.pango_item_index = -1;
@@ -1077,7 +1070,7 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
                         new_span.line_height.setZero();
                         new_span.line_height_multiplier = 1.0;
                     }
-                    TRACE("add style init span %d", para->unbroken_spans.size());
+                    TRACE(("add style init span %d\n", para->unbroken_spans.size()));
                 }
                 para->unbroken_spans.push_back(new_span);
 
@@ -1097,7 +1090,7 @@ unsigned Layout::Calculator::_buildSpansForPara(ParagraphInfo *para) const
             char_index_in_para += char_index_in_source;
         }
     }
-    TRACE("end build spans");
+    TRACE(("end build spans\n"));
     return input_index;
 }
 
@@ -1113,7 +1106,7 @@ bool Layout::Calculator::_goToNextWrapShape()
     _current_shape_index++;
     if (_current_shape_index == _flow._input_wrap_shapes.size()) return false;
     _scanline_maker = new ShapeScanlineMaker(_flow._input_wrap_shapes[_current_shape_index].shape, _block_progression);
-    TRACE("begin wrap shape %d", _current_shape_index);
+    TRACE(("begin wrap shape %d\n", _current_shape_index));
     return true;
 }
 
@@ -1170,7 +1163,7 @@ bool Layout::Calculator::_findChunksForLine(ParagraphInfo const &para,
             scan_runs = _scanline_maker->makeScanline(*line_height);
         }
 
-        TRACE("finding line fit y=%f, %d scan runs", scan_runs.front().y, scan_runs.size());
+        TRACE(("finding line fit y=%f, %d scan runs\n", scan_runs.front().y, scan_runs.size()));
         chunk_info->clear();
         chunk_info->reserve(scan_runs.size());
         if (para.direction == RIGHT_TO_LEFT) std::reverse(scan_runs.begin(), scan_runs.end());
@@ -1221,7 +1214,7 @@ bool Layout::Calculator::_buildChunksInScanRun(ParagraphInfo const &para,
     last_span_at_emergency_break.start = start_span_pos;
     last_span_at_emergency_break.setZero();
 
-    TRACE("trying chunk from %f to %g", scan_run.x_start, scan_run.x_end);
+    TRACE(("trying chunk from %f to %g\n", scan_run.x_start, scan_run.x_end));
     BrokenSpan new_span;
     new_span.end = start_span_pos;
     while (new_span.end.iter_span != para.unbroken_spans.end()) {    // this loops once for each UnbrokenSpan
@@ -1229,7 +1222,7 @@ bool Layout::Calculator::_buildChunksInScanRun(ParagraphInfo const &para,
         new_span.start = new_span.end;
 
         // force a chunk change at x or y attribute change
-        if ((new_span.start.iter_span->x.set || new_span.start.iter_span->y.set) && new_span.start.char_byte == 0) {
+        if ((new_span.start.iter_span->x._set || new_span.start.iter_span->y._set) && new_span.start.char_byte == 0) {
 
             if (new_span.start.iter_span != start_span_pos.iter_span)
                 chunk_info->push_back(new_chunk);
@@ -1238,7 +1231,7 @@ bool Layout::Calculator::_buildChunksInScanRun(ParagraphInfo const &para,
             new_chunk.text_width = 0.0;
             new_chunk.whitespace_count = 0;
             new_chunk.broken_spans.clear();
-            if (new_span.start.iter_span->x.set) new_chunk.x = new_span.start.iter_span->x.computed;
+            if (new_span.start.iter_span->x._set) new_chunk.x = new_span.start.iter_span->x.computed;
             // y doesn't need to be done until output time
         }
 
@@ -1269,7 +1262,7 @@ bool Layout::Calculator::_buildChunksInScanRun(ParagraphInfo const &para,
         }
     }
 
-    TRACE("chunk complete, used %f width (%d whitespaces, %d brokenspans)", new_chunk.text_width, new_chunk.whitespace_count, new_chunk.broken_spans.size());
+    TRACE(("chunk complete, used %f width (%d whitespaces, %d brokenspans)\n", new_chunk.text_width, new_chunk.whitespace_count, new_chunk.broken_spans.size()));
     chunk_info->push_back(new_chunk);
 
     if (scan_run.width() >= 4.0 * line_height->total() && last_span_at_break.end == start_span_pos) {
@@ -1307,7 +1300,7 @@ bool Layout::Calculator::_buildChunksInScanRun(ParagraphInfo const &para,
                 chunk_info->back().text_width += last_span_at_break.width;
                 chunk_info->back().whitespace_count += last_span_at_break.whitespace_count;
             }
-            TRACE("correction: fitted span %d width = %f", last_span_at_break.start.iter_span - para.unbroken_spans.begin(), last_span_at_break.width);
+            TRACE(("correction: fitted span %d width = %f\n", last_span_at_break.start.iter_span - para.unbroken_spans.begin(), last_span_at_break.width));
         }
     }
 
@@ -1332,7 +1325,7 @@ bool Layout::Calculator::calculate()
     if (_flow._input_stream.front()->Type() != TEXT_SOURCE)
         return false;
 
-    TRACE("begin calculateFlow()");
+    TRACE(("begin calculateFlow()\n"));
 
     _flow._clearOutputObjects();
 
@@ -1350,7 +1343,7 @@ bool Layout::Calculator::calculate()
         if (_flow._input_stream[para.first_input_index]->Type() == CONTROL_CODE) {
             InputStreamControlCode const *control_code = static_cast<InputStreamControlCode const *>(_flow._input_stream[para.first_input_index]);
             if (control_code->code == SHAPE_BREAK) {
-                TRACE("shape break control code");
+                TRACE(("shape break control code\n"));
                 if (!_goToNextWrapShape()) break;
                 continue;
             }
@@ -1366,7 +1359,7 @@ bool Layout::Calculator::calculate()
         else
             para.alignment = para.direction == LEFT_TO_RIGHT ? LEFT : RIGHT;
 
-        TRACE("para prepared, adding as #%d", _flow._paragraphs.size());
+        TRACE(("para prepared, adding as #%d\n", _flow._paragraphs.size()));
         Layout::Paragraph new_paragraph;
         new_paragraph.base_direction = para.direction;
         new_paragraph.alignment = para.alignment;
@@ -1379,7 +1372,7 @@ bool Layout::Calculator::calculate()
         span_pos.char_index = 0;
 
         do {   // for each line in the paragraph
-            TRACE("begin line");
+            TRACE(("begin line\n"));
             std::vector<ChunkInfo> line_chunk_info;
             if (!_findChunksForLine(para, &span_pos, &line_chunk_info, &line_height))
                 break;   // out of shapes to wrap in to
@@ -1388,7 +1381,7 @@ bool Layout::Calculator::calculate()
             _scanline_maker->completeLine();
         } while (span_pos.iter_span != para.unbroken_spans.end());
 
-        TRACE("para %d end\n", _flow._paragraphs.size() - 1);
+        TRACE(("para %d end\n\n", _flow._paragraphs.size() - 1));
         if (_scanline_maker != NULL) {
             bool is_empty_para = _flow._characters.empty() || _flow._characters.back().line(&_flow).in_paragraph != _flow._paragraphs.size() - 1;
             if ((is_empty_para && para_end_input_index + 1 >= _flow._input_stream.size())
@@ -1479,8 +1472,8 @@ void Layout::_calculateCursorShapeForEmpty()
     _empty_cursor_shape.rotation = caret_slope;
 
     if (_input_wrap_shapes.empty()) {
-        _empty_cursor_shape.position = NR::Point(text_source->x.empty() || !text_source->x.front().set ? 0.0 : text_source->x.front().computed,
-                                                 text_source->y.empty() || !text_source->y.front().set ? 0.0 : text_source->y.front().computed);
+        _empty_cursor_shape.position = NR::Point(text_source->x.empty() || !text_source->x.front()._set ? 0.0 : text_source->x.front().computed,
+                                                 text_source->y.empty() || !text_source->y.front()._set ? 0.0 : text_source->y.front().computed);
     } else {
         Direction block_progression = text_source->styleGetBlockProgression();
         ShapeScanlineMaker scanline_maker(_input_wrap_shapes.front().shape, block_progression);
