@@ -8,13 +8,11 @@
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
-#include <algorithm>
 #include "Layout-TNG.h"
 #include "style.h"
-#include "svg/svg-types.h"
+#include "svg/svg-length.h"
 #include "sp-object.h"
 #include "FontFactory.h"
-#include <glib/glist.h>
 
 namespace Inkscape {
 namespace Text {
@@ -57,13 +55,13 @@ void Layout::appendText(Glib::ustring const &text, SPStyle *style, void *source_
     _input_stream.push_back(new_source);
 }
 
-void Layout::_copyInputVector(std::vector<SPSVGLength> const &input_vector, unsigned input_offset, std::vector<SPSVGLength> *output_vector, size_t max_length)
+void Layout::_copyInputVector(std::vector<SVGLength> const &input_vector, unsigned input_offset, std::vector<SVGLength> *output_vector, size_t max_length)
 {
     output_vector->clear();
     if (input_offset >= input_vector.size()) return;
     output_vector->reserve(std::min(max_length, input_vector.size() - input_offset));
     while (input_offset < input_vector.size() && max_length != 0) {
-        if (!input_vector[input_offset].set)
+        if (!input_vector[input_offset]._set)
             break;
         output_vector->push_back(input_vector[input_offset]);
         input_offset++;
@@ -230,8 +228,8 @@ static const Layout::EnumConversionItem enum_convert_spstyle_weight_to_pango_wei
     {SP_CSS_FONT_WEIGHT_100, PANGO_WEIGHT_ULTRALIGHT},
     {SP_CSS_FONT_WEIGHT_200, PANGO_WEIGHT_ULTRALIGHT},
     {SP_CSS_FONT_WEIGHT_300, PANGO_WEIGHT_LIGHT},
-    {SP_CSS_FONT_WEIGHT_400, PANGO_WEIGHT_LIGHT},
-    {SP_CSS_FONT_WEIGHT_500, PANGO_WEIGHT_NORMAL},
+    {SP_CSS_FONT_WEIGHT_400, PANGO_WEIGHT_NORMAL},
+    {SP_CSS_FONT_WEIGHT_500, PANGO_WEIGHT_SEMIBOLD},
     {SP_CSS_FONT_WEIGHT_600, PANGO_WEIGHT_BOLD},
     {SP_CSS_FONT_WEIGHT_BOLD,PANGO_WEIGHT_BOLD},
     {SP_CSS_FONT_WEIGHT_700, PANGO_WEIGHT_BOLD},
@@ -254,13 +252,48 @@ static const Layout::EnumConversionItem enum_convert_spstyle_variant_to_pango_va
     {SP_CSS_FONT_VARIANT_SMALL_CAPS, PANGO_VARIANT_SMALL_CAPS}};
 
 font_instance *Layout::InputStreamTextSource::styleGetFontInstance() const
+{
+    PangoFontDescription *descr = styleGetFontDescription();
+    if (descr == NULL) return NULL;
+    font_instance *res = (font_factory::Default())->Face(descr);
+    pango_font_description_free(descr);
+    return res;
+}
+
+PangoFontDescription *Layout::InputStreamTextSource::styleGetFontDescription() const
 {
     if (style->text == NULL) return NULL;
-    return (font_factory::Default())->Face(style->text->font_family.value,
-                                           _enum_converter(style->font_variant.computed, enum_convert_spstyle_variant_to_pango_variant, sizeof(enum_convert_spstyle_variant_to_pango_variant)/sizeof(enum_convert_spstyle_variant_to_pango_variant[0])),
-                                           _enum_converter(style->font_style.computed,   enum_convert_spstyle_style_to_pango_style,     sizeof(enum_convert_spstyle_style_to_pango_style)/sizeof(enum_convert_spstyle_style_to_pango_style[0])),
-                                           _enum_converter(style->font_weight.computed,  enum_convert_spstyle_weight_to_pango_weight,   sizeof(enum_convert_spstyle_weight_to_pango_weight)/sizeof(enum_convert_spstyle_weight_to_pango_weight[0])),
-                                           _enum_converter(style->font_stretch.computed, enum_convert_spstyle_stretch_to_pango_stretch, sizeof(enum_convert_spstyle_stretch_to_pango_stretch)/sizeof(enum_convert_spstyle_stretch_to_pango_stretch[0])));
+    PangoFontDescription *descr = pango_font_description_new();
+    // Pango can't cope with spaces before or after the commas - let's remove them.
+    // this code is not exactly unicode-safe, but it's similar to what's done in
+    // pango, so it's not the limiting factor
+    Glib::ustring family;
+    if (style->text->font_family.value == NULL) {
+        family = "Sans";
+    } else {
+        gchar **families = g_strsplit(style->text->font_family.value, ",", -1);
+        if (families) {
+            for (gchar **f = families ; *f ; ++f) {
+                g_strstrip(*f);
+                if (!family.empty()) family += ',';
+                family += *f;
+            }
+        }
+        g_strfreev(families);
+    }
+
+    pango_font_description_set_family(descr,family.c_str());
+    pango_font_description_set_weight(descr,(PangoWeight)_enum_converter(style->font_weight.computed,  enum_convert_spstyle_weight_to_pango_weight,   sizeof(enum_convert_spstyle_weight_to_pango_weight)/sizeof(enum_convert_spstyle_weight_to_pango_weight[0])));
+    pango_font_description_set_stretch(descr,(PangoStretch)_enum_converter(style->font_stretch.computed, enum_convert_spstyle_stretch_to_pango_stretch, sizeof(enum_convert_spstyle_stretch_to_pango_stretch)/sizeof(enum_convert_spstyle_stretch_to_pango_stretch[0])));
+    pango_font_description_set_style(descr,(PangoStyle)_enum_converter(style->font_style.computed,   enum_convert_spstyle_style_to_pango_style,     sizeof(enum_convert_spstyle_style_to_pango_style)/sizeof(enum_convert_spstyle_style_to_pango_style[0])));
+    pango_font_description_set_variant(descr,(PangoVariant)_enum_converter(style->font_variant.computed, enum_convert_spstyle_variant_to_pango_variant, sizeof(enum_convert_spstyle_variant_to_pango_variant)/sizeof(enum_convert_spstyle_variant_to_pango_variant[0])));
+#ifdef USE_PANGO_WIN32
+    // damn Pango fudges the size, so we need to unfudge. See source of pango_win32_font_map_init()
+    pango_font_description_set_size(descr, (int) ((font_factory::Default())->fontSize*PANGO_SCALE*72/GetDeviceCaps(pango_win32_get_dc(),LOGPIXELSY))); // mandatory huge size (hinting workaround)
+#else
+    pango_font_description_set_size(descr, (int) ((font_factory::Default())->fontSize*PANGO_SCALE)); // mandatory huge size (hinting workaround)
+#endif
+    return descr;
 }
 
 Layout::InputStreamTextSource::~InputStreamTextSource()
