@@ -8,19 +8,16 @@
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
+#include <glib/gmem.h>
 #include "Layout-TNG.h"
 #include "display/nr-arena-glyphs.h"
 #include "style.h"
 #include "print.h"
 #include "extension/print.h"
 #include "livarot/Path.h"
-#include "libnr/nr-matrix-ops.h"
 #include "libnr/nr-scale-matrix-ops.h"
-#include "libnr/nr-point-matrix-ops.h"
 #include "font-instance.h"
-#include "display/curve.h"
-#include <pango/pango-types.h>
-#include "svg/svg-types.h"
+#include "svg/svg-length.h"
 
 namespace Inkscape {
 namespace Text {
@@ -87,10 +84,16 @@ void Layout::show(NRArenaGroup *in_arena, NRRect const *paintbox) const
     nr_arena_item_request_update(NR_ARENA_ITEM(in_arena), NR_ARENA_ITEM_STATE_ALL, FALSE);
 }
 
-void Layout::getBoundingBox(NRRect *bounding_box, NR::Matrix const &transform) const
+void Layout::getBoundingBox(NRRect *bounding_box, NR::Matrix const &transform, int start, int length) const
 {
     for (unsigned glyph_index = 0 ; glyph_index < _glyphs.size() ; glyph_index++) {
         if (_characters[_glyphs[glyph_index].in_character].in_glyph == -1) continue;
+        if (start != -1 && (int) _glyphs[glyph_index].in_character < start) continue;
+        if (length != -1) {
+            if (start == -1)
+                start = 0;
+            if ((int) _glyphs[glyph_index].in_character > start + length) continue;
+        }
         // this could be faster
         NRMatrix glyph_matrix;
         _getGlyphTransformMatrix(glyph_index, &glyph_matrix);
@@ -143,7 +146,7 @@ void Layout::print(SPPrintContext *ctx,
                     sp_print_fill(ctx, &abp, &ctm, text_source->style, pbox, dbox, bbox);
                 if (text_source->style->stroke.type != SP_PAINT_TYPE_NONE)
                     sp_print_stroke(ctx, &abp, &ctm, text_source->style, pbox, dbox, bbox);
-                nr_free(abp.path);
+                g_free(abp.path);
             }
             glyph_index++;
         } else {
@@ -181,7 +184,7 @@ void Layout::print(SPPrintContext *ctx,
             } while (glyph_index < _glyphs.size()
                      && _path_fitted == NULL
                      && _characters[_glyphs[glyph_index].in_character].in_span == this_span_index
-                     && fabs(char_x - _characters[_glyphs[glyph_index].in_character].x) < FLT_EPSILON);
+                     && fabs(char_x - _characters[_glyphs[glyph_index].in_character].x) < 1e-5);
             sp_print_bind(ctx, glyph_matrix, 1.0);
             sp_print_text(ctx, span_string.c_str(), g_pos, text_source->style);
             sp_print_release(ctx);
@@ -216,9 +219,7 @@ static char const *weight_to_text(PangoWeight w)
     switch (w) {
         case PANGO_WEIGHT_ULTRALIGHT: return "ultralight";
         case PANGO_WEIGHT_LIGHT     : return "light";
-#ifdef PANGO_WEIGHT_SEMIBOLD    // not available on pango before 1.8
         case PANGO_WEIGHT_SEMIBOLD  : return "semibold";
-#endif
         case PANGO_WEIGHT_NORMAL    : return "normalweight";
         case PANGO_WEIGHT_BOLD      : return "bold";
         case PANGO_WEIGHT_ULTRABOLD : return "ultrabold";
@@ -283,12 +284,12 @@ Glib::ustring Layout::dumpAsText() const
     return result;
 }
 
-void Layout::fitToPathAlign(SPSVGLength const &startOffset, Path const &path)
+void Layout::fitToPathAlign(SVGLength const &startOffset, Path const &path)
 {
     double offset = 0.0;
 
-    if (startOffset.set) {
-        if (startOffset.unit == SP_SVG_UNIT_PERCENT)
+    if (startOffset._set) {
+        if (startOffset.unit == SVGLength::PERCENT)
             offset = startOffset.computed * const_cast<Path&>(path).Length();
         else
             offset = startOffset.computed;
