@@ -8,7 +8,22 @@
 
 #ifndef my_defs
 #define my_defs
-#include <inttypes.h>
+
+#if defined(WIN32) || defined(__WIN32__)
+# include <inttypes.h>
+#endif
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#ifdef HAVE_INTTYPES_H
+# include <inttypes.h>
+#else
+# ifdef HAVE_STDINT_H
+#  include <stdint.h>
+# endif
+#endif
 
 // error codes (mostly obsolete)
 enum
