@@ -6,15 +6,10 @@
  *
  */
 
-#include <algorithm>
-#include <iostream>
 #include <glib.h>
 #include "Path.h"
 #include "livarot/path-description.h"
-#include <libnr/nr-point.h>
-#include <libnr/nr-point-ops.h>
 #include <libnr/nr-matrix-ops.h>
-#include "../svg/stringstream.h"
 
 /*
  * manipulation of the path data: path description and polyline
@@ -433,6 +428,18 @@ int Path::AddPoint(NR::Point const &iPt, bool mvto)
 }
 
 
+int Path::ReplacePoint(NR::Point const &iPt)
+{
+    if (pts.empty()) {
+        return -1;
+    }
+  
+    int const n = pts.size() - 1;
+    pts[n] = path_lineto(polyline_lineto, iPt);
+    return n;
+}
+
+
 int Path::AddPoint(NR::Point const &iPt, int ip, double it, bool mvto)
 {
     if (back == false) {
