@@ -15,11 +15,7 @@
 # include "config.h"
 #endif
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtksignal.h>
-#include <string.h>
 #include "macros.h"
-#include "xml/repr.h"
-#include "svg/svg.h"
 #include <glibmm/i18n.h>
 #include "display/sp-canvas-util.h"
 #include "object-edit.h"
@@ -27,27 +23,16 @@
 #include "path-chemistry.h"
 #include "rubberband.h"
 #include "desktop.h"
-#include "desktop-affine.h"
 #include "desktop-handles.h"
 #include "selection.h"
-#include "nodepath.h"
-#include "knotholder.h"
 #include "pixmaps/cursor-node.xpm"
 #include "message-context.h"
 #include "node-context.h"
-#include "sp-cursor.h"
 #include "pixmaps/cursor-node-d.xpm"
-#include "document.h"
 #include "prefs-utils.h"
-#include "xml/repr.h"
 #include "xml/node-event-vector.h"
-#include "libnr/nr-point-matrix-ops.h"
-#include "livarot/Path.h"
 #include "style.h"
-
-//from splivarot.cpp
-Path::cut_position get_nearest_position_on_Path(SPItem * item, NR::Point p);
-NR::Point get_point_on_Path(SPItem * item, int piece, double t);
+#include "splivarot.h"
 
 static void sp_node_context_class_init(SPNodeContextClass *klass);
 static void sp_node_context_init(SPNodeContext *node_context);
@@ -72,10 +57,6 @@ static Inkscape::XML::NodeEventVector nodepath_repr_events = {
 
 static SPEventContextClass *parent_class;
 
-static gchar *undo_label_1 = "dragcurve:1";
-static gchar *undo_label_2 = "dragcurve:2";
-static gchar *undo_label = undo_label_1;
-
 GType
 sp_node_context_get_type()
 {
@@ -149,7 +130,7 @@ sp_node_context_dispose(GObject *object)
 
     if (repr) {
         sp_repr_remove_listener_by_data(repr, ec);
-        sp_repr_unref(repr);
+        Inkscape::GC::release(repr);
     }
 
     if (nc->nodepath) {
@@ -178,9 +159,9 @@ sp_node_context_setup(SPEventContext *ec)
         ((SPEventContextClass *) parent_class)->setup(ec);
 
     nc->sel_changed_connection.disconnect();
-    nc->sel_changed_connection = SP_DT_SELECTION(ec->desktop)->connectChanged(sigc::bind(sigc::ptr_fun(&sp_node_context_selection_changed), (gpointer)nc));
+    nc->sel_changed_connection = sp_desktop_selection(ec->desktop)->connectChanged(sigc::bind(sigc::ptr_fun(&sp_node_context_selection_changed), (gpointer)nc));
 
-    Inkscape::Selection *selection = SP_DT_SELECTION(ec->desktop);
+    Inkscape::Selection *selection = sp_desktop_selection(ec->desktop);
     SPItem *item = selection->singleItem();
 
     nc->nodepath = NULL;
@@ -193,7 +174,7 @@ sp_node_context_setup(SPEventContext *ec)
     nc->added_node = false;
 
     if (item) {
-        nc->nodepath = sp_nodepath_new(ec->desktop, item);
+        nc->nodepath = sp_nodepath_new(ec->desktop, item, (prefs_get_int_attribute("tools.nodes", "show_handles", 1) != 0));
         if ( nc->nodepath) {
             //point pack to parent in case nodepath is deleted
             nc->nodepath->nodeContext = nc;
@@ -206,11 +187,10 @@ sp_node_context_setup(SPEventContext *ec)
             if (ec->shape_knot_holder)
                 repr = ec->shape_knot_holder->repr;
             else
-                repr = SP_OBJECT_REPR(item); 
+                repr = SP_OBJECT_REPR(item);
             if (repr) {
-                sp_repr_ref(repr);
+                Inkscape::GC::anchor(repr);
                 sp_repr_add_listener(repr, &nodepath_repr_events, ec);
-                sp_repr_synthesize_events(repr, &nodepath_repr_events, ec);
             }
         }
     }
@@ -242,7 +222,9 @@ sp_node_context_selection_changed(Inkscape::Selection *selection, gpointer data)
     if (nc->nodepath) {
         old_repr = nc->nodepath->repr;
         sp_nodepath_destroy(nc->nodepath);
+        nc->nodepath = NULL;
     }
+
     if (ec->shape_knot_holder) {
         old_repr = ec->shape_knot_holder->repr;
         sp_knot_holder_destroy(ec->shape_knot_holder);
@@ -250,7 +232,7 @@ sp_node_context_selection_changed(Inkscape::Selection *selection, gpointer data)
 
     if (old_repr) { // remove old listener
         sp_repr_remove_listener_by_data(old_repr, ec);
-        sp_repr_unref(old_repr);
+        Inkscape::GC::release(old_repr);
     }
 
     SPItem *item = selection->singleItem();
@@ -259,7 +241,7 @@ sp_node_context_selection_changed(Inkscape::Selection *selection, gpointer data)
     nc->nodepath = NULL;
     ec->shape_knot_holder = NULL;
     if (item) {
-        nc->nodepath = sp_nodepath_new(desktop, item);
+        nc->nodepath = sp_nodepath_new(desktop, item, (prefs_get_int_attribute("tools.nodes", "show_handles", 1) != 0));
         if (nc->nodepath) {
             nc->nodepath->nodeContext = nc;
         }
@@ -271,11 +253,10 @@ sp_node_context_selection_changed(Inkscape::Selection *selection, gpointer data)
             if (ec->shape_knot_holder)
                 repr = ec->shape_knot_holder->repr;
             else
-                repr = SP_OBJECT_REPR(item); 
+                repr = SP_OBJECT_REPR(item);
             if (repr) {
-                sp_repr_ref(repr);
+                Inkscape::GC::anchor(repr);
                 sp_repr_add_listener(repr, &nodepath_repr_events, ec);
-                sp_repr_synthesize_events(repr, &nodepath_repr_events, ec);
             }
         }
     }
@@ -299,19 +280,22 @@ sp_nodepath_update_from_item(SPNodeContext *nc, SPItem *item)
 
     if (nc->nodepath) {
         sp_nodepath_destroy(nc->nodepath);
+        nc->nodepath = NULL;
     }
 
     if (ec->shape_knot_holder) {
         sp_knot_holder_destroy(ec->shape_knot_holder);
+        ec->shape_knot_holder = NULL;
     }
 
-    Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+    Inkscape::Selection *selection = sp_desktop_selection(desktop);
     item = selection->singleItem();
 
-    nc->nodepath = NULL;
-    ec->shape_knot_holder = NULL;
     if (item) {
-        nc->nodepath = sp_nodepath_new(desktop, item);
+        nc->nodepath = sp_nodepath_new(desktop, item, (prefs_get_int_attribute("tools.nodes", "show_handles", 1) != 0));
+        if (nc->nodepath) {
+            nc->nodepath->nodeContext = nc;
+        }
         ec->shape_knot_holder = sp_item_knot_holder(item, desktop);
     }
     sp_nodepath_update_statusbar(nc->nodepath);
@@ -326,7 +310,6 @@ nodepath_event_attr_changed(Inkscape::XML::Node *repr, gchar const *name,
                             bool is_interactive, gpointer data)
 {
     SPItem *item = NULL;
-    char const *newd = NULL, *newtypestr = NULL;
     gboolean changed = FALSE;
 
     g_assert(data);
@@ -338,21 +321,18 @@ nodepath_event_attr_changed(Inkscape::XML::Node *repr, gchar const *name,
 
     if (np) {
         item = SP_ITEM(np->path);
-        if (!strcmp(name, "d")) {
-            newd = new_value;
-            changed = nodepath_repr_d_changed(np, new_value);
-        } else if (!strcmp(name, "sodipodi:nodetypes")) {
-            newtypestr = new_value;
-            changed = nodepath_repr_typestr_changed(np, new_value);
-        } else {
-            return;
-            // With paths, we only need to act if one of the path-affecting attributes has changed.
+        if (!strcmp(name, "d") || !strcmp(name, "sodipodi:nodetypes")) { // With paths, we only need to act if one of the path-affecting attributes has changed.
+            changed = (np->local_change == 0);
+            if (np->local_change > 0)
+                np->local_change--;
         }
+
     } else if (kh) {
         item = SP_ITEM(kh->item);
         changed = !(kh->local_change);
         kh->local_change = FALSE;
     }
+
     if (np && changed) {
         GList *saved = NULL;
         SPDesktop *desktop = np->desktop;
@@ -381,27 +361,27 @@ sp_node_context_show_modifier_tip(SPEventContext *event_context, GdkEvent *event
          _("<b>Alt</b>: lock handle length; <b>Ctrl+Alt</b>: move along handles"));
 }
 
-bool 
-sp_node_context_is_over_stroke (SPNodeContext *nc, SPItem *item, NR::Point event_p, bool remember) 
+bool
+sp_node_context_is_over_stroke (SPNodeContext *nc, SPItem *item, NR::Point event_p, bool remember)
 {
     SPDesktop *desktop = SP_EVENT_CONTEXT (nc)->desktop;
 
     //Translate click point into proper coord system
-    nc->curvepoint_doc = sp_desktop_w2d_xy_point(desktop, event_p);
-    nc->curvepoint_doc *= sp_item_dt2i_affine(item, desktop);
+    nc->curvepoint_doc = desktop->w2d(event_p);
+    nc->curvepoint_doc *= sp_item_dt2i_affine(item);
     nc->curvepoint_doc *= sp_item_i2doc_affine(item);
 
-    Path::cut_position position = get_nearest_position_on_Path(item, nc->curvepoint_doc);
-    NR::Point nearest = get_point_on_Path(item, position.piece, position.t);
+    NR::Maybe<Path::cut_position> position = get_nearest_position_on_Path(nc->nodepath->livarot_path, nc->curvepoint_doc);
+    NR::Point nearest = get_point_on_Path(nc->nodepath->livarot_path, position.assume().piece, position.assume().t);
     NR::Point delta = nearest - nc->curvepoint_doc;
 
-    delta = sp_desktop_d2w_xy_point(desktop, delta);
+    delta = desktop->d2w(delta);
 
-    double stroke_tolerance = 
-        (SP_OBJECT_STYLE (item)->stroke.type != SP_PAINT_TYPE_NONE? 
-         desktop->current_zoom() * 
-         SP_OBJECT_STYLE (item)->stroke_width.computed * 
-         sp_item_i2d_affine (item).expansion() * 0.5 
+    double stroke_tolerance =
+        (SP_OBJECT_STYLE (item)->stroke.type != SP_PAINT_TYPE_NONE?
+         desktop->current_zoom() *
+         SP_OBJECT_STYLE (item)->stroke_width.computed *
+         sp_item_i2d_affine (item).expansion() * 0.5
          : 0.0)
         + (double) SP_EVENT_CONTEXT(nc)->tolerance;
 
@@ -411,8 +391,8 @@ sp_node_context_is_over_stroke (SPNodeContext *nc, SPItem *item, NR::Point event
         nc->curvepoint_event[NR::X] = (gint) event_p [NR::X];
         nc->curvepoint_event[NR::Y] = (gint) event_p [NR::Y];
         nc->hit = true;
-        nc->grab_t = position.t;
-        nc->grab_node = sp_nodepath_get_node_by_index(position.piece);
+        nc->grab_t = position.assume().t;
+        nc->grab_node = sp_nodepath_get_node_by_index(position.assume().piece);
     }
 
     return close;
@@ -425,7 +405,7 @@ sp_node_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEve
     gint ret = FALSE;
 
     SPDesktop *desktop = event_context->desktop;
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     SPNodeContext *nc = SP_NODE_CONTEXT(event_context);
 
@@ -436,12 +416,13 @@ sp_node_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEve
                 if (!nc->drag) {
 
                     // find out clicked item, disregarding groups, honoring Alt
-                    SPItem *item_clicked = sp_event_context_find_item (desktop, 
+                    SPItem *item_clicked = sp_event_context_find_item (desktop,
                             NR::Point(event->button.x, event->button.y),
                             (event->button.state & GDK_MOD1_MASK) && !(event->button.state & GDK_CONTROL_MASK), TRUE);
                     // find out if we're over the selected item, disregarding groups
-                    SPItem *item_over = sp_event_context_over_item (desktop, selection->singleItem(), 
+                    SPItem *item_over = sp_event_context_over_item (desktop, selection->singleItem(),
                                                                     NR::Point(event->button.x, event->button.y));
+
                     bool over_stroke = false;
                     if (item_over && nc->nodepath) {
                         over_stroke = sp_node_context_is_over_stroke (nc, item_over, NR::Point(event->button.x, event->button.y), false);
@@ -452,7 +433,7 @@ sp_node_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEve
                             case GDK_BUTTON_RELEASE:
                                 if (event->button.state & GDK_CONTROL_MASK && event->button.state & GDK_MOD1_MASK) {
                                     //add a node
-                                    sp_nodepath_add_node_near_point(item_over, nc->curvepoint_doc);
+                                    sp_nodepath_add_node_near_point(nc->nodepath, nc->curvepoint_doc);
                                 } else {
                                     if (nc->added_node) { // we just received double click, ignore release
                                         nc->added_node = false;
@@ -460,20 +441,20 @@ sp_node_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEve
                                     }
                                     //select the segment
                                     if (event->button.state & GDK_SHIFT_MASK) {
-                                        sp_nodepath_select_segment_near_point(item_over, nc->curvepoint_doc, true);
+                                        sp_nodepath_select_segment_near_point(nc->nodepath, nc->curvepoint_doc, true);
                                     } else {
-                                        sp_nodepath_select_segment_near_point(item_over, nc->curvepoint_doc, false);
+                                        sp_nodepath_select_segment_near_point(nc->nodepath, nc->curvepoint_doc, false);
                                     }
                                 }
-                                break; 
+                                break;
                             case GDK_2BUTTON_PRESS:
                                 //add a node
-                                sp_nodepath_add_node_near_point(item_over, nc->curvepoint_doc);
+                                sp_nodepath_add_node_near_point(nc->nodepath, nc->curvepoint_doc);
                                 nc->added_node = true;
                                 break;
                             default:
                                 break;
-                        } 
+                        }
                     } else if (event->button.state & GDK_SHIFT_MASK) {
                         selection->toggle(item_clicked);
                     } else {
@@ -495,7 +476,7 @@ sp_node_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEve
 
                 if (!nc->drag) {
                     // find out if we're over the selected item, disregarding groups
-                    SPItem *item_over = sp_event_context_over_item (desktop, selection->singleItem(), 
+                    SPItem *item_over = sp_event_context_over_item (desktop, selection->singleItem(),
                                                                     NR::Point(event->button.x, event->button.y));
 
                         if (nc->nodepath && selection->single() && item_over) {
@@ -504,7 +485,7 @@ sp_node_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEve
                             bool over_stroke = sp_node_context_is_over_stroke (nc, item_over, NR::Point(event->button.x, event->button.y), true);
                             //only dragging curves
                             if (over_stroke) {
-                                sp_nodepath_select_segment_near_point(item_over, nc->curvepoint_doc, false);
+                                sp_nodepath_select_segment_near_point(nc->nodepath, nc->curvepoint_doc, false);
                                 ret = TRUE;
                             } else {
                                 break;
@@ -534,7 +515,7 @@ static gint
 sp_node_context_root_handler(SPEventContext *event_context, GdkEvent *event)
 {
     SPDesktop *desktop = event_context->desktop;
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     SPNodeContext *nc = SP_NODE_CONTEXT(event_context);
     double const nudge = prefs_get_double_attribute_limited("options.nudgedistance", "value", 2, 0, 1000); // in px
@@ -555,8 +536,8 @@ sp_node_context_root_handler(SPEventContext *event_context, GdkEvent *event)
 
                 NR::Point const button_w(event->button.x,
                                          event->button.y);
-                NR::Point const button_dt(sp_desktop_w2d_xy_point(desktop, button_w));
-                sp_rubberband_start(desktop, button_dt);
+                NR::Point const button_dt(desktop->w2d(button_w));
+                Inkscape::Rubberband::get()->start(desktop, button_dt);
                 ret = TRUE;
             }
             break;
@@ -576,16 +557,16 @@ sp_node_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                 if (nc->nodepath && nc->hit) {
                     NR::Point const delta_w(event->motion.x - nc->curvepoint_event[NR::X],
                                          event->motion.y - nc->curvepoint_event[NR::Y]);
-                    NR::Point const delta_dt(sp_desktop_w2d_xy_point(desktop, delta_w));
-                    sp_nodepath_curve_drag (nc->grab_node, nc->grab_t, delta_dt, undo_label);
-                    nc->curvepoint_event[NR::X] = (gint) event->motion.x;   
+                    NR::Point const delta_dt(desktop->w2d(delta_w));
+                    sp_nodepath_curve_drag (nc->grab_node, nc->grab_t, delta_dt);
+                    nc->curvepoint_event[NR::X] = (gint) event->motion.x;
                     nc->curvepoint_event[NR::Y] = (gint) event->motion.y;
                     gobble_motion_events(GDK_BUTTON1_MASK);
                 } else {
                     NR::Point const motion_w(event->motion.x,
                                          event->motion.y);
-                    NR::Point const motion_dt(sp_desktop_w2d_xy_point(desktop, motion_w));
-                    sp_rubberband_move(motion_dt);
+                    NR::Point const motion_dt(desktop->w2d(motion_w));
+                    Inkscape::Rubberband::get()->move(motion_dt);
                 }
                 nc->drag = TRUE;
                 ret = TRUE;
@@ -594,7 +575,7 @@ sp_node_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                     break;
                 }
 
-                SPItem *item_over = sp_event_context_over_item (desktop, selection->singleItem(), 
+                SPItem *item_over = sp_event_context_over_item (desktop, selection->singleItem(),
                                                                 NR::Point(event->motion.x, event->motion.y));
                 bool over_stroke = false;
                 if (item_over && nc->nodepath) {
@@ -619,26 +600,25 @@ sp_node_context_root_handler(SPEventContext *event_context, GdkEvent *event)
         case GDK_BUTTON_RELEASE:
             event_context->xp = event_context->yp = 0;
             if (event->button.button == 1) {
-                NRRect b;
+
+                NR::Maybe<NR::Rect> b = Inkscape::Rubberband::get()->getRectangle();
+
                 if (nc->hit && !event_context->within_tolerance) { //drag curve
-                    if (undo_label == undo_label_1)
-                        undo_label = undo_label_2;
-                    else 
-                        undo_label = undo_label_1;
-                } else if (sp_rubberband_rect(&b) && !event_context->within_tolerance) { // drag to select
+                    sp_nodepath_update_repr (nc->nodepath);
+                } else if (b != NR::Nothing() && !event_context->within_tolerance) { // drag to select
                     if (nc->nodepath) {
-                        sp_nodepath_select_rect(nc->nodepath, &b, event->button.state & GDK_SHIFT_MASK);
+                        sp_nodepath_select_rect(nc->nodepath, b.assume(), event->button.state & GDK_SHIFT_MASK);
                     }
                 } else {
                     if (!(nc->rb_escaped)) { // unless something was cancelled
                         if (nc->nodepath && nc->nodepath->selected)
                             sp_nodepath_deselect(nc->nodepath);
                         else
-                            SP_DT_SELECTION(desktop)->clear();
+                            sp_desktop_selection(desktop)->clear();
                     }
                 }
                 ret = TRUE;
-                sp_rubberband_stop();
+                Inkscape::Rubberband::get()->stop();
                 nc->rb_escaped = false;
                 nc->drag = FALSE;
                 nc->hit = false;
@@ -656,8 +636,13 @@ sp_node_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                 case GDK_Delete:
                 case GDK_KP_Delete:
                 case GDK_BackSpace:
-                    // with any modifiers
-                    sp_node_selected_delete();
+                    if (MOD__CTRL_ONLY) {
+                        sp_node_selected_delete();
+                    } else {
+                        if (nc->nodepath && nc->nodepath->selected) {
+                            sp_node_delete_preserve(g_list_copy(nc->nodepath->selected));
+                        }
+                    }
                     ret = TRUE;
                     break;
                 case GDK_C:
@@ -709,8 +694,8 @@ sp_node_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                         ret = TRUE;
                     }
                     break;
-                case GDK_K:
-                case GDK_k:
+                case GDK_U:
+                case GDK_u:
                     if (MOD__SHIFT_ONLY) {
                         sp_node_selected_set_line_type(NR_CURVETO);
                         ret = TRUE;
@@ -798,15 +783,15 @@ sp_node_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                     break;
                 case GDK_Escape:
                 {
-                    NRRect b;
-                    if (sp_rubberband_rect(&b)) { // cancel rubberband
-                        sp_rubberband_stop();
+                    NR::Maybe<NR::Rect> const b = Inkscape::Rubberband::get()->getRectangle();
+                    if (b != NR::Nothing()) {
+                        Inkscape::Rubberband::get()->stop();
                         nc->rb_escaped = true;
                     } else {
                         if (nc->nodepath && nc->nodepath->selected) {
                             sp_nodepath_deselect(nc->nodepath);
                         } else {
-                            SP_DT_SELECTION(desktop)->clear();
+                            sp_desktop_selection(desktop)->clear();
                         }
                     }
                     ret = TRUE;
