@@ -9,8 +9,6 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <algorithm>
-#include <glib/gmessages.h>
 #include "sp-object.h"
 #include "object-hierarchy.h"
 
@@ -63,7 +61,7 @@ void ObjectHierarchy::setTop(SPObject *object) {
 }
 
 /**
- * Add hierarchy from junior's parent to senior to this 
+ * Add hierarchy from junior's parent to senior to this
  * hierarchy's top.
  */
 void ObjectHierarchy::_addTop(SPObject *senior, SPObject *junior) {
