@@ -1,5 +1,5 @@
-/** \file 
- * Pen event context implementation. 
+/** \file
+ * Pen event context implementation.
  */
 
 /*
@@ -21,26 +21,23 @@
 #include "sp-namedview.h"
 #include "sp-metrics.h"
 #include "desktop.h"
-#include "desktop-affine.h"
 #include "desktop-handles.h"
 #include "selection.h"
 #include "draw-anchor.h"
 #include "message-stack.h"
 #include "message-context.h"
-#include "event-context.h"
 #include "prefs-utils.h"
-#include "sp-item.h"
 #include "sp-path.h"
+
 #include "pixmaps/cursor-pen.xpm"
 #include "display/canvas-bpath.h"
-#include "display/sp-canvas.h"
 #include "display/sp-ctrlline.h"
 #include "display/sodipodi-ctrl.h"
 #include <glibmm/i18n.h>
-#include "libnr/nr-point-ops.h"
 #include "libnr/n-art-bpath.h"
 #include "helper/units.h"
-#include "snap.h"
+#include "macros.h"
+#include "context-fns.h"
 
 
 static void sp_pen_context_class_init(SPPenContextClass *klass);
@@ -63,7 +60,7 @@ static gint pen_handle_button_press(SPPenContext *const pc, GdkEventButton const
 static gint pen_handle_motion_notify(SPPenContext *const pc, GdkEventMotion const &mevent);
 static gint pen_handle_button_release(SPPenContext *const pc, GdkEventButton const &revent);
 static gint pen_handle_2button_press(SPPenContext *const pc);
-static gint pen_handle_key_press(SPPenContext *const pc, guint const keyval);
+static gint pen_handle_key_press(SPPenContext *const pc, GdkEvent *event);
 static void spdc_reset_colors(SPPenContext *pc);
 
 
@@ -123,12 +120,13 @@ sp_pen_context_class_init(SPPenContextClass *klass)
 static void
 sp_pen_context_init(SPPenContext *pc)
 {
+
     SPEventContext *event_context = SP_EVENT_CONTEXT(pc);
 
     event_context->cursor_shape = cursor_pen_xpm;
     event_context->hot_x = 4;
     event_context->hot_y = 4;
-    
+
     pc->npoints = 0;
     pc->mode = SP_PEN_CONTEXT_MODE_CLICK;
     pc->state = SP_PEN_CONTEXT_POINT;
@@ -184,13 +182,13 @@ sp_pen_context_setup(SPEventContext *ec)
     }
 
     /* Pen indicators */
-    pc->c0 = sp_canvas_item_new(SP_DT_CONTROLS(SP_EVENT_CONTEXT_DESKTOP(ec)), SP_TYPE_CTRL, "shape", SP_CTRL_SHAPE_CIRCLE,
+    pc->c0 = sp_canvas_item_new(sp_desktop_controls(SP_EVENT_CONTEXT_DESKTOP(ec)), SP_TYPE_CTRL, "shape", SP_CTRL_SHAPE_CIRCLE,
                                 "size", 4.0, "filled", 0, "fill_color", 0xff00007f, "stroked", 1, "stroke_color", 0x0000ff7f, NULL);
-    pc->c1 = sp_canvas_item_new(SP_DT_CONTROLS(SP_EVENT_CONTEXT_DESKTOP(ec)), SP_TYPE_CTRL, "shape", SP_CTRL_SHAPE_CIRCLE,
+    pc->c1 = sp_canvas_item_new(sp_desktop_controls(SP_EVENT_CONTEXT_DESKTOP(ec)), SP_TYPE_CTRL, "shape", SP_CTRL_SHAPE_CIRCLE,
                                 "size", 4.0, "filled", 0, "fill_color", 0xff00007f, "stroked", 1, "stroke_color", 0x0000ff7f, NULL);
-    pc->cl0 = sp_canvas_item_new(SP_DT_CONTROLS(SP_EVENT_CONTEXT_DESKTOP(ec)), SP_TYPE_CTRLLINE, NULL);
+    pc->cl0 = sp_canvas_item_new(sp_desktop_controls(SP_EVENT_CONTEXT_DESKTOP(ec)), SP_TYPE_CTRLLINE, NULL);
     sp_ctrlline_set_rgba32(SP_CTRLLINE(pc->cl0), 0x0000007f);
-    pc->cl1 = sp_canvas_item_new(SP_DT_CONTROLS(SP_EVENT_CONTEXT_DESKTOP(ec)), SP_TYPE_CTRLLINE, NULL);
+    pc->cl1 = sp_canvas_item_new(sp_desktop_controls(SP_EVENT_CONTEXT_DESKTOP(ec)), SP_TYPE_CTRLLINE, NULL);
     sp_ctrlline_set_rgba32(SP_CTRLLINE(pc->cl1), 0x0000007f);
 
     sp_canvas_item_hide(pc->c0);
@@ -207,13 +205,30 @@ sp_pen_context_setup(SPEventContext *ec)
     }
 }
 
+static void
+pen_cancel (SPPenContext *const pc) 
+{
+    pc->state = SP_PEN_CONTEXT_STOP;
+    spdc_reset_colors(pc);
+    sp_canvas_item_hide(pc->c0);
+    sp_canvas_item_hide(pc->c1);
+    sp_canvas_item_hide(pc->cl0);
+    sp_canvas_item_hide(pc->cl1);
+    pc->_message_context->clear();
+    pc->_message_context->flash(Inkscape::NORMAL_MESSAGE, _("Drawing cancelled"));
+}
+
 /**
  * Finalization callback.
  */
 static void
 sp_pen_context_finish(SPEventContext *ec)
 {
-    spdc_pen_finish(SP_PEN_CONTEXT(ec), FALSE);
+    SPPenContext *pc = SP_PEN_CONTEXT(ec);
+
+    if (pc->npoints != 0) {
+        pen_cancel (pc);
+    }
 
     if (((SPEventContextClass *) pen_parent_class)->finish) {
         ((SPEventContextClass *) pen_parent_class)->finish(ec);
@@ -237,19 +252,20 @@ sp_pen_context_set(SPEventContext *ec, gchar const *key, gchar const *val)
     }
 }
 
-/** 
+/**
  * Snaps new node relative to the previous node.
  */
 static void
 spdc_endpoint_snap(SPPenContext const *const pc, NR::Point &p, guint const state)
 {
-    spdc_endpoint_snap_internal(pc, p, ( pc->npoints != 0
-                                         ? pc->p[0]
-                                         : p ),
-                                state);
+    if (pc->npoints > 0) {
+        spdc_endpoint_snap_rotation(pc, p, pc->p[0], state);
+    }
+
+    spdc_endpoint_snap_free(pc, p, state);
 }
 
-/** 
+/**
  * Snaps new node's handle relative to the new node.
  */
 static void
@@ -258,7 +274,8 @@ spdc_endpoint_snap_handle(SPPenContext const *const pc, NR::Point &p, guint cons
     g_return_if_fail(( pc->npoints == 2 ||
                        pc->npoints == 5   ));
 
-    spdc_endpoint_snap_internal(pc, p, pc->p[pc->npoints - 2], state);
+    spdc_endpoint_snap_rotation(pc, p, pc->p[pc->npoints - 2], state);
+    spdc_endpoint_snap_free(pc, p, state);
 }
 
 /**
@@ -289,7 +306,7 @@ sp_pen_context_root_handler(SPEventContext *ec, GdkEvent *event)
             break;
 
         case GDK_KEY_PRESS:
-            ret = pen_handle_key_press(pc, get_group0_keyval (&event->key));
+            ret = pen_handle_key_press(pc, event);
             break;
 
         default:
@@ -310,34 +327,26 @@ sp_pen_context_root_handler(SPEventContext *ec, GdkEvent *event)
 /**
  * Handle mouse button press event.
  */
-static gint
-pen_handle_button_press(SPPenContext *const pc, GdkEventButton const &bevent)
+static gint pen_handle_button_press(SPPenContext *const pc, GdkEventButton const &bevent)
 {
-
     gint ret = FALSE;
-    if ( bevent.button == 1 ) {
+    if (bevent.button == 1) {
 
-        SPDrawContext *dc = SP_DRAW_CONTEXT (pc);
-        SPDesktop *desktop = SP_EVENT_CONTEXT_DESKTOP(dc);
-        SPItem *layer=SP_ITEM(desktop->currentLayer());
-        if ( !layer || desktop->itemIsHidden(layer)) {
-            dc->_message_context->flash(Inkscape::WARNING_MESSAGE, _("<b>Current layer is hidden</b>. Unhide it to be able to draw on it."));
-            return TRUE;
-        }
-        if ( !layer || layer->isLocked()) {
-            dc->_message_context->flash(Inkscape::WARNING_MESSAGE, _("<b>Current layer is locked</b>. Unlock it to be able to draw on it."));
+        SPDrawContext * const dc = SP_DRAW_CONTEXT(pc);
+        SPDesktop * const desktop = SP_EVENT_CONTEXT_DESKTOP(dc);
+
+        if (Inkscape::have_viable_layer(desktop, dc->_message_context) == false) {
             return TRUE;
         }
 
-        NR::Point const event_w(bevent.x,
-                                bevent.y);
+        NR::Point const event_w(bevent.x, bevent.y);
         pen_drag_origin_w = event_w;
         pen_within_tolerance = true;
 
         /* Test whether we hit any anchor. */
-        SPDrawAnchor *anchor = spdc_test_inside(pc, event_w);
+        SPDrawAnchor * const anchor = spdc_test_inside(pc, event_w);
 
-        NR::Point const event_dt(sp_desktop_w2d_xy_point(pc->desktop, event_w));
+        NR::Point const event_dt(desktop->w2d(event_w));
         switch (pc->mode) {
             case SP_PEN_CONTEXT_MODE_CLICK:
                 /* In click mode we add point on release */
@@ -359,58 +368,66 @@ pen_handle_button_press(SPPenContext *const pc, GdkEventButton const &bevent)
                     case SP_PEN_CONTEXT_STOP:
                         /* This is allowed, if we just cancelled curve */
                     case SP_PEN_CONTEXT_POINT:
-                        if ( pc->npoints == 0 ) {
+                        if (pc->npoints == 0) {
+
                             /* Set start anchor */
                             pc->sa = anchor;
                             NR::Point p;
                             if (anchor) {
+
                                 /* Adjust point to anchor if needed */
                                 p = anchor->dp;
-                                SP_EVENT_CONTEXT_DESKTOP(dc)->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Continuing selected path"));
+                                desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Continuing selected path"));
+
                             } else {
 
                                 // This is the first click of a new curve; deselect item so that
                                 // this curve is not combined with it (unless it is drawn from its
                                 // anchor, which is handled by the sibling branch above)
+                                Inkscape::Selection * const selection = sp_desktop_selection(desktop);
                                 if (!(bevent.state & GDK_SHIFT_MASK)) {
-                                    SP_DT_SELECTION(desktop)->clear();
-                                    SP_EVENT_CONTEXT_DESKTOP(dc)->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Creating new path"));
-                                } else if (SP_DT_SELECTION(desktop)->singleItem() && SP_IS_PATH(SP_DT_SELECTION(desktop)->singleItem())) {
-                                    SP_EVENT_CONTEXT_DESKTOP(dc)->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Appending to selected path"));
+
+                                    selection->clear();
+                                    desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Creating new path"));
+
+                                } else if (selection->singleItem() && SP_IS_PATH(selection->singleItem())) {
+
+                                    desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Appending to selected path"));
                                 }
 
                                 /* Create green anchor */
                                 p = event_dt;
-                                /* This is the first point, so just snap it to the grid as there's
-                                ** no other points to go off.
-                                */
-                                if (!(bevent.state & GDK_SHIFT_MASK)) {
-                                    namedview_free_snap_all_types(pc->desktop->namedview, p);
-                                }
+                                spdc_endpoint_snap(pc, p, bevent.state);
                                 pc->green_anchor = sp_draw_anchor_new(pc, pc->green_curve, TRUE, p);
                             }
                             spdc_pen_set_initial_point(pc, p);
                         } else {
+
                             /* Set end anchor */
                             pc->ea = anchor;
                             NR::Point p;
-                            if (anchor) {   
+                            if (anchor) {
+
                                 p = anchor->dp;
-                                // we hit an anchor, will finish the curve (either with or without closing) in release handler
+                                // we hit an anchor, will finish the curve (either with or without closing)
+                                // in release handler
                                 pc->state = SP_PEN_CONTEXT_CLOSE;
 
-                                if ( pc->green_anchor && pc->green_anchor->active ) {
-                                    // we clicked on the current curve start, so close it even if we drag a handle away from it
-                                    dc->green_closed = TRUE; 
+                                if (pc->green_anchor && pc->green_anchor->active) {
+                                    // we clicked on the current curve start, so close it even if
+                                    // we drag a handle away from it
+                                    dc->green_closed = TRUE;
                                 }
-
                                 ret = TRUE;
                                 break;
-                            } else { 
+
+                            } else {
+
                                 p = event_dt;
                                 spdc_endpoint_snap(pc, p, bevent.state); /* Snap node only if not hitting anchor. */
                                 spdc_pen_set_subsequent_point(pc, p, true);
                             }
+
                         }
                         pc->state = SP_PEN_CONTEXT_CONTROL;
                         ret = TRUE;
@@ -434,6 +451,7 @@ pen_handle_button_press(SPPenContext *const pc, GdkEventButton const &bevent)
             ret = TRUE;
         }
     }
+
     return ret;
 }
 
@@ -475,7 +493,7 @@ pen_handle_motion_notify(SPPenContext *const pc, GdkEventMotion const &mevent)
     }
 
     /* Find desktop coordinates */
-    NR::Point p = sp_desktop_w2d_xy_point(dt, event_w);
+    NR::Point p = dt->w2d(event_w);
 
     /* Test, whether we hit any anchor */
     SPDrawAnchor *anchor = spdc_test_inside(pc, event_w);
@@ -573,7 +591,7 @@ pen_handle_button_release(SPPenContext *const pc, GdkEventButton const &revent)
         NR::Point const event_w(revent.x,
                                 revent.y);
         /* Find desktop coordinates */
-        NR::Point p = sp_desktop_w2d_xy_point(pc->desktop, event_w);
+        NR::Point p = pc->desktop->w2d(event_w);
 
         /* Test whether we hit any anchor. */
         SPDrawAnchor *anchor = spdc_test_inside(pc, event_w);
@@ -681,12 +699,204 @@ pen_handle_2button_press(SPPenContext *const pc)
     return ret;
 }
 
+void
+pen_redraw_all (SPPenContext *const pc)
+{
+    // green
+    if (pc->green_bpaths) {
+        // remove old piecewise green canvasitems
+        while (pc->green_bpaths) {
+            gtk_object_destroy(GTK_OBJECT(pc->green_bpaths->data));
+            pc->green_bpaths = g_slist_remove(pc->green_bpaths, pc->green_bpaths->data);
+        }
+        // one canvas bpath for all of green_curve
+        SPCanvasItem *cshape = sp_canvas_bpath_new(sp_desktop_sketch(pc->desktop), pc->green_curve);
+        sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(cshape), pc->green_color, 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
+        sp_canvas_bpath_set_fill(SP_CANVAS_BPATH(cshape), 0, SP_WIND_RULE_NONZERO);
+
+        pc->green_bpaths = g_slist_prepend(pc->green_bpaths, cshape);
+    }
+
+    if (pc->green_anchor)
+        SP_CTRL(pc->green_anchor->ctrl)->moveto(pc->green_anchor->dp);
+
+    sp_curve_reset(pc->red_curve);
+    sp_curve_moveto(pc->red_curve, pc->p[0]);
+    sp_curve_curveto(pc->red_curve, pc->p[1], pc->p[2], pc->p[3]);
+    sp_canvas_bpath_set_bpath(SP_CANVAS_BPATH(pc->red_bpath), pc->red_curve);
+
+    // handles
+    if (pc->p[0] != pc->p[1]) {
+        SP_CTRL(pc->c1)->moveto(pc->p[1]);
+        sp_ctrlline_set_coords(SP_CTRLLINE(pc->cl1), pc->p[0], pc->p[1]);
+        sp_canvas_item_show (pc->c1);
+        sp_canvas_item_show (pc->cl1);
+    } else {
+        sp_canvas_item_hide (pc->c1);
+        sp_canvas_item_hide (pc->cl1);
+    }
+
+    NArtBpath *const bpath = sp_curve_last_bpath(pc->green_curve);
+    if (bpath) {
+        if (bpath->code == NR_CURVETO && NR::Point(bpath->x2, bpath->y2) != pc->p[0]) {
+            SP_CTRL(pc->c0)->moveto(NR::Point(bpath->x2, bpath->y2));
+            sp_ctrlline_set_coords(SP_CTRLLINE(pc->cl0), NR::Point(bpath->x2, bpath->y2), pc->p[0]);
+            sp_canvas_item_show (pc->c0);
+            sp_canvas_item_show (pc->cl0);
+        } else {
+            sp_canvas_item_hide (pc->c0);
+            sp_canvas_item_hide (pc->cl0);
+        }
+    }
+}
+
+void
+pen_lastpoint_move (SPPenContext *const pc, gdouble x, gdouble y)
+{
+    if (pc->npoints != 5)
+        return;
+
+    // green
+    NArtBpath *const bpath = sp_curve_last_bpath(pc->green_curve);
+    if (bpath) {
+        if (bpath->code == NR_CURVETO) {
+            bpath->x2 += x;
+            bpath->y2 += y;
+        }
+        bpath->x3 += x;
+        bpath->y3 += y;
+    } else {
+        // start anchor too
+        if (pc->green_anchor) {
+            pc->green_anchor->dp += NR::Point(x, y);
+        }
+    }
+
+    // red
+    pc->p[0] += NR::Point(x, y);
+    pc->p[1] += NR::Point(x, y);
+    pen_redraw_all(pc);
+}
+
+void
+pen_lastpoint_move_screen (SPPenContext *const pc, gdouble x, gdouble y)
+{
+    pen_lastpoint_move (pc, x / pc->desktop->current_zoom(), y / pc->desktop->current_zoom());
+}
+
+void
+pen_lastpoint_tocurve (SPPenContext *const pc)
+{
+    if (pc->npoints != 5)
+        return;
+
+    // red
+    NArtBpath *const bpath = sp_curve_last_bpath(pc->green_curve);
+    if (bpath && bpath->code == NR_CURVETO) {
+        pc->p[1] = pc->p[0] + (NR::Point(bpath->x3, bpath->y3) - NR::Point(bpath->x2, bpath->y2));
+    } else {
+        pc->p[1] = pc->p[0] + (pc->p[3] - pc->p[0])*(1/3);
+    }
+
+    pen_redraw_all(pc);
+}
+
+void
+pen_lastpoint_toline (SPPenContext *const pc)
+{
+    if (pc->npoints != 5)
+        return;
+
+    pc->p[1] = pc->p[0];
+
+    pen_redraw_all(pc);
+}
+
+
 static gint
-pen_handle_key_press(SPPenContext *const pc, guint const keyval)
+pen_handle_key_press(SPPenContext *const pc, GdkEvent *event)
 {
     gint ret = FALSE;
-    /* fixme: */
-    switch (keyval) {
+    gdouble const nudge = prefs_get_double_attribute_limited("options.nudgedistance", "value", 2, 0, 1000); // in px
+
+    switch (get_group0_keyval (&event->key)) {
+
+        case GDK_Left: // move last point left
+        case GDK_KP_Left:
+        case GDK_KP_4:
+            if (!MOD__CTRL) { // not ctrl
+                if (MOD__ALT) { // alt
+                    if (MOD__SHIFT) pen_lastpoint_move_screen(pc, -10, 0); // shift
+                    else pen_lastpoint_move_screen(pc, -1, 0); // no shift
+                }
+                else { // no alt
+                    if (MOD__SHIFT) pen_lastpoint_move(pc, -10*nudge, 0); // shift
+                    else pen_lastpoint_move(pc, -nudge, 0); // no shift
+                }
+                ret = TRUE;
+            }
+            break;
+        case GDK_Up: // move last point up
+        case GDK_KP_Up:
+        case GDK_KP_8:
+            if (!MOD__CTRL) { // not ctrl
+                if (MOD__ALT) { // alt
+                    if (MOD__SHIFT) pen_lastpoint_move_screen(pc, 0, 10); // shift
+                    else pen_lastpoint_move_screen(pc, 0, 1); // no shift
+                }
+                else { // no alt
+                    if (MOD__SHIFT) pen_lastpoint_move(pc, 0, 10*nudge); // shift
+                    else pen_lastpoint_move(pc, 0, nudge); // no shift
+                }
+                ret = TRUE;
+            }
+            break;
+        case GDK_Right: // move last point right
+        case GDK_KP_Right:
+        case GDK_KP_6:
+            if (!MOD__CTRL) { // not ctrl
+                if (MOD__ALT) { // alt
+                    if (MOD__SHIFT) pen_lastpoint_move_screen(pc, 10, 0); // shift
+                    else pen_lastpoint_move_screen(pc, 1, 0); // no shift
+                }
+                else { // no alt
+                    if (MOD__SHIFT) pen_lastpoint_move(pc, 10*nudge, 0); // shift
+                    else pen_lastpoint_move(pc, nudge, 0); // no shift
+                }
+                ret = TRUE;
+            }
+            break;
+        case GDK_Down: // move last point down
+        case GDK_KP_Down:
+        case GDK_KP_2:
+            if (!MOD__CTRL) { // not ctrl
+                if (MOD__ALT) { // alt
+                    if (MOD__SHIFT) pen_lastpoint_move_screen(pc, 0, -10); // shift
+                    else pen_lastpoint_move_screen(pc, 0, -1); // no shift
+                }
+                else { // no alt
+                    if (MOD__SHIFT) pen_lastpoint_move(pc, 0, -10*nudge); // shift
+                    else pen_lastpoint_move(pc, 0, -nudge); // no shift
+                }
+                ret = TRUE;
+            }
+            break;
+
+        case GDK_U:
+        case GDK_u:
+            if (MOD__SHIFT_ONLY) {
+                pen_lastpoint_tocurve(pc);
+                ret = TRUE;
+            }
+            break;
+        case GDK_L:
+        case GDK_l:
+            if (MOD__SHIFT_ONLY) {
+                pen_lastpoint_toline(pc);
+                ret = TRUE;
+            }
+            break;
+
         case GDK_Return:
         case GDK_KP_Enter:
             if (pc->npoints != 0) {
@@ -697,24 +907,23 @@ pen_handle_key_press(SPPenContext *const pc, guint const keyval)
         case GDK_Escape:
             if (pc->npoints != 0) {
                 // if drawing, cancel, otherwise pass it up for deselecting
-                pc->state = SP_PEN_CONTEXT_STOP;
-                spdc_reset_colors(pc);
-                sp_canvas_item_hide(pc->c0);
-                sp_canvas_item_hide(pc->c1);
-                sp_canvas_item_hide(pc->cl0);
-                sp_canvas_item_hide(pc->cl1);
+                pen_cancel (pc);
+                ret = TRUE;
+            }
+            break;
+        case GDK_z:
+        case GDK_Z:
+            if (MOD__CTRL_ONLY && pc->npoints != 0) {
+                // if drawing, cancel, otherwise pass it up for undo
+                pen_cancel (pc);
                 ret = TRUE;
             }
             break;
         case GDK_BackSpace:
+        case GDK_Delete:
+        case GDK_KP_Delete:
             if (sp_curve_is_empty(pc->green_curve)) {
-                /* Same as cancel */
-                pc->state = SP_PEN_CONTEXT_STOP;
-                spdc_reset_colors(pc);
-                sp_canvas_item_hide(pc->c0);
-                sp_canvas_item_hide(pc->c1);
-                sp_canvas_item_hide(pc->cl0);
-                sp_canvas_item_hide(pc->cl1);
+                pen_cancel (pc);
                 ret = TRUE;
             } else {
                 /* Reset red curve */
@@ -724,7 +933,7 @@ pen_handle_key_press(SPPenContext *const pc, guint const keyval)
                     if (pc->green_bpaths->data)
                         gtk_object_destroy(GTK_OBJECT(pc->green_bpaths->data));
                     pc->green_bpaths = g_slist_remove(pc->green_bpaths, pc->green_bpaths->data);
-                }    
+                }
                 /* Get last segment */
                 NArtBpath const *const p = SP_CURVE_BPATH(pc->green_curve);
                 gint const e = SP_CURVE_LENGTH(pc->green_curve);
@@ -733,7 +942,11 @@ pen_handle_key_press(SPPenContext *const pc, guint const keyval)
                     break;
                 }
                 pc->p[0] = p[e - 2].c(3);
-                pc->p[1] = p[e - 1].c(1);
+                if (p[e - 1].code == NR_CURVETO) {
+                    pc->p[1] = p[e - 1].c(1);
+                } else {
+                    pc->p[1] = pc->p[0];
+                }
                 NR::Point const pt(( pc->npoints < 4
                                      ? p[e - 1].c(3)
                                      : pc->p[3] ));
@@ -891,8 +1104,8 @@ spdc_pen_finish_segment(SPPenContext *const pc, NR::Point const p, guint const s
     if (!sp_curve_empty(pc->red_curve)) {
         sp_curve_append_continuous(pc->green_curve, pc->red_curve, 0.0625);
         SPCurve *curve = sp_curve_copy(pc->red_curve);
-        /// \todo fixme: 
-        SPCanvasItem *cshape = sp_canvas_bpath_new(SP_DT_SKETCH(pc->desktop), curve);
+        /// \todo fixme:
+        SPCanvasItem *cshape = sp_canvas_bpath_new(sp_desktop_sketch(pc->desktop), curve);
         sp_curve_unref(curve);
         sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(cshape), pc->green_color, 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
 
@@ -911,7 +1124,7 @@ spdc_pen_finish(SPPenContext *const pc, gboolean const closed)
 {
     SPDesktop *const desktop = pc->desktop;
     pc->_message_context->clear();
-    desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Finishing pen"));
+    desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Drawing finished"));
 
     sp_curve_reset(pc->red_curve);
     spdc_concat_colors_and_flush(pc, closed);
