@@ -1,4 +1,4 @@
-/** \file 
+/** \file
  * Pencil event context implementation.
  */
 
@@ -19,25 +19,23 @@
 
 #include "pencil-context.h"
 #include "desktop.h"
-#include "desktop-affine.h"
 #include "desktop-handles.h"
 #include "selection.h"
 #include "draw-anchor.h"
-#include "draw-context.h"
 #include "message-stack.h"
 #include "message-context.h"
 #include "modifier-fns.h"
-#include "sp-item.h"
 #include "sp-path.h"
 #include "prefs-utils.h"
 #include "snap.h"
 #include "pixmaps/cursor-pencil.xpm"
 #include "display/bezier-utils.h"
 #include "display/canvas-bpath.h"
-#include "display/sp-canvas.h"
 #include <glibmm/i18n.h>
 #include "libnr/in-svg-plane.h"
 #include "libnr/n-art-bpath.h"
+#include "context-fns.h"
+#include "sp-namedview.h"
 
 static void sp_pencil_context_class_init(SPPencilContextClass *klass);
 static void sp_pencil_context_init(SPPencilContext *pc);
@@ -113,7 +111,7 @@ sp_pencil_context_init(SPPencilContext *pc)
     event_context->cursor_shape = cursor_pencil_xpm;
     event_context->hot_x = 4;
     event_context->hot_y = 4;
-    
+
     pc->npoints = 0;
     pc->state = SP_PENCIL_CONTEXT_IDLE;
     pc->req_tangent = NR::Point(0, 0);
@@ -149,7 +147,8 @@ sp_pencil_context_dispose(GObject *object)
 static void
 spdc_endpoint_snap(SPPencilContext const *pc, NR::Point &p, guint const state)
 {
-    spdc_endpoint_snap_internal(pc, p, pc->p[0], state);
+    spdc_endpoint_snap_rotation(pc, p, pc->p[0], state);
+    spdc_endpoint_snap_free(pc, p, state);
 }
 
 /**
@@ -202,20 +201,16 @@ pencil_handle_button_press(SPPencilContext *const pc, GdkEventButton const &beve
 
         SPDrawContext *dc = SP_DRAW_CONTEXT (pc);
         SPDesktop *desktop = SP_EVENT_CONTEXT_DESKTOP(dc);
-        SPItem *layer=SP_ITEM(desktop->currentLayer());
-        if ( !layer || desktop->itemIsHidden(layer)) {
-            dc->_message_context->flash(Inkscape::WARNING_MESSAGE, _("<b>Current layer is hidden</b>. Unhide it to be able to draw on it."));
-            return TRUE;
-        }
-        if ( !layer || layer->isLocked()) {
-            dc->_message_context->flash(Inkscape::WARNING_MESSAGE, _("<b>Current layer is locked</b>. Unlock it to be able to draw on it."));
+        Inkscape::Selection *selection = sp_desktop_selection(desktop);
+
+        if (Inkscape::have_viable_layer(desktop, dc->_message_context) == false) {
             return TRUE;
         }
 
-        NR::Point const button_w(bevent.x,
-                                 bevent.y);
+        NR::Point const button_w(bevent.x, bevent.y);
+
         /* Find desktop coordinates */
-        NR::Point p = sp_desktop_w2d_xy_point(pc->desktop, button_w);
+        NR::Point p = pc->desktop->w2d(button_w);
 
         /* Test whether we hit any anchor. */
         SPDrawAnchor *anchor = spdc_test_inside(pc, button_w);
@@ -229,7 +224,7 @@ pencil_handle_button_press(SPPencilContext *const pc, GdkEventButton const &beve
                 /* Set first point of sequence */
                 if (anchor) {
                     p = anchor->dp;
-                    SP_EVENT_CONTEXT_DESKTOP(dc)->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Continuing selected path"));
+                    desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Continuing selected path"));
                 } else {
 
                     if (!(bevent.state & GDK_SHIFT_MASK)) {
@@ -237,12 +232,12 @@ pencil_handle_button_press(SPPencilContext *const pc, GdkEventButton const &beve
                         // This is the first click of a new curve; deselect item so that
                         // this curve is not combined with it (unless it is drawn from its
                         // anchor, which is handled by the sibling branch above)
-                        SP_DT_SELECTION(desktop)->clear();
-                        SP_EVENT_CONTEXT_DESKTOP(dc)->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Creating new path"));
-
-                        namedview_free_snap_all_types(SP_EVENT_CONTEXT_DESKTOP(pc)->namedview, p);
-                    } else if (SP_DT_SELECTION(desktop)->singleItem() && SP_IS_PATH(SP_DT_SELECTION(desktop)->singleItem())) {
-                        SP_EVENT_CONTEXT_DESKTOP(dc)->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Appending to selected path"));
+                        selection->clear();
+                        desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Creating new path"));
+                        SnapManager const &m = desktop->namedview->snap_manager;
+                        p = m.freeSnap(Inkscape::Snapper::BBOX_POINT | Inkscape::Snapper::SNAP_POINT, p, NULL).getPoint();
+                    } else if (selection->singleItem() && SP_IS_PATH(selection->singleItem())) {
+                        desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Appending to selected path"));
                     }
                 }
                 pc->sa = anchor;
@@ -277,7 +272,7 @@ pencil_handle_motion_notify(SPPencilContext *const pc, GdkEventMotion const &mev
     }
 
     /* Find desktop coordinates */
-    NR::Point p = sp_desktop_w2d_xy_point(dt, NR::Point(mevent.x, mevent.y));
+    NR::Point p = dt->w2d(NR::Point(mevent.x, mevent.y));
 
     /* Test whether we hit any anchor. */
     SPDrawAnchor *anchor = spdc_test_inside(pc, NR::Point(mevent.x, mevent.y));
@@ -301,14 +296,15 @@ pencil_handle_motion_notify(SPPencilContext *const pc, GdkEventMotion const &mev
                     /* Create green anchor */
                     pc->green_anchor = sp_draw_anchor_new(pc, pc->green_curve, TRUE, pc->p[0]);
                 }
-                /** \todo 
-                 * fixme: I am not sure whether we want to snap to anchors 
+                /** \todo
+                 * fixme: I am not sure whether we want to snap to anchors
                  * in middle of freehand (Lauris)
                  */
                 if (anchor) {
                     p = anchor->dp;
                 } else if ((mevent.state & GDK_SHIFT_MASK) == 0) {
-                    namedview_free_snap_all_types(dt->namedview, p);
+                    SnapManager const &m = dt->namedview->snap_manager;
+                    p = m.freeSnap(Inkscape::Snapper::BBOX_POINT | Inkscape::Snapper::SNAP_POINT, p, NULL).getPoint();
                 }
                 if ( pc->npoints != 0 ) { // buttonpress may have happened before we entered draw context!
                     spdc_add_freehand_point(pc, p, mevent.state);
@@ -350,8 +346,7 @@ pencil_handle_button_release(SPPencilContext *const pc, GdkEventButton const &re
         pc->is_drawing = false;
 
         /* Find desktop coordinates */
-        NR::Point p = sp_desktop_w2d_xy_point(dt, NR::Point(revent.x,
-                                                            revent.y));
+        NR::Point p = dt->w2d(NR::Point(revent.x, revent.y));
 
         /* Test whether we hit any anchor. */
         SPDrawAnchor *anchor = spdc_test_inside(pc, NR::Point(revent.x,
@@ -486,8 +481,8 @@ spdc_set_endpoint(SPPencilContext *const pc, NR::Point const p)
 
 /**
  * Finalize addline.
- * 
- * \todo 
+ *
+ * \todo
  * fixme: I'd like remove red reset from concat colors (lauris).
  * Still not sure, how it will make most sense.
  */
@@ -533,7 +528,7 @@ fit_and_split(SPPencilContext *pc)
 {
     g_assert( pc->npoints > 1 );
 
-    double const tolerance_sq = square( NR::expansion(pc->desktop->w2d)
+    double const tolerance_sq = square( NR::expansion(pc->desktop->w2d())
                                         * prefs_get_double_attribute_limited("tools.freehand.pencil",
                                                                              "tolerance", 10.0, 1.0, 100.0) );
 
@@ -573,8 +568,8 @@ fit_and_split(SPPencilContext *pc)
         sp_curve_append_continuous(pc->green_curve, pc->red_curve, 0.0625);
         SPCurve *curve = sp_curve_copy(pc->red_curve);
 
-        /// \todo fixme: 
-        SPCanvasItem *cshape = sp_canvas_bpath_new(SP_DT_SKETCH(pc->desktop), curve);
+        /// \todo fixme:
+        SPCanvasItem *cshape = sp_canvas_bpath_new(sp_desktop_sketch(pc->desktop), curve);
         sp_curve_unref(curve);
         sp_canvas_bpath_set_stroke(SP_CANVAS_BPATH(cshape), pc->green_color, 1.0, SP_STROKE_LINEJOIN_MITER, SP_STROKE_LINECAP_BUTT);
 
