@@ -15,37 +15,28 @@
 
 #include "config.h"
 
-#include <math.h>
-#include <string.h>
-#include <glib.h>
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "macros.h"
 #include "display/sp-canvas.h"
 #include "sp-rect.h"
-#include "inkscape.h"
 #include "document.h"
 #include "sp-namedview.h"
 #include "selection.h"
 #include "desktop-handles.h"
-#include "desktop-affine.h"
 #include "snap.h"
 #include "desktop.h"
 #include "desktop-style.h"
 #include "message-context.h"
 #include "pixmaps/cursor-rect.xpm"
 #include "rect-context.h"
-#include "widgets/desktop-widget.h"
 #include "sp-metrics.h"
 #include <glibmm/i18n.h>
 #include "object-edit.h"
-#include "knotholder.h"
 #include "xml/repr.h"
 #include "xml/node-event-vector.h"
 #include "prefs-utils.h"
-#include "widgets/spw-utilities.h"
-#include "selcue.h"
+#include "context-fns.h"
 
 static void sp_rect_context_class_init(SPRectContextClass *klass);
 static void sp_rect_context_init(SPRectContext *rect_context);
@@ -143,7 +134,7 @@ static void sp_rect_context_dispose(GObject *object)
 
     if (ec->shape_repr) { // remove old listener
         sp_repr_remove_listener_by_data(ec->shape_repr, ec);
-        sp_repr_unref(ec->shape_repr);
+        Inkscape::GC::release(ec->shape_repr);
         ec->shape_repr = 0;
     }
 
@@ -178,7 +169,7 @@ void sp_rect_context_selection_changed(Inkscape::Selection *selection, gpointer
 
     if (ec->shape_repr) { // remove old listener
         sp_repr_remove_listener_by_data(ec->shape_repr, ec);
-        sp_repr_unref(ec->shape_repr);
+        Inkscape::GC::release(ec->shape_repr);
         ec->shape_repr = 0;
     }
 
@@ -188,9 +179,8 @@ void sp_rect_context_selection_changed(Inkscape::Selection *selection, gpointer
         Inkscape::XML::Node *shape_repr = SP_OBJECT_REPR(item);
         if (shape_repr) {
             ec->shape_repr = shape_repr;
-            sp_repr_ref(shape_repr);
+            Inkscape::GC::anchor(shape_repr);
             sp_repr_add_listener(shape_repr, &ec_shape_repr_events, ec);
-            sp_repr_synthesize_events(shape_repr, &ec_shape_repr_events, ec);
         }
     }
 }
@@ -203,20 +193,19 @@ static void sp_rect_context_setup(SPEventContext *ec)
         ((SPEventContextClass *) parent_class)->setup(ec);
     }
 
-    SPItem *item = SP_DT_SELECTION(ec->desktop)->singleItem();
+    SPItem *item = sp_desktop_selection(ec->desktop)->singleItem();
     if (item) {
         ec->shape_knot_holder = sp_item_knot_holder(item, ec->desktop);
         Inkscape::XML::Node *shape_repr = SP_OBJECT_REPR(item);
         if (shape_repr) {
             ec->shape_repr = shape_repr;
-            sp_repr_ref(shape_repr);
+            Inkscape::GC::anchor(shape_repr);
             sp_repr_add_listener(shape_repr, &ec_shape_repr_events, ec);
-            sp_repr_synthesize_events(shape_repr, &ec_shape_repr_events, ec);
         }
     }
 
     rc->sel_changed_connection.disconnect();
-    rc->sel_changed_connection = SP_DT_SELECTION(ec->desktop)->connectChanged(
+    rc->sel_changed_connection = sp_desktop_selection(ec->desktop)->connectChanged(
         sigc::bind(sigc::ptr_fun(&sp_rect_context_selection_changed), (gpointer)rc)
     );
 
@@ -260,15 +249,7 @@ static gint sp_rect_context_item_handler(SPEventContext *event_context, SPItem *
     switch (event->type) {
     case GDK_BUTTON_PRESS:
         if ( event->button.button == 1 ) {
-
-            // save drag origin
-            event_context->xp = (gint) event->button.x;
-            event_context->yp = (gint) event->button.y;
-            event_context->within_tolerance = true;
-
-            // remember clicked item, disregarding groups, honoring Alt
-            event_context->item_to_select = sp_event_context_find_item (desktop, NR::Point(event->button.x, event->button.y), event->button.state & GDK_MOD1_MASK, TRUE);
-
+            Inkscape::setup_for_drag_start(desktop, event_context, event);
             ret = TRUE;
         }
         break;
@@ -289,7 +270,7 @@ static gint sp_rect_context_root_handler(SPEventContext *event_context, GdkEvent
     static bool dragging;
 
     SPDesktop *desktop = event_context->desktop;
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     SPRectContext *rc = SP_RECT_CONTEXT(event_context);
 
@@ -311,16 +292,19 @@ static gint sp_rect_context_root_handler(SPEventContext *event_context, GdkEvent
             event_context->item_to_select = sp_event_context_find_item (desktop, button_w, event->button.state & GDK_MOD1_MASK, TRUE);
 
             dragging = true;
+
             /* Position center */
-            NR::Point const button_dt(sp_desktop_w2d_xy_point(event_context->desktop, button_w));
-            /* Snap center to nearest magnetic point */
-            rc->center = button_dt;
-            namedview_free_snap_all_types(event_context->desktop->namedview, rc->center);
+            NR::Point const button_dt(desktop->w2d(button_w));
+
+            /* Snap center */
+            SnapManager const &m = desktop->namedview->snap_manager;
+            rc->center = m.freeSnap(Inkscape::Snapper::SNAP_POINT | Inkscape::Snapper::BBOX_POINT,
+                                    button_dt, rc->item).getPoint();
+
             sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
-                                ( GDK_KEY_PRESS_MASK | 
+                                ( GDK_KEY_PRESS_MASK |
                                   GDK_BUTTON_RELEASE_MASK       |
                                   GDK_POINTER_MOTION_MASK       |
-                                  GDK_POINTER_MOTION_HINT_MASK  |
                                   GDK_BUTTON_PRESS_MASK ),
                                 NULL, event->button.time);
             ret = TRUE;
@@ -342,7 +326,7 @@ static gint sp_rect_context_root_handler(SPEventContext *event_context, GdkEvent
 
             NR::Point const motion_w(event->motion.x,
                                      event->motion.y);
-            NR::Point const motion_dt(sp_desktop_w2d_xy_point(event_context->desktop, motion_w));
+            NR::Point const motion_dt(desktop->w2d(motion_w));
             sp_rect_drag(*rc, motion_dt, event->motion.state);
             ret = TRUE;
         }
@@ -400,16 +384,13 @@ static gint sp_rect_context_root_handler(SPEventContext *event_context, GdkEvent
         case GDK_x:
         case GDK_X:
             if (MOD__ALT_ONLY) {
-                gpointer hb = sp_search_by_data_recursive (desktop->owner->aux_toolbox, (gpointer) "altx-rect");
-                if (hb && GTK_IS_WIDGET(hb)) {
-                    gtk_widget_grab_focus (GTK_WIDGET (hb));
-                }
+                desktop->setToolboxFocusTo ("altx-rect");
                 ret = TRUE;
             }
             break;
 
         case GDK_Escape:
-            SP_DT_SELECTION(desktop)->clear();
+            sp_desktop_selection(desktop)->clear();
             //TODO: make dragging escapable by Esc
         default:
             break;
@@ -450,13 +431,7 @@ static void sp_rect_drag(SPRectContext &rc, NR::Point const pt, guint state)
 
     if (!rc.item) {
 
-        SPItem *layer=SP_ITEM(desktop->currentLayer());
-        if ( !layer || desktop->itemIsHidden(layer)) {
-            rc._message_context->set(Inkscape::ERROR_MESSAGE, _("<b>Current layer is hidden</b>. Unhide it to be able to draw on it."));
-            return;
-        }
-        if ( !layer || layer->isLocked()) {
-            rc._message_context->set(Inkscape::ERROR_MESSAGE, _("<b>Current layer is locked</b>. Unlock it to be able to draw on it."));
+        if (Inkscape::have_viable_layer(desktop, rc._message_context) == false) {
             return;
         }
 
@@ -467,88 +442,27 @@ static void sp_rect_drag(SPRectContext &rc, NR::Point const pt, guint state)
         sp_desktop_apply_style_tool (desktop, repr, "tools.shapes.rect", false);
 
         rc.item = (SPItem *) desktop->currentLayer()->appendChildRepr(repr);
-        sp_repr_unref(repr);
+        Inkscape::GC::release(repr);
         rc.item->transform = SP_ITEM(desktop->currentRoot())->getRelativeTransform(desktop->currentLayer());
         rc.item->updateRepr();
     }
 
-    NR::Point p0, p1;
-    if ( state & GDK_CONTROL_MASK ) {
-        NR::Point delta = pt - rc.center;
-        /* fixme: Snapping */
-        if ( ( fabs(delta[0]) > fabs(delta[1]) )
-             && ( delta[1] != 0.0) )
-        {
-            delta[0] = floor( delta[0] / delta[1] + 0.5 ) * delta[1];
-        } else if ( delta[0] != 0.0 ) {
-            delta[1] = floor( delta[1] / delta[0] + 0.5 ) * delta[0];
-        }
-        p1 = rc.center + delta;
-        if ( state & GDK_SHIFT_MASK ) {
-            p0 = rc.center - delta;
-            NR::Coord const l0 = namedview_vector_snap_all_types(desktop->namedview, p0, p0 - p1);
-            NR::Coord const l1 = namedview_vector_snap_all_types(desktop->namedview, p1, p1 - p0);
+    NR::Rect const r = Inkscape::snap_rectangular_box(desktop, rc.item, pt, rc.center, state);
 
-            if (l0 < l1) {
-                p1 = 2 * rc.center - p0;
-            } else {
-                p0 = 2 * rc.center - p1;
-            }
-        } else {
-            p0 = rc.center;
-            namedview_vector_snap_all_types(desktop->namedview, p1, p1 - p0);
-        }
-    } else if ( state & GDK_SHIFT_MASK ) {
-        /* Corner point movements are bound */
-        p1 = pt;
-        p0 = 2 * rc.center - p1;
-        for (unsigned d = 0 ; d < 2 ; ++d) {
-            double snap_movement[2];
-            snap_movement[0] = namedview_dim_snap_all_types(desktop->namedview, p0, NR::Dim2(d));
-            snap_movement[1] = namedview_dim_snap_all_types(desktop->namedview, p1, NR::Dim2(d));
-            if ( snap_movement[0] <
-                 snap_movement[1] )
-            {
-                /* Use point 0 position. */
-                p1[d] = 2 * rc.center[d] - p0[d];
-            } else {
-                p0[d] = 2 * rc.center[d] - p1[d];
-            }
-        }
-    } else {
-        /* Free movement for corner point */
-        p0 = rc.center;
-        p1 = pt;
-        namedview_free_snap_all_types(desktop->namedview, p1);
-    }
-
-    p0 = sp_desktop_dt2root_xy_point(desktop, p0);
-    p1 = sp_desktop_dt2root_xy_point(desktop, p1);
-
-    // TODO: use NR::Rect
-    using NR::X;
-    using NR::Y;
-    NR::Coord const x0 = MIN(p0[X], p1[X]);
-    NR::Coord const y0 = MIN(p0[Y], p1[Y]);
-    NR::Coord const x1 = MAX(p0[X], p1[X]);
-    NR::Coord const y1 = MAX(p0[Y], p1[Y]);
-    NR::Coord const w  = x1 - x0;
-    NR::Coord const h  = y1 - y0;
-
-    sp_rect_position_set(SP_RECT(rc.item), x0, y0, w, h);
+    sp_rect_position_set(SP_RECT(rc.item), r.min()[NR::X], r.min()[NR::Y], r.dimensions()[NR::X], r.dimensions()[NR::Y]);
     if ( rc.rx != 0.0 ) {
         sp_rect_set_rx (SP_RECT(rc.item), TRUE, rc.rx);
     }
     if ( rc.ry != 0.0 ) {
         if (rc.rx == 0.0)
-            sp_rect_set_ry (SP_RECT(rc.item), TRUE, CLAMP(rc.ry, 0, MIN(w, h)/2));
-        else 
-            sp_rect_set_ry (SP_RECT(rc.item), TRUE, CLAMP(rc.ry, 0, h));
+            sp_rect_set_ry (SP_RECT(rc.item), TRUE, CLAMP(rc.ry, 0, MIN(r.dimensions()[NR::X], r.dimensions()[NR::Y])/2));
+        else
+            sp_rect_set_ry (SP_RECT(rc.item), TRUE, CLAMP(rc.ry, 0, r.dimensions()[NR::Y]));
     }
 
     // status text
-    GString *xs = SP_PX_TO_METRIC_STRING(fabs( x1 - x0 ), desktop->namedview->getDefaultMetric());
-    GString *ys = SP_PX_TO_METRIC_STRING(fabs( y1 - y0 ), desktop->namedview->getDefaultMetric());
+    GString *xs = SP_PX_TO_METRIC_STRING(r.dimensions()[NR::X], desktop->namedview->getDefaultMetric());
+    GString *ys = SP_PX_TO_METRIC_STRING(r.dimensions()[NR::Y], desktop->namedview->getDefaultMetric());
     rc._message_context->setF(Inkscape::NORMAL_MESSAGE, _("<b>Rectangle</b>: %s &#215; %s; with <b>Ctrl</b> to make square or integer-ratio rectangle; with <b>Shift</b> to draw around the starting point"), xs->str, ys->str);
     g_string_free(xs, FALSE);
     g_string_free(ys, FALSE);
@@ -565,8 +479,8 @@ static void sp_rect_finish(SPRectContext *rc)
 
         SP_OBJECT(rc->item)->updateRepr();
 
-        SP_DT_SELECTION(dt)->set(rc->item);
-        sp_document_done(SP_DT_DOCUMENT(dt));
+        sp_desktop_selection(dt)->set(rc->item);
+        sp_document_done(sp_desktop_document(dt));
 
         rc->item = NULL;
     }
@@ -576,9 +490,9 @@ static void sp_rect_finish(SPRectContext *rc)
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
