@@ -1,8 +1,6 @@
-#include "satisfied-guide-cns.h"
 #include <desktop-handles.h>
 #include <libnr/nr-point-fns.h>
 #include <sp-guide.h>
-#include <sp-guide-attachment.h>
 #include <sp-guide-constraint.h>
 #include <sp-namedview.h>
 #include <approx-equal.h>
@@ -11,7 +9,7 @@ void satisfied_guide_cns(SPDesktop const &desktop,
                          std::vector<NR::Point> const &snappoints,
                          std::vector<SPGuideConstraint> &cns)
 {
-    SPNamedView const &nv = *SP_DT_NAMEDVIEW(&desktop);
+    SPNamedView const &nv = *sp_desktop_namedview(&desktop);
     for (GSList const *l = nv.guides; l != NULL; l = l->next) {
         SPGuide &g = *SP_GUIDE(l->data);
         for (unsigned int i = 0; i < snappoints.size(); ++i) {
@@ -27,9 +25,9 @@ void satisfied_guide_cns(SPDesktop const &desktop,
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
