@@ -15,44 +15,28 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-#include <math.h>
-#include <string.h>
-#include <glib.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
 #include "macros.h"
-#include "display/sp-canvas-util.h"
 #include "rubberband.h"
-#include "inkscape-private.h"
 #include "document.h"
-#include "sp-namedview.h"
 #include "selection.h"
-#include "desktop-affine.h"
 #include "seltrans-handles.h"
 #include "sp-cursor.h"
-#include "widgets/desktop-widget.h"
 #include "pixmaps/cursor-select-m.xpm"
 #include "pixmaps/cursor-select-d.xpm"
 #include "pixmaps/handles.xpm"
 #include <glibmm/i18n.h>
-#include "widgets/spw-utilities.h"
-#include "message-context.h"
 
 #include "select-context.h"
 #include "selection-chemistry.h"
-#include "path-chemistry.h"
 #include "desktop.h"
 #include "desktop-handles.h"
-#include "dialogs/object-properties.h"
-#include "sp-metrics.h"
-#include "sp-item.h"
-#include "sp-item-group.h"
 #include "sp-root.h"
-#include "snap.h"
 #include "prefs-utils.h"
 #include "tools-switch.h"
-#include "message-context.h"
 #include "message-stack.h"
+#include "selection-describer.h"
+#include "seltrans.h"
 
 static void sp_select_context_class_init(SPSelectContextClass *klass);
 static void sp_select_context_init(SPSelectContext *select_context);
@@ -63,8 +47,6 @@ static void sp_select_context_set(SPEventContext *ec, gchar const *key, gchar co
 static gint sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event);
 static gint sp_select_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEvent *event);
 
-static void sp_selection_moveto(SPSelTrans *seltrans, NR::Point const &xy, guint state);
-
 static SPEventContextClass *parent_class;
 
 static GdkCursor *CursorSelectMouseover = NULL;
@@ -188,7 +170,7 @@ sp_select_context_setup(SPEventContext *ec)
 
     select_context->_describer = new Inkscape::SelectionDescriber(desktop->selection, desktop->messageStack());
 
-    select_context->_seltrans = new SPSelTrans(desktop);
+    select_context->_seltrans = new Inkscape::SelTrans(desktop);
 
     sp_event_context_read(ec, "show");
     sp_event_context_read(ec, "transform");
@@ -205,11 +187,11 @@ sp_select_context_set(SPEventContext *ec, gchar const *key, gchar const *val)
 
     if (!strcmp(key, "show")) {
         if (val && !strcmp(val, "outline")) {
-            sc->_seltrans->show = SP_SELTRANS_SHOW_OUTLINE;
+            sc->_seltrans->setShow(Inkscape::SelTrans::SHOW_OUTLINE);
         } else {
-            sc->_seltrans->show = SP_SELTRANS_SHOW_CONTENT;
+            sc->_seltrans->setShow(Inkscape::SelTrans::SHOW_CONTENT);
         }
-    } 
+    }
 }
 
 static bool
@@ -217,11 +199,11 @@ sp_select_context_abort(SPEventContext *event_context)
 {
     SPDesktop *desktop = event_context->desktop;
     SPSelectContext *sc = SP_SELECT_CONTEXT(event_context);
-    SPSelTrans *seltrans = sc->_seltrans;
+    Inkscape::SelTrans *seltrans = sc->_seltrans;
 
     if (sc->dragging) {
         if (sc->moved) { // cancel dragging an object
-            sp_sel_trans_ungrab(seltrans);
+            seltrans->ungrab();
             sc->moved = FALSE;
             sc->dragging = FALSE;
             drag_escaped = 1;
@@ -229,7 +211,7 @@ sp_select_context_abort(SPEventContext *event_context)
             if (sc->item) {
                 // only undo if the item is still valid
                 if (SP_OBJECT_DOCUMENT( SP_OBJECT(sc->item))) {
-                    sp_document_undo(SP_DT_DOCUMENT(desktop));
+                    sp_document_undo(sp_desktop_document(desktop));
                 }
 
                 sp_object_unref( SP_OBJECT(sc->item), NULL);
@@ -237,7 +219,7 @@ sp_select_context_abort(SPEventContext *event_context)
                 // NOTE:  This is a workaround to a bug.
                 // When the ctrl key is held, sc->item is not defined
                 // so in this case (only), we skip the object doc check
-                sp_document_undo(SP_DT_DOCUMENT(desktop));
+                sp_document_undo(sp_desktop_document(desktop));
             }
             sc->item = NULL;
 
@@ -245,19 +227,18 @@ sp_select_context_abort(SPEventContext *event_context)
             return true;
         }
     } else {
-        NRRect b;
-
-        if (sp_rubberband_rect(&b)) { // cancel rubberband
-            sp_rubberband_stop();
+        NR::Maybe<NR::Rect> const b = Inkscape::Rubberband::get()->getRectangle();
+        if (b != NR::Nothing()) {
+            Inkscape::Rubberband::get()->stop();
             rb_escaped = 1;
             SP_EVENT_CONTEXT(sc)->desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Selection canceled."));
             return true;
-        } 
+        }
     }
     return false;
 }
 
-bool 
+bool
 key_is_a_modifier (guint key) {
     return (key == GDK_Alt_L ||
                 key == GDK_Alt_R ||
@@ -269,6 +250,36 @@ key_is_a_modifier (guint key) {
             key == GDK_Meta_R);
 }
 
+void
+sp_select_context_up_one_layer(SPDesktop *desktop)
+{
+    /* Click in empty place, go up one level -- but don't leave a layer to root.
+     *
+     * (Rationale: we don't usually allow users to go to the root, since that
+     * detracts from the layer metaphor: objects at the root level can in front
+     * of or behind layers.  Whereas it's fine to go to the root if editing
+     * a document that has no layers (e.g. a non-Inkscape document).)
+     *
+     * Once we support editing SVG "islands" (e.g. <svg> embedded in an xhtml
+     * document), we might consider further restricting the below to disallow
+     * leaving a layer to go to a non-layer.
+     */
+    SPObject *const current_layer = desktop->currentLayer();
+    if (current_layer) {
+        SPObject *const parent = SP_OBJECT_PARENT(current_layer);
+        if ( parent
+             && ( SP_OBJECT_PARENT(parent)
+                  || !( SP_IS_GROUP(current_layer)
+                        && ( SPGroup::LAYER
+                             == SP_GROUP(current_layer)->layerMode() ) ) ) )
+        {
+            desktop->setCurrentLayer(parent);
+            if (SP_IS_GROUP(current_layer) && SPGroup::LAYER != SP_GROUP(current_layer)->layerMode())
+                sp_desktop_selection(desktop)->set(current_layer);
+        }
+    }
+}
+
 static gint
 sp_select_context_item_handler(SPEventContext *event_context, SPItem *item, GdkEvent *event)
 {
@@ -276,7 +287,7 @@ sp_select_context_item_handler(SPEventContext *event_context, SPItem *item, GdkE
 
     SPDesktop *desktop = event_context->desktop;
     SPSelectContext *sc = SP_SELECT_CONTEXT(event_context);
-    SPSelTrans *seltrans = sc->_seltrans;
+    Inkscape::SelTrans *seltrans = sc->_seltrans;
 
     tolerance = prefs_get_int_attribute_limited("options.dragtolerance", "value", 0, 0, 100);
 
@@ -308,7 +319,7 @@ sp_select_context_item_handler(SPEventContext *event_context, SPItem *item, GdkE
                     sc->moved = FALSE;
 
                     // remember the clicked item in sc->item:
-                    sc->item = sp_event_context_find_item (desktop, 
+                    sc->item = sp_event_context_find_item (desktop,
                                               NR::Point(event->button.x, event->button.y), event->button.state & GDK_MOD1_MASK, FALSE);
                     sp_object_ref(sc->item, NULL);
 
@@ -316,7 +327,7 @@ sp_select_context_item_handler(SPEventContext *event_context, SPItem *item, GdkE
 
                     sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->drawing),
                                         GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK |
-                                        GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK,
+                                        GDK_POINTER_MOTION_MASK,
                                         NULL, event->button.time);
                     sc->grabbed = SP_CANVAS_ITEM(desktop->drawing);
 
@@ -331,20 +342,20 @@ sp_select_context_item_handler(SPEventContext *event_context, SPItem *item, GdkE
         case GDK_ENTER_NOTIFY:
         {
             GdkCursor *cursor = gdk_cursor_new(GDK_FLEUR);
-            gdk_window_set_cursor(GTK_WIDGET(SP_DT_CANVAS(desktop))->window, cursor);
+            gdk_window_set_cursor(GTK_WIDGET(sp_desktop_canvas(desktop))->window, cursor);
             gdk_cursor_destroy(cursor);
             break;
         }
 
         case GDK_LEAVE_NOTIFY:
-            gdk_window_set_cursor(GTK_WIDGET(SP_DT_CANVAS(desktop))->window, event_context->cursor);
+            gdk_window_set_cursor(GTK_WIDGET(sp_desktop_canvas(desktop))->window, event_context->cursor);
             break;
 
         case GDK_KEY_PRESS:
             if (get_group0_keyval (&event->key) == GDK_space) {
                 if (sc->dragging && sc->grabbed) {
                     /* stamping mode: show content mode moving */
-                    sp_sel_trans_stamp(seltrans);
+                    seltrans->stamp();
                     ret = TRUE;
                 }
             }
@@ -368,12 +379,11 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
     SPItem *item = NULL;
     SPItem *item_at_point = NULL, *group_at_point = NULL, *item_in_group = NULL;
     gint ret = FALSE;
-    NRRect b;
 
     SPDesktop *desktop = event_context->desktop;
     SPSelectContext *sc = SP_SELECT_CONTEXT(event_context);
-    SPSelTrans *seltrans = sc->_seltrans;
-    Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+    Inkscape::SelTrans *seltrans = sc->_seltrans;
+    Inkscape::Selection *selection = sp_desktop_selection(desktop);
     gdouble const nudge = prefs_get_double_attribute_limited("options.nudgedistance", "value", 2, 0, 1000); // in px
     gdouble const offset = prefs_get_double_attribute_limited("options.defaultscale", "value", 2, 0, 1000);
     tolerance = prefs_get_int_attribute_limited("options.dragtolerance", "value", 0, 0, 100);
@@ -391,35 +401,13 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                     SPItem *clicked_item = (SPItem *) selection->itemList()->data;
                     if (SP_IS_GROUP (clicked_item)) { // enter group
                         desktop->setCurrentLayer(reinterpret_cast<SPObject *>(clicked_item));
-                        SP_DT_SELECTION(desktop)->clear();
+                        sp_desktop_selection(desktop)->clear();
                         sc->dragging = false;
                     } else { // switch tool
                         tools_switch_by_item (desktop, clicked_item);
                     }
                 } else {
-                    /* Click in empty place, go up one level -- but don't leave a layer to root.
-                     *
-                     * (Rationale: we don't usually allow users to go to the root, since that
-                     * detracts from the layer metaphor: objects at the root level can in front
-                     * of or behind layers.  Whereas it's fine to go to the root if editing
-                     * a document that has no layers (e.g. a non-Inkscape document).)
-                     *
-                     * Once we support editing SVG "islands" (e.g. <svg> embedded in an xhtml
-                     * document), we might consider further restricting the below to disallow
-                     * leaving a layer to go to a non-layer.
-                     */
-                    SPObject *const current_layer = desktop->currentLayer();
-                    if (current_layer) {
-                        SPObject *const parent = SP_OBJECT_PARENT(current_layer);
-                        if ( parent
-                             && ( SP_OBJECT_PARENT(parent)
-                                  || !( SP_IS_GROUP(current_layer)
-                                        && ( SPGroup::LAYER
-                                             == SP_GROUP(current_layer)->layerMode() ) ) ) )
-                        {
-                            desktop->setCurrentLayer(parent);
-                        }
-                    }
+                    sp_select_context_up_one_layer(desktop);
                 }
                 ret = TRUE;
             }
@@ -433,8 +421,8 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                 within_tolerance = true;
 
                 NR::Point const button_pt(event->button.x, event->button.y);
-                NR::Point const p(sp_desktop_w2d_xy_point(desktop, button_pt));
-                sp_rubberband_start(desktop, p);
+                NR::Point const p(desktop->w2d(button_pt));
+                Inkscape::Rubberband::get()->start(desktop, p);
                 sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
                                     GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
                                     NULL, event->button.time);
@@ -459,7 +447,7 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
         case GDK_MOTION_NOTIFY:
             if (event->motion.state & GDK_BUTTON1_MASK) {
                 NR::Point const motion_pt(event->motion.x, event->motion.y);
-                NR::Point const p(sp_desktop_w2d_xy_point(desktop, motion_pt));
+                NR::Point const p(desktop->w2d(motion_pt));
 
                 if ( within_tolerance
                      && ( abs( (gint) event->motion.x - xp ) < tolerance )
@@ -478,11 +466,11 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                     /* User has dragged fast, so we get events on root (lauris)*/
                     // not only that; we will end up here when ctrl-dragging as well
                     // and also when we started within tolerance, but trespassed tolerance outside of item
-                    sp_rubberband_stop();
+                    Inkscape::Rubberband::get()->stop();
                     item_at_point = desktop->item_at_point(NR::Point(event->button.x, event->button.y), FALSE);
                     if (!item_at_point) // if no item at this point, try at the click point (bug 1012200)
                         item_at_point = desktop->item_at_point(NR::Point(xp, yp), FALSE);
-                    if (item_at_point || sc->moved || sc->button_press_alt) { 
+                    if (item_at_point || sc->moved || sc->button_press_alt) {
                         // drag only if starting from an item, or if something is already grabbed, or if alt-dragging
                         if (!sc->moved) {
                             item_in_group = desktop->item_at_point(NR::Point(event->button.x, event->button.y), TRUE);
@@ -492,17 +480,18 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                                 (!group_at_point || !selection->includes(group_at_point))
                                 && !sc->button_press_alt) {
                                 // select what is under cursor
-                                if (!seltrans->empty)
-                                    sp_sel_trans_reset_state(seltrans);
+                                if (!seltrans->isEmpty()) {
+                                    seltrans->resetState();
+                                }
                                 // when simply ctrl-dragging, we don't want to go into groups
                                 if (item_at_point && !selection->includes(item_at_point))
                                     selection->set(item_at_point);
                             } // otherwise, do not change selection so that dragging selected-within-group items, as well as alt-dragging, is possible
-                            sp_sel_trans_grab(seltrans, p, -1, -1, FALSE);
+                            seltrans->grab(p, -1, -1, FALSE);
                             sc->moved = TRUE;
                         }
-                        if (!seltrans->empty)
-                            sp_selection_moveto(seltrans, p, event->button.state);
+                        if (!seltrans->isEmpty())
+                            seltrans->moveTo(p, event->button.state);
                         if (desktop->scroll_to_point(&p))
                             // unfortunately in complex drawings, gobbling results in losing grab of the object, for some mysterious reason
                             ; //gobble_motion_events(GDK_BUTTON1_MASK);
@@ -511,7 +500,7 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                         sc->dragging = FALSE;
                     }
                 } else {
-                    sp_rubberband_move(p);
+                    Inkscape::Rubberband::get()->move(p);
                     gobble_motion_events(GDK_BUTTON1_MASK);
                 }
             }
@@ -522,26 +511,26 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                 if (sc->dragging) {
                     if (sc->moved) {
                         // item has been moved
-                        sp_sel_trans_ungrab(seltrans);
+                        seltrans->ungrab();
                         sc->moved = FALSE;
                     } else if (sc->item && !drag_escaped) {
                         // item has not been moved -> simply a click, do selecting
                         if (!selection->isEmpty()) {
                             if (event->button.state & GDK_SHIFT_MASK) {
                                 // with shift, toggle selection
-                                sp_sel_trans_reset_state(seltrans);
+                                seltrans->resetState();
                                 selection->toggle(sc->item);
                             } else {
                                 // without shift, increase state (i.e. toggle scale/rotation handles)
                                 if (selection->includes(sc->item)) {
-                                    sp_sel_trans_increase_state(seltrans);
+                                    seltrans->increaseState();
                                 } else {
-                                    sp_sel_trans_reset_state(seltrans);
+                                    seltrans->resetState();
                                     selection->set(sc->item);
                                 }
                             }
                         } else { // simple or shift click, no previous selection
-                            sp_sel_trans_reset_state(seltrans);
+                            seltrans->resetState();
                             selection->set(sc->item);
                         }
                     }
@@ -551,12 +540,13 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                     }
                     sc->item = NULL;
                 } else {
-                    if (sp_rubberband_rect(&b) && !within_tolerance) {
+                    NR::Maybe<NR::Rect> const b = Inkscape::Rubberband::get()->getRectangle();
+                    if (b != NR::Nothing() && !within_tolerance) {
                         // this was a rubberband drag
-                        sp_rubberband_stop();
-                        sp_sel_trans_reset_state(seltrans);
+                        Inkscape::Rubberband::get()->stop();
+                        seltrans->resetState();
                         // find out affected items:
-                        GSList *items = sp_document_items_in_box(SP_DT_DOCUMENT(desktop), desktop->dkey, &b);
+                        GSList *items = sp_document_items_in_box(sp_desktop_document(desktop), desktop->dkey, b.assume());
                         if (event->button.state & GDK_SHIFT_MASK) {
                             // with shift, add to selection
                             selection->addList (items);
@@ -566,7 +556,7 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                         }
                         g_slist_free (items);
                     } else { // it was just a click, or a too small rubberband
-                        sp_rubberband_stop();
+                        Inkscape::Rubberband::get()->stop();
                         if (sc->button_press_shift && !rb_escaped && !drag_escaped) {
                             // this was a shift-click, select what was clicked upon
 
@@ -574,12 +564,12 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
 
                             if (sc->button_press_ctrl) {
                                 // go into groups, honoring Alt
-                                item = sp_event_context_find_item (desktop, 
+                                item = sp_event_context_find_item (desktop,
                                                    NR::Point(event->button.x, event->button.y), event->button.state & GDK_MOD1_MASK, TRUE);
                                 sc->button_press_ctrl = FALSE;
                             } else {
                                 // don't go into groups, honoring Alt
-                                item = sp_event_context_find_item (desktop, 
+                                item = sp_event_context_find_item (desktop,
                                                    NR::Point(event->button.x, event->button.y), event->button.state & GDK_MOD1_MASK, FALSE);
                             }
 
@@ -592,14 +582,14 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
 
                             sc->button_press_ctrl = FALSE;
 
-                            item = sp_event_context_find_item (desktop, 
+                            item = sp_event_context_find_item (desktop,
                                          NR::Point(event->button.x, event->button.y), event->button.state & GDK_MOD1_MASK, TRUE);
 
                             if (item) {
                                 if (selection->includes(item)) {
-                                    sp_sel_trans_increase_state(seltrans);
+                                    seltrans->increaseState();
                                 } else {
-                                    sp_sel_trans_reset_state(seltrans);
+                                    seltrans->resetState();
                                     selection->set(item);
                                 }
                                 item = NULL;
@@ -727,17 +717,14 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                     /* stamping mode: show outline mode moving */
                     /* FIXME: Is next condition ok? (lauris) */
                     if (sc->dragging && sc->grabbed) {
-                        sp_sel_trans_stamp(seltrans);
+                        seltrans->stamp();
                         ret = TRUE;
                     }
                     break;
                 case GDK_x:
                 case GDK_X:
                     if (MOD__ALT_ONLY) {
-                        gpointer hb = sp_search_by_data_recursive(desktop->owner->aux_toolbox, (gpointer) "altx");
-                        if (hb && GTK_IS_WIDGET(hb)) {
-                            gtk_widget_grab_focus(GTK_WIDGET(hb));
-                        }
+                        desktop->setToolboxFocusTo ("altx");
                         ret = TRUE;
                     }
                     break;
@@ -783,6 +770,26 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
                     }
                     ret = TRUE;
                     break;
+                case GDK_Return:
+                    if (MOD__CTRL_ONLY) {
+                        if (selection->singleItem()) {
+                            SPItem *clicked_item = selection->singleItem();
+                            if (SP_IS_GROUP (clicked_item)) { // enter group
+                                desktop->setCurrentLayer(reinterpret_cast<SPObject *>(clicked_item));
+                                sp_desktop_selection(desktop)->clear();
+                            } else {
+                                SP_EVENT_CONTEXT(sc)->desktop->messageStack()->flash(Inkscape::NORMAL_MESSAGE, _("Selected object is not a group. Cannot enter."));
+                            }
+                        }
+                        ret = TRUE;
+                    }
+                    break;
+                case GDK_BackSpace:
+                    if (MOD__CTRL_ONLY) {
+                        sp_select_context_up_one_layer(desktop);
+                        ret = TRUE;
+                    }
+                    break;
                 default:
                     break;
             }
@@ -803,56 +810,6 @@ sp_select_context_root_handler(SPEventContext *event_context, GdkEvent *event)
     return ret;
 }
 
-static void sp_selection_moveto(SPSelTrans *seltrans, NR::Point const &xy, guint state)
-{
-    using NR::X;
-    using NR::Y;
-
-    SPDesktop *desktop = seltrans->desktop;
-
-    NR::Point dxy = xy - sp_sel_trans_point_desktop(seltrans);
-
-    if (state & GDK_MOD1_MASK) {
-        /* Alt pressed means keep offset: snap the moved distance to the grid */
-        namedview_free_snap(desktop->namedview, Snapper::SNAP_POINT, dxy);
-    } else if ((state & GDK_SHIFT_MASK) == 0) {
-        /* Snap as normal.  Shift-drag will not snap to the grid even if it is enabled. */
-        for (unsigned int dim = 0 ; dim < 2 ; ++dim) {
-            std::pair<NR::Coord, bool> b = namedview_dim_snap_list (desktop->namedview, Snapper::BBOX_POINT, seltrans->bbox_points,
-                                                                    dxy[dim], NR::Dim2(dim));
-            std::pair<NR::Coord, bool> s = namedview_dim_snap_list (desktop->namedview, Snapper::SNAP_POINT, seltrans->snap_points,
-                                                                    dxy[dim], NR::Dim2(dim));
-            
-            /* Pick the snap that puts us closest to the original point */
-            NR::Coord bd = b.second ? fabs(b.first - dxy[dim]) : NR_HUGE;
-            NR::Coord sd = s.second ? fabs(s.first - dxy[dim]) : NR_HUGE;
-            dxy[dim] = (bd < sd) ? b.first : s.first;
-        }
-    }
-
-    /* N.B. If we ever implement angled guides, then we'll want to make sure that the movement
-       respects both the snapped-to guide and the h-or-v constraint implied by control mask.
-       This should be a special case of snapping to h-or-v followed by snapping to whatever
-       real guides there are. */
-    if (state & GDK_CONTROL_MASK) {
-        if ( fabs(dxy[X]) > fabs(dxy[Y]) ) {
-            dxy[Y] = 0.0;
-        } else {
-            dxy[X] = 0.0;
-        }
-    }
-
-    NR::Matrix const move((NR::translate(dxy)));
-    NR::Point const norm(0, 0);
-    sp_sel_trans_transform(seltrans, move, norm);
-
-    // status text
-    GString *xs = SP_PX_TO_METRIC_STRING(dxy[X], desktop->namedview->getDefaultMetric());
-    GString *ys = SP_PX_TO_METRIC_STRING(dxy[Y], desktop->namedview->getDefaultMetric());
-    seltrans->messageContext().setF(Inkscape::NORMAL_MESSAGE, _("<b>Move</b> by %s, %s; with <b>Ctrl</b> to restrict to horizontal/vertical; with <b>Shift</b> to disable snapping"), xs->str, ys->str);
-    g_string_free(xs, TRUE);
-    g_string_free(ys, TRUE);
-}
 
 /*
   Local Variables:
