@@ -53,6 +53,9 @@ void sp_selection_copy();
 void sp_selection_paste(bool in_place);
 void sp_selection_paste_style();
 
+void sp_selection_paste_size(bool apply_x, bool apply_y);
+void sp_selection_paste_size_separately(bool apply_x, bool apply_y);
+
 void sp_selection_to_next_layer ();
 void sp_selection_to_prev_layer ();
 
@@ -87,6 +90,13 @@ void sp_redo (SPDesktop *desktop, SPDocument *doc);
 
 void sp_selection_create_bitmap_copy ();
 
+void sp_selection_set_mask(bool apply_clip_path, bool apply_to_layer);
+void sp_selection_unset_mask(bool apply_clip_path);
+
+void fit_canvas_to_selection(SPDesktop *desktop);
+void fit_canvas_to_drawing(SPDocument *doc);
+void fit_canvas_to_selection_or_drawing(SPDesktop *desktop);
+
 /* selection cycling */
 
 typedef enum
