@@ -18,13 +18,11 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkwindow.h>
-#include <gtk/gtksignal.h>
 
 #include <glibmm/i18n.h>
 #include "document.h"
-#include "sp-text.h"
 #include "svg-view-widget.h"
-#include "ui/view/view.h"
+#include "svg-view.h"
 
 static gint
 sp_slideshow_event (SPViewWidget *vw, GdkEvent *event, GtkWidget *window)
@@ -62,14 +60,14 @@ sp_slideshow_event (SPViewWidget *vw, GdkEvent *event, GtkWidget *window)
 	}
 
 	nname = (const gchar*)g_slist_nth_data (slides, idx);
-	g_print ("Old %s new %s\n", fname, nname);
+//	g_print ("Old %s new %s\n", fname, nname);
 
 	if (nname && (nname != fname)) {
 		SPDocument *doc;
-		g_print ("Trying to load\n");
+		g_print ("Trying to load %s\n", nname);
 		doc = sp_document_new (nname, TRUE);
 		if (doc) {
-			(SP_VIEW_WIDGET_VIEW (vw))->setDocument (doc);
+			reinterpret_cast<SPSVGView*>(SP_VIEW_WIDGET_VIEW (vw))->setDocument (doc);
 			sp_document_unref (doc);
 		}
 		g_object_set_data (G_OBJECT (window), "current", (gpointer) nname);
