@@ -1,21 +1,13 @@
-#include <glib/gmessages.h>
-#include <glib/gstrfuncs.h>
 
 #include "display/curve.h"
 #include "libnr/nr-matrix-div.h"
 #include "libnr/nr-matrix-fns.h"
-#include "libnr/nr-matrix-ops.h"
-#include "libnr/nr-point.h"
-#include "libnr/nr-point-matrix-ops.h"
-#include "libnr/nr-rect.h"
 #include "xml/repr.h"
 #include "sp-conn-end.h"
 #include "sp-path.h"
 #include "uri.h"
 #include "document.h"
 
-#include "libavoid/vertices.h"
-#include "libavoid/connector.h"
 
 static void change_endpts(SPCurve *const curve, NR::Point const h2endPt[2]);
 static NR::Point calc_bbox_conn_pt(NR::Rect const &bbox, NR::Point const &p);
@@ -30,15 +22,6 @@ SPConnEnd::SPConnEnd(SPObject *const owner) :
 {
 }
 
-/* In principle, SPItem is const, but invoke_bbox is currently non-const. */
-static NR::Rect
-get_bbox(SPItem *const item, NR::Matrix const &m)
-{
-    NRRect bbox;
-    sp_item_invoke_bbox(item, &bbox, m, true);
-    return NR::Rect(bbox);
-}
-
 static SPObject const *
 get_nearest_common_ancestor(SPObject const *const obj, SPItem const *const objs[2]) {
     SPObject const *anc_sofar = obj;
@@ -55,11 +38,11 @@ sp_conn_end_move_compensate(NR::Matrix const *mp, SPItem *moved_item,
                             SPPath *const path,
                             bool const updatePathRepr = true)
 {
-    // TODO: sp_item_invoke_bbox gives the wrong result for some objects
+    // TODO: SPItem::invokeBbox gives the wrong result for some objects
     //       that have internal representations that are updated later
     //       by the sp_*_update functions, e.g., text.
     sp_document_ensure_up_to_date(path->document);
-    
+
     // Get the new route around obstacles.
     path->connEndPair.reroutePath();
 
@@ -82,22 +65,24 @@ sp_conn_end_move_compensate(NR::Matrix const *mp, SPItem *moved_item,
         NR::Point h2endPt_icoordsys[2];
         NR::Matrix h2i2anc[2];
         NR::Rect h2bbox_icoordsys[2] = {
-            get_bbox(h2attItem[0], NR::identity()),
-            get_bbox(h2attItem[1], NR::identity())
+            h2attItem[0]->invokeBbox(NR::identity()),
+            h2attItem[1]->invokeBbox(NR::identity())
+        };
+        NR::Point last_seg_endPt[2] = {
+            sp_curve_second_point(path->curve),
+            sp_curve_penultimate_point(path->curve)
         };
         for (unsigned h = 0; h < 2; ++h) {
             h2i2anc[h] = i2anc_affine(h2attItem[h], ancestor);
             h2endPt_icoordsys[h] = h2bbox_icoordsys[h].midpoint();
         }
 
-        /* For each attached object, change the corresponding point to be on the edge of
-         * the bbox. */
+        // For each attached object, change the corresponding point to be
+        // on the edge of the bbox.
         NR::Point h2endPt_pcoordsys[2];
         for (unsigned h = 0; h < 2; ++h) {
             h2endPt_icoordsys[h] = calc_bbox_conn_pt(h2bbox_icoordsys[h],
-                                                     ( h2endPt_icoordsys[!h]
-                                                       * h2i2anc[!h]
-                                                       / h2i2anc[h] ));
+                                         ( last_seg_endPt[h] / h2i2anc[h] ));
             h2endPt_pcoordsys[h] = h2endPt_icoordsys[h] * h2i2anc[h] / path2anc;
         }
         change_endpts(path->curve, h2endPt_pcoordsys);
@@ -105,59 +90,41 @@ sp_conn_end_move_compensate(NR::Matrix const *mp, SPItem *moved_item,
         // We leave the unattached endpoint where it is, and adjust the
         // position of the attached endpoint to be on the edge of the bbox.
         unsigned ind;
-        NR::Point otherpt;
+        NR::Point other_endpt;
+        NR::Point last_seg_pt;
         if (h2attItem[0] != NULL) {
-            otherpt = sp_curve_last_point(path->curve);
+            other_endpt = sp_curve_last_point(path->curve);
+            last_seg_pt = sp_curve_second_point(path->curve);
             ind = 0;
         }
         else {
-            otherpt = sp_curve_first_point(path->curve);
+            other_endpt = sp_curve_first_point(path->curve);
+            last_seg_pt = sp_curve_penultimate_point(path->curve);
             ind = 1;
         }
         NR::Point h2endPt_icoordsys[2];
         NR::Matrix h2i2anc;
 
-        NR::Rect otherpt_rect = NR::Rect(otherpt, otherpt);
+        NR::Rect otherpt_rect = NR::Rect(other_endpt, other_endpt);
         NR::Rect h2bbox_icoordsys[2] = { otherpt_rect, otherpt_rect };
-        h2bbox_icoordsys[ind] = get_bbox(h2attItem[ind], NR::identity());
-        
+        h2bbox_icoordsys[ind] = h2attItem[ind]->invokeBbox(NR::identity());
+
         h2i2anc = i2anc_affine(h2attItem[ind], ancestor);
         h2endPt_icoordsys[ind] = h2bbox_icoordsys[ind].midpoint();
-        
-        h2endPt_icoordsys[!ind] = otherpt;
+
+        h2endPt_icoordsys[!ind] = other_endpt;
 
         // For the attached object, change the corresponding point to be
         // on the edge of the bbox.
         NR::Point h2endPt_pcoordsys[2];
         h2endPt_icoordsys[ind] = calc_bbox_conn_pt(h2bbox_icoordsys[ind],
-                                                 ( h2endPt_icoordsys[!ind]
-                                                   / h2i2anc ));
+                                                 ( last_seg_pt / h2i2anc ));
         h2endPt_pcoordsys[ind] = h2endPt_icoordsys[ind] * h2i2anc / path2anc;
-        
-        // Leave the other where it is.
-        h2endPt_pcoordsys[!ind] = otherpt;
-        
-        change_endpts(path->curve, h2endPt_pcoordsys);
 
-#if 0
-        /* Only one end attached.  Do translate. */
-        unsigned const att_h = ( h2attItem[0] == NULL );
-        SPCurve const *const curve = path->curve;
-        NR::Point const h2oldEndPt_pcoordsys[2] = { sp_curve_first_point(curve),
-                                                    sp_curve_last_point(curve) };
-        NR::Point const dirn_pcoordsys = ( h2oldEndPt_pcoordsys[!att_h] -
-                                           h2oldEndPt_pcoordsys[att_h]   );
-        NR::Matrix const i2anc(i2anc_affine(h2attItem[att_h], ancestor));
-        NR::Point const dirn_icoordsys = ( dirn_pcoordsys
-                                           * NR::transform(path2anc)
-                                           / NR::transform(i2anc) );
-        NR::Rect const bbox_icoordsys(get_bbox(h2attItem[att_h], NR::identity()));
-        NR::Point const ctr_icoordsys = bbox_icoordsys.midpoint();
-        NR::Point const connPt = calc_bbox_conn_pt(bbox_icoordsys,
-                                                ctr_icoordsys + dirn_icoordsys);
-        sp_curve_transform(path->curve,
-                           NR::translate(connPt - h2oldEndPt_pcoordsys[att_h]));
-#endif
+        // Leave the other where it is.
+        h2endPt_pcoordsys[!ind] = other_endpt;
+
+        change_endpts(path->curve, h2endPt_pcoordsys);
     }
     if (updatePathRepr) {
         path->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
@@ -257,7 +224,7 @@ sp_conn_end_deleted(SPObject *, SPObject *const owner, unsigned const handle_ix)
     g_return_if_fail(handle_ix < 2);
     char const *const attr_str[] = {"inkscape:connection-start",
                                     "inkscape:connection-end"};
-    sp_repr_set_attr(SP_OBJECT_REPR(owner), attr_str[handle_ix], NULL);
+    SP_OBJECT_REPR(owner)->setAttribute(attr_str[handle_ix], NULL);
     /* I believe this will trigger sp_conn_end_href_changed. */
 }
 
@@ -269,7 +236,7 @@ sp_conn_end_detach(SPObject *const owner, unsigned const handle_ix)
 
 void
 SPConnEnd::setAttacherHref(gchar const *value)
-{    
+{
     if ( value && href && ( strcmp(value, href) == 0 ) ) {
         /* No change, do nothing. */
     } else {
