@@ -18,12 +18,7 @@
 
 #define noSP_GRADIENT_VERBOSE
 
-#include <math.h>
-#include <string.h>
-#include <stdlib.h>
 
-#include <libnr/nr-gradient.h>
-#include <libnr/nr-matrix.h>
 #include <libnr/nr-matrix-div.h>
 #include <libnr/nr-matrix-fns.h>
 #include <libnr/nr-matrix-ops.h>
@@ -31,31 +26,26 @@
 #include <libnr/nr-matrix-translate-ops.h>
 #include "libnr/nr-scale-translate-ops.h"
 
-#include <gtk/gtksignal.h>
 
 #include "display/nr-gradient-gpl.h"
 #include "svg/svg.h"
+#include "svg/svg-color.h"
 #include "svg/css-ostringstream.h"
 #include "attributes.h"
 #include "document-private.h"
-#include "sp-object-repr.h"
-#include "sp-gradient.h"
 #include "gradient-chemistry.h"
-#include "sp-gradient-fns.h"
 #include "sp-gradient-reference.h"
-#include "sp-gradient-vector.h"
 #include "sp-linear-gradient.h"
 #include "sp-radial-gradient.h"
 #include "sp-stop.h"
 #include "streq.h"
 #include "uri.h"
-#include "uri-references.h"
 #include "xml/repr.h"
 
 #define SP_MACROS_SILENT
 #include "macros.h"
 
-/// Has to be power of 2 
+/// Has to be power of 2
 #define NCOLORS NR_GRADIENT_VECTOR_LENGTH
 
 static void sp_stop_class_init(SPStopClass *klass);
@@ -146,8 +136,8 @@ sp_stop_set(SPObject *object, unsigned key, gchar const *value)
          * We need presentation attributes etc.
          * \par
          * remove the hackish "style reading" from here: see comments in
-         * sp_object_get_style_property about the bugs in our current 
-         * approach.  However, note that SPStyle doesn't currently have 
+         * sp_object_get_style_property about the bugs in our current
+         * approach.  However, note that SPStyle doesn't currently have
          * stop-color and stop-opacity properties.
          */
             {
@@ -155,7 +145,7 @@ sp_stop_set(SPObject *object, unsigned key, gchar const *value)
                 if (streq(p, "currentColor")) {
                     stop->currentColor = true;
                 } else {
-                    guint32 const color = sp_svg_read_color(p, 0);                    
+                    guint32 const color = sp_svg_read_color(p, 0);
                     sp_color_set_rgb_rgba32(&stop->specified_color, color);
                 }
             }
@@ -226,9 +216,9 @@ sp_stop_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
         os << c;
     }
     os << ";stop-opacity:" << stop->opacity;
-    sp_repr_set_attr(repr, "style", os.str().c_str());
-    sp_repr_set_attr(repr, "stop-color", NULL);
-    sp_repr_set_attr(repr, "stop-opacity", NULL);
+    repr->setAttribute("style", os.str().c_str());
+    repr->setAttribute("stop-color", NULL);
+    repr->setAttribute("stop-opacity", NULL);
     sp_repr_set_css_double(repr, "offset", stop->offset);
     /* strictly speaking, offset an SVG <number> rather than a CSS one, but exponents make no sense
      * for offset proportions. */
@@ -638,25 +628,25 @@ sp_gradient_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
             if (crepr) l = g_slist_prepend(l, crepr);
         }
         while (l) {
-            sp_repr_add_child(repr, (Inkscape::XML::Node *) l->data, NULL);
-            sp_repr_unref((Inkscape::XML::Node *) l->data);
+            repr->addChild((Inkscape::XML::Node *) l->data, NULL);
+            Inkscape::GC::release((Inkscape::XML::Node *) l->data);
             l = g_slist_remove(l, l->data);
         }
     }
 
     if (gr->ref->getURI()) {
         gchar *uri_string = gr->ref->getURI()->toString();
-        sp_repr_set_attr(repr, "xlink:href", uri_string);
+        repr->setAttribute("xlink:href", uri_string);
         g_free(uri_string);
     }
 
     if ((flags & SP_OBJECT_WRITE_ALL) || gr->units_set) {
         switch (gr->units) {
             case SP_GRADIENT_UNITS_USERSPACEONUSE:
-                sp_repr_set_attr(repr, "gradientUnits", "userSpaceOnUse");
+                repr->setAttribute("gradientUnits", "userSpaceOnUse");
                 break;
             default:
-                sp_repr_set_attr(repr, "gradientUnits", "objectBoundingBox");
+                repr->setAttribute("gradientUnits", "objectBoundingBox");
                 break;
         }
     }
@@ -664,9 +654,9 @@ sp_gradient_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
     if ((flags & SP_OBJECT_WRITE_ALL) || gr->gradientTransform_set) {
         gchar c[256];
         if (sp_svg_transform_write(c, 256, gr->gradientTransform)) {
-            sp_repr_set_attr(repr, "gradientTransform", c);
+            repr->setAttribute("gradientTransform", c);
         } else {
-            sp_repr_set_attr(repr, "gradientTransform", NULL);
+            repr->setAttribute("gradientTransform", NULL);
         }
     }
 
@@ -676,13 +666,13 @@ sp_gradient_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
          */
         switch (gr->spread) {
             case SP_GRADIENT_SPREAD_REFLECT:
-                sp_repr_set_attr(repr, "spreadMethod", "reflect");
+                repr->setAttribute("spreadMethod", "reflect");
                 break;
             case SP_GRADIENT_SPREAD_REPEAT:
-                sp_repr_set_attr(repr, "spreadMethod", "repeat");
+                repr->setAttribute("spreadMethod", "repeat");
                 break;
             default:
-                sp_repr_set_attr(repr, "spreadMethod", "pad");
+                repr->setAttribute("spreadMethod", "pad");
                 break;
         }
     }
@@ -855,7 +845,7 @@ sp_gradient_repr_clear_vector(SPGradient *gr)
 }
 
 /**
- * Writes the gradient's internal vector (whether from its own stops, or 
+ * Writes the gradient's internal vector (whether from its own stops, or
  * inherited from refs) into the gradient repr as svg:stop elements.
  */
 void
@@ -878,7 +868,7 @@ sp_gradient_repr_write_vector(SPGradient *gr)
         gchar c[64];
         sp_svg_write_color(c, 64, sp_color_get_rgba32_ualpha(&gr->vector.stops[i].color, 0x00));
         os << "stop-color:" << c << ";stop-opacity:" << gr->vector.stops[i].opacity;
-        sp_repr_set_attr(child, "style", os.str().c_str());
+        child->setAttribute("style", os.str().c_str());
         /* Order will be reversed here */
         cl = g_slist_prepend(cl, child);
     }
@@ -888,8 +878,8 @@ sp_gradient_repr_write_vector(SPGradient *gr)
     /* And insert new children from list */
     while (cl) {
         Inkscape::XML::Node *child = static_cast<Inkscape::XML::Node *>(cl->data);
-        sp_repr_add_child(repr, child, NULL);
-        sp_repr_unref(child);
+        repr->addChild(child, NULL);
+        Inkscape::GC::release(child);
         cl = g_slist_remove(cl, child);
     }
 }
@@ -1084,7 +1074,7 @@ sp_gradient_ensure_colors(SPGradient *gr)
 
 /**
  * Renders gradient vector to buffer as line.
- * 
+ *
  * RGB buffer background should be set up beforehand.
  *
  * @param len,width,height,rowstride Buffer parameters (1 or 2 dimensional).
@@ -1160,7 +1150,7 @@ sp_gradient_render_vector_block_rgba(SPGradient *const gradient, guchar *buf,
 
 /**
  * Render rectangular RGB area from gradient vector.
- */ 
+ */
 void
 sp_gradient_render_vector_block_rgb(SPGradient *gradient, guchar *buf,
                                     gint const width, gint const height, gint const rowstride,
@@ -1330,10 +1320,10 @@ static void sp_lineargradient_class_init(SPLinearGradientClass *klass)
  */
 static void sp_lineargradient_init(SPLinearGradient *lg)
 {
-    sp_svg_length_unset(&lg->x1, SP_SVG_UNIT_PERCENT, 0.0, 0.0);
-    sp_svg_length_unset(&lg->y1, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
-    sp_svg_length_unset(&lg->x2, SP_SVG_UNIT_PERCENT, 1.0, 1.0);
-    sp_svg_length_unset(&lg->y2, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
+    lg->x1.unset(SVGLength::PERCENT, 0.0, 0.0);
+    lg->y1.unset(SVGLength::PERCENT, 0.5, 0.5);
+    lg->x2.unset(SVGLength::PERCENT, 1.0, 1.0);
+    lg->y2.unset(SVGLength::PERCENT, 0.5, 0.5);
 }
 
 /**
@@ -1362,27 +1352,19 @@ sp_lineargradient_set(SPObject *object, unsigned key, gchar const *value)
 
     switch (key) {
         case SP_ATTR_X1:
-            if (!sp_svg_length_read(value, &lg->x1)) {
-                sp_svg_length_unset(&lg->x1, SP_SVG_UNIT_PERCENT, 0.0, 0.0);
-            }
+            lg->x1.readOrUnset(value, SVGLength::PERCENT, 0.0, 0.0);
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
         case SP_ATTR_Y1:
-            if (!sp_svg_length_read(value, &lg->y1)) {
-                sp_svg_length_unset(&lg->y1, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
-            }
+            lg->y1.readOrUnset(value, SVGLength::PERCENT, 0.5, 0.5);
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
         case SP_ATTR_X2:
-            if (!sp_svg_length_read(value, &lg->x2)) {
-                sp_svg_length_unset(&lg->x2, SP_SVG_UNIT_PERCENT, 1.0, 1.0);
-            }
+            lg->x2.readOrUnset(value, SVGLength::PERCENT, 1.0, 1.0);
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
         case SP_ATTR_Y2:
-            if (!sp_svg_length_read(value, &lg->y2)) {
-                sp_svg_length_unset(&lg->y2, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
-            }
+            lg->y2.readOrUnset(value, SVGLength::PERCENT, 0.5, 0.5);
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
         default:
@@ -1404,13 +1386,13 @@ sp_lineargradient_write(SPObject *object, Inkscape::XML::Node *repr, guint flags
         repr = sp_repr_new("svg:linearGradient");
     }
 
-    if ((flags & SP_OBJECT_WRITE_ALL) || lg->x1.set)
+    if ((flags & SP_OBJECT_WRITE_ALL) || lg->x1._set)
         sp_repr_set_svg_double(repr, "x1", lg->x1.computed);
-    if ((flags & SP_OBJECT_WRITE_ALL) || lg->y1.set)
+    if ((flags & SP_OBJECT_WRITE_ALL) || lg->y1._set)
         sp_repr_set_svg_double(repr, "y1", lg->y1.computed);
-    if ((flags & SP_OBJECT_WRITE_ALL) || lg->x2.set)
+    if ((flags & SP_OBJECT_WRITE_ALL) || lg->x2._set)
         sp_repr_set_svg_double(repr, "x2", lg->x2.computed);
-    if ((flags & SP_OBJECT_WRITE_ALL) || lg->y2.set)
+    if ((flags & SP_OBJECT_WRITE_ALL) || lg->y2._set)
         sp_repr_set_svg_double(repr, "y2", lg->y2.computed);
 
     if (((SPObjectClass *) lg_parent_class)->write)
@@ -1421,7 +1403,7 @@ sp_lineargradient_write(SPObject *object, Inkscape::XML::Node *repr, guint flags
 
 /**
  * Create linear gradient context.
- * 
+ *
  * Basically we have to deal with transformations
  *
  * 1) color2norm - maps point in (0,NCOLORS) vector to (0,1) vector
@@ -1429,10 +1411,10 @@ sp_lineargradient_write(SPObject *object, Inkscape::XML::Node *repr, guint flags
  * 2) gradientTransform
  * 3) bbox2user
  * 4) ctm == userspace to pixel grid
- * 
+ *
  * See also (*) in sp-pattern about why we may need parent_transform.
- * 
- * \todo (point 1 above) fixme: I do not know how to deal with start > 0 
+ *
+ * \todo (point 1 above) fixme: I do not know how to deal with start > 0
  * and end < 1.
  */
 static SPPainter *
@@ -1454,10 +1436,10 @@ sp_lineargradient_painter_new(SPPaintServer *ps,
     lgp->lg = lg;
 
     /** \todo
-     * Technically speaking, we map NCOLORS on line [start,end] onto line 
-     * [0,1].  I almost think we should fill color array start and end in 
-     * that case. The alternative would be to leave these just empty garbage 
-     * or something similar. Originally I had 1023.9999 here - not sure 
+     * Technically speaking, we map NCOLORS on line [start,end] onto line
+     * [0,1].  I almost think we should fill color array start and end in
+     * that case. The alternative would be to leave these just empty garbage
+     * or something similar. Originally I had 1023.9999 here - not sure
      * whether we have really to cut out ceil int (Lauris).
      */
     NR::Matrix color2norm(NR::identity());
@@ -1512,10 +1494,10 @@ sp_lineargradient_set_position(SPLinearGradient *lg,
     g_return_if_fail(SP_IS_LINEARGRADIENT(lg));
 
     /* fixme: units? (Lauris)  */
-    sp_svg_length_set(&lg->x1, SP_SVG_UNIT_NONE, x1, x1);
-    sp_svg_length_set(&lg->y1, SP_SVG_UNIT_NONE, y1, y1);
-    sp_svg_length_set(&lg->x2, SP_SVG_UNIT_NONE, x2, x2);
-    sp_svg_length_set(&lg->y2, SP_SVG_UNIT_NONE, y2, y2);
+    lg->x1.set(SVGLength::NONE, x1, x1);
+    lg->y1.set(SVGLength::NONE, y1, y1);
+    lg->x2.set(SVGLength::NONE, x2, x2);
+    lg->y2.set(SVGLength::NONE, y2, y2);
 
     SP_OBJECT(lg)->requestModified(SP_OBJECT_MODIFIED_FLAG);
 }
@@ -1616,11 +1598,11 @@ static void sp_radialgradient_class_init(SPRadialGradientClass *klass)
 static void
 sp_radialgradient_init(SPRadialGradient *rg)
 {
-    sp_svg_length_unset(&rg->cx, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
-    sp_svg_length_unset(&rg->cy, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
-    sp_svg_length_unset(&rg->r, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
-    sp_svg_length_unset(&rg->fx, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
-    sp_svg_length_unset(&rg->fy, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
+    rg->cx.unset(SVGLength::PERCENT, 0.5, 0.5);
+    rg->cy.unset(SVGLength::PERCENT, 0.5, 0.5);
+    rg->r.unset(SVGLength::PERCENT, 0.5, 0.5);
+    rg->fx.unset(SVGLength::PERCENT, 0.5, 0.5);
+    rg->fy.unset(SVGLength::PERCENT, 0.5, 0.5);
 }
 
 /**
@@ -1649,40 +1631,40 @@ sp_radialgradient_set(SPObject *object, unsigned key, gchar const *value)
 
     switch (key) {
         case SP_ATTR_CX:
-            if (!sp_svg_length_read(value, &rg->cx)) {
-                sp_svg_length_unset(&rg->cx, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
+            if (!rg->cx.read(value)) {
+                rg->cx.unset(SVGLength::PERCENT, 0.5, 0.5);
             }
-            if (!rg->fx.set) {
+            if (!rg->fx._set) {
                 rg->fx.value = rg->cx.value;
                 rg->fx.computed = rg->cx.computed;
             }
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
         case SP_ATTR_CY:
-            if (!sp_svg_length_read(value, &rg->cy)) {
-                sp_svg_length_unset(&rg->cy, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
+            if (!rg->cy.read(value)) {
+                rg->cy.unset(SVGLength::PERCENT, 0.5, 0.5);
             }
-            if (!rg->fy.set) {
+            if (!rg->fy._set) {
                 rg->fy.value = rg->cy.value;
                 rg->fy.computed = rg->cy.computed;
             }
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
         case SP_ATTR_R:
-            if (!sp_svg_length_read(value, &rg->r)) {
-                sp_svg_length_unset(&rg->r, SP_SVG_UNIT_PERCENT, 0.5, 0.5);
+            if (!rg->r.read(value)) {
+                rg->r.unset(SVGLength::PERCENT, 0.5, 0.5);
             }
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
         case SP_ATTR_FX:
-            if (!sp_svg_length_read(value, &rg->fx)) {
-                sp_svg_length_unset(&rg->fx, rg->cx.unit, rg->cx.value, rg->cx.computed);
+            if (!rg->fx.read(value)) {
+                rg->fx.unset(rg->cx.unit, rg->cx.value, rg->cx.computed);
             }
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
         case SP_ATTR_FY:
-            if (!sp_svg_length_read(value, &rg->fy)) {
-                sp_svg_length_unset(&rg->fy, rg->cy.unit, rg->cy.value, rg->cy.computed);
+            if (!rg->fy.read(value)) {
+                rg->fy.unset(rg->cy.unit, rg->cy.value, rg->cy.computed);
             }
             object->requestModified(SP_OBJECT_MODIFIED_FLAG);
             break;
@@ -1705,11 +1687,11 @@ sp_radialgradient_write(SPObject *object, Inkscape::XML::Node *repr, guint flags
         repr = sp_repr_new("svg:radialGradient");
     }
 
-    if ((flags & SP_OBJECT_WRITE_ALL) || rg->cx.set) sp_repr_set_svg_double(repr, "cx", rg->cx.computed);
-    if ((flags & SP_OBJECT_WRITE_ALL) || rg->cy.set) sp_repr_set_svg_double(repr, "cy", rg->cy.computed);
-    if ((flags & SP_OBJECT_WRITE_ALL) || rg->r.set) sp_repr_set_svg_double(repr, "r", rg->r.computed);
-    if ((flags & SP_OBJECT_WRITE_ALL) || rg->fx.set) sp_repr_set_svg_double(repr, "fx", rg->fx.computed);
-    if ((flags & SP_OBJECT_WRITE_ALL) || rg->fy.set) sp_repr_set_svg_double(repr, "fy", rg->fy.computed);
+    if ((flags & SP_OBJECT_WRITE_ALL) || rg->cx._set) sp_repr_set_svg_double(repr, "cx", rg->cx.computed);
+    if ((flags & SP_OBJECT_WRITE_ALL) || rg->cy._set) sp_repr_set_svg_double(repr, "cy", rg->cy.computed);
+    if ((flags & SP_OBJECT_WRITE_ALL) || rg->r._set) sp_repr_set_svg_double(repr, "r", rg->r.computed);
+    if ((flags & SP_OBJECT_WRITE_ALL) || rg->fx._set) sp_repr_set_svg_double(repr, "fx", rg->fx.computed);
+    if ((flags & SP_OBJECT_WRITE_ALL) || rg->fy._set) sp_repr_set_svg_double(repr, "fy", rg->fy.computed);
 
     if (((SPObjectClass *) rg_parent_class)->write)
         (* ((SPObjectClass *) rg_parent_class)->write)(object, repr, flags);
@@ -1742,7 +1724,7 @@ sp_radialgradient_painter_new(SPPaintServer *ps,
 
     if (gr->units == SP_GRADIENT_UNITS_OBJECTBOUNDINGBOX) {
         /** \todo
-         * fixme: We may try to normalize here too, look at 
+         * fixme: We may try to normalize here too, look at
          * linearGradient (Lauris)
          */
 
@@ -1755,7 +1737,7 @@ sp_radialgradient_painter_new(SPPaintServer *ps,
     } else {
         /** \todo
          * Problem: What to do, if we have mixed lengths and percentages?
-         * Currently we do ignore percentages at all, but that is not 
+         * Currently we do ignore percentages at all, but that is not
          * good (lauris)
          */
 
@@ -1791,11 +1773,11 @@ sp_radialgradient_set_position(SPRadialGradient *rg,
     g_return_if_fail(SP_IS_RADIALGRADIENT(rg));
 
     /* fixme: units? (Lauris)  */
-    sp_svg_length_set(&rg->cx, SP_SVG_UNIT_NONE, cx, cx);
-    sp_svg_length_set(&rg->cy, SP_SVG_UNIT_NONE, cy, cy);
-    sp_svg_length_set(&rg->fx, SP_SVG_UNIT_NONE, fx, fx);
-    sp_svg_length_set(&rg->fy, SP_SVG_UNIT_NONE, fy, fy);
-    sp_svg_length_set(&rg->r, SP_SVG_UNIT_NONE, r, r);
+    rg->cx.set(SVGLength::NONE, cx, cx);
+    rg->cy.set(SVGLength::NONE, cy, cy);
+    rg->fx.set(SVGLength::NONE, fx, fx);
+    rg->fy.set(SVGLength::NONE, fy, fy);
+    rg->r.set(SVGLength::NONE, r, r);
 
     SP_OBJECT(rg)->requestModified(SP_OBJECT_MODIFIED_FLAG);
 }
