@@ -11,9 +11,7 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <string.h>
 
-#include <libnr/nr-matrix.h>
 #include "display/nr-arena.h"
 #include "display/nr-arena-group.h"
 #include <xml/repr.h>
@@ -21,6 +19,7 @@
 #include "enums.h"
 #include "attributes.h"
 #include "document.h"
+#include "document-private.h"
 #include "sp-item.h"
 
 #include "sp-mask.h"
@@ -89,8 +88,8 @@ sp_mask_init (SPMask *mask)
 	mask->maskUnits_set = FALSE;
 	mask->maskUnits = SP_CONTENT_UNITS_OBJECTBOUNDINGBOX;
 
-	mask->maskUnits_set = FALSE;
-	mask->maskUnits = SP_CONTENT_UNITS_USERSPACEONUSE;
+	mask->maskContentUnits_set = FALSE;
+	mask->maskContentUnits = SP_CONTENT_UNITS_USERSPACEONUSE;
 
 	mask->display = NULL;
 }
@@ -119,7 +118,7 @@ sp_mask_release (SPObject * object)
 
 	SPMask *cp = SP_MASK (object);
 	while (cp->display) {
-		/* We simply unref and let item to manage this in handler */
+		/* We simply unref and let item manage this in handler */
 		cp->display = sp_mask_view_list_remove (cp->display, cp->display);
 	}
 
@@ -268,6 +267,36 @@ sp_mask_write (SPObject *object, Inkscape::XML::Node *repr, guint flags)
 	return repr;
 }
 
+// Create a mask element (using passed elements), add it to <defs>
+const gchar *
+sp_mask_create (GSList *reprs, SPDocument *document, NR::Matrix const* applyTransform)
+{
+    Inkscape::XML::Node *defsrepr = SP_OBJECT_REPR (SP_DOCUMENT_DEFS (document));
+
+    Inkscape::XML::Node *repr = sp_repr_new ("svg:mask");
+    repr->setAttribute("maskUnits", "userSpaceOnUse");
+    
+    defsrepr->appendChild(repr);
+    const gchar *mask_id = repr->attribute("id");
+    SPObject *mask_object = document->getObjectById(mask_id);
+    
+    for (GSList *it = reprs; it != NULL; it = it->next) {
+        Inkscape::XML::Node *node = (Inkscape::XML::Node *)(it->data);
+        SPItem *item = SP_ITEM(mask_object->appendChildRepr(node));
+        
+        if (NULL != applyTransform) {
+            NR::Matrix transform (item->transform);
+            transform *= (*applyTransform);
+            sp_item_write_transform(item, SP_OBJECT_REPR(item), transform);
+        }
+    }
+
+    defsrepr->changeOrder(repr, defsrepr->lastChild()); // workaround for bug 989084
+    
+    Inkscape::GC::release(repr);
+    return mask_id;
+}
+
 NRArenaItem *
 sp_mask_show (SPMask *mask, NRArena *arena, unsigned int key)
 {
@@ -334,7 +363,6 @@ sp_mask_set_bbox (SPMask *mask, unsigned int key, NRRect *bbox)
 			    !NR_DF_TEST_CLOSE (v->bbox.x1, bbox->x1, NR_EPSILON) ||
 			    !NR_DF_TEST_CLOSE (v->bbox.y1, bbox->y1, NR_EPSILON)) {
 				v->bbox = *bbox;
-				SP_OBJECT(mask)->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
 			}
 			break;
 		}
@@ -375,3 +403,13 @@ sp_mask_view_list_remove (SPMaskView *list, SPMaskView *view)
 	return list;
 }
 
+/*
+  Local Variables:
+  mode:c++
+  c-file-style:"stroustrup"
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
+  indent-tabs-mode:nil
+  fill-column:99
+  End:
+*/
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
