@@ -13,7 +13,6 @@
  */
 
 #include "sp-object-group.h"
-#include "sp-object-repr.h"
 #include "xml/repr.h"
 
 static void sp_objectgroup_class_init (SPObjectGroupClass *klass);
@@ -115,8 +114,8 @@ sp_objectgroup_write (SPObject *object, Inkscape::XML::Node *repr, guint flags)
 			if (crepr) l = g_slist_prepend (l, crepr);
 		}
 		while (l) {
-			sp_repr_add_child (repr, (Inkscape::XML::Node *) l->data, NULL);
-			sp_repr_unref ((Inkscape::XML::Node *) l->data);
+			repr->addChild((Inkscape::XML::Node *) l->data, NULL);
+			Inkscape::GC::release((Inkscape::XML::Node *) l->data);
 			l = g_slist_remove (l, l->data);
 		}
 	} else {
