@@ -11,15 +11,11 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "document.h"
-#include "sp-item.h"
 #include "sp-defs.h"
 #include "sp-symbol.h"
 #include "sp-marker.h"
 #include "sp-use.h"
 #include "sp-root.h"
-#include "sp-namedview.h"
-#include "sp-guide.h"
 #include "sp-image.h"
 #include "sp-linear-gradient-fns.h"
 #include "sp-path.h"
@@ -33,8 +29,7 @@
 #include "sp-line.h"
 #include "sp-metadata.h"
 #include "sp-polyline.h"
-#include "sp-polygon.h"
-#include "sp-text.h"
+#include "sp-textpath.h"
 #include "sp-tspan.h"
 #include "sp-pattern.h"
 #include "sp-clippath.h"
@@ -44,8 +39,9 @@
 #include "sp-flowdiv.h"
 #include "sp-flowregion.h"
 #include "sp-flowtext.h"
-#include "sp-object-repr.h"
 #include "sp-style-elem.h"
+#include "sp-switch.h"
+#include "color-profile-fns.h"
 #include "xml/repr.h"
 
 enum NameType { REPR_NAME, SODIPODI_TYPE };
@@ -100,6 +96,7 @@ populate_dtables()
         { "svg:a", SP_TYPE_ANCHOR },
         //{ "svg:animate", SP_TYPE_ANIMATE },
         { "svg:circle", SP_TYPE_CIRCLE },
+        { "svg:color-profile", COLORPROFILE_TYPE },
         { "svg:clipPath", SP_TYPE_CLIPPATH },
         { "svg:defs", SP_TYPE_DEFS },
         { "svg:ellipse", SP_TYPE_ELLIPSE },
@@ -129,7 +126,7 @@ populate_dtables()
         { "svg:stop", SP_TYPE_STOP },
         { "svg:svg", SP_TYPE_ROOT },
         { "svg:style", SP_TYPE_STYLE_ELEM },
-        { "svg:switch", SP_TYPE_GROUP },
+        { "svg:switch", SP_TYPE_SWITCH },
         { "svg:symbol", SP_TYPE_SYMBOL },
         { "svg:text", SP_TYPE_TEXT },
         { "svg:textPath", SP_TYPE_TEXTPATH },
