@@ -287,6 +287,10 @@ struct SPObject : public GObject {
         }
     }
 
+    /** @brief Check if object is referenced by any other object.
+     */
+    bool isReferenced() { return ( _total_hrefcount > 0 ); }
+
     /** @brief Deletes an object.
      *
      * Detaches the object's repr, and optionally sends notification that the object has been
@@ -322,6 +326,10 @@ struct SPObject : public GObject {
         return _delete_signal.connect(slot);
     }
 
+    sigc::connection connectPositionChanged(sigc::slot<void, SPObject *> slot) {
+        return _position_changed_signal.connect(slot);
+    }
+
     /** @brief Returns the object which supercedes this one (if any).
      *
      * This is mainly useful for ensuring we can correctly perform a series of moves or deletes,
@@ -442,6 +450,7 @@ struct SPObject : public GObject {
     void _requireSVGVersion(Inkscape::Version version);
 
     sigc::signal<void, SPObject *> _delete_signal;
+    sigc::signal<void, SPObject *> _position_changed_signal;
     SPObject *_successor;
     CollectionPolicy _collection_policy;
     gchar *_label;
