@@ -19,14 +19,10 @@
 # include "config.h"
 #endif
 
-#include <math.h>
-#include <string.h>
-#include <stdlib.h>
 
 #include "svg/svg.h"
 #include "attributes.h"
 #include "display/curve.h"
-#include "dialogs/object-attributes.h"
 #include <glibmm/i18n.h>
 
 #include "livarot/Path.h"
@@ -35,18 +31,12 @@
 #include "enums.h"
 #include "prefs-utils.h"
 #include "sp-text.h"
-#include "sp-shape.h"
 #include "sp-offset.h"
 #include "sp-use-reference.h"
 #include "uri.h"
 
 #include "libnr/n-art-bpath.h"
-#include "libnr/nr-point.h"
-#include <libnr/nr-point-fns.h>
-#include <libnr/nr-point-ops.h>
-#include <libnr/nr-matrix.h>
 #include <libnr/nr-matrix-fns.h>
-#include <libnr/nr-matrix-ops.h>
 
 #include "xml/repr.h"
 
@@ -56,24 +46,24 @@ class SPDocument;
 
 /** \note
  * SPOffset is a derivative of SPShape, much like the SPSpiral or SPRect.
- * The goal is to have a source shape (= originalPath), an offset (= radius) 
- * and compute the offset of the source by the radius. To get it to work, 
- * one needs to know what the source is and what the radius is, and how it's 
- * stored in the xml representation. The object itself is a "path" element, 
- * to get lots of shape functionality for free. The source is the easy part: 
- * it's stored in a "inkscape:original" attribute in the path. In case of 
+ * The goal is to have a source shape (= originalPath), an offset (= radius)
+ * and compute the offset of the source by the radius. To get it to work,
+ * one needs to know what the source is and what the radius is, and how it's
+ * stored in the xml representation. The object itself is a "path" element,
+ * to get lots of shape functionality for free. The source is the easy part:
+ * it's stored in a "inkscape:original" attribute in the path. In case of
  * "linked" offset, as they've been dubbed, there is an additional
- * "inkscape:href" that contains the id of an element of the svg. 
- * When built, the object will attach a listener vector to that object and 
- * rebuild the "inkscape:original" whenever the href'd object changes. This 
- * is of course grossly inefficient, and also does not react to changes 
- * to the href'd during context stuff (like changing the shape of a star by 
- * dragging control points) unless the path of that object is changed during 
- * the context (seems to be the case for SPEllipse). The computation of the 
- * offset is done in sp_offset_set_shape(), a function that is called whenever 
+ * "inkscape:href" that contains the id of an element of the svg.
+ * When built, the object will attach a listener vector to that object and
+ * rebuild the "inkscape:original" whenever the href'd object changes. This
+ * is of course grossly inefficient, and also does not react to changes
+ * to the href'd during context stuff (like changing the shape of a star by
+ * dragging control points) unless the path of that object is changed during
+ * the context (seems to be the case for SPEllipse). The computation of the
+ * offset is done in sp_offset_set_shape(), a function that is called whenever
  * a change occurs to the offset (change of source or change of radius).
- * just like the sp-star and other, this path derivative can make control 
- * points, or more precisely one control point, that's enough to define the 
+ * just like the sp-star and other, this path derivative can make control
+ * points, or more precisely one control point, that's enough to define the
  * radius (look in object-edit).
  */
 
@@ -109,7 +99,7 @@ static void sp_offset_source_modified (SPObject *iSource, guint flags, SPItem *i
 // slow= source path->polygon->offset of polygon->polygon->path
 // fast= source path->offset of source path->polygon->path
 // fast is not mathematically correct, because computing the offset of a single
-// cubic bezier patch is not trivial; in particular, there are problems with holes 
+// cubic bezier patch is not trivial; in particular, there are problems with holes
 // reappearing in offset when the radius becomes too large
 static bool   use_slow_but_correct_offset_method=false;
 
@@ -124,7 +114,7 @@ GType
 sp_offset_get_type (void)
 {
     static GType offset_type = 0;
-  
+
     if (!offset_type)
     {
         GTypeInfo offset_info = {
@@ -156,9 +146,9 @@ sp_offset_class_init(SPOffsetClass *klass)
     SPObjectClass *sp_object_class = (SPObjectClass *) klass;
     SPItemClass   *item_class = (SPItemClass *) klass;
     SPShapeClass  *shape_class = (SPShapeClass *) klass;
-  
+
     parent_class = (SPShapeClass *) g_type_class_ref (SP_TYPE_SHAPE);
-  
+
     gobject_class->finalize = sp_offset_finalize;
 
     sp_object_class->build = sp_offset_build;
@@ -166,10 +156,10 @@ sp_offset_class_init(SPOffsetClass *klass)
     sp_object_class->set = sp_offset_set;
     sp_object_class->update = sp_offset_update;
     sp_object_class->release = sp_offset_release;
-  
+
     item_class->description = sp_offset_description;
     item_class->snappoints = sp_offset_snappoints;
-  
+
     shape_class->set_shape = sp_offset_set_shape;
 }
 
@@ -204,7 +194,7 @@ static void
 sp_offset_finalize(GObject *obj)
 {
     SPOffset *offset = (SPOffset *) obj;
-	
+
     delete offset->sourceRef;
     offset->_delete_connection.~connection();
     offset->_changed_connection.~connection();
@@ -219,22 +209,22 @@ sp_offset_build(SPObject *object, SPDocument *document, Inkscape::XML::Node *rep
 {
     if (((SPObjectClass *) parent_class)->build)
         ((SPObjectClass *) parent_class)->build (object, document, repr);
-  
+
     if (object->repr->attribute("inkscape:radius")) {
         sp_object_read_attr (object, "inkscape:radius");
     } else {
         gchar const *oldA = object->repr->attribute("sodipodi:radius");
-        sp_repr_set_attr(object->repr,"inkscape:radius",oldA);
-        sp_repr_set_attr(object->repr,"sodipodi:radius",NULL);
-    
+        object->repr->setAttribute("inkscape:radius",oldA);
+        object->repr->setAttribute("sodipodi:radius",NULL);
+
         sp_object_read_attr (object, "inkscape:radius");
     }
     if (object->repr->attribute("inkscape:original")) {
         sp_object_read_attr (object, "inkscape:original");
-    } else {    
+    } else {
         gchar const *oldA = object->repr->attribute("sodipodi:original");
-        sp_repr_set_attr(object->repr,"inkscape:original",oldA);
-        sp_repr_set_attr(object->repr,"sodipodi:original",NULL);
+        object->repr->setAttribute("inkscape:original",oldA);
+        object->repr->setAttribute("sodipodi:original",NULL);
 
         sp_object_read_attr (object, "inkscape:original");
     }
@@ -248,9 +238,9 @@ sp_offset_build(SPObject *object, SPDocument *document, Inkscape::XML::Node *rep
             memcpy(nA+1,oldA,lA*sizeof(char));
             nA[0]='#';
             nA[lA+1]=0;
-            sp_repr_set_attr(object->repr,"xlink:href",nA);
+            object->repr->setAttribute("xlink:href",nA);
             free(nA);
-            sp_repr_set_attr(object->repr,"inkscape:href",NULL);
+            object->repr->setAttribute("inkscape:href",NULL);
         }
         sp_object_read_attr (object, "xlink:href");
     }
@@ -263,38 +253,38 @@ static Inkscape::XML::Node *
 sp_offset_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
 {
     SPOffset *offset = SP_OFFSET (object);
-  
+
     if ((flags & SP_OBJECT_WRITE_BUILD) && !repr) {
         repr = sp_repr_new ("svg:path");
     }
-  
+
     if (flags & SP_OBJECT_WRITE_EXT) {
         /** \todo
          * Fixme: we may replace these attributes by
          * inkscape:offset="cx cy exp revo rad arg t0"
          */
-        sp_repr_set_attr (repr, "sodipodi:type", "inkscape:offset");
+        repr->setAttribute("sodipodi:type", "inkscape:offset");
         sp_repr_set_svg_double(repr, "inkscape:radius", offset->rad);
-        sp_repr_set_attr (repr, "inkscape:original", offset->original);
-        sp_repr_set_attr (repr, "inkscape:href", offset->sourceHref);
+        repr->setAttribute("inkscape:original", offset->original);
+        repr->setAttribute("inkscape:href", offset->sourceHref);
     }
 
 
-    // Make sure the object has curve 
+    // Make sure the object has curve
     SPCurve *curve = sp_shape_get_curve (SP_SHAPE (offset));
     if (curve == NULL) {
         sp_offset_set_shape (SP_SHAPE (offset));
     }
 
     // write that curve to "d"
-    char *d = sp_svg_write_path (((SPShape *) offset)->curve->bpath);
-    sp_repr_set_attr (repr, "d", d);
+    char *d = sp_svg_write_path (SP_CURVE_BPATH(((SPShape *) offset)->curve));
+    repr->setAttribute("d", d);
     g_free (d);
-  
+
     if (((SPObjectClass *) (parent_class))->write)
         ((SPObjectClass *) (parent_class))->write (object, repr,
                                                    flags | SP_SHAPE_WRITE_PATH);
-  
+
     return repr;
 }
 
@@ -305,36 +295,36 @@ static void
 sp_offset_release(SPObject *object)
 {
     SPOffset *offset = (SPOffset *) object;
-  
+
     if (offset->original) free (offset->original);
     if (offset->originalPath) delete ((Path *) offset->originalPath);
     offset->original = NULL;
     offset->originalPath = NULL;
-  
+
     sp_offset_quit_listening(offset);
-	
+
     offset->_changed_connection.disconnect();
     g_free(offset->sourceHref);
     offset->sourceHref = NULL;
     offset->sourceRef->detach();
-    
+
     if (((SPObjectClass *) parent_class)->release) {
         ((SPObjectClass *) parent_class)->release (object);
     }
-  
+
 }
 
 /**
- * Set callback: the function that is called whenever a change is made to 
+ * Set callback: the function that is called whenever a change is made to
  * the description of the object.
  */
 static void
 sp_offset_set(SPObject *object, unsigned key, gchar const *value)
 {
     SPOffset *offset = SP_OFFSET (object);
-  
+
     if ( offset->sourceDirty ) refresh_offset_source(offset);
-  
+
     /* fixme: we should really collect updates */
     switch (key)
     {
@@ -350,15 +340,15 @@ sp_offset_set(SPObject *object, unsigned key, gchar const *value)
                 }
                 NArtBpath *bpath;
                 SPCurve *curve;
-        
+
                 offset->original = strdup (value);
-        
+
                 bpath = sp_svg_read_path (offset->original);
                 curve = sp_curve_new_from_bpath (bpath);	// curve se chargera de detruire bpath
                 g_assert (curve != NULL);
-                offset->originalPath = bpath_to_liv_path (curve->bpath);
+                offset->originalPath = bpath_to_liv_path (SP_CURVE_BPATH(curve));
                 sp_curve_unref (curve);
-        
+
                 offset->knotSet = false;
                 if ( offset->isUpdating == false ) object->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
             }
@@ -415,7 +405,7 @@ sp_offset_update(SPObject *object, SPCtx *ctx, guint flags)
         sp_shape_set_shape ((SPShape *) object);
     }
     offset->isUpdating=false;
-  
+
     if (((SPObjectClass *) parent_class)->update)
         ((SPObjectClass *) parent_class)->update (object, ctx, flags);
 }
@@ -440,7 +430,7 @@ sp_offset_description(SPItem *item)
 }
 
 /**
- * Converts an NArtBpath (like the one stored in a SPCurve) into a 
+ * Converts an NArtBpath (like the one stored in a SPCurve) into a
  * livarot Path. Duplicate of splivarot.
  */
 Path *
@@ -448,7 +438,7 @@ bpath_to_liv_path(NArtBpath *bpath)
 {
     if (bpath == NULL)
         return NULL;
-  
+
     Path *dest = new Path;
     dest->SetBackData (false);
     {
@@ -456,7 +446,7 @@ bpath_to_liv_path(NArtBpath *bpath)
         bool closed = false;
         float lastX = 0.0;
         float lastY = 0.0;
-    
+
         for (i = 0; bpath[i].code != NR_END; i++)
         {
             switch (bpath[i].code)
@@ -469,7 +459,7 @@ bpath_to_liv_path(NArtBpath *bpath)
                         dest->LineTo (tmp);
                     }
                     break;
-          
+
                 case NR_CURVETO:
                 {
                     NR::Point  tmp(bpath[i].x3, bpath[i].y3);
@@ -484,7 +474,7 @@ bpath_to_liv_path(NArtBpath *bpath)
                 lastX = bpath[i].x3;
                 lastY = bpath[i].y3;
                 break;
-          
+
                 case NR_MOVETO_OPEN:
                 case NR_MOVETO:
                     if (closed)
@@ -504,7 +494,7 @@ bpath_to_liv_path(NArtBpath *bpath)
         if (closed)
             dest->Close ();
     }
-  
+
     return dest;
 }
 
@@ -515,7 +505,7 @@ static void
 sp_offset_set_shape(SPShape *shape)
 {
     SPOffset *offset = SP_OFFSET (shape);
-  
+
     if ( offset->originalPath == NULL ) {
         // oops : no path?! (the offset object should do harakiri)
         return;
@@ -524,12 +514,12 @@ sp_offset_set_shape(SPShape *shape)
     g_print ("rad=%g\n", offset->rad);
 #endif
     // au boulot
-  
+
     if ( fabs(offset->rad) < 0.01 ) {
         // grosso modo: 0
         // just put the source shape as the offseted one, no one will notice
         // it's also useless to compute the offset with a 0 radius
-    
+
         const char *res_d = SP_OBJECT(shape)->repr->attribute("inkscape:original");
         if ( res_d ) {
             NArtBpath *bpath = sp_svg_read_path (res_d);
@@ -540,14 +530,14 @@ sp_offset_set_shape(SPShape *shape)
         }
         return;
     }
-  
+
     // extra paraniac careful check. the preceding if () should take care of this case
     if (fabs (offset->rad) < 0.01)
         offset->rad = (offset->rad < 0) ? -0.01 : 0.01;
-  
+
     Path *orig = new Path;
     orig->Copy ((Path *) offset->originalPath);
-  
+
     if ( use_slow_but_correct_offset_method == false ) {
         // version par outline
         Shape *theShape = new Shape;
@@ -555,7 +545,7 @@ sp_offset_set_shape(SPShape *shape)
         Path *originaux[1];
         Path *res = new Path;
         res->SetBackData (false);
-  
+
         // and now: offset
         float o_width;
         if (offset->rad >= 0)
@@ -568,7 +558,7 @@ sp_offset_set_shape(SPShape *shape)
             o_width = -offset->rad;
             orig->OutsideOutline (res, -o_width, join_round, butt_straight, 20.0);
         }
-  
+
         if (o_width >= 1.0)
         {
             //      res->ConvertForOffset (1.0, orig, offset->rad);
@@ -582,7 +572,7 @@ sp_offset_set_shape(SPShape *shape)
         res->Fill (theShape, 0);
         theRes->ConvertToShape (theShape, fill_positive);
         originaux[0] = res;
-  
+
         theRes->ConvertToForme (orig, 1, originaux);
 
         SPItem *item = shape;
@@ -590,13 +580,13 @@ sp_offset_set_shape(SPShape *shape)
         if (!bbox.isEmpty()) {
             gdouble size = L2(bbox.dimensions());
             gdouble const exp = NR::expansion(item->transform);
-            if (exp != 0) 
+            if (exp != 0)
                 size /= exp;
             orig->Coalesce (size * 0.001);
             //g_print ("coa %g    exp %g    item %p\n", size * 0.001, exp, item);
         }
 
-  
+
         //  if (o_width >= 1.0)
         //  {
         //    orig->Coalesce (0.1);  // small treshhold, since we only want to get rid of small segments
@@ -610,7 +600,7 @@ sp_offset_set_shape(SPShape *shape)
         //   orig->ConvertEvenLines (o_width);
         //   orig->Simplify (0.5 * o_width);
         //  }
-  
+
         delete theShape;
         delete theRes;
         delete res;
@@ -618,8 +608,8 @@ sp_offset_set_shape(SPShape *shape)
         // version par makeoffset
         Shape *theShape = new Shape;
         Shape *theRes = new Shape;
-    
-    
+
+
         // and now: offset
         float o_width;
         if (offset->rad >= 0)
@@ -630,7 +620,7 @@ sp_offset_set_shape(SPShape *shape)
         {
             o_width = -offset->rad;
         }
-    
+
         // one has to have a measure of the details
         if (o_width >= 1.0)
         {
@@ -674,7 +664,7 @@ sp_offset_set_shape(SPShape *shape)
                     onePart->ConvertToShape(oneCleanPart,fill_positive); // there aren't intersections in that one, but maybe duplicate points and null edges
                     oneCleanPart->MakeOffset(onePart,offset->rad,join_round,20.0);
                     onePart->ConvertToShape(oneCleanPart,fill_positive);
-          
+
                     onePart->CalcBBox();
                     double  typicalSize=0.5*((onePart->rightX-onePart->leftX)+(onePart->bottomY-onePart->topY));
                     if ( typicalSize < 0.05 ) typicalSize=0.05;
@@ -701,7 +691,7 @@ sp_offset_set_shape(SPShape *shape)
                     oneCleanPart->MakeOffset(onePart,-offset->rad,join_round,20.0);
                     onePart->ConvertToShape(oneCleanPart,fill_positive);
 //          for (int j=0;j<onePart->nbAr;j++) onePart->Inverse(j); // pas oublier de reinverser
-          
+
                     onePart->CalcBBox();
                     double  typicalSize=0.5*((onePart->rightX-onePart->leftX)+(onePart->bottomY-onePart->topY));
                     if ( typicalSize < 0.05 ) typicalSize=0.05;
@@ -717,7 +707,7 @@ sp_offset_set_shape(SPShape *shape)
                         parts[i]=NULL;
                     } else {
                     }
-          
+
                     /*         int  firstP=theShape->nbPt;
                                for (int j=0;j<onePart->nbPt;j++) theShape->AddPoint(onePart->pts[j].x);
                                for (int j=0;j<onePart->nbAr;j++) theShape->AddEdge(firstP+onePart->aretes[j].en,firstP+onePart->aretes[j].st);*/
@@ -734,9 +724,9 @@ sp_offset_set_shape(SPShape *shape)
                 if ( parts[i] ) {
                     parts[i]->ConvertWithBackData(1.0);
                     if ( holes[i] ) {
-                        parts[i]->Fill(theShape,i,true,true,true);        
+                        parts[i]->Fill(theShape,i,true,true,true);
                     } else {
-                        parts[i]->Fill(theShape,i,true,true,false);        
+                        parts[i]->Fill(theShape,i,true,true,false);
                     }
                 }
             }
@@ -751,7 +741,7 @@ sp_offset_set_shape(SPShape *shape)
         }
 //    theRes->ConvertToShape (theShape, fill_positive);
 //    theRes->ConvertToForme (orig);
-    
+
 /*    if (o_width >= 1.0) {
       orig->ConvertEvenLines (1.0);
       orig->Simplify (1.0);
@@ -759,13 +749,13 @@ sp_offset_set_shape(SPShape *shape)
       orig->ConvertEvenLines (1.0*o_width);
       orig->Simplify (1.0 * o_width);
       }*/
-    
+
         if ( parts ) free(parts);
         if ( holes ) free(holes);
         delete res;
         delete theShape;
         delete theRes;
-    } 
+    }
     {
         char *res_d = NULL;
         if (orig->descr_cmd.size() <= 1)
@@ -776,17 +766,17 @@ sp_offset_set_shape(SPShape *shape)
         }
         else
         {
-      
+
             res_d = orig->svg_dump_path ();
-        } 
+        }
         delete orig;
-    
+
         NArtBpath *bpath = sp_svg_read_path (res_d);
         SPCurve *c = sp_curve_new_from_bpath (bpath);
         g_assert(c != NULL);
         sp_shape_set_curve_insync ((SPShape *) offset, c, TRUE);
         sp_curve_unref (c);
-    
+
         free (res_d);
     }
 }
@@ -805,21 +795,21 @@ static void sp_offset_snappoints(SPItem const *item, SnapPointsIter p)
 // utilitaires pour les poignees
 // used to get the distance to the shape: distance to polygon give the fabs(radius), we still need
 // the sign. for edges, it's easy to determine which side the point is on, for points of the polygon
-// it's trickier: we need to identify which angle the point is in; to that effect, we take each 
+// it's trickier: we need to identify which angle the point is in; to that effect, we take each
 // successive clockwise angle (A,C) and check if the vector B given by the point is in the angle or
 // outside.
-// another method would be to use the Winding() function to test whether the point is inside or outside 
+// another method would be to use the Winding() function to test whether the point is inside or outside
 // the polygon (it would be wiser to do so, in fact, but i like being stupid)
 
-/** 
+/**
  *
  * \todo
  * FIXME: This can be done using linear operations, more stably and
  *  faster.  method: transform A and C into B's space, A should be
  *  negative and B should be positive in the orthogonal component.  I
- *  think this is equivalent to 
- *  dot(A, rot90(B))*dot(C, rot90(B)) == -1.  
- *    -- njh 
+ *  think this is equivalent to
+ *  dot(A, rot90(B))*dot(C, rot90(B)) == -1.
+ *    -- njh
  */
 bool
 vectors_are_clockwise (NR::Point A, NR::Point B, NR::Point C)
@@ -831,7 +821,7 @@ vectors_are_clockwise (NR::Point A, NR::Point B, NR::Point C)
     double bc_c = dot(B, C);
     double ca_s = dot(C, rot90(A));
     double ca_c = dot(C, A);
-  
+
     double ab_a = acos (ab_c);
     if (ab_c <= -1.0)
         ab_a = M_PI;
@@ -853,20 +843,20 @@ vectors_are_clockwise (NR::Point A, NR::Point B, NR::Point C)
         ca_a = 0;
     if (ca_s < 0)
         ca_a = 2 * M_PI - ca_a;
-  
+
     double lim = 2 * M_PI - ca_a;
-  
+
     if (ab_a < lim)
         return true;
     return false;
 }
 
-/** 
- * Distance to the original path; that function is called from object-edit 
+/**
+ * Distance to the original path; that function is called from object-edit
  * to set the radius when the control knot moves.
  *
- * The sign of the result is the radius we're going to offset the shape with, 
- * so result > 0 ==outset and result < 0 ==inset. thus result<0 means 
+ * The sign of the result is the radius we're going to offset the shape with,
+ * so result > 0 ==outset and result < 0 ==inset. thus result<0 means
  * 'px inside source'.
  */
 double
@@ -878,24 +868,24 @@ sp_offset_distance_to_original (SPOffset * offset, NR::Point px)
     double dist = 1.0;
     Shape *theShape = new Shape;
     Shape *theRes = new Shape;
-  
-    /** \todo 
-     * Awfully damn stupid method: uncross the source path EACH TIME you 
-     * need to compute the distance. The good way to do this would be to 
+
+    /** \todo
+     * Awfully damn stupid method: uncross the source path EACH TIME you
+     * need to compute the distance. The good way to do this would be to
      * store the uncrossed source path somewhere, and delete it when the
-     * context is finished. Hopefully this part is much faster than actually 
-     * computing the offset (which happen just after), so the time spent in 
-     * this function should end up being negligible with respect to the 
+     * context is finished. Hopefully this part is much faster than actually
+     * computing the offset (which happen just after), so the time spent in
+     * this function should end up being negligible with respect to the
      * delay of one context.
      */
     // move
     ((Path *) offset->originalPath)->Convert (1.0);
     ((Path *) offset->originalPath)->Fill (theShape, 0);
     theRes->ConvertToShape (theShape, fill_oddEven);
-  
+
     if (theRes->numberOfEdges() <= 1)
     {
-    
+
     }
     else
     {
@@ -940,7 +930,7 @@ sp_offset_distance_to_original (SPOffset * offset, NR::Point px)
                         {
                             nex = -nex;
                         }
-            
+
                         if (vectors_are_clockwise (nex, nx, prx))
                         {
                             // we're in that angle. set the sign, and exit that loop
@@ -998,15 +988,15 @@ sp_offset_distance_to_original (SPOffset * offset, NR::Point px)
                 dist = arDist;
         }
     }
-  
+
     delete theShape;
     delete theRes;
-  
+
     return dist;
 }
 
-/** 
- * Computes a point on the offset;  used to set a "seed" position for 
+/**
+ * Computes a point on the offset;  used to set a "seed" position for
  * the control knot.
  *
  * \return the topmost point on the offset.
@@ -1017,13 +1007,13 @@ sp_offset_top_point (SPOffset * offset, NR::Point *px)
     (*px) = NR::Point(0, 0);
     if (offset == NULL)
         return;
-  
+
     if (offset->knotSet)
     {
         (*px) = offset->knot;
         return;
     }
-  
+
     SPCurve *curve = sp_shape_get_curve (SP_SHAPE (offset));
     if (curve == NULL)
     {
@@ -1032,25 +1022,25 @@ sp_offset_top_point (SPOffset * offset, NR::Point *px)
         if (curve == NULL)
             return;
     }
-  
-    Path *finalPath = bpath_to_liv_path (curve->bpath);
+
+    Path *finalPath = bpath_to_liv_path (SP_CURVE_BPATH(curve));
     if (finalPath == NULL)
     {
         sp_curve_unref (curve);
         return;
     }
-  
+
     Shape *theShape = new Shape;
-  
+
     finalPath->Convert (1.0);
     finalPath->Fill (theShape, 0);
-  
+
     if (theShape->hasPoints())
     {
         theShape->SortPoints ();
         *px = theShape->getPoint(0).x;
     }
-  
+
     delete theShape;
     delete finalPath;
     sp_curve_unref (curve);
@@ -1059,7 +1049,7 @@ sp_offset_top_point (SPOffset * offset, NR::Point *px)
 // the listening functions
 static void sp_offset_start_listening(SPOffset *offset,SPObject* to)
 {
-    if ( to == NULL ) 
+    if ( to == NULL )
         return;
 
     offset->sourceObject = to;
@@ -1072,7 +1062,7 @@ static void sp_offset_start_listening(SPOffset *offset,SPObject* to)
 
 static void sp_offset_quit_listening(SPOffset *offset)
 {
-    if ( offset->sourceObject == NULL )  
+    if ( offset->sourceObject == NULL )
         return;
 
     g_signal_handler_disconnect (offset->sourceObject, offset->_modified_connection);
@@ -1097,7 +1087,7 @@ sp_offset_href_changed(SPObject */*old_ref*/, SPObject */*ref*/, SPOffset *offse
 
 static void
 sp_offset_move_compensate(NR::Matrix const *mp, SPItem *original, SPOffset *self)
-{	
+{
     guint mode = prefs_get_int_attribute("options.clonecompensation", "value", SP_CLONE_COMPENSATION_PARALLEL);
     if (mode == SP_CLONE_COMPENSATION_NONE) return;
 
@@ -1131,7 +1121,7 @@ static void
 sp_offset_delete_self(SPObject */*deleted*/, SPOffset *offset)
 {
     guint const mode = prefs_get_int_attribute("options.cloneorphans", "value", SP_CLONE_ORPHANS_UNLINK);
-	
+
     if (mode == SP_CLONE_ORPHANS_UNLINK) {
         // leave it be. just forget about the source
         sp_offset_quit_listening(offset);
@@ -1152,19 +1142,19 @@ sp_offset_source_modified (SPObject *iSource, guint flags, SPItem *item)
     sp_shape_set_shape ((SPShape *) offset);
 }
 
-static void 
+static void
 refresh_offset_source(SPOffset* offset)
 {
     if ( offset == NULL ) return;
     offset->sourceDirty=false;
     Path *orig = NULL;
-  
+
     // le mauvais cas: pas d'attribut d => il faut verifier que c'est une SPShape puis prendre le contour
     // The bad case: no d attribute.  Must check that it's an SPShape and then take the outline.
     SPObject *refobj=offset->sourceObject;
     if ( refobj == NULL ) return;
     SPItem *item = SP_ITEM (refobj);
-  
+
     SPCurve *curve=NULL;
     if (!SP_IS_SHAPE (item) && !SP_IS_TEXT (item)) return;
     if (SP_IS_SHAPE (item)) {
@@ -1177,20 +1167,20 @@ refresh_offset_source(SPOffset* offset)
         if (curve == NULL)
 	    return;
     }
-    orig = bpath_to_liv_path (curve->bpath);
+    orig = bpath_to_liv_path (SP_CURVE_BPATH(curve));
     sp_curve_unref (curve);
-  
-  
+
+
     // Finish up.
     {
         SPCSSAttr *css;
         const gchar *val;
         Shape *theShape = new Shape;
         Shape *theRes = new Shape;
-    
+
         orig->ConvertWithBackData (1.0);
         orig->Fill (theShape, 0);
-    
+
         css = sp_repr_css_attr (offset->sourceRepr , "style");
         val = sp_repr_css_property (css, "fill-rule", NULL);
         if (val && strcmp (val, "nonzero") == 0)
@@ -1205,21 +1195,21 @@ refresh_offset_source(SPOffset* offset)
         {
             theRes->ConvertToShape (theShape, fill_nonZero);
         }
-    
+
         Path *originaux[1];
         originaux[0] = orig;
         Path *res = new Path;
         theRes->ConvertToForme (res, 1, originaux);
-    
+
         delete theShape;
         delete theRes;
-    
+
         char *res_d = res->svg_dump_path ();
         delete res;
         delete orig;
-    
-        sp_repr_set_attr (SP_OBJECT (offset)->repr, "inkscape:original", res_d);
-    
+
+        SP_OBJECT (offset)->repr->setAttribute("inkscape:original", res_d);
+
         free (res_d);
     }
 }
