@@ -14,24 +14,14 @@
 
 #include "config.h"
 
-#include <string.h>
-#include <libnr/nr-rect.h>
-#include <libnr/nr-matrix.h>
-#include <libnr/nr-pixblock.h>
 #include <libnr/nr-matrix-ops.h>
-#include "libnr/nr-matrix-div.h"
 #include "libnr/nr-matrix-fns.h"
 #include <libnr/nr-translate-matrix-ops.h>
-#include <gtk/gtksignal.h>
 #include "macros.h"
 #include "svg/svg.h"
 #include "display/nr-arena.h"
 #include "display/nr-arena-group.h"
 #include "attributes.h"
-#include "document.h"
-#include "sp-object-repr.h"
-#include "sp-item.h"
-#include "document.h"
 #include "document-private.h"
 #include "uri.h"
 #include "sp-pattern.h"
@@ -141,10 +131,10 @@ sp_pattern_init (SPPattern *pat)
 	pat->patternTransform = NR::identity();
 	pat->patternTransform_set = FALSE;
 
-	sp_svg_length_unset (&pat->x, SP_SVG_UNIT_NONE, 0.0, 0.0);
-	sp_svg_length_unset (&pat->y, SP_SVG_UNIT_NONE, 0.0, 0.0);
-	sp_svg_length_unset (&pat->width, SP_SVG_UNIT_NONE, 0.0, 0.0);
-	sp_svg_length_unset (&pat->height, SP_SVG_UNIT_NONE, 0.0, 0.0);
+	pat->x.unset();
+	pat->y.unset();
+	pat->width.unset();
+	pat->height.unset();
 
 	pat->viewBox_set = FALSE;
 }
@@ -238,27 +228,19 @@ sp_pattern_set (SPObject *object, unsigned int key, const gchar *value)
 		break;
 	}
 	case SP_ATTR_X:
-		if (!sp_svg_length_read (value, &pat->x)) {
-			sp_svg_length_unset (&pat->x, SP_SVG_UNIT_NONE, 0.0, 0.0);
-		}
+	        pat->x.readOrUnset(value);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_Y:
-		if (!sp_svg_length_read (value, &pat->y)) {
-			sp_svg_length_unset (&pat->y, SP_SVG_UNIT_NONE, 0.0, 0.0);
-		}
+	        pat->y.readOrUnset(value);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_WIDTH:
-		if (!sp_svg_length_read (value, &pat->width)) {
-			sp_svg_length_unset (&pat->width, SP_SVG_UNIT_NONE, 0.0, 0.0);
-		}
+	        pat->width.readOrUnset(value);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_HEIGHT:
-		if (!sp_svg_length_read (value, &pat->height)) {
-			sp_svg_length_unset (&pat->height, SP_SVG_UNIT_NONE, 0.0, 0.0);
-		}
+	        pat->height.readOrUnset(value);
 		object->requestModified(SP_OBJECT_MODIFIED_FLAG);
 		break;
 	case SP_ATTR_VIEWBOX: {
@@ -350,7 +332,7 @@ sp_pattern_child_added (SPObject *object, Inkscape::XML::Node *child, Inkscape::
 }
 
 /* TODO: do we need a ::remove_child handler? */
- 
+
 /* fixme: We need ::order_changed handler too (Lauris) */
 
 GSList *
@@ -453,12 +435,12 @@ pattern_chain (SPPattern *pattern)
 	Inkscape::XML::Node *defsrepr = SP_OBJECT_REPR (SP_DOCUMENT_DEFS (document));
 
 	Inkscape::XML::Node *repr = sp_repr_new ("svg:pattern");
-	sp_repr_set_attr(repr, "inkscape:collect", "always");
+	repr->setAttribute("inkscape:collect", "always");
 	gchar *parent_ref = g_strconcat ("#", SP_OBJECT_REPR(pattern)->attribute("id"), NULL);
-	sp_repr_set_attr (repr, "xlink:href",  parent_ref);
+	repr->setAttribute("xlink:href",  parent_ref);
 	g_free (parent_ref);
 
-	sp_repr_add_child (defsrepr, repr, NULL);
+	defsrepr->addChild(repr, NULL);
 	const gchar *child_id = repr->attribute("id");
 	SPObject *child = document->getObjectById(child_id);
 	g_assert (SP_IS_PATTERN (child));
@@ -476,7 +458,7 @@ sp_pattern_clone_if_necessary (SPItem *item, SPPattern *pattern, const gchar *pr
 		SPCSSAttr *css = sp_repr_css_attr_new ();
 		sp_repr_css_set_property (css, property, href);
 		sp_repr_css_change_recursive (SP_OBJECT_REPR (item), css, "style");
-	} 
+	}
 	return pattern;
 }
 
@@ -497,9 +479,9 @@ sp_pattern_transform_multiply (SPPattern *pattern, NR::Matrix postmul, bool set)
 
 	gchar c[256];
 	if (sp_svg_transform_write(c, 256, pattern->patternTransform)) {
-		sp_repr_set_attr(SP_OBJECT_REPR(pattern), "patternTransform", c);
+		SP_OBJECT_REPR(pattern)->setAttribute("patternTransform", c);
 	} else {
-		sp_repr_set_attr(SP_OBJECT_REPR(pattern), "patternTransform", NULL);
+		SP_OBJECT_REPR(pattern)->setAttribute("patternTransform", NULL);
 	}
 }
 
@@ -509,15 +491,15 @@ pattern_tile (GSList *reprs, NR::Rect bounds, SPDocument *document, NR::Matrix t
 	Inkscape::XML::Node *defsrepr = SP_OBJECT_REPR (SP_DOCUMENT_DEFS (document));
 
 	Inkscape::XML::Node *repr = sp_repr_new ("svg:pattern");
-	sp_repr_set_attr (repr, "patternUnits", "userSpaceOnUse");
+	repr->setAttribute("patternUnits", "userSpaceOnUse");
 	sp_repr_set_svg_double(repr, "width", bounds.extent(NR::X));
 	sp_repr_set_svg_double(repr, "height", bounds.extent(NR::Y));
 
 	gchar t[256];
 	if (sp_svg_transform_write(t, 256, transform)) {
-		sp_repr_set_attr(repr, "patternTransform", t);
+		repr->setAttribute("patternTransform", t);
 	} else {
-		sp_repr_set_attr(repr, "patternTransform", NULL);
+		repr->setAttribute("patternTransform", NULL);
 	}
 
 
@@ -530,19 +512,19 @@ pattern_tile (GSList *reprs, NR::Rect bounds, SPDocument *document, NR::Matrix t
 		SPItem *copy = SP_ITEM(pat_object->appendChildRepr(node));
 
 		NR::Matrix dup_transform;
-		if (!sp_svg_transform_read (node->attribute("transform"), &dup_transform)) 
+		if (!sp_svg_transform_read (node->attribute("transform"), &dup_transform))
 			dup_transform = NR::identity();
 		dup_transform *= move;
 
 		sp_item_write_transform(copy, SP_OBJECT_REPR(copy), dup_transform);
 	}
 
-	sp_repr_unref (repr);
+	Inkscape::GC::release(repr);
 	return pat_id;
 }
 
 SPPattern *
-pattern_getroot (SPPattern *pat) 
+pattern_getroot (SPPattern *pat)
 {
 	for (SPPattern *pat_i = pat; pat_i != NULL; pat_i = pat_i->ref ? pat_i->ref->getObject() : NULL) {
 		if (sp_object_first_child(SP_OBJECT(pat_i))) { // find the first one with children
@@ -586,7 +568,7 @@ NR::Matrix const &pattern_patternTransform(SPPattern const *pat)
 gdouble pattern_x (SPPattern *pat)
 {
 	for (SPPattern *pat_i = pat; pat_i != NULL; pat_i = pat_i->ref ? pat_i->ref->getObject() : NULL) {
-		if (pat_i->x.set)
+		if (pat_i->x._set)
 			return pat_i->x.computed;
 	}
 	return 0;
@@ -595,7 +577,7 @@ gdouble pattern_x (SPPattern *pat)
 gdouble pattern_y (SPPattern *pat)
 {
 	for (SPPattern *pat_i = pat; pat_i != NULL; pat_i = pat_i->ref ? pat_i->ref->getObject() : NULL) {
-		if (pat_i->y.set)
+		if (pat_i->y._set)
 			return pat_i->y.computed;
 	}
 	return 0;
@@ -604,7 +586,7 @@ gdouble pattern_y (SPPattern *pat)
 gdouble pattern_width (SPPattern *pat)
 {
 	for (SPPattern *pat_i = pat; pat_i != NULL; pat_i = pat_i->ref ? pat_i->ref->getObject() : NULL) {
-		if (pat_i->width.set)
+		if (pat_i->width._set)
 			return pat_i->width.computed;
 	}
 	return 0;
@@ -613,7 +595,7 @@ gdouble pattern_width (SPPattern *pat)
 gdouble pattern_height (SPPattern *pat)
 {
 	for (SPPattern *pat_i = pat; pat_i != NULL; pat_i = pat_i->ref ? pat_i->ref->getObject() : NULL) {
-		if (pat_i->height.set)
+		if (pat_i->height._set)
 			return pat_i->height.computed;
 	}
 	return 0;
@@ -628,6 +610,17 @@ NRRect *pattern_viewBox (SPPattern *pat)
 	return &(pat->viewBox);
 }
 
+bool pattern_hasItemChildren (SPPattern *pat)
+{
+	for (SPObject *child = sp_object_first_child(SP_OBJECT(pat)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
+		if (SP_IS_ITEM (child)) {
+			return true;
+		}
+	}
+	return false;
+}
+
+
 
 /* Painter */
 
@@ -643,8 +636,6 @@ sp_pattern_painter_new (SPPaintServer *ps, NR::Matrix const &full_transform, NR:
 	SPPattern *pat = SP_PATTERN (ps);
 	SPPatPainter *pp = g_new (SPPatPainter, 1);
 
-	SPObject *child;
-
 	pp->painter.type = SP_PAINTER_IND;
 	pp->painter.fill = sp_pat_fill;
 
@@ -687,14 +678,11 @@ sp_pattern_painter_new (SPPaintServer *ps, NR::Matrix const &full_transform, NR:
 	nr_matrix_invert (&pp->px2ps, &pp->ps2px);
 
 	if (pat->viewBox_set) {
-		/* Forget content units at all (lauris) */
-		gdouble tmp_x = pattern_width (pat) / (pattern_viewBox(pat)->x1 - pattern_viewBox(pat)->x0);
-		gdouble tmp_y = pattern_height (pat) / (pattern_viewBox(pat)->y1 - pattern_viewBox(pat)->y0);
+		gdouble tmp_x = (pattern_viewBox(pat)->x1 - pattern_viewBox(pat)->x0) / pattern_width (pat);
+		gdouble tmp_y = (pattern_viewBox(pat)->y1 - pattern_viewBox(pat)->y0) / pattern_height (pat);
 
-		NR::Matrix vb2ps (tmp_x, 0.0, 0.0, tmp_y, -pattern_viewBox(pat)->x0 * tmp_x, -pattern_viewBox(pat)->y0 * tmp_y);
-
-		/* Problem: What to do, if we have mixed lengths and percentages? (Lauris) */
-		/* Currently we do ignore percentages at all, but that is not good (Lauris) */
+		// FIXME: preserveAspectRatio must be taken into account here too!
+		NR::Matrix vb2ps (tmp_x, 0.0, 0.0, tmp_y, pattern_x(pat) - pattern_viewBox(pat)->x0, pattern_y(pat) - pattern_viewBox(pat)->y0);
 
 		NR::Matrix vb2us = vb2ps * pattern_patternTransform(pat);
 
@@ -720,7 +708,7 @@ sp_pattern_painter_new (SPPaintServer *ps, NR::Matrix const &full_transform, NR:
 			pcs2px = pattern_patternTransform(pat) * full_transform;
 		}
 
-		pcs2px = NR::translate (pattern_x (pat), pattern_y (pat)) * pcs2px; 
+		pcs2px = NR::translate (pattern_x (pat), pattern_y (pat)) * pcs2px;
 
 		pcs2px.copyto (&pp->pcs2px);
 	}
@@ -735,8 +723,8 @@ sp_pattern_painter_new (SPPaintServer *ps, NR::Matrix const &full_transform, NR:
 
 	/* Show items */
 	for (SPPattern *pat_i = pat; pat_i != NULL; pat_i = pat_i->ref ? pat_i->ref->getObject() : NULL) {
-		if (sp_object_first_child(SP_OBJECT(pat_i))) { // find the first one with children
-			for (child = sp_object_first_child(SP_OBJECT(pat_i)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
+		if (pat_i && SP_IS_OBJECT (pat_i) && pattern_hasItemChildren(pat_i)) { // find the first one with item children
+			for (SPObject *child = sp_object_first_child(SP_OBJECT(pat_i)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
 				if (SP_IS_ITEM (child)) {
 					NRArenaItem *cai;
 					cai = sp_item_invoke_show (SP_ITEM (child), pp->arena, pp->dkey, SP_ITEM_REFERENCE_FLAGS);
@@ -806,16 +794,12 @@ sp_pattern_painter_new (SPPaintServer *ps, NR::Matrix const &full_transform, NR:
 static void
 sp_pattern_painter_free (SPPaintServer *ps, SPPainter *painter)
 {
-	SPPatPainter *pp;
-	SPPattern *pat;
-	SPObject *child;
-
-	pp = (SPPatPainter *) painter;
-	pat = pp->pat;
+	SPPatPainter *pp = (SPPatPainter *) painter;
+	SPPattern *pat = pp->pat;
 
 	for (SPPattern *pat_i = pat; pat_i != NULL; pat_i = pat_i->ref ? pat_i->ref->getObject() : NULL) {
-		if (pat_i && SP_IS_OBJECT (pat_i) && sp_object_first_child(SP_OBJECT(pat_i))) { // find the first one with children
-			for (child = sp_object_first_child(SP_OBJECT(pat_i)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
+		if (pat_i && SP_IS_OBJECT (pat_i) && pattern_hasItemChildren(pat_i)) { // find the first one with item children
+			for (SPObject *child = sp_object_first_child(SP_OBJECT(pat_i)) ; child != NULL; child = SP_OBJECT_NEXT(child) ) {
 				if (SP_IS_ITEM (child)) {
 						sp_item_invoke_hide (SP_ITEM (child), pp->dkey);
 				}
@@ -962,10 +946,10 @@ sp_pat_fill (SPPainter *painter, NRPixBlock *pb)
 		ba.y1 = pb->area.y1;
 		nr_rect_d_matrix_transform (&psa, &ba, &pp->px2ps);
 		
-		psa.x0 = floor ((psa.x0 - pattern_x (pp->pat)) / pattern_width (pp->pat));
-		psa.y0 = floor ((psa.y0 - pattern_y (pp->pat)) / pattern_height (pp->pat));
-		psa.x1 = ceil ((psa.x1 - pattern_x (pp->pat)) / pattern_width (pp->pat));
-		psa.y1 = ceil ((psa.y1 - pattern_y (pp->pat)) / pattern_height (pp->pat));
+		psa.x0 = floor ((psa.x0 - pattern_x (pp->pat)) / pattern_width (pp->pat)) -1;
+		psa.y0 = floor ((psa.y0 - pattern_y (pp->pat)) / pattern_height (pp->pat)) -1;
+		psa.x1 = ceil ((psa.x1 - pattern_x (pp->pat)) / pattern_width (pp->pat)) +1;
+		psa.y1 = ceil ((psa.y1 - pattern_y (pp->pat)) / pattern_height (pp->pat)) +1;
 		
 		for (y = psa.y0; y < psa.y1; y++) {
 			for (x = psa.x0; x < psa.x1; x++) {
@@ -980,10 +964,10 @@ sp_pat_fill (SPPainter *painter, NRPixBlock *pb)
 				area.x1 = area.x0 + pb->area.x1 - pb->area.x0;
 				area.y1 = area.y0 + pb->area.y1 - pb->area.y0;
 				
-				// We do not update here anymore 
+				// We do not update here anymore
 
-				// Set up buffer 
-				// fixme: (Lauris) 
+				// Set up buffer
+				// fixme: (Lauris)
 				nr_pixblock_setup_extern (&ppb, pb->mode, area.x0, area.y0, area.x1, area.y1, NR_PIXBLOCK_PX (pb), pb->rs, FALSE, FALSE);
 				
 				nr_arena_item_invoke_render (pp->root, &area, &ppb, 0);
