@@ -13,9 +13,6 @@
 
 #include "config.h"
 
-#include <math.h>
-#include <string.h>
-#include <stdlib.h>
 #include "attributes.h"
 #include "sp-polyline.h"
 #include "display/curve.h"
