@@ -15,16 +15,13 @@
 
 #include "config.h"
 
-#include <string.h>
 #include "svg/svg.h"
 #include "display/nr-arena-group.h"
 #include "attributes.h"
 #include "print.h"
 #include "document.h"
 #include "sp-defs.h"
-#include "sp-item.h"
 #include "sp-root.h"
-#include <libnr/nr-matrix.h>
 #include <libnr/nr-matrix-fns.h>
 #include <libnr/nr-matrix-ops.h>
 #include <libnr/nr-matrix-translate-ops.h>
@@ -121,10 +118,10 @@ sp_root_init(SPRoot *root)
     root->version.inkscape = root->original.inkscape =
         root->version.sodipodi = root->original.sodipodi = zero_version;
 
-    sp_svg_length_unset(&root->x, SP_SVG_UNIT_NONE, 0.0, 0.0);
-    sp_svg_length_unset(&root->y, SP_SVG_UNIT_NONE, 0.0, 0.0);
-    sp_svg_length_unset(&root->width, SP_SVG_UNIT_PERCENT, 1.0, 1.0);
-    sp_svg_length_unset(&root->height, SP_SVG_UNIT_PERCENT, 1.0, 1.0);
+    root->x.unset();
+    root->y.unset();
+    root->width.unset(SVGLength::PERCENT, 1.0, 1.0);
+    root->height.unset(SVGLength::PERCENT, 1.0, 1.0);
 
     /* nr_matrix_set_identity(&root->viewbox); */
     root->viewBox_set = FALSE;
@@ -214,32 +211,32 @@ sp_root_set(SPObject *object, unsigned int key, gchar const *value)
             }
             break;
         case SP_ATTR_X:
-            if (!sp_svg_length_read_absolute(value, &root->x)) {
+            if (!root->x.readAbsolute(value)) {
                 /* fixme: em, ex, % are probably valid, but require special treatment (Lauris) */
-                sp_svg_length_unset(&root->x, SP_SVG_UNIT_NONE, 0.0, 0.0);
+                root->x.unset();
             }
             /* fixme: I am almost sure these do not require viewport flag (Lauris) */
             object->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG | SP_OBJECT_VIEWPORT_MODIFIED_FLAG);
             break;
         case SP_ATTR_Y:
-            if (!sp_svg_length_read_absolute(value, &root->y)) {
+            if (!root->y.readAbsolute(value)) {
                 /* fixme: em, ex, % are probably valid, but require special treatment (Lauris) */
-                sp_svg_length_unset(&root->y, SP_SVG_UNIT_NONE, 0.0, 0.0);
+                root->y.unset();
             }
             /* fixme: I am almost sure these do not require viewport flag (Lauris) */
             object->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG | SP_OBJECT_VIEWPORT_MODIFIED_FLAG);
             break;
         case SP_ATTR_WIDTH:
-            if (!sp_svg_length_read_absolute(value, &root->width) || !(root->width.computed > 0.0)) {
+            if (!root->width.readAbsolute(value) || !(root->width.computed > 0.0)) {
                 /* fixme: em, ex, % are probably valid, but require special treatment (Lauris) */
-                sp_svg_length_unset(&root->width, SP_SVG_UNIT_PERCENT, 1.0, 1.0);
+                root->width.unset(SVGLength::PERCENT, 1.0, 1.0);
             }
             object->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG | SP_OBJECT_VIEWPORT_MODIFIED_FLAG);
             break;
         case SP_ATTR_HEIGHT:
-            if (!sp_svg_length_read_absolute(value, &root->height) || !(root->height.computed > 0.0)) {
+            if (!root->height.readAbsolute(value) || !(root->height.computed > 0.0)) {
                 /* fixme: em, ex, % are probably valid, but require special treatment (Lauris) */
-                sp_svg_length_unset(&root->height, SP_SVG_UNIT_PERCENT, 1.0, 1.0);
+                root->height.unset(SVGLength::PERCENT, 1.0, 1.0);
             }
             object->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG | SP_OBJECT_VIEWPORT_MODIFIED_FLAG);
             break;
@@ -412,16 +409,16 @@ sp_root_update(SPObject *object, SPCtx *ctx, guint flags)
     /* fixme: This will be invoked too often (Lauris) */
     /* fixme: We should calculate only if parent viewport has changed (Lauris) */
     /* If position is specified as percentage, calculate actual values */
-    if (root->x.unit == SP_SVG_UNIT_PERCENT) {
+    if (root->x.unit == SVGLength::PERCENT) {
         root->x.computed = root->x.value * (ictx->vp.x1 - ictx->vp.x0);
     }
-    if (root->y.unit == SP_SVG_UNIT_PERCENT) {
+    if (root->y.unit == SVGLength::PERCENT) {
         root->y.computed = root->y.value * (ictx->vp.y1 - ictx->vp.y0);
     }
-    if (root->width.unit == SP_SVG_UNIT_PERCENT) {
+    if (root->width.unit == SVGLength::PERCENT) {
         root->width.computed = root->width.value * (ictx->vp.x1 - ictx->vp.x0);
     }
-    if (root->height.unit == SP_SVG_UNIT_PERCENT) {
+    if (root->height.unit == SVGLength::PERCENT) {
         root->height.computed = root->height.value * (ictx->vp.y1 - ictx->vp.y0);
     }
 
@@ -585,11 +582,11 @@ sp_root_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
     }
 
     if (flags & SP_OBJECT_WRITE_EXT) {
-        sp_repr_set_attr(repr, "sodipodi:version", SODIPODI_VERSION);
-        sp_repr_set_attr(repr, "inkscape:version", INKSCAPE_VERSION);
+        repr->setAttribute("sodipodi:version", SODIPODI_VERSION);
+        repr->setAttribute("inkscape:version", INKSCAPE_VERSION);
     }
 
-    sp_repr_set_attr(repr, "version", SVG_VERSION);
+    repr->setAttribute("version", SVG_VERSION);
 
     if (fabs(root->x.computed) > 1e-9)
         sp_repr_set_svg_double(repr, "x", root->x.computed);
@@ -599,14 +596,14 @@ sp_root_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
     /* Unlike all other SPObject, here we want to preserve absolute units too (and only here,
      * according to the recommendation in http://www.w3.org/TR/SVG11/coords.html#Units).
      */
-    sp_repr_set_attr(repr, "width", sp_svg_length_write_with_units(root->width).c_str());
-    sp_repr_set_attr(repr, "height", sp_svg_length_write_with_units(root->height).c_str());
+    repr->setAttribute("width", sp_svg_length_write_with_units(root->width).c_str());
+    repr->setAttribute("height", sp_svg_length_write_with_units(root->height).c_str());
 
     if (root->viewBox_set) {
         Inkscape::SVGOStringStream os;
         os << root->viewBox.x0 << " " << root->viewBox.y0 << " " << root->viewBox.x1 - root->viewBox.x0 << " " << root->viewBox.y1 - root->viewBox.y0;
-        sp_repr_set_attr(repr, "viewBox", os.str().c_str());
-    } 
+        repr->setAttribute("viewBox", os.str().c_str());
+    }
 
     if (((SPObjectClass *) (parent_class))->write)
         ((SPObjectClass *) (parent_class))->write(object, repr, flags);
