@@ -17,39 +17,22 @@
 # include "config.h"
 #endif
 
-#include <glib/gmessages.h>
-#include <string.h>
 
 #include <libnr/n-art-bpath.h>
-#include <libnr/nr-pixblock.h>
-#include <libnr/nr-matrix.h>
 #include <libnr/nr-matrix-fns.h>
 #include <libnr/nr-matrix-ops.h>
 #include <libnr/nr-matrix-translate-ops.h>
-#include <libnr/nr-point-fns.h>
-#include <libnr/nr-point-matrix-ops.h>
 #include <libnr/nr-scale-matrix-ops.h>
 
-#include <xml/repr.h>
 
 #include "macros.h"
-#include <glibmm/i18n.h>
-#include "svg/svg.h"
-#include "svg/css-ostringstream.h"
-#include "display/curve.h"
 #include "display/nr-arena-shape.h"
-#include "uri-references.h"
 #include "print.h"
 #include "document.h"
 #include "marker-status.h"
-#include "selection.h"
-#include "sp-paint-server.h"
 #include "style.h"
-#include "sp-root.h"
 #include "sp-marker.h"
-#include "sp-shape.h"
 #include "sp-path.h"
-#include "sp-defs.h"
 #include "prefs-utils.h"
 
 #define noSHAPE_VERBOSE
@@ -70,11 +53,12 @@ static void sp_shape_hide (SPItem *item, unsigned int key);
 static void sp_shape_snappoints (SPItem const *item, SnapPointsIter p);
 
 static void sp_shape_update_marker_view (SPShape *shape, NRArenaItem *ai);
-static int sp_shape_has_markers (SPShape const *shape);
-static int sp_shape_number_of_markers (SPShape* Shape, int type);
 
 static SPItemClass *parent_class;
 
+/**
+ * Registers the SPShape class with Gdk and returns its type number.
+ */
 GType
 sp_shape_get_type (void)
 {
@@ -95,6 +79,10 @@ sp_shape_get_type (void)
 	return type;
 }
 
+/**
+ * Initializes a SPShapeClass object.  Establishes the function pointers to the class'
+ * member routines in the class vtable, and sets pointers to parent classes.
+ */
 static void
 sp_shape_class_init (SPShapeClass *klass)
 {
@@ -120,59 +108,42 @@ sp_shape_class_init (SPShapeClass *klass)
         item_class->snappoints = sp_shape_snappoints;
 }
 
+/**
+ * Initializes an SPShape object.  Nothing particular is needed to initialize
+ * an SPShape object; this is just here as a stub.
+ */
 static void
 sp_shape_init (SPShape *shape)
 {
 	/* Nothing here */
 }
 
+/**
+ * Virtual build callback for SPMarker.
+ *
+ * This is to be invoked immediately after creation of an SPShape.  This is 
+ * just a stub.
+ *
+ * \see sp_object_build()
+ */
 static void
 sp_shape_build (SPObject *object, SPDocument *document, Inkscape::XML::Node *repr)
 {
-	Inkscape::Version version;
-
-	version = sp_object_get_sodipodi_version (object);
-
-	if (sp_version_inside_range (version, 0, 0, 0, 25)) {
-		SPCSSAttr *css;
-		const gchar *val;
-		gboolean changed;
-		/* Have to check for percentage opacities */
-		css = sp_repr_css_attr (repr, "style");
-		/* We force style rewrite at moment (Lauris) */
-		changed = TRUE;
-		val = sp_repr_css_property (css, "opacity", NULL);
-		if (val && strchr (val, '%')) {
-			Inkscape::CSSOStringStream os;
-			os << sp_svg_read_percentage (val, 1.0);
-			sp_repr_css_set_property (css, "opacity", os.str().c_str());
-			changed = TRUE;
-		}
-		val = sp_repr_css_property (css, "fill-opacity", NULL);
-		if (val && strchr (val, '%')) {
-			Inkscape::CSSOStringStream os;
-			os << sp_svg_read_percentage (val, 1.0);
-			sp_repr_css_set_property (css, "fill-opacity", os.str().c_str());
-			changed = TRUE;
-		}
-		val = sp_repr_css_property (css, "stroke-opacity", NULL);
-		if (val && strchr (val, '%')) {
-			Inkscape::CSSOStringStream os;
-			os << sp_svg_read_percentage (val, 1.0);
-			sp_repr_css_set_property (css, "stroke-opacity", os.str().c_str());
-			changed = TRUE;
-		}
-		if (changed) {
-		  sp_repr_css_set (repr, css, "style");
-		}
-		sp_repr_css_attr_unref (css);
-	}
-
 	if (((SPObjectClass *) (parent_class))->build) {
 	  (*((SPObjectClass *) (parent_class))->build) (object, document, repr);
 	}
 }
 
+/**
+ * Removes, releases and unrefs all children of object
+ *
+ * This is the inverse of sp_shape_build().  It must be invoked as soon
+ * as the shape is removed from the tree, even if it is still referenced
+ * by other objects.  This routine also disconnects/unrefs markers and
+ * curves attached to it.
+ *
+ * \see sp_object_release()
+ */
 static void
 sp_shape_release (SPObject *object)
 {
@@ -202,6 +173,10 @@ sp_shape_release (SPObject *object)
 	}
 }
 
+/** 
+ * Updates the shape when its attributes have changed.  Also establishes
+ * marker objects to match the style settings.  
+ */
 static void
 sp_shape_update (SPObject *object, SPCtx *ctx, unsigned int flags)
 {
@@ -236,15 +211,15 @@ sp_shape_update (SPObject *object, SPCtx *ctx, unsigned int flags)
 	}
 
 	if (flags & (SP_OBJECT_MODIFIED_FLAG | SP_OBJECT_PARENT_MODIFIED_FLAG)) {
-		NRRect paintbox;
 		/* This is suboptimal, because changing parent style schedules recalculation */
 		/* But on the other hand - how can we know that parent does not tie style and transform */
-		sp_item_invoke_bbox(SP_ITEM (object), &paintbox, NR::identity(), TRUE);
+                NR::Rect const paintbox = SP_ITEM(object)->invokeBbox(NR::identity());
 		for (SPItemView *v = SP_ITEM (shape)->display; v != NULL; v = v->next) {
-			if (flags & SP_OBJECT_MODIFIED_FLAG) {
-				nr_arena_shape_set_path(NR_ARENA_SHAPE(v->arenaitem), shape->curve,(flags & SP_OBJECT_USER_MODIFIED_FLAG_B));
-			}
-			nr_arena_shape_set_paintbox (NR_ARENA_SHAPE (v->arenaitem), &paintbox);
+                    NRArenaShape * const s = NR_ARENA_SHAPE(v->arenaitem);
+                    if (flags & SP_OBJECT_MODIFIED_FLAG) {
+                        nr_arena_shape_set_path(s, shape->curve, (flags & SP_OBJECT_USER_MODIFIED_FLAG_B));
+                    }
+                    s->setPaintBox(paintbox);
 		}
 	}
 
@@ -289,14 +264,14 @@ sp_shape_update (SPObject *object, SPCtx *ctx, unsigned int flags)
 * \param bp Path segment.
 * \return 1 if a marker is required here, otherwise 0.
 */
-static bool
+bool
 sp_shape_marker_required(SPShape const *shape, int const m, NArtBpath *bp)
 {
     if (shape->marker[m] == NULL) {
         return false;
     }
 
-    if (bp == shape->curve->bpath)
+    if (bp == SP_CURVE_BPATH(shape->curve))
         return m == SP_MARKER_LOC_START;
     else if (bp[1].code == NR_END)
         return m == SP_MARKER_LOC_END;
@@ -310,7 +285,12 @@ is_moveto(NRPathcode const c)
     return c == NR_MOVETO || c == NR_MOVETO_OPEN;
 }
 
-/** \pre The bpath[] containing bp begins with a moveto. */
+/** 
+ * Helper function that advances a subpath's bpath to the first subpath
+ * by checking for moveto segments.
+ *
+ * \pre The bpath[] containing bp begins with a moveto. 
+ */
 static NArtBpath const *
 first_seg_in_subpath(NArtBpath const *bp)
 {
@@ -320,6 +300,9 @@ first_seg_in_subpath(NArtBpath const *bp)
     return bp;
 }
 
+/**
+ * Advances the bpath to the last segment in the subpath.
+ */
 static NArtBpath const *
 last_seg_in_subpath(NArtBpath const *bp)
 {
@@ -357,7 +340,11 @@ last_seg_in_subpath(NArtBpath const *bp)
 
 static double const no_tangent = 128.0;  /* arbitrarily-chosen value outside the range of atan2, i.e. outside of [-pi, pi]. */
 
-/** \pre The bpath[] containing bp0 begins with a moveto. */
+/**
+ * Helper function to calculate the outgoing tangent of a path 
+ * ( atan2(other - p0) )
+ * \pre The bpath[] containing bp0 begins with a moveto. 
+ */
 static double
 outgoing_tangent(NArtBpath const *bp0)
 {
@@ -419,7 +406,12 @@ found:
     return atan2( other - p0 );
 }
 
-/** \pre The bpath[] containing bp0 begins with a moveto. */
+/**
+ * Helper function to calculate the incoming tangent of a path
+ * ( atan2(p0 - other) )
+ * 
+ * \pre The bpath[] containing bp0 begins with a moveto. 
+ */
 static double
 incoming_tangent(NArtBpath const *bp0)
 {
@@ -478,25 +470,24 @@ found:
 
 
 /**
-* Calculate the transform required to get a marker's path object in the
-* right place for particular path segment on a shape.  You should
-* call sp_shape_marker_required first to see if a marker is required
-* at this point.
-*
-* \see sp_shape_marker_required.
-*
-* \param shape Shape which the marker is for.
-* \param m Marker type (e.g. SP_MARKER_LOC_START)
-* \param bp Path segment which the arrow is for.
-* \return Transform matrix.
-*/
-
-static NR::Matrix
+ * Calculate the transform required to get a marker's path object in the
+ * right place for particular path segment on a shape.  You should
+ * call sp_shape_marker_required first to see if a marker is required
+ * at this point.
+ *
+ * \see sp_shape_marker_required.
+ *
+ * \param shape Shape which the marker is for.
+ * \param m Marker type (e.g. SP_MARKER_LOC_START)
+ * \param bp Path segment which the arrow is for.
+ * \return Transform matrix.
+ */
+NR::Matrix
 sp_shape_marker_get_transform(SPShape const *shape, NArtBpath const *bp)
 {
-    g_return_val_if_fail(( is_moveto(shape->curve->bpath[0].code)
+    g_return_val_if_fail(( is_moveto(SP_CURVE_BPATH(shape->curve)[0].code)
                            && ( 0 < shape->curve->end )
-                           && ( shape->curve->bpath[shape->curve->end].code == NR_END ) ),
+                           && ( SP_CURVE_BPATH(shape->curve)[shape->curve->end].code == NR_END ) ),
                          NR::Matrix(NR::translate(bp->c(3))));
     double const angle1 = incoming_tangent(bp);
     double const angle2 = outgoing_tangent(bp);
@@ -532,8 +523,11 @@ sp_shape_marker_get_transform(SPShape const *shape, NArtBpath const *bp)
     return NR::Matrix(NR::rotate(ret_angle)) * NR::translate(bp->c(3));
 }
 
-/* Marker views have to be scaled already */
-
+/**
+ * Updates the instances (views) of a given marker in a shape.
+ * Marker views have to be scaled already.  The transformation
+ * is retrieved and then shown by calling sp_marker_show_instance.
+ */
 static void
 sp_shape_update_marker_view (SPShape *shape, NRArenaItem *ai)
 {
@@ -548,7 +542,7 @@ sp_shape_update_marker_view (SPShape *shape, NRArenaItem *ai)
 
             int n = 0;
 
-            for (NArtBpath *bp = shape->curve->bpath; bp->code != NR_END; bp++) {
+            for (NArtBpath *bp = SP_CURVE_BPATH(shape->curve); bp->code != NR_END; bp++) {
                 if (sp_shape_marker_required (shape, i, bp)) {
                     NR::Matrix const m(sp_shape_marker_get_transform(shape, bp));
                     sp_marker_show_instance ((SPMarker* ) shape->marker[i], ai,
@@ -560,6 +554,9 @@ sp_shape_update_marker_view (SPShape *shape, NRArenaItem *ai)
 	}
 }
 
+/**
+ * Sets modified flag for all sub-item views.
+ */
 static void
 sp_shape_modified (SPObject *object, unsigned int flags)
 {
@@ -576,6 +573,10 @@ sp_shape_modified (SPObject *object, unsigned int flags)
 	}
 }
 
+/**
+ * Calculates the bounding box for item, storing it into bbox.
+ * This also includes the bounding boxes of any markers included in the shape.
+ */
 static void sp_shape_bbox(SPItem const *item, NRRect *bbox, NR::Matrix const &transform, unsigned const flags)
 {
     SPShape const *shape = SP_SHAPE (item);
@@ -608,7 +609,7 @@ static void sp_shape_bbox(SPItem const *item, NRRect *bbox, NR::Matrix const &tr
 
         // Union with bboxes of the markers, if any
         if (sp_shape_has_markers (shape)) {
-            for (NArtBpath* bp = shape->curve->bpath; bp->code != NR_END; bp++) {
+            for (NArtBpath* bp = SP_CURVE_BPATH(shape->curve); bp->code != NR_END; bp++) {
                 for (int m = SP_MARKER_LOC_START; m < SP_MARKER_LOC_QTY; m++) {
                     if (sp_shape_marker_required (shape, m, bp)) {
 
@@ -634,18 +635,21 @@ static void sp_shape_bbox(SPItem const *item, NRRect *bbox, NR::Matrix const &tr
             }
         }
 
-        if ( fabs(cbbox.x1-cbbox.x0) > -0.00001 && fabs(cbbox.y1-cbbox.y0) > -0.00001 ) {
-            NRRect tbbox=*bbox;
-            nr_rect_d_union (bbox, &cbbox, &tbbox);
-        }
+        // copy our bbox to the variable we're given
+        *bbox = cbbox;
     }
 }
 
+/**
+ * Prepares shape for printing.  Handles printing of comments for printing
+ * debugging, sizes the item to fit into the document width/height,
+ * applies print fill/stroke, sets transforms for markers, and adds
+ * comment labels.
+ */
 void
 sp_shape_print (SPItem *item, SPPrintContext *ctx)
 {
 	NRRect pbox, dbox, bbox;
-	NRMatrix i2d;
 
 	SPShape *shape = SP_SHAPE(item);
 
@@ -666,23 +670,23 @@ sp_shape_print (SPItem *item, SPPrintContext *ctx)
 	dbox.x1 = sp_document_width (SP_OBJECT_DOCUMENT (item));
 	dbox.y1 = sp_document_height (SP_OBJECT_DOCUMENT (item));
 	sp_item_bbox_desktop (item, &bbox);
-	sp_item_i2d_affine (item, &i2d);
+	NR::Matrix const i2d = sp_item_i2d_affine(item);
 
         SPStyle* style = SP_OBJECT_STYLE (item);
 
 	if (style->fill.type != SP_PAINT_TYPE_NONE) {
 		NRBPath bp;
-		bp.path = shape->curve->bpath;
-		sp_print_fill (ctx, &bp, &i2d, style, &pbox, &dbox, &bbox);
+		bp.path = SP_CURVE_BPATH(shape->curve);
+		sp_print_fill (ctx, &bp, i2d, style, &pbox, &dbox, &bbox);
 	}
 
 	if (style->stroke.type != SP_PAINT_TYPE_NONE) {
 		NRBPath bp;
-		bp.path = shape->curve->bpath;
-		sp_print_stroke (ctx, &bp, &i2d, style, &pbox, &dbox, &bbox);
+		bp.path = SP_CURVE_BPATH(shape->curve);
+		sp_print_stroke (ctx, &bp, i2d, style, &pbox, &dbox, &bbox);
 	}
 
-        for (NArtBpath* bp = shape->curve->bpath; bp->code != NR_END; bp++) {
+        for (NArtBpath* bp = SP_CURVE_BPATH(shape->curve); bp->code != NR_END; bp++) {
             for (int m = SP_MARKER_LOC_START; m < SP_MARKER_LOC_QTY; m++) {
                 if (sp_shape_marker_required (shape, m, bp)) {
 
@@ -713,26 +717,25 @@ sp_shape_print (SPItem *item, SPPrintContext *ctx)
         }
 }
 
+/**
+ * Sets style, path, and paintbox.  Updates marker views, including dimensions.
+ */
 static NRArenaItem *
 sp_shape_show (SPItem *item, NRArena *arena, unsigned int key, unsigned int flags)
 {
-	SPObject *object;
-	SPShape *shape;
-	NRRect paintbox;
-	NRArenaItem *arenaitem;
+	SPObject *object = SP_OBJECT(item);
+	SPShape *shape = SP_SHAPE(item);
 
-	object = SP_OBJECT (item);
-	shape = SP_SHAPE (item);
-
-	arenaitem = NRArenaShape::create(arena);
-	nr_arena_shape_set_style (NR_ARENA_SHAPE (arenaitem), object->style);
-	nr_arena_shape_set_path(NR_ARENA_SHAPE(arenaitem), shape->curve,false);
-	sp_item_invoke_bbox(item, &paintbox, NR::identity(), TRUE);
-	nr_arena_shape_set_paintbox (NR_ARENA_SHAPE (arenaitem), &paintbox);
+	NRArenaItem *arenaitem = NRArenaShape::create(arena);
+        NRArenaShape * const s = NR_ARENA_SHAPE(arenaitem);
+	nr_arena_shape_set_style(s, object->style);
+	nr_arena_shape_set_path(s, shape->curve, false);
+        NR::Rect const paintbox = item->invokeBbox(NR::identity());
+        s->setPaintBox(paintbox);
 
         if (sp_shape_has_markers (shape)) {
 
-            /* Dimension marker views */
+            /* Dimension the marker views */
             if (!arenaitem->key) {
                 NR_ARENA_ITEM_SET_KEY (arenaitem, sp_item_display_key_new (SP_MARKER_LOC_QTY));
             }
@@ -753,6 +756,9 @@ sp_shape_show (SPItem *item, NRArena *arena, unsigned int key, unsigned int flag
 	return arenaitem;
 }
 
+/**
+ * Hides/removes marker views from the shape.
+ */
 static void
 sp_shape_hide (SPItem *item, unsigned int key)
 {
@@ -778,13 +784,11 @@ sp_shape_hide (SPItem *item, unsigned int key)
 	}
 }
 
-/* Marker stuff */
-
 /**
 * \param shape Shape.
 * \return TRUE if the shape has any markers, or FALSE if not.
 */
-static int
+int
 sp_shape_has_markers (SPShape const *shape)
 {
     /* Note, we're ignoring 'marker' settings, which technically should apply for
@@ -805,11 +809,11 @@ sp_shape_has_markers (SPShape const *shape)
 * \param type Marker type (e.g. SP_MARKER_LOC_START)
 * \return Number of markers that the shape has of this type.
 */
-static int
+int
 sp_shape_number_of_markers (SPShape *shape, int type)
 {
     int n = 0;
-    for (NArtBpath* bp = shape->curve->bpath; bp->code != NR_END; bp++) {
+    for (NArtBpath* bp = SP_CURVE_BPATH(shape->curve); bp->code != NR_END; bp++) {
         if (sp_shape_marker_required (shape, type, bp)) {
             n++;
         }
@@ -818,6 +822,11 @@ sp_shape_number_of_markers (SPShape *shape, int type)
     return n;
 }
 
+/**
+ * Checks if the given marker is used in the shape, and if so, it
+ * releases it by calling sp_marker_hide.  Also detaches signals
+ * and unrefs the marker from the shape.
+ */
 static void
 sp_shape_marker_release (SPObject *marker, SPShape *shape)
 {
@@ -843,6 +852,9 @@ sp_shape_marker_release (SPObject *marker, SPShape *shape)
 	}
 }
 
+/**
+ * No-op.  Exists for handling 'modified' messages
+ */
 static void
 sp_shape_marker_modified (SPObject *marker, guint flags, SPItem *item)
 {
@@ -850,6 +862,13 @@ sp_shape_marker_modified (SPObject *marker, guint flags, SPItem *item)
 	/* g_warning ("Item %s mask %s modified", SP_OBJECT_ID (item), SP_OBJECT_ID (mask)); */
 }
 
+/**
+ * Adds a new marker to shape object at the location indicated by key.  value 
+ * must be a valid URI reference resolvable from the shape object (i.e., present
+ * in the document <defs>).  If the shape object already has a marker
+ * registered at the given position, it is removed first.  Then the
+ * new marker is hrefed and its signals connected.
+ */
 void
 sp_shape_set_marker (SPObject *object, unsigned int key, const gchar *value)
 {
@@ -894,6 +913,9 @@ sp_shape_set_marker (SPObject *object, unsigned int key, const gchar *value)
 
 /* Shape section */
 
+/**
+ * Calls any registered handlers for the set_shape action
+ */
 void
 sp_shape_set_shape (SPShape *shape)
 {
@@ -905,6 +927,12 @@ sp_shape_set_shape (SPShape *shape)
 	}
 }
 
+/**
+ * Adds a curve to the shape.  If owner is specified, a reference
+ * will be made, otherwise the curve will be copied into the shape.
+ * Any existing curve in the shape will be unreferenced first.
+ * This routine also triggers a request to update the display.
+ */
 void
 sp_shape_set_curve (SPShape *shape, SPCurve *curve, unsigned int owner)
 {
@@ -921,7 +949,9 @@ sp_shape_set_curve (SPShape *shape, SPCurve *curve, unsigned int owner)
         SP_OBJECT(shape)->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
 }
 
-/* Return duplicate of curve or NULL */
+/**
+ * Return duplicate of curve (if any exists) or NULL if there is no curve
+ */
 SPCurve *
 sp_shape_get_curve (SPShape *shape)
 {
@@ -947,6 +977,9 @@ sp_shape_set_curve_insync (SPShape *shape, SPCurve *curve, unsigned int owner)
 	}
 }
 
+/**
+ * Sets the snappoint p to the end point of the path segment
+ */
 static void sp_shape_snappoints(SPItem const *item, SnapPointsIter p)
 {
     g_assert(item != NULL);
@@ -960,7 +993,7 @@ static void sp_shape_snappoints(SPItem const *item, SnapPointsIter p)
     NR::Matrix const i2d (sp_item_i2d_affine (item));
 
     /* Use the end points of each segment of the path */
-    NArtBpath const *bp = shape->curve->bpath;
+    NArtBpath const *bp = SP_CURVE_BPATH(shape->curve);
     while (bp->code != NR_END) {
         *p = bp->c(3) * i2d;
         bp++;
