@@ -23,43 +23,21 @@
  *
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
 
-#include <string.h>
-
-#include <libnr/nr-rect.h>
-#include <libnr/nr-matrix.h>
-#include <libnr/nr-matrix-ops.h>
-#include <libnr/nr-matrix-fns.h>
-#include <libnr/nr-rotate.h>
-
-#include <livarot/LivarotDefs.h>
-#include <livarot/Shape.h>
 #include <livarot/Path.h>
-
-#include <glib.h>
-//#include <gtk/gtk.h>
-
-#include <glibmm/i18n.h>
-#include "svg/svg.h"
 #include "svg/stringstream.h"
-#include "display/nr-arena-group.h"
-#include "display/nr-arena-glyphs.h"
 #include "attributes.h"
-#include "document.h"
-#include "style.h"
-
 #include "sp-use-reference.h"
-
-
-#include "sp-object.h"
-#include "sp-shape.h"
 #include "sp-tspan.h"
-#include "sp-text.h"
-
+#include "sp-textpath.h"
+#include "text-editing.h"
+#include "style.h"
+#include "libnr/nr-matrix-fns.h"
 #include "xml/repr.h"
 
-#include "prefs-utils.h"
 
 /*#####################################################
 #  SPTSPAN
@@ -73,6 +51,7 @@ static void sp_tspan_release(SPObject *object);
 static void sp_tspan_set(SPObject *object, unsigned key, gchar const *value);
 static void sp_tspan_update(SPObject *object, SPCtx *ctx, guint flags);
 static void sp_tspan_modified(SPObject *object, unsigned flags);
+static void sp_tspan_bbox(SPItem const *item, NRRect *bbox, NR::Matrix const &transform, unsigned const flags);
 static Inkscape::XML::Node *sp_tspan_write(SPObject *object, Inkscape::XML::Node *repr, guint flags);
 
 static SPItemClass *tspan_parent_class;
@@ -119,6 +98,8 @@ sp_tspan_class_init(SPTSpanClass *classname)
     sp_object_class->update = sp_tspan_update;
     sp_object_class->modified = sp_tspan_modified;
     sp_object_class->write = sp_tspan_write;
+
+    item_class->bbox = sp_tspan_bbox;
 }
 
 static void
@@ -215,6 +196,32 @@ sp_tspan_modified(SPObject *object, unsigned flags)
     }
 }
 
+static void sp_tspan_bbox(SPItem const *item, NRRect *bbox, NR::Matrix const &transform, unsigned const flags)
+{
+    // find out the ancestor text which holds our layout
+    SPObject *parent_text = SP_OBJECT(item);
+    for (; parent_text != NULL && !SP_IS_TEXT(parent_text); parent_text = SP_OBJECT_PARENT (parent_text));
+    if (parent_text == NULL) return;
+
+    // get the bbox of our portion of the layout
+    SP_TEXT(parent_text)->layout.getBoundingBox(bbox, transform, sp_text_get_length_upto(parent_text, item), sp_text_get_length_upto(item, NULL) - 1);
+
+    // Add stroke width
+    SPStyle* style=SP_OBJECT_STYLE (item);
+    if (style->stroke.type != SP_PAINT_TYPE_NONE) {
+        double const scale = expansion(transform);
+        if ( fabs(style->stroke_width.computed * scale) > 0.01 ) { // sinon c'est 0=oon veut pas de bord
+            double const width = MAX(0.125, style->stroke_width.computed * scale);
+            if ( fabs(bbox->x1 - bbox->x0) > -0.00001 && fabs(bbox->y1 - bbox->y0) > -0.00001 ) {
+                bbox->x0-=0.5*width;
+                bbox->x1+=0.5*width;
+                bbox->y0-=0.5*width;
+                bbox->y1+=0.5*width;
+            }
+        }
+    }
+}
+
 static Inkscape::XML::Node *
 sp_tspan_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
 {
@@ -240,8 +247,8 @@ sp_tspan_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
             if ( c_repr ) l = g_slist_prepend(l, c_repr);
         }
         while ( l ) {
-            sp_repr_add_child(repr, (Inkscape::XML::Node *) l->data, NULL);
-            sp_repr_unref((Inkscape::XML::Node *) l->data);
+            repr->addChild((Inkscape::XML::Node *) l->data, NULL);
+            Inkscape::GC::release((Inkscape::XML::Node *) l->data);
             l = g_slist_remove(l, l->data);
         }
     } else {
@@ -334,7 +341,7 @@ sp_textpath_init(SPTextPath *textpath)
 {
     new (&textpath->attributes) TextTagAttributes;
 	
-    textpath->startOffset.set = 0;
+    textpath->startOffset._set = false;
     textpath->originalPath = NULL;
     textpath->isUpdating=false;
     // set up the uri reference
@@ -384,7 +391,7 @@ sp_textpath_build(SPObject *object, SPDocument *doc, Inkscape::XML::Node *repr)
 	
     if ( no_content ) {
         Inkscape::XML::Node* rch = sp_repr_new_text("");
-        sp_repr_add_child(repr, rch, NULL);
+        repr->addChild(rch, NULL);
     }
 	
     if (((SPObjectClass *) textpath_parent_class)->build)
@@ -404,9 +411,7 @@ sp_textpath_set(SPObject *object, unsigned key, gchar const *value)
                 textpath->sourcePath->link((char*)value);
                 break;
             case SP_ATTR_STARTOFFSET:
-                if (!sp_svg_length_read(value, &textpath->startOffset)) {
-                    sp_svg_length_unset(&textpath->startOffset, SP_SVG_UNIT_NONE, 0.0, 0.0);
-                }
+                textpath->startOffset.readOrUnset(value);
                 object->requestDisplayUpdate(SP_OBJECT_MODIFIED_FLAG);
                 break;
             default:
@@ -448,7 +453,7 @@ void   refresh_textpath_source(SPTextPath* tp)
     tp->sourcePath->sourceDirty=false;
 	
     // finalisons
-    if ( tp->sourcePath->originalPath ) { 
+    if ( tp->sourcePath->originalPath ) {
         if (tp->originalPath) {
             delete tp->originalPath;
         }
@@ -488,8 +493,8 @@ sp_textpath_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
     }
 	
     textpath->attributes.writeTo(repr);
-    if (textpath->startOffset.set) {
-        if (textpath->startOffset.unit == SP_SVG_UNIT_PERCENT) {
+    if (textpath->startOffset._set) {
+        if (textpath->startOffset.unit == SVGLength::PERCENT) {
 	        Inkscape::SVGOStringStream os;
             os << (textpath->startOffset.computed * 100.0) << "%";
             SP_OBJECT_REPR(textpath)->setAttribute("startOffset", os.str().c_str());
@@ -500,7 +505,7 @@ sp_textpath_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
         }
     }
 
-    if ( textpath->sourcePath->sourceHref ) sp_repr_set_attr(repr, "xlink:href", textpath->sourcePath->sourceHref);
+    if ( textpath->sourcePath->sourceHref ) repr->setAttribute("xlink:href", textpath->sourcePath->sourceHref);
 	
     if ( flags&SP_OBJECT_WRITE_BUILD ) {
         GSList *l = NULL;
@@ -516,8 +521,8 @@ sp_textpath_write(SPObject *object, Inkscape::XML::Node *repr, guint flags)
             if ( c_repr ) l = g_slist_prepend(l, c_repr);
         }
         while ( l ) {
-            sp_repr_add_child(repr, (Inkscape::XML::Node *) l->data, NULL);
-            sp_repr_unref((Inkscape::XML::Node *) l->data);
+            repr->addChild((Inkscape::XML::Node *) l->data, NULL);
+            Inkscape::GC::release((Inkscape::XML::Node *) l->data);
             l = g_slist_remove(l, l->data);
         }
     } else {
@@ -569,16 +574,16 @@ sp_textpath_to_text(SPObject *tp)
         // make a copy of each textpath child
         Inkscape::XML::Node *copy = ((Inkscape::XML::Node *) i->data)->duplicate();
         // remove the old repr from under textpath
-        sp_repr_remove_child(SP_OBJECT_REPR(tp), (Inkscape::XML::Node *) i->data); 
+        SP_OBJECT_REPR(tp)->removeChild((Inkscape::XML::Node *) i->data);
         // put its copy into under textPath
-        sp_repr_add_child(SP_OBJECT_REPR(text), copy, NULL); // fixme: copy id
+        SP_OBJECT_REPR(text)->addChild(copy, NULL); // fixme: copy id
     }
 
     //remove textpath
     tp->deleteObject();
     g_slist_free(tp_reprs);
 
-    // set x/y on text 
+    // set x/y on text
     /* fixme: Yuck, is this really the right test? */
     if (xy[NR::X] != 1e18 && xy[NR::Y] != 1e18) {
         sp_repr_set_svg_double(SP_OBJECT_REPR(text), "x", xy[NR::X]);
