@@ -16,21 +16,11 @@
 
 #include "config.h"
 
-#include <math.h>
-#include <string.h>
-#include <glib.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtklabel.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkcheckbutton.h>
 
 #include "macros.h"
 #include "display/sp-canvas.h"
 #include "sp-star.h"
-#include "inkscape.h"
 #include "document.h"
 #include "sp-namedview.h"
 #include "selection.h"
@@ -41,16 +31,13 @@
 #include "desktop-style.h"
 #include "message-context.h"
 #include "pixmaps/cursor-star.xpm"
-#include "widgets/desktop-widget.h"
 #include "sp-metrics.h"
 #include <glibmm/i18n.h>
 #include "prefs-utils.h"
-#include "knotholder.h"
 #include "xml/repr.h"
 #include "xml/node-event-vector.h"
 #include "object-edit.h"
-#include "widgets/spw-utilities.h"
-#include <libnr/nr-point-fns.h>
+#include "context-fns.h"
 
 #include "star-context.h"
 
@@ -146,7 +133,7 @@ sp_star_context_dispose (GObject *object)
 
     if (ec->shape_repr) { // remove old listener
         sp_repr_remove_listener_by_data (ec->shape_repr, ec);
-        sp_repr_unref (ec->shape_repr);
+        Inkscape::GC::release(ec->shape_repr);
         ec->shape_repr = 0;
     }
 
@@ -188,7 +175,7 @@ sp_star_context_selection_changed (Inkscape::Selection * selection, gpointer dat
 
     if (ec->shape_repr) { // remove old listener
         sp_repr_remove_listener_by_data (ec->shape_repr, ec);
-        sp_repr_unref (ec->shape_repr);
+        Inkscape::GC::release(ec->shape_repr);
         ec->shape_repr = 0;
     }
 
@@ -198,9 +185,8 @@ sp_star_context_selection_changed (Inkscape::Selection * selection, gpointer dat
         Inkscape::XML::Node *shape_repr = SP_OBJECT_REPR (item);
         if (shape_repr) {
             ec->shape_repr = shape_repr;
-            sp_repr_ref (shape_repr);
+            Inkscape::GC::anchor(shape_repr);
             sp_repr_add_listener (shape_repr, &ec_shape_repr_events, ec);
-            sp_repr_synthesize_events (shape_repr, &ec_shape_repr_events, ec);
         }
     }
 }
@@ -219,7 +205,7 @@ sp_star_context_setup (SPEventContext *ec)
     sp_event_context_read (ec, "rounded");
     sp_event_context_read (ec, "randomized");
 
-    Inkscape::Selection *selection = SP_DT_SELECTION(ec->desktop);
+    Inkscape::Selection *selection = sp_desktop_selection(ec->desktop);
 
     SPItem *item = selection->singleItem();
         if (item) {
@@ -227,9 +213,8 @@ sp_star_context_setup (SPEventContext *ec)
             Inkscape::XML::Node *shape_repr = SP_OBJECT_REPR (item);
             if (shape_repr) {
                 ec->shape_repr = shape_repr;
-                sp_repr_ref (shape_repr);
+                Inkscape::GC::anchor(shape_repr);
                 sp_repr_add_listener (shape_repr, &ec_shape_repr_events, ec);
-                sp_repr_synthesize_events (shape_repr, &ec_shape_repr_events, ec);
             }
         }
 
@@ -266,43 +251,37 @@ sp_star_context_set (SPEventContext *ec, const gchar *key, const gchar *val)
         sc->rounded = (val) ? g_ascii_strtod (val, NULL) : 0.0;
     } else if (!strcmp (key, "randomized")) {
         sc->randomized = (val) ? g_ascii_strtod (val, NULL) : 0.0;
-    }    
+    }
 }
 
-static gint
-sp_star_context_root_handler (SPEventContext * event_context, GdkEvent * event)
+static gint sp_star_context_root_handler(SPEventContext *event_context, GdkEvent *event)
 {
     static gboolean dragging;
 
     SPDesktop *desktop = event_context->desktop;
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
 
     SPStarContext *sc = SP_STAR_CONTEXT (event_context);
 
-    event_context->tolerance = prefs_get_int_attribute_limited ("options.dragtolerance", "value", 0, 0, 100);
+    event_context->tolerance = prefs_get_int_attribute_limited("options.dragtolerance", "value", 0, 0, 100);
 
     gint ret = FALSE;
 
-
     switch (event->type) {
     case GDK_BUTTON_PRESS:
         if (event->button.button == 1) {
-           // save drag origin
-            event_context->xp = (gint) event->button.x;
-            event_context->yp = (gint) event->button.y;
-            event_context->within_tolerance = true;
-
-           // remember clicked item, disregarding groups, honoring Alt
-            event_context->item_to_select = sp_event_context_find_item (desktop, NR::Point(event->button.x, event->button.y), event->button.state & GDK_MOD1_MASK, TRUE);
 
             dragging = TRUE;
-            /* Position center */
-            sc->center = sp_desktop_w2d_xy_point (event_context->desktop, NR::Point(event->button.x, event->button.y));
-            /* Snap center to nearest magnetic point */
-            namedview_free_snap (event_context->desktop->namedview, Snapper::SNAP_POINT, sc->center);
-            sp_canvas_item_grab (SP_CANVAS_ITEM (desktop->acetate),
-                                 GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
-                                 NULL, event->button.time);
+
+            sc->center = Inkscape::setup_for_drag_start(desktop, event_context, event);
+
+            SnapManager const &m = desktop->namedview->snap_manager;
+            sc->center = m.freeSnap(Inkscape::Snapper::SNAP_POINT, sc->center, sc->item).getPoint();
+
+            sp_canvas_item_grab(SP_CANVAS_ITEM(desktop->acetate),
+                                GDK_KEY_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
+                                GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK,
+                                NULL, event->button.time);
             ret = TRUE;
         }
         break;
@@ -320,7 +299,7 @@ sp_star_context_root_handler (SPEventContext * event_context, GdkEvent * event)
             event_context->within_tolerance = false;
 
             NR::Point const motion_w(event->motion.x, event->motion.y);
-            NR::Point const motion_dt(sp_desktop_w2d_xy_point(event_context->desktop, motion_w));
+            NR::Point const motion_dt(event_context->desktop->w2d(motion_w));
             sp_star_drag (sc, motion_dt, event->motion.state);
             ret = TRUE;
         }
@@ -331,7 +310,7 @@ sp_star_context_root_handler (SPEventContext * event_context, GdkEvent * event)
             dragging = FALSE;
             if (!event_context->within_tolerance) {
                 // we've been dragging, finish the star
-            sp_star_finish (sc);
+                sp_star_finish (sc);
             } else if (event_context->item_to_select) {
                 // no dragging, select clicked item if any
                 if (event->button.state & GDK_SHIFT_MASK) {
@@ -346,11 +325,11 @@ sp_star_context_root_handler (SPEventContext * event_context, GdkEvent * event)
 
             event_context->item_to_select = NULL;
             ret = TRUE;
-            sp_canvas_item_ungrab (SP_CANVAS_ITEM (desktop->acetate), event->button.time);
+            sp_canvas_item_ungrab(SP_CANVAS_ITEM (desktop->acetate), event->button.time);
         }
         break;
     case GDK_KEY_PRESS:
-        switch (get_group0_keyval (&event->key)) {
+        switch (get_group0_keyval(&event->key)) {
         case GDK_Alt_R:
         case GDK_Control_L:
         case GDK_Control_R:
@@ -358,10 +337,10 @@ sp_star_context_root_handler (SPEventContext * event_context, GdkEvent * event)
         case GDK_Shift_R:
         case GDK_Meta_L:  // Meta is when you press Shift+Alt (at least on my machine)
         case GDK_Meta_R:
-            sp_event_show_modifier_tip (event_context->defaultMessageContext(), event,
-                                        _("<b>Ctrl</b>: snap angle; keep rays radial"),
-                                        NULL,
-                                        NULL);
+            sp_event_show_modifier_tip(event_context->defaultMessageContext(), event,
+                                       _("<b>Ctrl</b>: snap angle; keep rays radial"),
+                                       NULL,
+                                       NULL);
             break;
         case GDK_Up:
         case GDK_Down:
@@ -374,15 +353,12 @@ sp_star_context_root_handler (SPEventContext * event_context, GdkEvent * event)
         case GDK_x:
         case GDK_X:
             if (MOD__ALT_ONLY) {
-                gpointer hb = sp_search_by_data_recursive (desktop->owner->aux_toolbox, (gpointer) "altx-star");
-                if (hb && GTK_IS_WIDGET(hb)) {
-                    gtk_widget_grab_focus (GTK_WIDGET (hb));
-                }
+                desktop->setToolboxFocusTo ("altx-star");
                 ret = TRUE;
             }
             break;
         case GDK_Escape:
-            SP_DT_SELECTION(desktop)->clear();
+            sp_desktop_selection(desktop)->clear();
             //TODO: make dragging escapable by Esc
         default:
             break;
@@ -416,51 +392,48 @@ sp_star_context_root_handler (SPEventContext * event_context, GdkEvent * event)
     return ret;
 }
 
-static void
-sp_star_drag(SPStarContext *sc, NR::Point p, guint state)
+static void sp_star_drag(SPStarContext *sc, NR::Point p, guint state)
 {
     SPDesktop *desktop = SP_EVENT_CONTEXT(sc)->desktop;
 
-    int snaps = prefs_get_int_attribute ("options.rotationsnapsperpi", "value", 12);
+    int const snaps = prefs_get_int_attribute ("options.rotationsnapsperpi", "value", 12);
 
     if (!sc->item) {
 
-        SPItem *layer=SP_ITEM(desktop->currentLayer());
-        if ( !layer || desktop->itemIsHidden(layer)) {
-            sc->_message_context->set(Inkscape::ERROR_MESSAGE, _("<b>Current layer is hidden</b>. Unhide it to be able to draw on it."));
-            return;
-        }
-        if ( !layer || layer->isLocked()) {
-            sc->_message_context->set(Inkscape::ERROR_MESSAGE, _("<b>Current layer is locked</b>. Unlock it to be able to draw on it."));
+        if (Inkscape::have_viable_layer(desktop, sc->_message_context) == false) {
             return;
         }
 
         /* Create object */
-        Inkscape::XML::Node *repr = sp_repr_new ("svg:path");
-        sp_repr_set_attr (repr, "sodipodi:type", "star");
+        Inkscape::XML::Node *repr = sp_repr_new("svg:path");
+        repr->setAttribute("sodipodi:type", "star");
 
         /* Set style */
-        sp_desktop_apply_style_tool (desktop, repr, "tools.shapes.star", false);
+        sp_desktop_apply_style_tool(desktop, repr, "tools.shapes.star", false);
 
         sc->item = SP_ITEM(desktop->currentLayer()->appendChildRepr(repr));
-        sp_repr_unref (repr);
+        Inkscape::GC::release(repr);
         sc->item->transform = SP_ITEM(desktop->currentRoot())->getRelativeTransform(desktop->currentLayer());
         sc->item->updateRepr();
     }
 
-    /* Free movement for corner point */
-    NR::Point p0 = sp_desktop_dt2root_xy_point (desktop, sc->center);
-    NR::Point p1 = sp_desktop_dt2root_xy_point (desktop, p);
-    namedview_free_snap (desktop->namedview, Snapper::SNAP_POINT, p1);
+    NR::Point const p0 = sp_desktop_dt2root_xy_point(desktop, sc->center);
+    NR::Point p1 = sp_desktop_dt2root_xy_point(desktop, p);
+
+    /* Snap corner point with no constraints */
+    SnapManager const &m = desktop->namedview->snap_manager;
+    p1 = m.freeSnap(Inkscape::Snapper::SNAP_POINT, p1, sc->item).getPoint();
 
     SPStar *star = SP_STAR(sc->item);
 
-    gdouble sides = (gdouble) sc->magnitude;
-    NR::Point d = p1 - p0;
-    gdouble r1 = NR::L2 (d);
-    gdouble arg1 = atan2 (d);
+    double const sides = (gdouble) sc->magnitude;
+    NR::Point const d = p1 - p0;
+    NR::Coord const r1 = NR::L2(d);
+    double arg1 = atan2(d);
+
     if (state & GDK_CONTROL_MASK) {
-        arg1 = sp_round(arg1, M_PI/snaps);
+        /* Snap angle */
+        arg1 = sp_round(arg1, M_PI / snaps);
     }
 
     sp_star_position_set(star, sc->magnitude, p0, r1, r1 * sc->proportion,
@@ -469,10 +442,11 @@ sp_star_drag(SPStarContext *sc, NR::Point p, guint state)
     /* status text */
     GString *rads = SP_PX_TO_METRIC_STRING(r1, desktop->namedview->getDefaultMetric());
     sc->_message_context->setF(Inkscape::NORMAL_MESSAGE,
-                                      ( sc->isflatsided?
-                                      _("<b>Polygon</b>: radius %s, angle %5g&#176;; with <b>Ctrl</b> to snap angle")
-                                          : _("<b>Star</b>: radius %s, angle %5g&#176;; with <b>Ctrl</b> to snap angle") ),
-                                      rads->str, sp_round ((arg1)*180/M_PI, 0.0001));
+                               ( sc->isflatsided?
+                                 _("<b>Polygon</b>: radius %s, angle %5g&#176;; with <b>Ctrl</b> to snap angle")
+                                 : _("<b>Star</b>: radius %s, angle %5g&#176;; with <b>Ctrl</b> to snap angle") ),
+                               rads->str, sp_round((arg1) * 180 / M_PI, 0.0001));
+
     g_string_free(rads, FALSE);
 }
 
@@ -489,8 +463,8 @@ sp_star_finish (SPStarContext * sc)
 
         object->updateRepr(NULL, SP_OBJECT_WRITE_EXT);
 
-        SP_DT_SELECTION(desktop)->set(sc->item);
-        sp_document_done(SP_DT_DOCUMENT(desktop));
+        sp_desktop_selection(desktop)->set(sc->item);
+        sp_document_done(sp_desktop_document(desktop));
 
         sc->item = NULL;
     }
@@ -500,9 +474,9 @@ sp_star_finish (SPStarContext * sc)
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
