@@ -148,6 +148,8 @@ enum {
     SP_PAINT_TYPE_IMPOSSIBLE
 };
 
+class SVGICCColor;
+
 /// Paint type internal to SPStyle.
 struct SPIPaint {
     unsigned set : 1;
@@ -161,6 +163,7 @@ struct SPIPaint {
             gchar *uri;
         } paint;
     } value;
+    SVGICCColor *iccColor;
 };
 
 enum {
@@ -321,6 +324,12 @@ struct SPStyle {
 
     /// style belongs to a cloned object, must not href anything
     bool cloned; 
+    /// style has hreffed its fill/stroke paintservers, needs to release.
+    bool fill_hreffed; 
+    bool stroke_hreffed; 
+    /// style is listening to changes in fill/stroke paintservers, needs to disconnect.
+    bool fill_listening; 
+    bool stroke_listening; 
 };
 
 SPStyle *sp_style_new();
