@@ -13,34 +13,19 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "config.h"
-
-#include <math.h>
-
-#if HAVE_STRING_H
-#include <string.h>
+#ifdef HAVE_CONFIG_H
+# include "config.h"
 #endif
 
-#if HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
-
-#include <stdio.h>
-#include <ctype.h>
-
-#include <libnr/nr-matrix.h>
+#include <glib/gstrfuncs.h>
 #include <libnr/nr-matrix-fns.h>
 #include <libnr/nr-matrix-ops.h>
 #include <libnr/nr-matrix-translate-ops.h>
 #include <libnr/nr-rotate-fns.h>
-#include <libnr/nr-rotate-ops.h>
 #include <libnr/nr-rotate-matrix-ops.h>
 #include <libnr/nr-scale-matrix-ops.h>
 #include <libnr/nr-translate-matrix-ops.h>
 #include <libnr/nr-translate-rotate-ops.h>
-#include <libnr/nr-translate-ops.h>
-#include <libnr/nr-values.h>
-#include <glib.h>
 #include "svg.h"
 
 #ifndef M_PI
@@ -203,9 +188,9 @@ sp_svg_transform_write(gchar str[], unsigned const size, NRMatrix const *transfo
 				unsigned p = 0;
 				strcpy (c + p, "scale(");
 				p += 6;
-				p += sp_svg_number_write_de (c + p, transform->c[0], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[0], 6, -8, FALSE);
 				c[p++] = ',';
-				p += sp_svg_number_write_de (c + p, transform->c[3], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[3], 6, -8, FALSE);
 				c[p++] = ')';
 				g_assert( p <= sizeof(c) );
 				p = MIN (p, size - 1 );
@@ -220,9 +205,9 @@ sp_svg_transform_write(gchar str[], unsigned const size, NRMatrix const *transfo
 				unsigned p = 0;
 				strcpy (c + p, "translate(");
 				p += 10;
-				p += sp_svg_number_write_de (c + p, transform->c[4], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[4], 6, -8, FALSE);
 				c[p++] = ',';
-				p += sp_svg_number_write_de (c + p, transform->c[5], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[5], 6, -8, FALSE);
 				c[p++] = ')';
 				g_assert( p <= sizeof(c) );
 				p = MIN(p, size - 1);
@@ -234,17 +219,17 @@ sp_svg_transform_write(gchar str[], unsigned const size, NRMatrix const *transfo
 				unsigned p = 0;
 				strcpy (c + p, "matrix(");
 				p += 7;
-				p += sp_svg_number_write_de (c + p, transform->c[0], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[0], 6, -8, FALSE);
 				c[p++] = ',';
-				p += sp_svg_number_write_de (c + p, transform->c[1], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[1], 6, -8, FALSE);
 				c[p++] = ',';
-				p += sp_svg_number_write_de (c + p, transform->c[2], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[2], 6, -8, FALSE);
 				c[p++] = ',';
-				p += sp_svg_number_write_de (c + p, transform->c[3], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[3], 6, -8, FALSE);
 				c[p++] = ',';
-				p += sp_svg_number_write_de (c + p, transform->c[4], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[4], 6, -8, FALSE);
 				c[p++] = ',';
-				p += sp_svg_number_write_de (c + p, transform->c[5], 6, FALSE);
+				p += sp_svg_number_write_de (c + p, transform->c[5], 6, -8, FALSE);
 				c[p++] = ')';
 				g_assert( p <= sizeof(c) );
 				p = MIN(p, size - 1);
@@ -258,17 +243,17 @@ sp_svg_transform_write(gchar str[], unsigned const size, NRMatrix const *transfo
 		unsigned p = 0;
 		strcpy (c + p, "matrix(");
 		p += 7;
-		p += sp_svg_number_write_de (c + p, transform->c[0], 6, FALSE);
+		p += sp_svg_number_write_de (c + p, transform->c[0], 6, -8, FALSE);
 		c[p++] = ',';
-		p += sp_svg_number_write_de (c + p, transform->c[1], 6, FALSE);
+		p += sp_svg_number_write_de (c + p, transform->c[1], 6, -8, FALSE);
 		c[p++] = ',';
-		p += sp_svg_number_write_de (c + p, transform->c[2], 6, FALSE);
+		p += sp_svg_number_write_de (c + p, transform->c[2], 6, -8, FALSE);
 		c[p++] = ',';
-		p += sp_svg_number_write_de (c + p, transform->c[3], 6, FALSE);
+		p += sp_svg_number_write_de (c + p, transform->c[3], 6, -8, FALSE);
 		c[p++] = ',';
-		p += sp_svg_number_write_de (c + p, transform->c[4], 6, FALSE);
+		p += sp_svg_number_write_de (c + p, transform->c[4], 6, -8, FALSE);
 		c[p++] = ',';
-		p += sp_svg_number_write_de (c + p, transform->c[5], 6, FALSE);
+		p += sp_svg_number_write_de (c + p, transform->c[5], 6, -8, FALSE);
 		c[p++] = ')';
 		g_assert( p <= sizeof(c) );
 		p = MIN(p, size - 1);
