@@ -10,29 +10,22 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
 
-#include <algorithm>
-#include <libnr/nr-matrix.h>
-#include <libnr/nr-point-matrix-ops.h>
-
-#include <glib.h>
-
-#include "svg/svg.h"
 #include "desktop.h"
 #include "style.h"
-#include "desktop-style.h"
 #include "unit-constants.h"
 
 #include "xml/repr.h"
 #include "xml/attribute-record.h"
 
-#include "sp-text.h"
+#include "sp-textpath.h"
 #include "sp-flowtext.h"
 #include "sp-flowdiv.h"
 #include "sp-flowregion.h"
 #include "sp-tspan.h"
-#include "sp-string.h"
 
 #include "text-editing.h"
 
@@ -110,9 +103,11 @@ SPStyle const * sp_te_style_at_position(SPItem const *text, Inkscape::Text::Layo
     Inkscape::Text::Layout const *layout = te_get_layout(text);
     if (layout == NULL)
         return NULL;
-    SPObject const *pos_obj = NULL;
-    layout->getSourceOfCharacter(position, (void**)&pos_obj);
-    if (pos_obj == NULL) pos_obj = text;
+    SPObject const *pos_obj = 0;
+    void *rawptr = 0;
+    layout->getSourceOfCharacter(position, &rawptr);
+    pos_obj = SP_OBJECT(rawptr);
+    if (pos_obj == 0) pos_obj = text;
     while (SP_OBJECT_STYLE(pos_obj) == NULL)
         pos_obj = SP_OBJECT_PARENT(pos_obj);   // SPStrings don't have style
     return SP_OBJECT_STYLE(pos_obj);
@@ -189,6 +184,43 @@ unsigned sp_text_get_length(SPObject const *item)
     return length;
 }
 
+/** Recursively gets the length of all the SPStrings at or below the given
+\a item, before and not including \a upto. Also adds 1 for each line break encountered. */
+unsigned sp_text_get_length_upto(SPObject const *item, SPObject const *upto)
+{
+    unsigned length = 0;
+
+    if (SP_IS_STRING(item)) {
+        return SP_STRING(item)->string.length();
+    }
+    if (is_line_break_object(item) && !SP_IS_TEXT(item)) {
+        if (item != SP_OBJECT_PARENT(item)->firstChild()) {
+            // add 1 for each newline
+            length++;
+        }
+    }
+    for (SPObject const *child = item->firstChild() ; child ; child = SP_OBJECT_NEXT(child)) {
+        if (upto && child == upto) {
+            // hit upto, return immediately
+            return length;
+        }
+        if (SP_IS_STRING(child)) {
+            length += SP_STRING(child)->string.length();
+        }
+        else {
+            if (upto && child->isAncestorOf(upto)) {
+                // upto is below us, recurse and break loop
+                length += sp_text_get_length_upto(child, upto);
+                return length;
+            } else {
+                // recurse and go to the next sibling
+                length += sp_text_get_length_upto(child, upto);
+            }
+        }
+    }
+    return length;
+}
+
 static Inkscape::XML::Node* duplicate_node_without_children(Inkscape::XML::Node const *old_node)
 {
     switch (old_node->type()) {
@@ -246,7 +278,7 @@ static SPObject* split_text_object_tree_at(SPObject *split_obj, unsigned char_in
     if (is_line_break_object(split_obj)) {
         Inkscape::XML::Node *new_node = duplicate_node_without_children(SP_OBJECT_REPR(split_obj));
         SP_OBJECT_REPR(SP_OBJECT_PARENT(split_obj))->addChild(new_node, SP_OBJECT_REPR(split_obj));
-        sp_repr_unref(new_node);
+        Inkscape::GC::release(new_node);
         split_attributes(split_obj, SP_OBJECT_NEXT(split_obj), char_index);
         return SP_OBJECT_NEXT(split_obj);
     }
@@ -256,7 +288,7 @@ static SPObject* split_text_object_tree_at(SPObject *split_obj, unsigned char_in
     // copy the split node
     Inkscape::XML::Node *new_node = duplicate_node_without_children(SP_OBJECT_REPR(split_obj));
     SP_OBJECT_REPR(duplicate_obj)->appendChild(new_node);
-    sp_repr_unref(new_node);
+    Inkscape::GC::release(new_node);
 
     // sort out the copied attributes (x/y/dx/dy/rotate)
     split_attributes(split_obj, duplicate_obj->firstChild(), char_index);
@@ -266,10 +298,10 @@ static SPObject* split_text_object_tree_at(SPObject *split_obj, unsigned char_in
     while (split_obj) {
         Inkscape::XML::Node *move_repr = SP_OBJECT_REPR(split_obj);
         SPObject *next_obj = SP_OBJECT_NEXT(split_obj);  // this is about to become invalidated by removeChild()
-        sp_repr_ref(move_repr);
+        Inkscape::GC::anchor(move_repr);
         SP_OBJECT_REPR(SP_OBJECT_PARENT(split_obj))->removeChild(move_repr);
         SP_OBJECT_REPR(duplicate_obj)->appendChild(move_repr);
-        sp_repr_unref(move_repr);
+        Inkscape::GC::release(move_repr);
 
         split_obj = next_obj;
     }
@@ -288,19 +320,20 @@ Inkscape::Text::Layout::iterator sp_te_insert_line (SPItem *item, Inkscape::Text
         return position;
 
     Inkscape::Text::Layout const *layout = te_get_layout(item);
-    SPObject *split_obj;
+    SPObject *split_obj = 0;
     Glib::ustring::iterator split_text_iter;
-    if (position == layout->end())
-        split_obj = NULL;
-    else
-        layout->getSourceOfCharacter(position, (void**)&split_obj, &split_text_iter);
+    if (position != layout->end()) {
+        void *rawptr = 0;
+        layout->getSourceOfCharacter(position, &rawptr, &split_text_iter);
+        split_obj = SP_OBJECT(rawptr);
+    }
 
-    if (split_obj == NULL || is_line_break_object(split_obj)) {
-        if (split_obj == NULL) split_obj = item->lastChild();
+    if (split_obj == 0 || is_line_break_object(split_obj)) {
+        if (split_obj == 0) split_obj = item->lastChild();
         if (split_obj) {
             Inkscape::XML::Node *new_node = duplicate_node_without_children(SP_OBJECT_REPR(split_obj));
             SP_OBJECT_REPR(SP_OBJECT_PARENT(split_obj))->addChild(new_node, SP_OBJECT_REPR(split_obj));
-            sp_repr_unref(new_node);
+            Inkscape::GC::release(new_node);
         }
     } else if (SP_IS_STRING(split_obj)) {
         Glib::ustring *string = &SP_STRING(split_obj)->string;
@@ -354,11 +387,11 @@ static void insert_into_spstring(SPString *string_item, Glib::ustring::iterator
 
     SPObject *parent_item = string_item;
     for ( ; ; ) {
+        char_index += sum_sibling_text_lengths_before(parent_item);
         parent_item = SP_OBJECT_PARENT(parent_item);
         TextTagAttributes *attributes = attributes_for_object(parent_item);
         if (!attributes) break;
         attributes->insert(char_index, char_count);
-        char_index += sum_sibling_text_lengths_before(parent_item);
     }
 }
 
@@ -374,14 +407,16 @@ sp_te_insert(SPItem *item, Inkscape::Text::Layout::iterator const &position, gch
     }
 
     Inkscape::Text::Layout const *layout = te_get_layout(item);
-    SPObject *source_obj;
+    SPObject *source_obj = 0;
+    void *rawptr = 0;
     Glib::ustring::iterator iter_text;
     // we want to insert after the previous char, not before the current char.
     // it makes a difference at span boundaries
     Inkscape::Text::Layout::iterator it_prev_char = position;
     bool cursor_at_start = !it_prev_char.prevCharacter();
     bool cursor_at_end = position == layout->end();
-    layout->getSourceOfCharacter(it_prev_char, (void**)&source_obj, &iter_text);
+    layout->getSourceOfCharacter(it_prev_char, &rawptr, &iter_text);
+    source_obj = SP_OBJECT(rawptr);
     if (SP_IS_STRING(source_obj)) {
         // the simple case
         if (!cursor_at_start) iter_text++;
@@ -414,7 +449,7 @@ sp_te_insert(SPItem *item, Inkscape::Text::Layout::iterator const &position, gch
                 // need to add an SPString in this (pathological) case
                 Inkscape::XML::Node *rstring = sp_repr_new_text("");
                 SP_OBJECT_REPR(source_obj)->addChild(rstring, NULL);
-                sp_repr_unref(rstring);
+                Inkscape::GC::release(rstring);
                 g_assert(SP_IS_STRING(source_obj->firstChild()));
                 string_item = SP_STRING(source_obj->firstChild());
             }
@@ -440,11 +475,11 @@ static void move_child_nodes(Inkscape::XML::Node *from_repr, Inkscape::XML::Node
 {
     while (from_repr->childCount()) {
         Inkscape::XML::Node *child = prepend ? from_repr->lastChild() : from_repr->firstChild();
-        sp_repr_ref(child);
+        Inkscape::GC::anchor(child);
         from_repr->removeChild(child);
         if (prepend) to_repr->addChild(child, NULL);
         else to_repr->appendChild(child);
-        sp_repr_unref(child);
+        Inkscape::GC::release(child);
     }
 }
 
@@ -491,6 +526,13 @@ static SPObject* delete_line_break(SPObject *root, SPObject *item, bool *next_is
     */
     Inkscape::XML::Node *new_span_repr = sp_repr_new(span_name_for_text_object(root));
 
+    if (gchar const *a = this_repr->attribute("dx"))
+        new_span_repr->setAttribute("dx", a);
+    if (gchar const *a = this_repr->attribute("dy"))
+        new_span_repr->setAttribute("dy", a);
+    if (gchar const *a = this_repr->attribute("rotate"))
+        new_span_repr->setAttribute("rotate", a);
+
     SPObject *following_item = item;
     while (SP_OBJECT_NEXT(following_item) == NULL) {
         following_item = SP_OBJECT_PARENT(following_item);
@@ -558,14 +600,13 @@ static void erase_from_spstring(SPString *string_item, Glib::ustring::iterator i
 
     SPObject *parent_item = string_item;
     for ( ; ; ) {
+        char_index += sum_sibling_text_lengths_before(parent_item);
         parent_item = SP_OBJECT_PARENT(parent_item);
         TextTagAttributes *attributes = attributes_for_object(parent_item);
         if (attributes == NULL) break;
 
         attributes->erase(char_index, char_count);
         attributes->writeTo(SP_OBJECT_REPR(parent_item));
-        for (SPObject *sibling = SP_OBJECT_PARENT(parent_item)->firstChild() ; sibling && sibling != parent_item ; sibling = SP_OBJECT_NEXT(sibling))
-            char_index += sp_text_get_length(sibling);
     }
 }
 
@@ -588,15 +629,18 @@ sp_te_delete (SPItem *item, Inkscape::Text::Layout::iterator const &start, Inksc
         last = start;
     }
     Inkscape::Text::Layout const *layout = te_get_layout(item);
-    SPObject *start_item, *end_item;
+    SPObject *start_item = 0, *end_item = 0;
+    void *rawptr = 0;
     Glib::ustring::iterator start_text_iter, end_text_iter;
-    layout->getSourceOfCharacter(first, (void**)&start_item, &start_text_iter);
-    layout->getSourceOfCharacter(last, (void**)&end_item, &end_text_iter);
-    if (start_item == NULL)
+    layout->getSourceOfCharacter(first, &rawptr, &start_text_iter);
+    start_item = SP_OBJECT(rawptr);
+    layout->getSourceOfCharacter(last, &rawptr, &end_text_iter);
+    end_item = SP_OBJECT(rawptr);
+    if (start_item == 0)
         return first;   // start is at end of text
     if (is_line_break_object(start_item))
         move_to_end_of_paragraph(&start_item, &start_text_iter);
-    if (end_item == NULL) {
+    if (end_item == 0) {
         end_item = item->lastChild();
         move_to_end_of_paragraph(&end_item, &end_text_iter);
     }
@@ -712,9 +756,11 @@ sp_te_get_string_multiline (SPItem const *text, Inkscape::Text::Layout::iterator
     Glib::ustring result;
     // not a particularly fast piece of code. I'll optimise it if people start to notice.
     for ( ; first < last ; first.nextCharacter()) {
-        SPObject *char_item;
+        SPObject *char_item = 0;
+        void *rawptr = 0;
         Glib::ustring::iterator text_iter;
-        layout->getSourceOfCharacter(first, (void**)&char_item, &text_iter);
+        layout->getSourceOfCharacter(first, &rawptr, &text_iter);
+        char_item = SP_OBJECT(rawptr);
         if (SP_IS_STRING(char_item))
             result += *text_iter;
         else
@@ -763,22 +809,22 @@ sp_te_set_repr_text_multiline(SPItem *text, gchar const *str)
             Inkscape::XML::Node *rtspan;
             if (SP_IS_TEXT(text)) { // create a tspan for each line
                 rtspan = sp_repr_new ("svg:tspan");
-                sp_repr_set_attr (rtspan, "sodipodi:role", "line");
+                rtspan->setAttribute("sodipodi:role", "line");
             } else { // create a flowPara for each line
                 rtspan = sp_repr_new ("svg:flowPara");
             }
             Inkscape::XML::Node *rstr = sp_repr_new_text(p);
-            sp_repr_add_child (rtspan, rstr, NULL);
-            sp_repr_unref(rstr);
+            rtspan->addChild(rstr, NULL);
+            Inkscape::GC::release(rstr);
             repr->appendChild(rtspan);
-            sp_repr_unref(rtspan);
+            Inkscape::GC::release(rtspan);
         }
         p = (e) ? e + 1 : NULL;
     }
     if (is_textpath) {
         Inkscape::XML::Node *rstr = sp_repr_new_text(content);
-        sp_repr_add_child (repr, rstr, NULL);
-        sp_repr_unref(rstr);
+        repr->addChild(rstr, NULL);
+        Inkscape::GC::release(rstr);
     }
 
     g_free (content);
@@ -796,9 +842,11 @@ text_tag_attributes_at_position(SPItem *item, Inkscape::Text::Layout::iterator c
         return NULL;   // flowtext doesn't support kerning yet
     SPText *text = SP_TEXT(item);
 
-    SPObject *source_item;
+    SPObject *source_item = 0;
+    void *rawptr = 0;
     Glib::ustring::iterator source_text_iter;
-    text->layout.getSourceOfCharacter(position, (void**)&source_item, &source_text_iter);
+    text->layout.getSourceOfCharacter(position, &rawptr, &source_text_iter);
+    source_item = SP_OBJECT(rawptr);
 
     if (!SP_IS_STRING(source_item)) return NULL;
     Glib::ustring *string = &SP_STRING(source_item)->string;
@@ -839,11 +887,13 @@ sp_te_adjust_rotation_screen(SPItem *text, Inkscape::Text::Layout::iterator cons
     gdouble factor = 1 / desktop->current_zoom();
     NR::Matrix t = sp_item_i2doc_affine(text);
     factor = factor / NR::expansion(t);
-    SPObject *source_item;
     Inkscape::Text::Layout const *layout = te_get_layout(text);
     if (layout == NULL) return;
-    layout->getSourceOfCharacter(std::min(start, end), (void**)&source_item);
-    if (source_item == NULL) return;
+    SPObject *source_item = 0;
+    void *rawptr = 0;
+    layout->getSourceOfCharacter(std::min(start, end), &rawptr);
+    source_item = SP_OBJECT(rawptr);
+    if (source_item == 0) return;
     gdouble degrees = (180/M_PI) * atan2(pixels, SP_OBJECT_PARENT(source_item)->style->font_size.computed / factor);
 
     sp_te_adjust_rotation(text, start, end, desktop, degrees);
@@ -877,13 +927,18 @@ sp_te_adjust_tspan_letterspacing_screen(SPItem *text, Inkscape::Text::Layout::it
     Inkscape::Text::Layout const *layout = te_get_layout(text);
 
     gdouble val;
-    SPObject *source_obj;
+    SPObject *source_obj = 0;
+    void *rawptr = 0;
     unsigned nb_let;
-    layout->getSourceOfCharacter(std::min(start, end), (void**)&source_obj);
-    if (source_obj == NULL)    // end of text
+    layout->getSourceOfCharacter(std::min(start, end), &rawptr);
+    source_obj = SP_OBJECT(rawptr);
+
+    if (source_obj == 0) {   // end of text
         source_obj = text->lastChild();
-    else if (SP_IS_STRING(source_obj))
+    }
+    if (SP_IS_STRING(source_obj)) {
         source_obj = source_obj->parent;
+    }
 
     SPStyle *style = SP_OBJECT_STYLE (source_obj);
 
@@ -1075,6 +1130,7 @@ static bool objects_have_equal_style(SPObject const *parent, SPObject const *chi
 
     Glib::ustring child_style_construction(parent_style);
     while (child != parent) {
+        // FIXME: this assumes that child's style is only in style= whereas it can also be in css attributes!
         char const *style_text = SP_OBJECT_REPR(child)->attribute("style");
         if (style_text && *style_text) {
             child_style_construction += ';';
@@ -1176,10 +1232,10 @@ static void recursively_apply_style(SPObject *common_ancestor, SPCSSAttr const *
                         Inkscape::XML::Node *text_before = sp_repr_new_text(string_item->string.substr(0, start_char_index).c_str());
                         SP_OBJECT_REPR(common_ancestor)->addChild(text_before, prev_repr);
                         SP_OBJECT_REPR(common_ancestor)->addChild(child_span, text_before);
-                        sp_repr_unref(text_before);
+                        Inkscape::GC::release(text_before);
                         Inkscape::XML::Node *text_in_span = sp_repr_new_text(string_item->string.substr(start_char_index, end_char_index - start_char_index).c_str());
                         child_span->appendChild(text_in_span);
-                        sp_repr_unref(text_in_span);
+                        Inkscape::GC::release(text_in_span);
                         SP_OBJECT_REPR(child)->setContent(string_item->string.substr(end_char_index).c_str());
 
                     } else if (child == end_item) {
@@ -1191,7 +1247,7 @@ static void recursively_apply_style(SPObject *common_ancestor, SPCSSAttr const *
                         SP_OBJECT_REPR(common_ancestor)->addChild(child_span, prev_repr);
                         Inkscape::XML::Node *text_in_span = sp_repr_new_text(string_item->string.substr(0, end_char_index).c_str());
                         child_span->appendChild(text_in_span);
-                        sp_repr_unref(text_in_span);
+                        Inkscape::GC::release(text_in_span);
                         SP_OBJECT_REPR(child)->setContent(string_item->string.substr(end_char_index).c_str());
 
                     } else if (start_text_iter != string_item->string.begin()) {
@@ -1201,10 +1257,10 @@ static void recursively_apply_style(SPObject *common_ancestor, SPCSSAttr const *
                         Inkscape::XML::Node *text_before = sp_repr_new_text(string_item->string.substr(0, start_char_index).c_str());
                         SP_OBJECT_REPR(common_ancestor)->addChild(text_before, prev_repr);
                         SP_OBJECT_REPR(common_ancestor)->addChild(child_span, text_before);
-                        sp_repr_unref(text_before);
+                        Inkscape::GC::release(text_before);
                         Inkscape::XML::Node *text_in_span = sp_repr_new_text(string_item->string.substr(start_char_index).c_str());
                         child_span->appendChild(text_in_span);
-                        sp_repr_unref(text_in_span);
+                        Inkscape::GC::release(text_in_span);
                         child->deleteObject();
                         child = sp_object_get_child_by_repr(common_ancestor, child_span);
 
@@ -1214,13 +1270,13 @@ static void recursively_apply_style(SPObject *common_ancestor, SPCSSAttr const *
                 if (surround_entire_string) {
                     Inkscape::XML::Node *child_repr = SP_OBJECT_REPR(child);
                     SP_OBJECT_REPR(common_ancestor)->addChild(child_span, child_repr);
-                    sp_repr_ref(child_repr);
+                    Inkscape::GC::anchor(child_repr);
                     SP_OBJECT_REPR(common_ancestor)->removeChild(child_repr);
                     child_span->appendChild(child_repr);
-                    sp_repr_unref(child_repr);
+                    Inkscape::GC::release(child_repr);
                     child = sp_object_get_child_by_repr(common_ancestor, child_span);
                 }
-                sp_repr_unref(child_span);
+                Inkscape::GC::release(child_span);
 
             } else if (child != end_item) {   // not a string and we're applying to the entire object. This is easy
                 apply_css_recursive(child, css);
@@ -1293,10 +1349,10 @@ static bool tidy_operator_inexplicable_spans(SPObject **item)
     SPObject *next = *item;
     while ((*item)->hasChildren()) {
         Inkscape::XML::Node *repr = SP_OBJECT_REPR((*item)->firstChild());
-        sp_repr_ref(repr);
+        Inkscape::GC::anchor(repr);
         SP_OBJECT_REPR(*item)->removeChild(repr);
         SP_OBJECT_REPR(SP_OBJECT_PARENT(*item))->addChild(repr, SP_OBJECT_REPR(next));
-        sp_repr_unref(repr);
+        Inkscape::GC::release(repr);
         next = SP_OBJECT_NEXT(next);
     }
     (*item)->deleteObject();
@@ -1387,10 +1443,10 @@ static bool redundant_double_nesting_processor(SPObject **item, SPObject *child,
     else insert_after_repr = SP_OBJECT_REPR(*item);
     while (SP_OBJECT_REPR(child)->childCount()) {
         Inkscape::XML::Node *move_repr = SP_OBJECT_REPR(child)->firstChild();
-        sp_repr_ref(move_repr);
+        Inkscape::GC::anchor(move_repr);
         SP_OBJECT_REPR(child)->removeChild(move_repr);
         SP_OBJECT_REPR(SP_OBJECT_PARENT(*item))->addChild(move_repr, insert_after_repr);
-        sp_repr_unref(move_repr);
+        Inkscape::GC::release(move_repr);
         insert_after_repr = move_repr;      // I think this will stay valid long enough. It's garbage collected these days.
     }
     child->deleteObject();
@@ -1454,7 +1510,7 @@ static bool redundant_semi_nesting_processor(SPObject **item, SPObject *child, b
         SP_OBJECT_REPR(SP_OBJECT_PARENT(*item))->addChild(new_span, SP_OBJECT_REPR(*item));
     new_span->setAttribute("style", SP_OBJECT_REPR(child)->attribute("style"));
     move_child_nodes(SP_OBJECT_REPR(child), new_span);
-    sp_repr_unref(new_span);
+    Inkscape::GC::release(new_span);
     child->deleteObject();
     return true;
 }
@@ -1605,17 +1661,20 @@ void sp_te_apply_style(SPItem *text, Inkscape::Text::Layout::iterator const &sta
         last = start;
     }
     Inkscape::Text::Layout const *layout = te_get_layout(text);
-    SPObject *start_item, *end_item;
+    SPObject *start_item = 0, *end_item = 0;
+    void *rawptr = 0;
     Glib::ustring::iterator start_text_iter, end_text_iter;
-    layout->getSourceOfCharacter(first, (void**)&start_item, &start_text_iter);
-    layout->getSourceOfCharacter(last, (void**)&end_item, &end_text_iter);
-    if (start_item == NULL)
+    layout->getSourceOfCharacter(first, &rawptr, &start_text_iter);
+    start_item = SP_OBJECT(rawptr);
+    layout->getSourceOfCharacter(last, &rawptr, &end_text_iter);
+    end_item = SP_OBJECT(rawptr);
+    if (start_item == 0)
         return;   // start is at end of text
     if (is_line_break_object(start_item))
         start_item = SP_OBJECT_NEXT(start_item);
     if (is_line_break_object(end_item))
         end_item = SP_OBJECT_NEXT(end_item);
-    if (end_item == NULL) end_item = text;
+    if (end_item == 0) end_item = text;
 
     /* stage 1: applying the style. Go up to the closest common ancestor of
     start and end and then semi-recursively apply the style to all the
