@@ -2,19 +2,14 @@
    This file is part of potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
-/* $Id: trace.cpp,v 1.2 2005/03/06 13:43:38 ishmal Exp $ */
+/* $Id: trace.cpp 10957 2006-02-28 23:16:27Z ishmal $ */
 /* transform jaggy paths into smooth curves */
 
-#include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
-#include <string.h>
 
-#include "potracelib.h"
 #include "curve.h"
 #include "lists.h"
-#include "auxiliary.h"
-#include "trace.h"
 #include "progress.h"
 
 #define INFTY 10000000	/* it suffices that this is longer than any
@@ -31,7 +26,7 @@
    a,n are integers and n>0. */
 
 #define SAFE_MALLOC(var, n, typ) \
-  if ((var = (typ *)malloc((n)*sizeof(typ))) == NULL) goto malloc_error 
+  if ((var = (typ *)malloc((n)*sizeof(typ))) == NULL) goto malloc_error
 
 /* ---------------------------------------------------------------------- */
 /* auxiliary functions */
@@ -40,7 +35,7 @@
    but then restricted to one of the major wind directions (n, nw, w, etc) */
 static inline point_t dorth_infty(dpoint_t p0, dpoint_t p2) {
   point_t r;
-  
+
   r.y = sign(p2.x-p0.x);
   r.x = -sign(p2.y-p0.y);
 
@@ -105,21 +100,21 @@ static void pointslope(privpath_t *pp, int i, int j, dpoint_t *ctr, dpoint_t *di
     i+=n;
     r+=1;
   }
-  
+
   x = sums[j+1].x-sums[i].x+r*sums[n].x;
   y = sums[j+1].y-sums[i].y+r*sums[n].y;
   x2 = sums[j+1].x2-sums[i].x2+r*sums[n].x2;
   xy = sums[j+1].xy-sums[i].xy+r*sums[n].xy;
   y2 = sums[j+1].y2-sums[i].y2+r*sums[n].y2;
   k = j+1-i+r*n;
-  
+
   ctr->x = x/k;
   ctr->y = y/k;
 
   a = (x2-(double)x*x/k)/k;
   b = (xy-(double)x*y/k)/k;
   c = (y2-(double)y*y/k)/k;
-  
+
   lambda2 = (a+c+sqrt((a-c)*(a-c)+4*b*b))/2; /* larger e.value */
 
   /* now find e.vector for lambda2 */
@@ -245,7 +240,7 @@ static double tangent(dpoint_t p0, dpoint_t p1, dpoint_t p2, dpoint_t p3, dpoint
   a = A - 2*B + C;
   b = -2*A + 2*B;
   c = A;
-  
+
   d = b*b - 4*a*c;
 
   if (a==0 || d<0) {
@@ -291,7 +286,7 @@ static int calc_sums(privpath_t *pp) {
     pp->sums[i+1].xy = pp->sums[i].xy + x*y;
     pp->sums[i+1].y2 = pp->sums[i].y2 + y*y;
   }
-  return 0;  
+  return 0;
 
  malloc_error:
   return 1;
@@ -362,7 +357,7 @@ static int calc_lon(privpath_t *pp) {
 
   /* determine pivot points: for each i, let pivk[i] be the furthest k
      such that all j with i<j<k lie on a line connecting i,k. */
-  
+
   for (i=n-1; i>=0; i--) {
     ct[0] = ct[1] = ct[2] = ct[3] = 0;
 
@@ -379,7 +374,7 @@ static int calc_lon(privpath_t *pp) {
     k = nc[i];
     k1 = i;
     while (1) {
-      
+
       dir = (3+3*sign(pt[k].x-pt[k1].x)+sign(pt[k].y-pt[k1].y))/2;
       ct[dir]++;
 
@@ -411,7 +406,7 @@ static int calc_lon(privpath_t *pp) {
 	if (xprod(constraint[1], off) <= 0) {
 	  constraint[1] = off;
 	}
-      }	
+      }
       k1 = k;
       k = nc[k1];
       if (!cyclic(k,i,k1)) {
@@ -475,7 +470,7 @@ static int calc_lon(privpath_t *pp) {
 
 
 /* ---------------------------------------------------------------------- */
-/* Stage 2: calculate the optimal polygon (Sec. 2.2.2-2.2.4). */ 
+/* Stage 2: calculate the optimal polygon (Sec. 2.2.2-2.2.4). */
 
 /* Auxiliary function: calculate the penalty of an edge from i to j in
    the given path. This needs the "lon" and "sum*" data. */
@@ -497,14 +492,14 @@ static double penalty3(privpath_t *pp, int i, int j) {
     j-=n;
     r+=1;
   }
-  
+
   x = sums[j+1].x-sums[i].x+r*sums[n].x;
   y = sums[j+1].y-sums[i].y+r*sums[n].y;
   x2 = sums[j+1].x2-sums[i].x2+r*sums[n].x2;
   xy = sums[j+1].xy-sums[i].xy+r*sums[n].xy;
   y2 = sums[j+1].y2-sums[i].y2+r*sums[n].y2;
   k = j+1-i+r*n;
-  
+
   px = (pt[i].x+pt[j].x)/2.0-pt[0].x;
   py = (pt[i].y+pt[j].y)/2.0-pt[0].y;
   ey = (pt[j].x-pt[i].x);
@@ -513,7 +508,7 @@ static double penalty3(privpath_t *pp, int i, int j) {
   a = ((x2-2*x*px)/k+px*px);
   b = ((xy-x*py-y*px)/k+px*py);
   c = ((y2-2*y*py)/k+py*py);
-  
+
   s = ex*ex*a + 2*ex*ey*b + ey*ey*c;
 
   return sqrt(s);
@@ -524,7 +519,7 @@ static double penalty3(privpath_t *pp, int i, int j) {
    is in the polygon. Fixme: ### implement cyclic version. */
 static int bestpolygon(privpath_t *pp)
 {
-  int i, j, m, k;     
+  int i, j, m, k;
   int n = pp->len;
   double *pen = NULL; /* pen[n+1]: penalty vector */
   int *prev = NULL;   /* prev[n+1]: best path pointer vector */
@@ -618,7 +613,7 @@ static int bestpolygon(privpath_t *pp)
   free(seg0);
   free(seg1);
   return 0;
-  
+
  malloc_error:
   free(pen);
   free(prev);
@@ -662,7 +657,7 @@ static int adjust_vertices(privpath_t *pp) {
   if (r) {
     goto malloc_error;
   }
-  
+
   /* calculate "optimal" point-slope representation for each line
      segment */
   for (i=0; i<m; i++) {
@@ -721,7 +716,7 @@ static int adjust_vertices(privpath_t *pp) {
 	Q[l][k] = q[j][l][k] + q[i][l][k];
       }
     }
-    
+
     while(1) {
       /* minimize the quadratic form Q on the unit square */
       /* find intersection */
@@ -730,7 +725,7 @@ static int adjust_vertices(privpath_t *pp) {
       /* work around gcc bug #12243 */
       free(NULL);
 #endif
-      
+
       det = Q[0][0]*Q[1][1] - Q[0][1]*Q[1][0];
       if (det != 0.0) {
 	w.x = (-Q[0][2]*Q[1][1] + Q[1][2]*Q[0][1]) / det;
@@ -891,7 +886,7 @@ static int smooth(privcurve_t *curve, int sign, double alphamax) {
     curve->alpha[j] = alpha;	/* store the "cropped" value of alpha */
     curve->beta[j] = 0.5;
   }
-
+  curve->alphacurve = 1;
   return 0;
 }
 
@@ -967,8 +962,8 @@ static int opti_penalty(privpath_t *pp, int i, int j, opti_t *res, double opttol
   A2 = dpara(p0, p1, p3);
   A3 = dpara(p0, p2, p3);
   /* A4 = dpara(p1, p2, p3); */
-  A4 = A1+A3-A2;    
-  
+  A4 = A1+A3-A2;
+
   if (A2 == A1) {  /* this should never happen */
     return 1;
   }
@@ -976,7 +971,7 @@ static int opti_penalty(privpath_t *pp, int i, int j, opti_t *res, double opttol
   t = A3/(A3-A4);
   s = A2/(A2-A1);
   A = A2 * t / 2.0;
-  
+
   if (A == 0.0) {  /* this should never happen */
     return 1;
   }
@@ -1165,6 +1160,7 @@ static int opticurve(privpath_t *pp, double opttolerance) {
     i1 = mod(i+1,om);
     pp->ocurve.beta[i] = s[i] / (s[i] + t[i1]);
   }
+  pp->ocurve.alphacurve = 1;
 
   free(pt);
   free(pen);
@@ -1205,7 +1201,7 @@ int process_path(path_t *plist, const potrace_param_t *param, progress_t *progre
     }
     cn = 0;
   }
-  
+
   /* call downstream function with each path */
   list_forall (p, plist) {
     TRY(calc_sums(p->priv));
