@@ -6,6 +6,7 @@
  *   Aubanel MONNIER <aubi@libertysurf.fr>
  *   Frank Felfe <innerspace@iname.com>
  *   Lauris Kaplinski <lauris@kaplinski.com>
+ *   Tim Dwyer <tgdwyer@gmail.com>
  *
  * Copyright (C) 1999-2004, 2005 Authors
  *
@@ -17,29 +18,16 @@
 # include <config.h>
 #endif
 
-#include "sp-item.h"
 #include "verbs.h"
 
 #include "dialogs/unclump.h"
+#include "removeoverlap/removeoverlap.h"
+#include "graphlayout/graphlayout.h"
 
-#include <gtkmm/buttonbox.h>
-#include <gtkmm/button.h>
-#include <gtkmm/table.h>
-#include <gtkmm/image.h>
-#include <gtkmm/frame.h>
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/tooltips.h>
+#include <gtkmm/spinbutton.h>
 
-#include <sigc++/sigc++.h>
 
-#include <list>
-#include <map>
-#include <vector>
 
-#include "libnr/nr-macros.h"
-#include "libnr/nr-point-fns.h"
-#include "libnr/nr-point-matrix-ops.h"
-#include "libnr/nr-rect.h"
 
 #include "util/glib-list-iterators.h"
 
@@ -59,7 +47,6 @@
 #include "text-editing.h"
 
 #include "node-context.h" //For node align/distribute function
-#include "nodepath.h" //For node align/distribute function
 
 #include "tools-switch.h"
 
@@ -83,7 +70,7 @@ public :
         _id(id),
         _parent(parent)
     {
-        Gtk::Widget*  pIcon = Gtk::manage( sp_icon_get_icon( _id, GTK_ICON_SIZE_LARGE_TOOLBAR) );
+        Gtk::Widget*  pIcon = Gtk::manage( sp_icon_get_icon( _id, Inkscape::ICON_SIZE_LARGE_TOOLBAR) );
         Gtk::Button * pButton = Gtk::manage(new Gtk::Button());
         pButton->set_relief(Gtk::RELIEF_NONE);
         pIcon->show();
@@ -131,7 +118,7 @@ private :
         SPDesktop *desktop = SP_ACTIVE_DESKTOP;
         if (!desktop) return;
 
-        Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+        Inkscape::Selection *selection = sp_desktop_selection(desktop);
         if (!selection) return;
 
         using Inkscape::Util::GSListConstIterator;
@@ -172,14 +159,14 @@ private :
         }
 
         case AlignAndDistribute::PAGE:
-            mp = NR::Point(a.mx1 * sp_document_width(SP_DT_DOCUMENT(desktop)),
-                           a.my1 * sp_document_height(SP_DT_DOCUMENT(desktop)));
+            mp = NR::Point(a.mx1 * sp_document_width(sp_desktop_document(desktop)),
+                           a.my1 * sp_document_height(sp_desktop_document(desktop)));
             break;
 
         case AlignAndDistribute::DRAWING:
         {
             NR::Rect b = sp_item_bbox_desktop
-                ( (SPItem *) sp_document_root (SP_DT_DOCUMENT (desktop)) );
+                ( (SPItem *) sp_document_root (sp_desktop_document (desktop)) );
             mp = NR::Point(a.mx0 * b.min()[NR::X] + a.mx1 * b.max()[NR::X],
                            a.my0 * b.min()[NR::Y] + a.my1 * b.max()[NR::Y]);
             break;
@@ -213,7 +200,7 @@ private :
              it != selected.end();
              it++)
         {
-            sp_document_ensure_up_to_date(SP_DT_DOCUMENT (desktop));
+            sp_document_ensure_up_to_date(sp_desktop_document (desktop));
             NR::Rect b = sp_item_bbox_desktop (*it);
             NR::Point const sp(a.sx0 * b.min()[NR::X] + a.sx1 * b.max()[NR::X],
                                a.sy0 * b.min()[NR::Y] + a.sy1 * b.max()[NR::Y]);
@@ -228,7 +215,7 @@ private :
         prefs_set_int_attribute("options.clonecompensation", "value", saved_compensation);
 
         if (changed) {
-            sp_document_done ( SP_DT_DOCUMENT (desktop) );
+            sp_document_done ( sp_desktop_document (desktop) );
         }
 
 
@@ -300,7 +287,7 @@ private :
         SPDesktop *desktop = SP_ACTIVE_DESKTOP;
         if (!desktop) return;
 
-        Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+        Inkscape::Selection *selection = sp_desktop_selection(desktop);
         if (!selection) return;
 
         using Inkscape::Util::GSListConstIterator;
@@ -387,7 +374,7 @@ private :
         prefs_set_int_attribute("options.clonecompensation", "value", saved_compensation);
 
         if (changed) {
-            sp_document_done ( SP_DT_DOCUMENT (desktop) );
+            sp_document_done ( sp_desktop_document (desktop) );
         }
     }
     guint _index;
@@ -421,7 +408,7 @@ private :
     {
 
         if (!SP_ACTIVE_DESKTOP) return;
-	SPEventContext *event_context = SP_DT_EVENTCONTEXT(SP_ACTIVE_DESKTOP);
+	SPEventContext *event_context = sp_desktop_event_context(SP_ACTIVE_DESKTOP);
 	if (!SP_IS_NODE_CONTEXT (event_context)) return ;
 
         Inkscape::NodePath::Path *nodepath = SP_NODE_CONTEXT (event_context)->nodepath;
@@ -434,6 +421,102 @@ private :
     }
 };
 
+class ActionRemoveOverlaps : public Action {
+private:
+    Gtk::Label removeOverlapXGapLabel;
+    Gtk::Label removeOverlapYGapLabel;
+    Gtk::SpinButton removeOverlapXGap;
+    Gtk::SpinButton removeOverlapYGap;
+
+public:
+    ActionRemoveOverlaps(Glib::ustring const &id,
+                         Glib::ustring const &tiptext,
+                         guint row,
+                         guint column,
+                         AlignAndDistribute &dialog) :
+        Action(id, tiptext, row, column + 4,
+               dialog.removeOverlap_table(), dialog.tooltips(), dialog)
+    {
+        dialog.removeOverlap_table().set_col_spacings(3);
+    
+        removeOverlapXGap.set_digits(1);
+        removeOverlapXGap.set_size_request(60, -1);
+        removeOverlapXGap.set_increments(1.0, 5.0);
+        removeOverlapXGap.set_range(-1000.0, 1000.0);
+        removeOverlapXGap.set_value(0);
+        dialog.tooltips().set_tip(removeOverlapXGap,
+                                  _("Minimum horizontal gap (in px units) between bounding boxes"));
+        /* TRANSLATORS: Horizontal gap */
+        removeOverlapXGapLabel.set_label(_("H:"));
+
+        removeOverlapYGap.set_digits(1);
+        removeOverlapYGap.set_size_request(60, -1);
+        removeOverlapYGap.set_increments(1.0, 5.0);
+        removeOverlapYGap.set_range(-1000.0, 1000.0);
+        removeOverlapYGap.set_value(0);
+        dialog.tooltips().set_tip(removeOverlapYGap,
+                                  _("Minimum vertical gap (in px units) between bounding boxes"));
+        /* TRANSLATORS: Vertical gap */
+        removeOverlapYGapLabel.set_label(_("V:"));
+
+        dialog.removeOverlap_table().attach(removeOverlapXGapLabel, column, column+1, row, row+1, Gtk::FILL, Gtk::FILL);
+        dialog.removeOverlap_table().attach(removeOverlapXGap, column+1, column+2, row, row+1, Gtk::FILL, Gtk::FILL);
+        dialog.removeOverlap_table().attach(removeOverlapYGapLabel, column+2, column+3, row, row+1, Gtk::FILL, Gtk::FILL);
+        dialog.removeOverlap_table().attach(removeOverlapYGap, column+3, column+4, row, row+1, Gtk::FILL, Gtk::FILL);
+
+    }
+
+private :
+    virtual void on_button_click()
+    {
+        if (!SP_ACTIVE_DESKTOP) return;
+
+        // see comment in ActionAlign above
+        int saved_compensation = prefs_get_int_attribute("options.clonecompensation", "value", SP_CLONE_COMPENSATION_UNMOVED);
+        prefs_set_int_attribute("options.clonecompensation", "value", SP_CLONE_COMPENSATION_UNMOVED);
+
+        // xGap and yGap are the minimum space required between bounding rectangles.
+        double const xGap = removeOverlapXGap.get_value();
+        double const yGap = removeOverlapYGap.get_value();
+        removeoverlap(sp_desktop_selection(SP_ACTIVE_DESKTOP)->itemList(),
+                      xGap, yGap);
+
+        // restore compensation setting
+        prefs_set_int_attribute("options.clonecompensation", "value", saved_compensation);
+
+        sp_document_done(sp_desktop_document(SP_ACTIVE_DESKTOP));
+    }
+};
+
+class ActionGraphLayout : public Action {
+public:
+    ActionGraphLayout(Glib::ustring const &id,
+                         Glib::ustring const &tiptext,
+                         guint row,
+                         guint column,
+                         AlignAndDistribute &dialog) :
+        Action(id, tiptext, row, column + 4,
+               dialog.graphLayout_table(), dialog.tooltips(), dialog)
+    {}
+
+private :
+    virtual void on_button_click()
+    {
+        if (!SP_ACTIVE_DESKTOP) return;
+
+        // see comment in ActionAlign above
+        int saved_compensation = prefs_get_int_attribute("options.clonecompensation", "value", SP_CLONE_COMPENSATION_UNMOVED);
+        prefs_set_int_attribute("options.clonecompensation", "value", SP_CLONE_COMPENSATION_UNMOVED);
+
+        graphlayout(sp_desktop_selection(SP_ACTIVE_DESKTOP)->itemList());
+
+        // restore compensation setting
+        prefs_set_int_attribute("options.clonecompensation", "value", saved_compensation);
+
+        sp_document_done(sp_desktop_document(SP_ACTIVE_DESKTOP));
+    }
+};
+
 class ActionUnclump : public Action {
 public :
     ActionUnclump(const Glib::ustring &id,
@@ -454,18 +537,18 @@ private :
         int saved_compensation = prefs_get_int_attribute("options.clonecompensation", "value", SP_CLONE_COMPENSATION_UNMOVED);
         prefs_set_int_attribute("options.clonecompensation", "value", SP_CLONE_COMPENSATION_UNMOVED);
 
-        unclump ((GSList *) SP_DT_SELECTION(SP_ACTIVE_DESKTOP)->itemList());
+        unclump ((GSList *) sp_desktop_selection(SP_ACTIVE_DESKTOP)->itemList());
 
         // restore compensation setting
         prefs_set_int_attribute("options.clonecompensation", "value", saved_compensation);
 
-        sp_document_done (SP_DT_DOCUMENT (SP_ACTIVE_DESKTOP));
+        sp_document_done (sp_desktop_document (SP_ACTIVE_DESKTOP));
     }
 };
 
-class ActionRadomize : public Action {
+class ActionRandomize : public Action {
 public :
-    ActionRadomize(const Glib::ustring &id,
+    ActionRandomize(const Glib::ustring &id,
                const Glib::ustring &tiptext,
                guint row,
                guint column,
@@ -480,7 +563,7 @@ private :
         SPDesktop *desktop = SP_ACTIVE_DESKTOP;
         if (!desktop) return;
 
-        Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+        Inkscape::Selection *selection = sp_desktop_selection(desktop);
         if (!selection) return;
 
         using Inkscape::Util::GSListConstIterator;
@@ -507,7 +590,7 @@ private :
             it != selected.end();
             ++it)
         {
-            sp_document_ensure_up_to_date(SP_DT_DOCUMENT (desktop));
+            sp_document_ensure_up_to_date(sp_desktop_document (desktop));
             NR::Rect item_box = sp_item_bbox_desktop (*it);
             // find new center, staying within bbox 
             double x = _dialog.randomize_bbox.min()[NR::X] + item_box.extent(NR::X)/2 +
@@ -522,7 +605,7 @@ private :
         // restore compensation setting
         prefs_set_int_attribute("options.clonecompensation", "value", saved_compensation);
 
-        sp_document_done (SP_DT_DOCUMENT (SP_ACTIVE_DESKTOP));
+        sp_document_done (sp_desktop_document (SP_ACTIVE_DESKTOP));
     }
 };
 
@@ -566,7 +649,7 @@ private :
         SPDesktop *desktop = SP_ACTIVE_DESKTOP;
         if (!desktop) return;
 
-        Inkscape::Selection *selection = SP_DT_SELECTION(desktop);
+        Inkscape::Selection *selection = sp_desktop_selection(desktop);
         if (!selection) return;
 
         using Inkscape::Util::GSListConstIterator;
@@ -634,7 +717,7 @@ private :
         }
 
         if (changed) {
-            sp_document_done (SP_DT_DOCUMENT (SP_ACTIVE_DESKTOP));
+            sp_document_done (sp_desktop_document (SP_ACTIVE_DESKTOP));
         }
     }
 };
@@ -644,7 +727,7 @@ private :
 void on_tool_changed(Inkscape::Application *inkscape, SPEventContext *context, AlignAndDistribute *daad)
 {
     SPDesktop *desktop = SP_ACTIVE_DESKTOP;
-    if (desktop && SP_DT_EVENTCONTEXT(desktop))
+    if (desktop && sp_desktop_event_context(desktop))
         daad->setMode(tools_active(desktop) == TOOLS_NODES);
 }
 
@@ -663,9 +746,13 @@ AlignAndDistribute::AlignAndDistribute()
       randomize_bbox (NR::Point (0, 0), NR::Point (0, 0)),
       _alignFrame(_("Align")),
       _distributeFrame(_("Distribute")),
+      _removeOverlapFrame(_("Remove overlaps")),
+      _graphLayoutFrame(_("Connector network layout")),
       _nodesFrame(_("Nodes")),
       _alignTable(2, 6, true),
       _distributeTable(3, 6, true),
+      _removeOverlapTable(1, 5, false),
+      _graphLayoutTable(1, 5, false),
       _nodesTable(1, 4, true),
       _anchorLabel(_("Relative to: "))
 {
@@ -729,15 +816,15 @@ AlignAndDistribute::AlignAndDistribute()
                         _("Make vertical gaps between objects equal"),
                         1, 4, true, NR::Y, .5, .5);
 
-    addDistributeButton("distribute_bottom",
-                        _("Distribute bottoms equidistantly"),
-                        1, 1, false, NR::Y, 1., 0.);
+    addDistributeButton("distribute_top",
+                        _("Distribute tops equidistantly"),
+                        1, 1, false, NR::Y, 0, 1);
     addDistributeButton("distribute_vcentre",
                         _("Distribute centers equidistantly vertically"),
                         1, 2, false, NR::Y, .5, .5);
-    addDistributeButton("distribute_top",
-                        _("Distribute tops equidistantly"),
-                        1, 3, false, NR::Y, 0, 1);
+    addDistributeButton("distribute_bottom",
+                        _("Distribute bottoms equidistantly"),
+                        1, 3, false, NR::Y, 1., 0.);
 
     //Baseline distribs
     addBaselineButton("distribute_baselines_hor",
@@ -755,6 +842,15 @@ AlignAndDistribute::AlignAndDistribute()
                         _("Unclump objects: try to equalize edge-to-edge distances"),
                         2, 4);
 
+    //Remove overlaps
+    addRemoveOverlapsButton("remove_overlaps",
+                            _("Move objects as little as possible so that their bounding boxes do not overlap"),
+                            0, 0);
+    //Graph Layout
+    addGraphLayoutButton("graph_layout",
+                            _("Nicely arrange selected connector network"),
+                            0, 0);
+
     //Node Mode buttons
     addNodeButton("node_halign",
                   _("Align selected nodes horizontally"),
@@ -790,6 +886,8 @@ AlignAndDistribute::AlignAndDistribute()
 
     _alignFrame.add(_alignBox);
     _distributeFrame.add(_distributeTable);
+    _removeOverlapFrame.add(_removeOverlapTable);
+    _graphLayoutFrame.add(_graphLayoutTable);
     _nodesFrame.add(_nodesTable);
 
     // Top level vbox
@@ -800,6 +898,8 @@ AlignAndDistribute::AlignAndDistribute()
 
     vbox->pack_start(_alignFrame, true, true);
     vbox->pack_start(_distributeFrame, true, true);
+    vbox->pack_start(_removeOverlapFrame, true, true);
+    vbox->pack_start(_graphLayoutFrame, true, true);
     vbox->pack_start(_nodesFrame, true, true);
 
     //Connect to the global tool change signal
@@ -845,6 +945,8 @@ void AlignAndDistribute::setMode(bool nodeEdit)
 
     ((_alignFrame).*(mSel))();
     ((_distributeFrame).*(mSel))();
+    ((_removeOverlapFrame).*(mSel))();
+    ((_graphLayoutFrame).*(mSel))();
     ((_nodesFrame).*(mNode))();
 
 }
@@ -878,6 +980,24 @@ void AlignAndDistribute::addNodeButton(const Glib::ustring &id, const Glib::ustr
             *this, orientation, distribute));
 }
 
+void AlignAndDistribute::addRemoveOverlapsButton(const Glib::ustring &id, const Glib::ustring tiptext,
+                                      guint row, guint col)
+{
+    _actionList.push_back(
+        new ActionRemoveOverlaps(
+            id, tiptext, row, col, *this)
+        );
+}
+
+void AlignAndDistribute::addGraphLayoutButton(const Glib::ustring &id, const Glib::ustring tiptext,
+                                      guint row, guint col)
+{
+    _actionList.push_back(
+        new ActionGraphLayout(
+            id, tiptext, row, col, *this)
+        );
+}
+
 void AlignAndDistribute::addUnclumpButton(const Glib::ustring &id, const Glib::ustring tiptext,
                                       guint row, guint col)
 {
@@ -891,7 +1011,7 @@ void AlignAndDistribute::addRandomizeButton(const Glib::ustring &id, const Glib:
                                       guint row, guint col)
 {
     _actionList.push_back(
-        new ActionRadomize(
+        new ActionRandomize(
             id, tiptext, row, col, *this)
         );
 }
@@ -954,7 +1074,7 @@ std::list<SPItem *>::iterator AlignAndDistribute::find_master( std::list<SPItem
         break;
 
     } // end of switch statement
-    return NULL;
+    return master;
 }
 
 AlignAndDistribute::AlignTarget AlignAndDistribute::getAlignTarget()const {
@@ -971,9 +1091,9 @@ AlignAndDistribute::AlignTarget AlignAndDistribute::getAlignTarget()const {
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
