@@ -57,6 +57,8 @@ public:
 
     Gtk::Table &align_table(){return _alignTable;}
     Gtk::Table &distribute_table(){return _distributeTable;}
+    Gtk::Table &removeOverlap_table(){return _removeOverlapTable;}
+    Gtk::Table &graphLayout_table(){return _graphLayoutTable;}
     Gtk::Table &nodes_table(){return _nodesTable;}
     Gtk::Tooltips &tooltips(){return _tooltips;}
 
@@ -77,6 +79,12 @@ protected:
                         guint row, guint col);
     void addNodeButton(const Glib::ustring &id, const Glib::ustring tiptext, 
                         guint col, NR::Dim2 orientation, bool distribute);
+    void addRemoveOverlapsButton(const Glib::ustring &id,
+                        const Glib::ustring tiptext,
+                        guint row, guint col);
+    void addGraphLayoutButton(const Glib::ustring &id,
+                        const Glib::ustring tiptext,
+                        guint row, guint col);
     void addUnclumpButton(const Glib::ustring &id, const Glib::ustring tiptext, 
                         guint row, guint col);
     void addRandomizeButton(const Glib::ustring &id, const Glib::ustring tiptext, 
@@ -85,8 +93,8 @@ protected:
                            guint row, guint col, Gtk::Table &table, NR::Dim2 orientation, bool distribute);
 
     std::list<Action *> _actionList;
-    Gtk::Frame _alignFrame, _distributeFrame, _nodesFrame;
-    Gtk::Table _alignTable, _distributeTable, _nodesTable;
+    Gtk::Frame _alignFrame, _distributeFrame, _removeOverlapFrame, _graphLayoutFrame, _nodesFrame;
+    Gtk::Table _alignTable, _distributeTable, _removeOverlapTable, _graphLayoutTable, _nodesTable;
     Gtk::HBox _anchorBox;
     Gtk::VBox _alignBox;
     Gtk::Label _anchorLabel;
@@ -108,9 +116,9 @@ private:
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
