@@ -18,7 +18,8 @@
 #include "ui/dialog/dialog-manager.h"
 
 #include "ui/dialog/align-and-distribute.h"
-#include "ui/dialog/document-preferences.h"
+#include "ui/dialog/document-metadata.h"
+#include "ui/dialog/document-properties.h"
 #include "ui/dialog/export.h"
 #include "ui/dialog/extension-editor.h"
 #include "ui/dialog/fill-and-stroke.h"
@@ -76,7 +77,8 @@ Dialog *create() { return T::create(); }
  */
 DialogManager::DialogManager() {
     registerFactory("AlignAndDistribute",  &create<AlignAndDistribute>);
-    registerFactory("DocumentPreferences", &create<DocumentPreferences>);
+    registerFactory("DocumentMetadata",    &create<DocumentMetadata>);
+    registerFactory("DocumentProperties",  &create<DocumentProperties>);
     registerFactory("Export",              &create<Export>);
     registerFactory("ExtensionEditor",     &create<ExtensionEditor>);
     registerFactory("FillAndStroke",       &create<FillAndStroke>);
@@ -181,9 +183,9 @@ void DialogManager::showDialog(GQuark name) {
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
