@@ -4,6 +4,7 @@
  *
  * Author:
  *   Bryce W. Harrington <bryce@bryceharrington.org>
+ *   buliabyak@gmail.com
  *
  * Copyright (C) 2004, 2005 Authors
  *
@@ -15,20 +16,18 @@
 #endif
 
 #include <gtkmm/stock.h>
-#include <gtk/gtksignal.h>
 #include <gtk/gtk.h>
 
+#include "application/application.h"
+#include "application/editor.h"
 #include "inkscape.h"
 #include "event-context.h"
-#include "widgets/desktop-widget.h"
 #include "desktop.h"
 #include "desktop-handles.h"
-#include "dialog.h"
 #include "dialog-manager.h"
 #include "dialogs/dialog-events.h"
 #include "shortcuts.h"
 #include "prefs-utils.h"
-#include "macros.h"
 #include "interface.h"
 #include "verbs.h"
 
@@ -49,82 +48,21 @@ sp_retransientize_again (gpointer dlgPtr)
 static void
 sp_retransientize (Inkscape::Application *inkscape, SPDesktop *desktop, gpointer dlgPtr)
 {
-    gint transient_policy = prefs_get_int_attribute_limited ( "options.transientpolicy", "value", 1, 0, 2);
-
-    if (!transient_policy)
-        return;
-
-#ifndef WIN32
     Dialog *dlg = (Dialog *)dlgPtr;
-
-    GtkWindow *dialog_win = GTK_WINDOW(dlg->gobj());
-
-    if (dlg->retransientize_suppress) {
-         /* if retransientizing of this dialog is still forbidden after
-          * previous call warning turned off because it was confusingly fired
-          * when loading many files from command line
-          */
-
-         // g_warning("Retranzientize aborted! You're switching windows too fast!");
-        return;
-    }
-
-    GtkWindow *desktop_win = SP_DT_WIDGET(desktop)->window;
-
-    if (desktop_win && dialog_win)
-    {
-        dlg->retransientize_suppress = true; // disallow other attempts to retranzientize this dialog
-
-        gtk_window_set_transient_for (dialog_win, desktop_win);
-
-        /*
-         * This enables "aggressive" transientization,
-         * i.e. dialogs always emerging on top when you switch documents. Note
-         * however that this breaks "click to raise" policy of a window
-         * manager because the switched-to document will be raised at once
-         * (so that its transients also could raise)
-         */
-        if (transient_policy == 2 && !dlg->_hiddenF12 && !dlg->_user_hidden) {
-            // without this, a transient window not always emerges on top
-            gtk_window_present (dialog_win);
-        }
-    }
-
-    // we're done, allow next retransientizing not sooner than after 120 msec
-    gtk_timeout_add (120, (GtkFunction) sp_retransientize_again, (gpointer) dlg);
-#endif
-}
-
-static void
-sp_dialog_destroy (GtkObject *object, gpointer dlgPtr)
-{
-    Dialog *dlg = (Dialog *)dlgPtr;
-    sp_signal_disconnect_by_data (INKSCAPE, dlg);
-
-    delete dlg;
-//    wd.win = dlg = NULL;
-//    wd.stop = 0;
-//    x = -1000; y = -1000; w = 0; h = 0;
-}
-
-static gboolean
-sp_dialog_delete (GtkObject *object, GdkEvent *event, gpointer dlgPtr)
-{
-    Dialog *dlg = (Dialog *)dlgPtr;
-
-    dlg->save_geometry();
-    dlg->_user_hidden = true;
-
-    return FALSE; // which means, go ahead and destroy it
+    dlg->onDesktopActivated (desktop);
 }
 
 static void
 sp_dialog_shutdown (GtkObject *object, gpointer dlgPtr)
 {
     Dialog *dlg = (Dialog *)dlgPtr;
+    dlg->onShutdown();
+}
 
-    dlg->save_geometry();
-    dlg->_user_hidden = true;
+void 
+Dialog::present()
+{
+    Gtk::Dialog::present();
 }
 
 void
@@ -137,6 +75,9 @@ Dialog::save_geometry()
 
 //    g_print ("write %d %d %d %d\n", x, y, w, h);
 
+    if (x<0) x=0;
+    if (y<0) y=0;
+
     prefs_set_int_attribute (_prefs_path, "x", x);
     prefs_set_int_attribute (_prefs_path, "y", y);
     prefs_set_int_attribute (_prefs_path, "w", w);
@@ -155,6 +96,9 @@ Dialog::read_geometry()
 
 //    g_print ("read %d %d %d %d\n", x, y, w, h);
 
+        if (x<0) x=0;
+        if (y<0) y=0;
+
     // If there are stored height and width values for the dialog,
     // resize the window to match; otherwise we leave it at its default
     if (w != 0 && h != 0) {
@@ -173,16 +117,22 @@ Dialog::read_geometry()
 
 void hideCallback(GtkObject *object, gpointer dlgPtr)
 {
+    g_return_if_fail( dlgPtr != NULL );
+
     Dialog *dlg = (Dialog *)dlgPtr;
     dlg->onHideF12();
 }
 
 void unhideCallback(GtkObject *object, gpointer dlgPtr)
 {
+    g_return_if_fail( dlgPtr != NULL );
+
     Dialog *dlg = (Dialog *)dlgPtr;
     dlg->onShowF12();
 }
 
+//=====================================================================
+
 /**
  * UI::Dialog::Dialog is a base class for all dialogs in Inkscape.  The
  * purpose of this class is to provide a unified place for ensuring
@@ -195,6 +145,7 @@ void unhideCallback(GtkObject *object, gpointer dlgPtr)
  */
 Dialog::Dialog(const char *prefs_path, int verb_num, const char *apply_label)
 {
+    hide();
     set_has_separator(false);
 
     _prefs_path = prefs_path;
@@ -210,28 +161,38 @@ Dialog::Dialog(const char *prefs_path, int verb_num, const char *apply_label)
 
     GtkWidget *dlg = GTK_WIDGET(gobj());
 
-    gchar title[500];
-    sp_ui_dialog_title_string (Inkscape::Verb::get(verb_num), title);
-    set_title(title);
+    if (verb_num)
+    {
+        gchar title[500];
+        sp_ui_dialog_title_string (Inkscape::Verb::get(verb_num), title);
+        set_title(title);
+    }
 
     sp_transientize(dlg);
     retransientize_suppress = false;
-    g_signal_connect   (G_OBJECT (INKSCAPE), "activate_desktop", G_CALLBACK (sp_retransientize), (void *)this);
 
     gtk_signal_connect( GTK_OBJECT (dlg), "event", GTK_SIGNAL_FUNC(sp_dialog_event_handler), dlg );
 
     _hiddenF12 = false;
-    g_signal_connect( G_OBJECT(INKSCAPE), "dialogs_hide", G_CALLBACK(hideCallback), (void *)this );
-    g_signal_connect( G_OBJECT(INKSCAPE), "dialogs_unhide", G_CALLBACK(unhideCallback), (void *)this );
-
-    gtk_signal_connect (GTK_OBJECT (dlg), "destroy", G_CALLBACK (sp_dialog_destroy), (void *)this);
-    gtk_signal_connect (GTK_OBJECT (dlg), "delete_event", G_CALLBACK (sp_dialog_delete), (void *)this);
-    g_signal_connect   (G_OBJECT (INKSCAPE), "shut_down", G_CALLBACK (sp_dialog_shutdown), (void *)this);
+    if (Inkscape::NSApplication::Application::getNewGui())
+    {
+        _desktop_activated_connection = Inkscape::NSApplication::Editor::connectDesktopActivated (sigc::mem_fun (*this, &Dialog::onDesktopActivated));
+        _dialogs_hidden_connection = Inkscape::NSApplication::Editor::connectDialogsHidden (sigc::mem_fun (*this, &Dialog::onHideF12));
+        _dialogs_unhidden_connection = Inkscape::NSApplication::Editor::connectDialogsUnhidden (sigc::mem_fun (*this, &Dialog::onShowF12));
+        _shutdown_connection = Inkscape::NSApplication::Editor::connectShutdown (sigc::mem_fun (*this, &Dialog::onShutdown));
+    }
+    else
+    {
+        g_signal_connect   (G_OBJECT (INKSCAPE), "activate_desktop", G_CALLBACK (sp_retransientize), (void *)this);
+        g_signal_connect( G_OBJECT(INKSCAPE), "dialogs_hide", G_CALLBACK(hideCallback), (void *)this );
+        g_signal_connect( G_OBJECT(INKSCAPE), "dialogs_unhide", G_CALLBACK(unhideCallback), (void *)this );
+        g_signal_connect   (G_OBJECT (INKSCAPE), "shut_down", G_CALLBACK (sp_dialog_shutdown), (void *)this);
+    }
 
     g_signal_connect_after( gobj(), "key_press_event", (GCallback)windowKeyPress, NULL );
 
-    present();
     read_geometry();
+    present();
 }
 
 Dialog::Dialog(BaseObjectType *gobj)
@@ -241,6 +202,14 @@ Dialog::Dialog(BaseObjectType *gobj)
 
 Dialog::~Dialog()
 {
+    if (Inkscape::NSApplication::Application::getNewGui())
+    {
+        _desktop_activated_connection.disconnect();
+        _dialogs_hidden_connection.disconnect();
+        _dialogs_unhidden_connection.disconnect();
+        _shutdown_connection.disconnect();
+    }
+    
     save_geometry();
 }
 
@@ -258,6 +227,32 @@ bool Dialog::windowKeyPress( GtkWidget *widget, GdkEventKey *event )
     return sp_shortcut_invoke( shortcut, SP_ACTIVE_DESKTOP );
 }
 
+//---------------------------------------------------------------------
+
+void
+Dialog::on_response(int response_id)
+{
+    switch (response_id) {
+        case Gtk::RESPONSE_APPLY: {
+            _apply();
+            break;
+        }
+        case Gtk::RESPONSE_CLOSE: {
+            _close();
+            break;
+        }
+    }
+}
+
+bool
+Dialog::on_delete_event (GdkEventAny *event)
+{
+    save_geometry();
+    _user_hidden = true;
+
+    return false;
+}
+
 void
 Dialog::onHideF12()
 {
@@ -280,26 +275,63 @@ Dialog::onShowF12()
     _hiddenF12 = false;
 }
 
+void 
+Dialog::onShutdown()
+{
+    save_geometry();
+    _user_hidden = true;
+}
+
+void
+Dialog::onDesktopActivated (SPDesktop *desktop)
+{
+    gint transient_policy = prefs_get_int_attribute_limited ( "options.transientpolicy", "value", 1, 0, 2);
+
+    if (!transient_policy)
+        return;
+
+#ifndef WIN32
+    GtkWindow *dialog_win = GTK_WINDOW(gobj());
+
+    if (retransientize_suppress) {
+         /* if retransientizing of this dialog is still forbidden after
+          * previous call warning turned off because it was confusingly fired
+          * when loading many files from command line
+          */
+
+         // g_warning("Retranzientize aborted! You're switching windows too fast!");
+        return;
+    }
+
+    if (dialog_win)
+    {
+        retransientize_suppress = true; // disallow other attempts to retranzientize this dialog
+
+        desktop->setWindowTransient (dialog_win);
+
+        /*
+         * This enables "aggressive" transientization,
+         * i.e. dialogs always emerging on top when you switch documents. Note
+         * however that this breaks "click to raise" policy of a window
+         * manager because the switched-to document will be raised at once
+         * (so that its transients also could raise)
+         */
+        if (transient_policy == 2 && !_hiddenF12 && !_user_hidden) {
+            // without this, a transient window not always emerges on top
+            gtk_window_present (dialog_win);
+        }
+    }
+
+    // we're done, allow next retransientizing not sooner than after 120 msec
+    gtk_timeout_add (120, (GtkFunction) sp_retransientize_again, (gpointer) this);
+#endif
+}
+
 
 Inkscape::Selection*
 Dialog::_getSelection()
 {
-    return SP_DT_SELECTION(SP_ACTIVE_DESKTOP);
-}
-
-void
-Dialog::on_response(int response_id)
-{
-    switch (response_id) {
-        case Gtk::RESPONSE_APPLY: {
-            _apply();
-            break;
-        }
-        case Gtk::RESPONSE_CLOSE: {
-            _close();
-            break;
-        }
-    }
+    return sp_desktop_selection(SP_ACTIVE_DESKTOP);
 }
 
 void
@@ -335,9 +367,9 @@ Dialog::_close()
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
