@@ -13,7 +13,8 @@
 #ifndef INKSCAPE_DIALOG_H
 #define INKSCAPE_DIALOG_H
 
-#include <gtkmm.h>
+#include <gtkmm/dialog.h>
+#include <gtkmm/tooltips.h>
 
 namespace Inkscape { class Selection; }
 class SPDesktop;
@@ -26,10 +27,15 @@ class Dialog : public Gtk::Dialog {
 public:
     Dialog(BaseObjectType *gobj); // fixme: remove this
 
-    Dialog(const char *prefs_path, int verb_num, const char *apply_label = NULL);
+    Dialog(const char *prefs_path, int verb_num = 0, const char *apply_label = NULL);
 
     virtual ~Dialog();
 
+    virtual void onDesktopActivated (SPDesktop*);
+    virtual void onShutdown();
+
+    virtual void present();
+
     /** Hide and show dialogs */
     virtual void   onHideF12();
     virtual void   onShowF12();
@@ -52,6 +58,7 @@ protected:
     Gtk::Tooltips tooltips;
 
     virtual void   on_response(int response_id);
+    virtual bool   on_delete_event (GdkEventAny*);
     virtual void   _apply();
     virtual void   _close();
 
@@ -59,6 +66,11 @@ protected:
 
     Inkscape::Selection*   _getSelection();
 
+    sigc::connection _desktop_activated_connection;
+    sigc::connection _dialogs_hidden_connection;
+    sigc::connection _dialogs_unhidden_connection;
+    sigc::connection _shutdown_connection;
+
 private:
     Dialog(); // no constructor without params
 
@@ -76,9 +88,9 @@ private:
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
