@@ -22,9 +22,9 @@ namespace Dialog {
 
 FillAndStroke::FillAndStroke() 
     : Dialog ("dialogs.fillstroke", SP_VERB_DIALOG_FILL_STROKE),
-      _page_fill("Fill", 1, 1),
-      _page_stroke_paint("Stroke paint", 1, 1),
-      _page_stroke_style("Stroke style", 1, 1)
+      _page_fill(1, 1),
+      _page_stroke_paint(1, 1),
+      _page_stroke_style(1, 1)
 {
     // Top level vbox
     Gtk::VBox *vbox = get_vbox();
@@ -54,9 +54,9 @@ FillAndStroke::~FillAndStroke()
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
