@@ -21,7 +21,7 @@ namespace UI {
 namespace Dialog {
 
 LayerEditor::LayerEditor() 
-    : Dialog ("dialogs.layereditor", SP_VERB_NONE /*FIXME*/)
+    : Dialog ("dialogs.layers", SP_VERB_NONE /*FIXME*/)
 {
     // TODO:  Insert widgets
 
@@ -40,9 +40,9 @@ LayerEditor::~LayerEditor()
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
