@@ -1,9 +1,4 @@
 /*
- * This dialog is for launching scripts whose main purpose if
- * the scripting of Inkscape itself.
- *
- * Authors:
- *   Bob Jamison
  *   Other dudes from The Inkscape Organization
  *
  * Copyright (C) 2004, 2005 Authors
@@ -14,14 +9,15 @@
 # include <config.h>
 #endif
 
+#include <glibmm/i18n.h>
+#include <gtkmm/menubar.h>
+#include <gtkmm/frame.h>
+#include <gtkmm/scrolledwindow.h>
+#include <gtkmm/textview.h>
+
 #include "scriptdialog.h"
-
-#include <gtkmm.h>
-#include <glibmm.h>
-
 #include <extension/script/InkscapeScript.h>
 
-#include <glibmm/i18n.h>
 
 namespace Inkscape {
 namespace UI {
@@ -145,7 +141,8 @@ lang)
     Glib::ustring output;
     Glib::ustring error;
     Inkscape::Extension::Script::InkscapeScript engine;
-    engine.interpretScript(script, output, error, lang);
+    bool ok = engine.interpretScript(script, output, error, lang);
+    if (!ok) return;
     outputText.get_buffer()->set_text(output);
     errorText.get_buffer()->set_text(error);
 }
