@@ -14,29 +14,18 @@
 # include <config.h>
 #endif
 
-#include "tracedialog.h"
-#include "trace/trace.h"
-#include "trace/potrace/inkscape-potrace.h"
+#include <gtkmm/notebook.h>
+#include <gtkmm/frame.h>
+#include <gtkmm/spinbutton.h>
+#include <gtkmm/stock.h>
 
-#include <gtkmm.h>
-#include <gtkmm/box.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/button.h>
-
-#include <gtk/gtk.h>
-
-#include <dialogs/dialog-events.h>
 #include <gtk/gtkdialog.h> //for GTK_RESPONSE* types
 #include <glibmm/i18n.h>
-#include "interface.h"
-#include "verbs.h"
-#include "prefs-utils.h"
-#include "inkscape.h"
-#include "macros.h"
 
-#include <glib.h>
 
-#include "dialog.h"
+
+#include "tracedialog.h"
+#include "trace/potrace/inkscape-potrace.h"
 
 
 namespace Inkscape {
@@ -95,6 +84,12 @@ class TraceDialogImpl : public TraceDialog
     Gtk::Notebook   notebook;
     Gtk::Tooltips   tips;
 
+    //########## General items
+    Gtk::Frame            sioxFrame;
+    Gtk::VBox             sioxVBox;
+    Gtk::HBox             sioxBox;
+    Gtk::CheckButton      sioxButton;
+
     //########## Potrace items
     Gtk::VBox             potraceBox;
     Gtk::RadioButtonGroup potraceGroup;
@@ -188,8 +183,14 @@ void TraceDialogImpl::potraceProcess(bool do_i_trace)
     bool invert = potraceInvertButton.get_active();
     pte.setInvert(invert);
 
-    //##### Get the single-scan settings
-    /* which one? */
+    //##### Get the preprocessor settings
+    /* siox -- performed by Tracer, and before any of the others */
+    if (sioxButton.get_active())
+        tracer.enableSiox(true);
+    else
+        tracer.enableSiox(false);
+
+    /* one of the following */
     if (potraceBrightnessRadioButton.get_active())
         pte.setTraceType(Inkscape::Trace::Potrace::TRACE_BRIGHTNESS);
     else if (potraceMultiScanBrightnessRadioButton.get_active())
@@ -209,6 +210,7 @@ void TraceDialogImpl::potraceProcess(bool do_i_trace)
         pte.setInvert(false);
         }
 
+    //##### Get the single-scan settings
     /* brightness */
     double brightnessThreshold = potraceBrightnessSpinner.get_value();
     pte.setBrightnessThreshold(brightnessThreshold);
@@ -230,20 +232,19 @@ void TraceDialogImpl::potraceProcess(bool do_i_trace)
     pte.setMultiScanSmooth(do_i_smooth);
 
     //##### Get intermediate bitmap image
-    GdkPixbuf *pixbuf = tracer.getSelectedImage();
+    Glib::RefPtr<Gdk::Pixbuf> pixbuf = tracer.getSelectedImage();
     if (pixbuf)
          {
-         GdkPixbuf *preview = pte.preview(pixbuf);
+         Glib::RefPtr<Gdk::Pixbuf> preview = pte.preview(pixbuf);
          if (preview)
              {
-             Glib::RefPtr<Gdk::Pixbuf> thePreview = Glib::wrap(preview);
-             int width  = thePreview->get_width();
-             int height = thePreview->get_height();
+             int width  = preview->get_width();
+             int height = preview->get_height();
              double scaleFactor = 100.0 / (double)height;
              int newWidth  = (int) (((double)width)  * scaleFactor);
              int newHeight = (int) (((double)height) * scaleFactor);
              Glib::RefPtr<Gdk::Pixbuf> scaledPreview =
-                    thePreview->scale_simple(newWidth, newHeight,
+                    preview->scale_simple(newWidth, newHeight,
                        Gdk::INTERP_NEAREST);
              //g_object_unref(preview);
              potracePreviewImage.set(scaledPreview);
@@ -339,6 +340,18 @@ TraceDialogImpl::TraceDialogImpl()
 
 #define MARGIN 4
 
+    /*#### SIOX ####*/
+    //# for now, put at the top of the potrace box.  something better later
+    sioxButton.set_label(_("SIOX foreground selection (experimental)"));
+    sioxBox.pack_start(sioxButton, false, false, MARGIN);
+    tips.set_tip(sioxButton, 
+        _("Cover the area you want to select as the foreground"));
+    sioxVBox.pack_start(sioxBox, false, false, MARGIN);
+    sioxFrame.set_label(_("SIOX"));
+    sioxFrame.add(sioxVBox);
+    potraceBox.pack_start(sioxFrame, false, false, 0);
+
+
     //##Set up the Potrace panel
 
     /*#### brightness ####*/
@@ -430,7 +443,7 @@ TraceDialogImpl::TraceDialogImpl()
     potraceMultiScanHBox1.pack_start(potraceMultiScanBrightnessRadioButton, false, false, MARGIN);
     tips.set_tip(potraceMultiScanBrightnessRadioButton, _("Trace the given number of brightness levels"));
 
-    potraceMultiScanNrColorSpinner.set_digits(2);
+    potraceMultiScanNrColorSpinner.set_digits(0);
     potraceMultiScanNrColorSpinner.set_increments(1.0, 4.0);
     potraceMultiScanNrColorSpinner.set_range(2.0, 256.0);
     potraceMultiScanNrColorSpinner.set_value(8.0);
