@@ -14,7 +14,7 @@
 
 
 #include "previewable.h"
-
+#include "../icon-size.h"
 
 namespace Inkscape {
 namespace UI {
@@ -25,9 +25,14 @@ public:
     virtual ~PreviewFillable() {}
     virtual void clear() = 0;
     virtual void addPreview( Previewable* preview ) = 0;
-    virtual void setStyle(Gtk::BuiltinIconSize size, ViewType type) = 0;
-    virtual Gtk::BuiltinIconSize getPreviewSize() const = 0;
+    virtual void freezeUpdates() = 0;
+    virtual void thawUpdates() = 0;
+    virtual void setStyle( Inkscape::IconSize size, ViewType type) = 0;
+    virtual void setOrientation( Gtk::AnchorType how ) = 0;
+    virtual Inkscape::IconSize getPreviewSize() const = 0;
     virtual ViewType getPreviewType() const = 0;
+    virtual void setWrap( bool b ) = 0;
+    virtual bool getWrap() const = 0;
 };
 
 
