@@ -17,6 +17,7 @@
 #include <gtkmm/bin.h>
 #include <gtkmm/table.h>
 #include "previewfillable.h"
+#include "../icon-size.h"
 
 namespace Inkscape {
 namespace UI {
@@ -29,18 +30,35 @@ public:
 
     virtual void clear();
     virtual void addPreview( Previewable* preview );
-    virtual void setStyle(Gtk::BuiltinIconSize size, ViewType view);
-    virtual Gtk::BuiltinIconSize getPreviewSize() const { return _baseSize; }
+    virtual void freezeUpdates();
+    virtual void thawUpdates();
+    virtual void setStyle( Inkscape::IconSize size, ViewType view );
+    virtual void setOrientation( Gtk::AnchorType how );
+    virtual int getColumnPref() const { return _prefCols; }
+    virtual void setColumnPref( int cols );
+    virtual Inkscape::IconSize getPreviewSize() const { return _baseSize; }
     virtual ViewType getPreviewType() const { return _view; }
+    virtual void setWrap( bool b );
+    virtual bool getWrap() const { return _wrap; }
+
+protected:
+    virtual void on_size_allocate( Gtk::Allocation& allocation );
+    virtual void on_size_request( Gtk::Requisition* requisition );
+
 
 private:
     void rebuildUI();
+    void calcGridSize( const Gtk::Widget* thing, int itemCount, int& width, int& height );
 
     std::vector<Previewable*> items;
     Gtk::Bin *_scroller;
     Gtk::Table *_insides;
-    Gtk::BuiltinIconSize _baseSize;
+    int _prefCols;
+    bool _updatesFrozen;
+    Gtk::AnchorType _anchor;
+    Inkscape::IconSize _baseSize;
     ViewType _view;
+    bool _wrap;
 };
 
 } //namespace UI
