@@ -11,11 +11,8 @@
  */
 
 #include <gtkmm/stock.h>
-#include <gtkmm/stockitem.h>
-#include <gdk/gdkkeysyms.h>
 #include <glibmm/i18n.h>
 
-#include "stock-items.h"
 #include "stock.h"
 
 namespace Inkscape {
@@ -210,9 +207,9 @@ init()
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
