@@ -20,21 +20,14 @@
 # include "config.h"
 #endif
 
-#include <glib.h>
-#include <glibmm/i18n.h>
-
+#include <gtkmm/paned.h>
 #include <gtk/gtk.h>
 
 #include "macros.h"
-#include "forward.h"
 #include "inkscape-private.h"
-#include "desktop.h"
 #include "desktop-handles.h"
 #include "desktop-events.h"
-#include "desktop-affine.h"
 #include "document.h"
-#include "selection.h"
-#include "select-context.h"
 #include "desktop-widget.h"
 #include "sp-namedview.h"
 #include "interface.h"
@@ -42,19 +35,20 @@
 #include "prefs-utils.h"
 #include "file.h"
 #include "display/canvas-arena.h"
-#include "display/gnome-canvas-acetate.h"
 #include <extension/db.h>
 #include "helper/units.h"
 #include "widgets/button.h"
 #include "widgets/ruler.h"
-#include "widgets/icon.h"
 #include "widgets/widget-sizes.h"
 #include "widgets/spw-utilities.h"
 #include "widgets/spinbutton-events.h"
 #include "widgets/layer-selector.h"
+#include "ui/widget/selected-style.h"
+#include "sp-item.h"
+#include "dialogs/swatches.h"
+#include "conn-avoid-ref.h"
 
 #ifdef WITH_INKBOARD
-#include "jabber_whiteboard/session-manager.h"
 #endif
 
 
@@ -106,12 +100,16 @@ SPDesktopWidget::setMessage (Inkscape::MessageType type, const gchar *message)
 {
     GtkLabel *sb=GTK_LABEL(this->select_status);
     gtk_label_set_markup (sb, message ? message : "");
+    // FIXME: TODO: remove <b></b> before displaying as tooltip
+    gtk_tooltips_set_tip (this->tt, this->select_status_eventbox, message ? message : "", NULL);
 }
 
-void 
-SPDesktopWidget::window_get_pointer (int *x, int *y)
+NR::Point
+SPDesktopWidget::window_get_pointer()
 {
-    gdk_window_get_pointer (GTK_WIDGET (canvas)->window, x, y, NULL);
+    gint x,y;
+    gdk_window_get_pointer (GTK_WIDGET (canvas)->window, &x, &y, NULL);
+    return NR::Point(x,y);
 }
 
 /**
@@ -160,7 +158,6 @@ sp_desktop_widget_init (SPDesktopWidget *dtw)
 {
     GtkWidget *widget;
     GtkWidget *tbl;
-    GtkWidget *w;
 
     GtkWidget *hbox;
     GtkWidget *eventbox;
@@ -176,12 +173,21 @@ sp_desktop_widget_init (SPDesktopWidget *dtw)
 
     /* Main table */
     dtw->vbox = gtk_vbox_new (FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (dtw), dtw->vbox);
+    gtk_container_add( GTK_CONTAINER(dtw), GTK_WIDGET(dtw->vbox) );
 
     dtw->statusbar = gtk_hbox_new (FALSE, 0);
     //gtk_widget_set_usize (dtw->statusbar, -1, BOTTOM_BAR_HEIGHT);
     gtk_box_pack_end (GTK_BOX (dtw->vbox), dtw->statusbar, FALSE, TRUE, 0);
 
+    {
+        using Inkscape::UI::Dialogs::SwatchesPanel;
+
+        SwatchesPanel* swatches = new SwatchesPanel("embedded.swatches");
+        swatches->setOrientation( Gtk::ANCHOR_SOUTH );
+        dtw->panels = GTK_WIDGET(swatches->gobj());
+        gtk_box_pack_end( GTK_BOX( dtw->vbox ), dtw->panels, FALSE, TRUE, 0 );
+    }
+
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_box_pack_end (GTK_BOX (dtw->vbox), hbox, TRUE, TRUE, 0);
     gtk_widget_show (hbox);
@@ -228,7 +234,7 @@ sp_desktop_widget_init (SPDesktopWidget *dtw)
     gtk_table_attach (GTK_TABLE (tbl), dtw->hscrollbar, 1, 2, 2, 3, (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), (GtkAttachOptions)(GTK_FILL), 0, 0);
     /* Vertical scrollbar and the sticky zoom button */
     dtw->vscrollbar_box = gtk_vbox_new (FALSE, 0);
-    dtw->sticky_zoom = sp_button_new_from_data ( GTK_ICON_SIZE_MENU,
+    dtw->sticky_zoom = sp_button_new_from_data ( Inkscape::ICON_SIZE_DECORATION,
                                                  SP_BUTTON_TYPE_TOGGLE,
                                                  NULL,
                                                  "sticky_zoom",
@@ -242,8 +248,6 @@ sp_desktop_widget_init (SPDesktopWidget *dtw)
     gtk_table_attach (GTK_TABLE (tbl), dtw->vscrollbar_box, 2, 3, 0, 2, (GtkAttachOptions)(GTK_FILL), (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 0, 0);
 
     /* Canvas */
-    w = gtk_frame_new (NULL);
-    gtk_table_attach (GTK_TABLE (tbl), w, 1, 2, 1, 2, (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 0, 0);
     dtw->canvas = SP_CANVAS (sp_canvas_new_aa ());
     GTK_WIDGET_SET_FLAGS (GTK_WIDGET (dtw->canvas), GTK_CAN_FOCUS);
     style = gtk_style_copy (GTK_WIDGET (dtw->canvas)->style);
@@ -251,7 +255,20 @@ sp_desktop_widget_init (SPDesktopWidget *dtw)
     gtk_widget_set_style (GTK_WIDGET (dtw->canvas), style);
     gtk_widget_set_extension_events(GTK_WIDGET (dtw->canvas) , GDK_EXTENSION_EVENTS_ALL);
     g_signal_connect (G_OBJECT (dtw->canvas), "event", G_CALLBACK (sp_desktop_widget_event), dtw);
-    gtk_container_add (GTK_CONTAINER (w), GTK_WIDGET (dtw->canvas));
+    gtk_table_attach (GTK_TABLE (tbl), GTK_WIDGET (dtw->canvas), 1, 2, 1, 2, (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), (GtkAttachOptions)(GTK_EXPAND | GTK_FILL), 0, 0);
+
+    dtw->selected_style = new Inkscape::UI::Widget::SelectedStyle(true);
+    GtkHBox *ss_ = dtw->selected_style->gobj();
+    gtk_box_pack_start (GTK_BOX (dtw->statusbar), GTK_WIDGET(ss_), FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (dtw->statusbar), gtk_vseparator_new(), FALSE, FALSE, 0);
+
+    // connect scrollbar signals
+    g_signal_connect (G_OBJECT (dtw->hadj), "value-changed", G_CALLBACK (sp_desktop_widget_adjustment_value_changed), dtw);
+    g_signal_connect (G_OBJECT (dtw->vadj), "value-changed", G_CALLBACK (sp_desktop_widget_adjustment_value_changed), dtw);
+
+    GtkWidget *statusbar_tail=gtk_statusbar_new();
+    gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(statusbar_tail), TRUE);
+    gtk_box_pack_end (GTK_BOX (dtw->statusbar), statusbar_tail, FALSE, FALSE, 0);
 
     // zoom status spinbutton
     dtw->zoom_status = gtk_spin_button_new_with_range (log(SP_DESKTOP_ZOOM_MIN)/log(2), log(SP_DESKTOP_ZOOM_MAX)/log(2), 0.1);
@@ -263,41 +280,55 @@ sp_desktop_widget_init (SPDesktopWidget *dtw)
     g_signal_connect (G_OBJECT (dtw->zoom_status), "input", G_CALLBACK (sp_dtw_zoom_input), dtw);
     g_signal_connect (G_OBJECT (dtw->zoom_status), "output", G_CALLBACK (sp_dtw_zoom_output), dtw);
     gtk_object_set_data (GTK_OBJECT (dtw->zoom_status), "dtw", dtw->canvas);
-    gtk_object_set_data (GTK_OBJECT (dtw), "altz", dtw->zoom_status);
     gtk_signal_connect (GTK_OBJECT (dtw->zoom_status), "focus-in-event", GTK_SIGNAL_FUNC (spinbutton_focus_in), dtw->zoom_status);
     gtk_signal_connect (GTK_OBJECT (dtw->zoom_status), "key-press-event", GTK_SIGNAL_FUNC (spinbutton_keypress), dtw->zoom_status);
     dtw->zoom_update = g_signal_connect (G_OBJECT (dtw->zoom_status), "value_changed", G_CALLBACK (sp_dtw_zoom_value_changed), dtw);
     dtw->zoom_update = g_signal_connect (G_OBJECT (dtw->zoom_status), "populate_popup", G_CALLBACK (sp_dtw_zoom_populate_popup), dtw);
-    sp_set_font_size (dtw->zoom_status, STATUS_ZOOM_FONT_SIZE);
-    gtk_box_pack_start (GTK_BOX (dtw->statusbar), dtw->zoom_status, FALSE, FALSE, 0);
-
-    /* connecting canvas, scrollbars, rulers, statusbar */
-    g_signal_connect (G_OBJECT (dtw->hadj), "value-changed", G_CALLBACK (sp_desktop_widget_adjustment_value_changed), dtw);
-    g_signal_connect (G_OBJECT (dtw->vadj), "value-changed", G_CALLBACK (sp_desktop_widget_adjustment_value_changed), dtw);
 
     // cursor coordinates
-    dtw->coord_status = gtk_label_new ("");
+    dtw->coord_status = gtk_table_new (5, 2, FALSE);
+    gtk_table_set_row_spacings(GTK_TABLE(dtw->coord_status), 0);
+    gtk_table_set_col_spacings(GTK_TABLE(dtw->coord_status), 2);
+    gtk_table_attach(GTK_TABLE(dtw->coord_status), gtk_vseparator_new(), 0,1, 0,2, GTK_FILL, GTK_FILL, 0, 0);
     eventbox = gtk_event_box_new ();
     gtk_container_add (GTK_CONTAINER (eventbox), dtw->coord_status);
     gtk_tooltips_set_tip (dtw->tt, eventbox, _("Cursor coordinates"), NULL);
-    gtk_widget_set_size_request (dtw->coord_status, STATUS_COORD_WIDTH, -1);
-    sp_set_font_size (dtw->coord_status, STATUS_COORD_FONT_SIZE);
-    gtk_box_pack_start (GTK_BOX (dtw->statusbar), eventbox, FALSE, FALSE, 1);
+    GtkWidget *label_x = gtk_label_new("X:");
+    gtk_misc_set_alignment (GTK_MISC(label_x), 0.0, 0.5);
+    gtk_table_attach(GTK_TABLE(dtw->coord_status),  label_x, 1,2, 0,1, GTK_FILL, GTK_FILL, 0, 0);
+    GtkWidget *label_y = gtk_label_new("Y:");
+    gtk_misc_set_alignment (GTK_MISC(label_y), 0.0, 0.5);
+    gtk_table_attach(GTK_TABLE(dtw->coord_status),  label_y, 1,2, 1,2, GTK_FILL, GTK_FILL, 0, 0);
+    dtw->coord_status_x = gtk_label_new("0.0");
+    gtk_misc_set_alignment (GTK_MISC(dtw->coord_status_x), 0.0, 0.5);
+    dtw->coord_status_y = gtk_label_new("0.0");
+    gtk_misc_set_alignment (GTK_MISC(dtw->coord_status_y), 0.0, 0.5);
+    gtk_table_attach(GTK_TABLE(dtw->coord_status), dtw->coord_status_x, 2,3, 0,1, GTK_FILL, GTK_FILL, 0, 0);
+    gtk_table_attach(GTK_TABLE(dtw->coord_status), dtw->coord_status_y, 2,3, 1,2, GTK_FILL, GTK_FILL, 0, 0);
+    gtk_table_attach(GTK_TABLE(dtw->coord_status),  gtk_label_new("Z:"), 3,4, 0,2, GTK_FILL, GTK_FILL, 0, 0);
+    gtk_table_attach(GTK_TABLE(dtw->coord_status),  dtw->zoom_status, 4,5, 0,2, GTK_FILL, GTK_FILL, 0, 0);
+    sp_set_font_size_smaller (dtw->coord_status);
+    gtk_box_pack_end (GTK_BOX (statusbar_tail), eventbox, FALSE, FALSE, 1);
 
     dtw->layer_selector = new Inkscape::Widgets::LayerSelector(NULL);
+    // FIXME: need to unreference on container destruction to avoid leak
     dtw->layer_selector->reference();
     //dtw->layer_selector->set_size_request(-1, SP_ICON_SIZE_BUTTON);
     gtk_box_pack_start(GTK_BOX(dtw->statusbar), GTK_WIDGET(dtw->layer_selector->gobj()), FALSE, FALSE, 1);
 
-    dtw->select_status = gtk_label_new (NULL);//gtk_statusbar_new ();
+    dtw->select_status_eventbox = gtk_event_box_new ();
+    dtw->select_status = gtk_label_new (NULL);
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 6
+    gtk_label_set_ellipsize (GTK_LABEL(dtw->select_status), PANGO_ELLIPSIZE_END);
+#endif
     gtk_misc_set_alignment (GTK_MISC (dtw->select_status), 0.0, 0.5);
     gtk_widget_set_size_request (dtw->select_status, 1, -1);
-    //sp_set_font_size (dtw->select_status, STATUS_BAR_FONT_SIZE);  // setting absolute size is bad, in some themes it ends up being larger!
     // display the initial welcome message in the statusbar
     gtk_label_set_markup (GTK_LABEL (dtw->select_status), _("<b>Welcome to Inkscape!</b> Use shape or freehand tools to create objects; use selector (arrow) to move or transform them."));
     // space label 2 pixels from left edge
+    gtk_container_add (GTK_CONTAINER (dtw->select_status_eventbox), dtw->select_status);
     gtk_box_pack_start (GTK_BOX (dtw->statusbar), gtk_hbox_new(FALSE, 0), FALSE, FALSE, 2);
-    gtk_box_pack_start (GTK_BOX (dtw->statusbar), dtw->select_status, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (dtw->statusbar), dtw->select_status_eventbox, TRUE, TRUE, 0);
 
     gtk_widget_show_all (dtw->vbox);
 }
@@ -313,6 +344,7 @@ sp_desktop_widget_destroy (GtkObject *object)
     if (dtw->desktop) {
         dtw->layer_selector->unreference();
         inkscape_remove_desktop (dtw->desktop); // clears selection too
+        sp_signal_disconnect_by_data (G_OBJECT (dtw->desktop->namedview), dtw);
         dtw->desktop->destroy();
         Inkscape::GC::release (dtw->desktop);
         dtw->desktop = NULL;
@@ -323,11 +355,7 @@ sp_desktop_widget_destroy (GtkObject *object)
     }
 }
 
-static void
-sp_desktop_widget_set_title (SPDesktopWidget *dtw)
-{
-    sp_desktop_widget_set_title (dtw, SP_DOCUMENT_NAME (dtw->desktop->doc()));
-}
+
 /**
  * Set the title in the desktop-window (if desktop has an own window).
  * 
@@ -335,16 +363,16 @@ sp_desktop_widget_set_title (SPDesktopWidget *dtw)
  * The desktop number is only shown if it's 2 or higher,
  */
 void
-sp_desktop_widget_set_title (SPDesktopWidget *dtw, gchar const* uri)
+SPDesktopWidget::updateTitle(gchar const* uri)
 {
-    GtkWindow *window = GTK_WINDOW (gtk_object_get_data (GTK_OBJECT(dtw), "window"));
+    GtkWindow *window = GTK_WINDOW (gtk_object_get_data (GTK_OBJECT(this), "window"));
     if (window) {
         gchar const *fname = ( TRUE
                                ? uri
                                : g_basename(uri) );
         GString *name = g_string_new ("");
-        if (dtw->desktop->number > 1) {
-            g_string_printf (name, _("%s: %d - Inkscape"), fname, dtw->desktop->number);
+        if (this->desktop->number > 1) {
+            g_string_printf (name, _("%s: %d - Inkscape"), fname, this->desktop->number);
         } else {
             g_string_printf (name, _("%s - Inkscape"), fname);
         }
@@ -371,31 +399,29 @@ sp_desktop_widget_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
     }
 
     if (GTK_WIDGET_REALIZED (widget)) {
-        NRRect area;
-        double zoom;
-        dtw->desktop->get_display_area (&area);
-        zoom = dtw->desktop->current_zoom();
+        NR::Rect const area = dtw->desktop->get_display_area();
+        double zoom = dtw->desktop->current_zoom();
 
-        if (GTK_WIDGET_CLASS (dtw_parent_class)->size_allocate)
-            GTK_WIDGET_CLASS (dtw_parent_class)->size_allocate (widget, allocation);
+        if (GTK_WIDGET_CLASS(dtw_parent_class)->size_allocate) {
+            GTK_WIDGET_CLASS(dtw_parent_class)->size_allocate (widget, allocation);
+        }
 
-        if (SP_BUTTON_IS_DOWN (dtw->sticky_zoom)) {
-            NRRect newarea;
-            double zpsp;
+        if (SP_BUTTON_IS_DOWN(dtw->sticky_zoom)) {
             /* Calculate zoom per pixel */
-            zpsp = zoom / hypot (area.x1 - area.x0, area.y1 - area.y0);
+            double const zpsp = zoom / hypot (area.dimensions()[NR::X], area.dimensions()[NR::Y]);
             /* Find new visible area */
-            dtw->desktop->get_display_area (&newarea);
+            NR::Rect newarea = dtw->desktop->get_display_area();
             /* Calculate adjusted zoom */
-            zoom = zpsp * hypot (newarea.x1 - newarea.x0, newarea.y1 - newarea.y0);
-            dtw->desktop->zoom_absolute (0.5F * (area.x1 + area.x0), 0.5F * (area.y1 + area.y0), zoom);
+            zoom = zpsp * hypot(newarea.dimensions()[NR::X], newarea.dimensions()[NR::Y]);
+            dtw->desktop->zoom_absolute(newarea.midpoint()[NR::X], newarea.midpoint()[NR::Y], zoom);
         } else {
-            dtw->desktop->zoom_absolute (0.5F * (area.x1 + area.x0), 0.5F * (area.y1 + area.y0), zoom);
+            dtw->desktop->zoom_absolute(area.midpoint()[NR::X], area.midpoint()[NR::Y], zoom);
         }
 
     } else {
-        if (GTK_WIDGET_CLASS (dtw_parent_class)->size_allocate)
+        if (GTK_WIDGET_CLASS (dtw_parent_class)->size_allocate) {
             GTK_WIDGET_CLASS (dtw_parent_class)->size_allocate (widget, allocation);
+        }
 //            this->size_allocate (widget, allocation);
     }
 }
@@ -426,7 +452,7 @@ sp_desktop_widget_realize (GtkWidget *widget)
     g_signal_connect (G_OBJECT (dtw->desktop->namedview), "modified", G_CALLBACK (sp_desktop_widget_namedview_modified), dtw);
     sp_desktop_widget_namedview_modified (dtw->desktop->namedview, SP_OBJECT_MODIFIED_FLAG, dtw);
 
-    sp_desktop_widget_set_title (dtw);
+    dtw->updateTitle(SP_DOCUMENT_NAME (dtw->desktop->doc()));
 }
 
 /**
@@ -465,13 +491,13 @@ sp_desktop_widget_event (GtkWidget *widget, GdkEvent *event, SPDesktopWidget *dt
 }
 
 void
-sp_dtw_desktop_activate (SPDesktop *desktop, SPDesktopWidget *dtw)
+sp_dtw_desktop_activate (SPDesktopWidget *dtw)
 {
     /* update active desktop indicator */
 }
 
 void
-sp_dtw_desktop_deactivate (SPDesktop *desktop, SPDesktopWidget *dtw)
+sp_dtw_desktop_deactivate (SPDesktopWidget *dtw)
 {
     /* update inactive desktop indicator */
 }
@@ -620,18 +646,119 @@ SPDesktopWidget::shutdown()
 }
 
 /**
- * \pre dtw->desktop->main != 0
+ * \pre this->desktop->main != 0
  */
 void 
-sp_desktop_widget_queue_draw (SPDesktopWidget* dtw)
-{
-    gtk_widget_queue_draw (GTK_WIDGET (SP_CANVAS_ITEM (dtw->desktop->main)->canvas));
+SPDesktopWidget::requestCanvasUpdate() {
+    gtk_widget_queue_draw (GTK_WIDGET (SP_CANVAS_ITEM (this->desktop->main)->canvas));
 }
 
 void 
-sp_desktop_widget_set_coordinate_status (SPDesktopWidget *dtw, gchar *cstr)
+SPDesktopWidget::setCoordinateStatus(NR::Point p)
 {
-    gtk_label_set_text (GTK_LABEL (dtw->coord_status), cstr);
+    gchar *cstr;
+    cstr=g_strdup_printf("%6.2f", dt2r * p[NR::X]);
+    gtk_label_set_text (GTK_LABEL (this->coord_status_x), cstr);
+    g_free(cstr);
+    cstr=g_strdup_printf("%6.2f", dt2r * p[NR::Y]);
+    gtk_label_set_text (GTK_LABEL (this->coord_status_y), cstr);
+    g_free(cstr);
+}
+
+void
+SPDesktopWidget::letZoomGrabFocus()
+{
+    if (zoom_status) 
+        gtk_widget_grab_focus (zoom_status);
+}
+    
+void 
+SPDesktopWidget::getWindowGeometry (gint &x, gint &y, gint &w, gint &h)
+{
+    GtkWindow *window = GTK_WINDOW (gtk_object_get_data (GTK_OBJECT(this), "window"));
+    if (window)
+    {
+        gtk_window_get_size (window, &w, &h);
+        gtk_window_get_position (window, &x, &y);
+    }
+}
+
+void
+SPDesktopWidget::setWindowPosition (NR::Point p)
+{
+    GtkWindow *window = GTK_WINDOW (gtk_object_get_data (GTK_OBJECT(this), "window"));
+    if (window)
+    {
+        gtk_window_move (window, gint(round(p[NR::X])), gint(round(p[NR::Y])));
+    }
+}
+
+void
+SPDesktopWidget::setWindowSize (gint w, gint h)
+{
+    GtkWindow *window = GTK_WINDOW (gtk_object_get_data (GTK_OBJECT(this), "window"));
+    if (window)
+    {
+        gtk_window_set_default_size (window, w, h);
+        gtk_window_reshow_with_initial_size (window);
+    }
+}
+
+/**
+ * \note transientizing does not work on windows; when you minimize a document 
+ * and then open it back, only its transient emerges and you cannot access 
+ * the document window.
+ */
+void
+SPDesktopWidget::setWindowTransient (void *p, int transient_policy)
+{
+#ifndef WIN32
+    GtkWindow *w =GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(this)));
+    if (w)
+    {
+        gtk_window_set_transient_for (GTK_WINDOW(p), w);
+        
+        /* 
+         * This enables "aggressive" transientization,
+         * i.e. dialogs always emerging on top when you switch documents. Note 
+         * however that this breaks "click to raise" policy of a window 
+         * manager because the switched-to document will be raised at once 
+         * (so that its transients also could raise)
+         */
+        if (transient_policy == 2)
+        
+            // without this, a transient window not always emerges on top
+            gtk_window_present (w); 
+    }
+#endif
+}
+
+void
+SPDesktopWidget::presentWindow()
+{
+    GtkWindow *w =GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(this)));
+    if (w)
+        gtk_window_present (w); 
+}
+
+bool
+SPDesktopWidget::warnDialog (gchar* text)
+{
+    GtkWindow *w =GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(this)));
+    if (w)
+    {
+        GtkWidget *dialog = gtk_message_dialog_new(
+                w,
+                GTK_DIALOG_DESTROY_WITH_PARENT,
+                GTK_MESSAGE_WARNING,
+                GTK_BUTTONS_YES_NO,
+                text);
+        gint response = gtk_dialog_run(GTK_DIALOG(dialog));
+        gtk_widget_destroy(dialog);
+        if (response == GTK_RESPONSE_YES)
+            return true;
+    }
+    return false;
 }
 
 void
@@ -693,6 +820,12 @@ sp_desktop_widget_layout (SPDesktopWidget *dtw)
         gtk_widget_show_all (dtw->statusbar);
     }
 
+    if (prefs_get_int_attribute (fullscreen ? "fullscreen.panels" : "window.panels", "state", 1) == 0) {
+        gtk_widget_hide_all( dtw->panels );
+    } else {
+        gtk_widget_show_all( dtw->panels );
+    }
+
     if (prefs_get_int_attribute (fullscreen ? "fullscreen.scrollbars" : "window.scrollbars", "state", 1) == 0) {
         gtk_widget_hide_all (dtw->hscrollbar);
         gtk_widget_hide_all (dtw->vscrollbar_box);
@@ -710,6 +843,34 @@ sp_desktop_widget_layout (SPDesktopWidget *dtw)
     }
 }
 
+void
+SPDesktopWidget::setToolboxFocusTo (const gchar* label)
+{
+    gpointer hb = sp_search_by_data_recursive(aux_toolbox, (gpointer) label);
+    if (hb && GTK_IS_WIDGET(hb)) 
+    {
+        gtk_widget_grab_focus(GTK_WIDGET(hb));
+    }
+}
+
+void
+SPDesktopWidget::setToolboxAdjustmentValue (gchar const *id, double value)
+{
+    gpointer hb = sp_search_by_data_recursive (aux_toolbox, (gpointer) id);
+    if (hb && GTK_IS_WIDGET(hb) && GTK_IS_SPIN_BUTTON(hb)) {
+        GtkAdjustment *a = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON(hb));
+        gtk_adjustment_set_value (a, value);
+    }
+}
+
+bool
+SPDesktopWidget::isToolboxButtonActive (const gchar* id)
+{
+    GtkToggleButton *b = (GtkToggleButton *) sp_search_by_data_recursive(aux_toolbox, (gpointer) id);
+
+    return gtk_toggle_button_get_active (b) != 0;
+}
+
 SPViewWidget *
 sp_desktop_widget_new (SPNamedView *namedview)
 {
@@ -719,8 +880,16 @@ sp_desktop_widget_new (SPNamedView *namedview)
     dtw->ruler_origin = namedview->gridorigin;
 
     dtw->desktop = new SPDesktop();
-    dtw->desktop->owner = dtw;
+    dtw->stub = new SPDesktopWidget::WidgetStub (dtw);
+    dtw->desktop->registerEditWidget (dtw->stub);
     dtw->desktop->init (namedview, dtw->canvas);
+    inkscape_add_desktop (dtw->desktop);
+
+    // Add the shape geometry to libavoid for autorouting connectors.
+    // This needs desktop set for its spacing preferences.
+    init_avoided_shape_geometry(dtw->desktop);
+    
+    dtw->selected_style->setDesktop(dtw->desktop);
 
     /* Once desktop is set, we can update rulers */
     sp_desktop_widget_update_rulers (dtw);
@@ -734,7 +903,7 @@ sp_desktop_widget_new (SPNamedView *namedview)
 
     dtw->menubar = sp_ui_main_menubar (dtw->desktop);
     gtk_widget_show_all (dtw->menubar);
-    gtk_box_pack_start (GTK_BOX (gtk_bin_get_child (GTK_BIN (dtw))), dtw->menubar, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (dtw->vbox), dtw->menubar, FALSE, FALSE, 0);
 
     sp_desktop_widget_layout (dtw);
 
@@ -746,32 +915,28 @@ sp_desktop_widget_new (SPNamedView *namedview)
 }
 
 void
-SPDesktopWidget::viewSetPosition (double x, double y)
+SPDesktopWidget::viewSetPosition (NR::Point p)
 {
-    using NR::X;
-    using NR::Y;
-
-    NR::Point const origin = ( NR::Point(x, y) - ruler_origin );
+    NR::Point const origin = ( p - ruler_origin );
 
     /// \todo fixme:
-    GTK_RULER(hruler)->position = origin[X];
+    GTK_RULER(hruler)->position = origin[NR::X];
     gtk_ruler_draw_pos (GTK_RULER (hruler));
-    GTK_RULER(vruler)->position = origin[Y];
+    GTK_RULER(vruler)->position = origin[NR::Y];
     gtk_ruler_draw_pos (GTK_RULER (vruler));
 }
 
 void
 sp_desktop_widget_update_rulers (SPDesktopWidget *dtw)
 {
-    NRRect viewbox;
-    sp_canvas_get_viewbox (dtw->canvas, &viewbox);
-    double scale = dtw->desktop->current_zoom();
-    double s = viewbox.x0 / scale - dtw->ruler_origin[NR::X];
-    double e = viewbox.x1 / scale - dtw->ruler_origin[NR::X];
-    gtk_ruler_set_range (GTK_RULER (dtw->hruler), s,  e, GTK_RULER (dtw->hruler)->position, (e - s));
-    s = viewbox.y0 / -scale - dtw->ruler_origin[NR::Y];
-    e = viewbox.y1 / -scale - dtw->ruler_origin[NR::Y];
-    gtk_ruler_set_range (GTK_RULER (dtw->vruler), s, e, GTK_RULER (dtw->vruler)->position, (e - s));
+    NR::Rect const viewbox = dtw->canvas->getViewbox();
+    double const scale = dtw->desktop->current_zoom();
+    double s = viewbox.min()[NR::X] / scale - dtw->ruler_origin[NR::X];
+    double e = viewbox.max()[NR::X] / scale - dtw->ruler_origin[NR::X];
+    gtk_ruler_set_range(GTK_RULER(dtw->hruler), s,  e, GTK_RULER(dtw->hruler)->position, (e - s));
+    s = viewbox.min()[NR::Y] / -scale - dtw->ruler_origin[NR::Y];
+    e = viewbox.max()[NR::Y] / -scale - dtw->ruler_origin[NR::Y];
+    gtk_ruler_set_range(GTK_RULER(dtw->vruler), s, e, GTK_RULER(dtw->vruler)->position, (e - s));
 }
 
 
@@ -780,7 +945,6 @@ sp_desktop_widget_namedview_modified (SPNamedView *nv, guint flags, SPDesktopWid
 {
     if (flags & SP_OBJECT_MODIFIED_FLAG) {
         dtw->dt2r = 1.0 / nv->doc_units->unittobase;
-
         dtw->ruler_origin = nv->gridorigin;
 
         sp_ruler_set_metric (GTK_RULER (dtw->vruler), nv->getDefaultMetric());
@@ -860,15 +1024,14 @@ sp_dtw_zoom_output (GtkSpinButton *spin, gpointer data)
 static void
 sp_dtw_zoom_value_changed (GtkSpinButton *spin, gpointer data)
 {
-    NRRect d;
-    double zoom_factor = pow (2, gtk_spin_button_get_value (spin));
+    double const zoom_factor = pow (2, gtk_spin_button_get_value (spin));
 
     SPDesktopWidget *dtw = SP_DESKTOP_WIDGET (data);
     SPDesktop *desktop = dtw->desktop;
 
-    desktop->get_display_area (&d);
+    NR::Rect const d = desktop->get_display_area();
     g_signal_handler_block (spin, dtw->zoom_update);
-    desktop->zoom_absolute ((d.x0 + d.x1) / 2, (d.y0 + d.y1) / 2, zoom_factor);
+    desktop->zoom_absolute (d.midpoint()[NR::X], d.midpoint()[NR::Y], zoom_factor);
     g_signal_handler_unblock (spin, dtw->zoom_update);
 
     spinbutton_defocus (GTK_OBJECT (spin));
@@ -921,10 +1084,8 @@ sp_dtw_zoom_populate_popup (GtkEntry *entry, GtkMenu *menu, gpointer data)
 static void
 sp_dtw_zoom_menu_handler (SPDesktop *dt, gdouble factor)
 {
-    NRRect d;
-
-    dt->get_display_area (&d);
-    dt->zoom_absolute (( d.x0 + d.x1 ) / 2, ( d.y0 + d.y1 ) / 2, factor);
+    NR::Rect const d = dt->get_display_area();
+    dt->zoom_absolute(d.midpoint()[NR::X], d.midpoint()[NR::Y], factor);
 }
 
 static void
@@ -974,30 +1135,30 @@ sp_desktop_widget_update_zoom (SPDesktopWidget *dtw)
 }
 
 void
-sp_desktop_widget_toggle_rulers (SPDesktopWidget *dtw, bool is_fullscreen)
+sp_desktop_widget_toggle_rulers (SPDesktopWidget *dtw)
 {
     if (GTK_WIDGET_VISIBLE (dtw->hruler)) {
         gtk_widget_hide_all (dtw->hruler);
         gtk_widget_hide_all (dtw->vruler);
-        prefs_set_int_attribute (is_fullscreen ? "fullscreen.rulers" : "window.rulers", "state", 0);
+        prefs_set_int_attribute (dtw->desktop->is_fullscreen ? "fullscreen.rulers" : "window.rulers", "state", 0);
     } else {
         gtk_widget_show_all (dtw->hruler);
         gtk_widget_show_all (dtw->vruler);
-        prefs_set_int_attribute (is_fullscreen ? "fullscreen.rulers" : "window.rulers", "state", 1);
+        prefs_set_int_attribute (dtw->desktop->is_fullscreen ? "fullscreen.rulers" : "window.rulers", "state", 1);
     }
 }
 
 void
-sp_desktop_widget_toggle_scrollbars (SPDesktopWidget *dtw, bool is_fullscreen)
+sp_desktop_widget_toggle_scrollbars (SPDesktopWidget *dtw)
 {
     if (GTK_WIDGET_VISIBLE (dtw->hscrollbar)) {
         gtk_widget_hide_all (dtw->hscrollbar);
         gtk_widget_hide_all (dtw->vscrollbar_box);
-        prefs_set_int_attribute (is_fullscreen ? "fullscreen.scrollbars" : "window.scrollbars", "state", 0);
+        prefs_set_int_attribute (dtw->desktop->is_fullscreen ? "fullscreen.scrollbars" : "window.scrollbars", "state", 0);
     } else {
         gtk_widget_show_all (dtw->hscrollbar);
         gtk_widget_show_all (dtw->vscrollbar_box);
-        prefs_set_int_attribute (is_fullscreen ? "fullscreen.scrollbars" : "window.scrollbars", "state", 1);
+        prefs_set_int_attribute (dtw->desktop->is_fullscreen ? "fullscreen.scrollbars" : "window.scrollbars", "state", 1);
     }
 }
 
@@ -1033,44 +1194,42 @@ set_adjustment (GtkAdjustment *adj, double l, double u, double ps, double si, do
 }
 
 void
-sp_desktop_widget_update_scrollbars (SPDesktopWidget *dtw, SPDocument *doc, double scale)
+sp_desktop_widget_update_scrollbars (SPDesktopWidget *dtw, double scale)
 {
     if (!dtw) return;
     if (dtw->update) return;
     dtw->update = 1;
 
     /* The desktop region we always show unconditionally */
-    NRRect darea;
-    sp_item_bbox_desktop (SP_ITEM (SP_DOCUMENT_ROOT (doc)), &darea);
-    darea.x0 = MIN (darea.x0, -sp_document_width (doc));
-    darea.y0 = MIN (darea.y0, -sp_document_height (doc));
-    darea.x1 = MAX (darea.x1, 2 * sp_document_width (doc));
-    darea.y1 = MAX (darea.y1, 2 * sp_document_height (doc));
+    SPDocument *doc = dtw->desktop->doc();
+    NR::Rect const r = sp_item_bbox_desktop(SP_ITEM(SP_DOCUMENT_ROOT(doc)));
+    NR::Rect darea(NR::Point(MIN(r.min()[NR::X], -sp_document_width(doc)),
+                             MIN(r.min()[NR::Y], -sp_document_height(doc))),
+                   NR::Point(MAX(r.max()[NR::X], 2 * sp_document_width(doc)),
+                             MAX(r.max()[NR::Y], 2 * sp_document_height(doc))));
 
     /* Canvas region we always show unconditionally */
-    NRRect carea;
-    carea.x0 = darea.x0 * scale - 64;
-    carea.y0 = darea.y1 * -scale - 64;
-    carea.x1 = darea.x1 * scale + 64;
-    carea.y1 = darea.y0 * -scale + 64;
+    NR::Rect carea(NR::Point(darea.min()[NR::X] * scale - 64,
+                             darea.max()[NR::Y] * -scale - 64),
+                   NR::Point(darea.max()[NR::X] * scale + 64,
+                             darea.min()[NR::Y] * -scale + 64));
 
-    NRRect viewbox;
-    sp_canvas_get_viewbox (dtw->canvas, &viewbox);
+    NR::Rect viewbox = dtw->canvas->getViewbox();
 
     /* Viewbox is always included into scrollable region */
-    nr_rect_d_union (&carea, &carea, &viewbox);
+    carea = NR::Rect::union_bounds(carea, viewbox);
 
-    set_adjustment (dtw->hadj, carea.x0, carea.x1,
-                    (viewbox.x1 - viewbox.x0),
-                    0.1 * (viewbox.x1 - viewbox.x0),
-                    (viewbox.x1 - viewbox.x0));
-    gtk_adjustment_set_value (dtw->hadj, viewbox.x0);
+    set_adjustment(dtw->hadj, carea.min()[NR::X], carea.max()[NR::X],
+                   viewbox.dimensions()[NR::X],
+                   0.1 * viewbox.dimensions()[NR::X],
+                   viewbox.dimensions()[NR::X]);
+    gtk_adjustment_set_value(dtw->hadj, viewbox.min()[NR::X]);
 
-    set_adjustment (dtw->vadj, carea.y0, carea.y1,
-                    (viewbox.y1 - viewbox.y0),
-                    0.1 * (viewbox.y1 - viewbox.y0),
-                    (viewbox.y1 - viewbox.y0));
-    gtk_adjustment_set_value (dtw->vadj, viewbox.y0);
+    set_adjustment(dtw->vadj, carea.min()[NR::Y], carea.max()[NR::Y],
+                   viewbox.dimensions()[NR::Y],
+                   0.1 * viewbox.dimensions()[NR::Y],
+                   viewbox.dimensions()[NR::Y]);
+    gtk_adjustment_set_value(dtw->vadj, viewbox.min()[NR::Y]);
 
     dtw->update = 0;
 }
