@@ -74,19 +74,6 @@ void sp_gradient_selector_set_bbox (SPGradientSelector *sel, gdouble x0, gdouble
 SPGradientUnits sp_gradient_selector_get_units (SPGradientSelector *sel);
 SPGradientSpread sp_gradient_selector_get_spread (SPGradientSelector *sel);
 
-void sp_gradient_selector_set_gs2d_matrix(SPGradientSelector *gsel, NR::Matrix const &gs2d);
-void sp_gradient_selector_set_gs2d_matrix_f(SPGradientSelector *gsel, NRMatrix const *gs2d);
-void sp_gradient_selector_get_gs2d_matrix_f (SPGradientSelector *gsel, NRMatrix *gs2d);
-
-void sp_gradient_selector_set_lgradient_position (SPGradientSelector *sel, gdouble x0, gdouble y0, gdouble x1, gdouble y1);
-void sp_gradient_selector_set_rgradient_position (SPGradientSelector *sel, gdouble cx, gdouble cy, gdouble fx, gdouble fy, gdouble r);
-
 SPGradient *sp_gradient_selector_get_vector (SPGradientSelector *sel);
 
-void sp_gradient_selector_get_lgradient_position_floatv (SPGradientSelector *gsel, gfloat *pos);
-void sp_gradient_selector_get_rgradient_position_floatv (SPGradientSelector *gsel, gfloat *pos);
-
-void sp_gradient_selector_get_lgradient_position_floatv (SPGradientSelector *gsel, gfloat *pos);
-void sp_gradient_selector_get_rgradient_position_floatv (SPGradientSelector *gsel, gfloat *pos);
-
 #endif
