@@ -13,62 +13,25 @@
 # include "config.h"
 #endif
 
-#include <sigc++/sigc++.h>
-#include <string.h>
-#include <glib.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkselection.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtktooltips.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhandlebox.h>
 
 #include "macros.h"
-#include "helper/window.h"
-#include "widgets/desktop-widget.h"
-#include "widgets/icon.h"
 #include "widgets/button.h"
 #include "widgets/widget-sizes.h"
 #include "widgets/spw-utilities.h"
-#include "widgets/sp-widget.h"
 #include "widgets/spinbutton-events.h"
 #include "widgets/gradient-vector.h"
 #include "widgets/gradient-image.h"
 #include "style.h"
 
 #include "prefs-utils.h"
-#include "inkscape-stock.h"
-#include "verbs.h"
-#include "file.h"
-#include "selection-chemistry.h"
-#include "path-chemistry.h"
-#include "inkscape-private.h"
-#include "document.h"
 #include "document-private.h"
-#include "inkscape.h"
 #include "desktop.h"
 #include "desktop-handles.h"
-#include "interface.h"
-#include "nodepath.h"
-#include "helper/gnome-utils.h"
 #include <glibmm/i18n.h>
-#include "helper/unit-menu.h"
-#include "helper/units.h"
 
-#include "select-toolbar.h"
-#include "star-context.h"
-#include "spiral-context.h"
 #include "gradient-context.h"
 #include "gradient-drag.h"
-#include "sp-rect.h"
-#include "sp-star.h"
-#include "sp-spiral.h"
-#include "sp-pattern.h"
-#include "sp-ellipse.h"
-#include "sp-gradient.h"
 #include "sp-linear-gradient.h"
 #include "sp-radial-gradient.h"
 #include "gradient-chemistry.h"
@@ -76,7 +39,6 @@
 
 #include "toolbox.h"
 
-#include "gradient-toolbar.h"
 
 //########################
 //##       Gradient     ##
@@ -175,12 +137,12 @@ gr_item_activate (GtkMenuItem *menuitem, gpointer data)
     gr = sp_gradient_ensure_vector_normalized(gr);
 
     SPDesktop *desktop = (SPDesktop *) data;
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
-    SPEventContext *ev = SP_DT_EVENTCONTEXT (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
+    SPEventContext *ev = sp_desktop_event_context (desktop);
 
     gr_apply_gradient (selection, ev? ev->get_drag() : NULL, gr);
 
-    sp_document_done (SP_DT_DOCUMENT (desktop));
+    sp_document_done (sp_desktop_document (desktop));
 }
 
 gchar *
@@ -195,7 +157,7 @@ gr_prepare_label (SPObject *obj)
 GtkWidget *
 gr_vector_list (SPDesktop *desktop, bool selection_empty, SPGradient *gr_selected, bool gr_multi)
 {
-    SPDocument *document = SP_DT_DOCUMENT (desktop);
+    SPDocument *document = sp_desktop_document (desktop);
 
     GtkWidget *om = gtk_option_menu_new ();
     GtkWidget *m = gtk_menu_new ();
@@ -383,11 +345,11 @@ gr_tb_selection_changed (Inkscape::Selection *, gpointer data)
     if (!desktop)
         return;
 
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop); // take from desktop, not from args
+    Inkscape::Selection *selection = sp_desktop_selection (desktop); // take from desktop, not from args
     if (!selection) 
         return;
     
-    SPEventContext *ev = SP_DT_EVENTCONTEXT (desktop);
+    SPEventContext *ev = sp_desktop_event_context (desktop);
 
     GtkWidget *om = (GtkWidget *) g_object_get_data (G_OBJECT (widget), "menu");
     if (om) gtk_widget_destroy (om);
@@ -439,9 +401,9 @@ static void
 gr_fork (GtkWidget *button, GtkWidget *widget)
 {
     SPDesktop *desktop = (SPDesktop *) g_object_get_data (G_OBJECT(widget), "desktop");
-    SPDocument *document = SP_DT_DOCUMENT (desktop);
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
-    SPEventContext *ev = SP_DT_EVENTCONTEXT (desktop);
+    SPDocument *document = sp_desktop_document (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
+    SPEventContext *ev = sp_desktop_event_context (desktop);
     GtkWidget *om = (GtkWidget *) g_object_get_data (G_OBJECT(widget), "menu");
 
     if (om && document) {
@@ -492,9 +454,9 @@ gr_edit (GtkWidget *button, GtkWidget *widget)
 GtkWidget *
 gr_change_widget (SPDesktop *desktop)
 {
-    Inkscape::Selection *selection = SP_DT_SELECTION (desktop);
-    SPDocument *document = SP_DT_DOCUMENT (desktop);
-    SPEventContext *ev = SP_DT_EVENTCONTEXT (desktop);
+    Inkscape::Selection *selection = sp_desktop_selection (desktop);
+    SPDocument *document = sp_desktop_document (desktop);
+    SPEventContext *ev = sp_desktop_event_context (desktop);
 
     SPGradient *gr_selected = NULL;
     bool gr_multi = false;
@@ -507,7 +469,7 @@ gr_change_widget (SPDesktop *desktop)
     gr_read_selection (selection, ev? ev->get_drag() : NULL, &gr_selected, &gr_multi, &spr_selected, &spr_multi);
  
     GtkWidget *widget = gtk_hbox_new(FALSE, FALSE);
-    gtk_object_set_data(GTK_OBJECT(widget), "dtw", desktop->owner->canvas);
+    gtk_object_set_data(GTK_OBJECT(widget), "dtw", desktop->canvas);
     g_object_set_data (G_OBJECT (widget), "desktop", desktop);
 
     GtkWidget *om = gr_vector_list (desktop, selection->isEmpty(), gr_selected, gr_multi);
@@ -585,7 +547,7 @@ sp_gradient_toolbox_new(SPDesktop *desktop)
 {
     GtkWidget *tbl = gtk_hbox_new(FALSE, 0);
 
-    gtk_object_set_data(GTK_OBJECT(tbl), "dtw", desktop->owner->canvas);
+    gtk_object_set_data(GTK_OBJECT(tbl), "dtw", desktop->canvas);
     gtk_object_set_data(GTK_OBJECT(tbl), "desktop", desktop);
 
     GtkTooltips *tt = gtk_tooltips_new();
@@ -599,7 +561,7 @@ sp_gradient_toolbox_new(SPDesktop *desktop)
     GtkWidget *cbox = gtk_hbox_new (FALSE, 0);
 
     {
-    GtkWidget *button = sp_button_new_from_data( GTK_ICON_SIZE_SMALL_TOOLBAR,
+    GtkWidget *button = sp_button_new_from_data( Inkscape::ICON_SIZE_DECORATION,
                                               SP_BUTTON_TYPE_TOGGLE,
                                               NULL,
                                               "fill_gradient",
@@ -613,7 +575,7 @@ sp_gradient_toolbox_new(SPDesktop *desktop)
     }
 
     {
-    GtkWidget *button = sp_button_new_from_data( GTK_ICON_SIZE_SMALL_TOOLBAR,
+    GtkWidget *button = sp_button_new_from_data( Inkscape::ICON_SIZE_DECORATION,
                                               SP_BUTTON_TYPE_TOGGLE,
                                               NULL,
                                               "fill_radial",
@@ -641,7 +603,7 @@ sp_gradient_toolbox_new(SPDesktop *desktop)
     GtkWidget *cbox = gtk_hbox_new (FALSE, 0);
 
     {
-    GtkWidget *button = sp_button_new_from_data( GTK_ICON_SIZE_SMALL_TOOLBAR,
+    GtkWidget *button = sp_button_new_from_data( Inkscape::ICON_SIZE_DECORATION,
                                               SP_BUTTON_TYPE_TOGGLE,
                                               NULL,
                                               "controls_fill",
@@ -655,7 +617,7 @@ sp_gradient_toolbox_new(SPDesktop *desktop)
     }
 
     {
-    GtkWidget *button = sp_button_new_from_data( GTK_ICON_SIZE_SMALL_TOOLBAR,
+    GtkWidget *button = sp_button_new_from_data( Inkscape::ICON_SIZE_DECORATION,
                                               SP_BUTTON_TYPE_TOGGLE,
                                               NULL,
                                               "controls_stroke",
