@@ -20,18 +20,8 @@
 # include "config.h"
 #endif
 #ifdef HAVE_STRING_H
-#include <string.h>
 #endif
 #include <gtk/gtk.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkoptionmenu.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkwindow.h>
 #include "macros.h"
 #include <glibmm/i18n.h>
 #include "../widgets/gradient-image.h"
@@ -45,10 +35,7 @@
 
 #include "../dialogs/dialog-events.h"
 #include "../prefs-utils.h"
-#include "../verbs.h"
-#include "../interface.h"
 #include "svg/css-ostringstream.h"
-#include "sp-gradient-vector.h"
 #include "sp-stop.h"
 
 enum {
@@ -402,13 +389,11 @@ sp_gvs_defs_modified (SPObject *defs, guint flags, SPGradientVectorSelector *gvs
 ###                 Vector Editing Widget
 ##################################################################*/
 
-#include "../widgets/sp-color-selector.h"
 #include "../widgets/sp-color-notebook.h"
 #include "../widgets/sp-color-preview.h"
 #include "../widgets/widget-sizes.h"
-#include "../selection.h"
 #include "../xml/node-event-vector.h"
-#include "../svg/svg.h"
+#include "../svg/svg-color.h"
 
 
 #define PAD 4
@@ -472,19 +457,19 @@ verify_grad(SPGradient *gradient)
 
 		child = sp_repr_new ("svg:stop");
 		sp_repr_set_css_double(child, "offset", 0.0);
-		sp_repr_set_attr (child, "style", os.str().c_str());
-		sp_repr_add_child (SP_OBJECT_REPR (gradient), child, NULL);
+		child->setAttribute("style", os.str().c_str());
+		SP_OBJECT_REPR (gradient)->addChild(child, NULL);
 
 		child = sp_repr_new ("svg:stop");
 		sp_repr_set_css_double(child, "offset", 1.0);
-		sp_repr_set_attr (child, "style", os.str().c_str());
-		sp_repr_add_child (SP_OBJECT_REPR (gradient), child, NULL);
+		child->setAttribute("style", os.str().c_str());
+		SP_OBJECT_REPR (gradient)->addChild(child, NULL);
 	}
 	if (i < 2) {
 		sp_repr_set_css_double(SP_OBJECT_REPR(stop), "offset", 0.0);
 		Inkscape::XML::Node *child = SP_OBJECT_REPR(stop)->duplicate();
 		sp_repr_set_css_double(child, "offset", 1.0);
-		sp_repr_add_child (SP_OBJECT_REPR(gradient), child, SP_OBJECT_REPR (stop));
+		SP_OBJECT_REPR(gradient)->addChild(child, SP_OBJECT_REPR (stop));
 	}
 }
 
@@ -497,7 +482,7 @@ select_stop_in_list( GtkWidget *mnu, SPGradient *gradient, SPStop *new_stop)
 			if (SP_OBJECT (ochild) == SP_OBJECT(new_stop)) {
 				gtk_option_menu_set_history (GTK_OPTION_MENU (mnu), i);
 				break;
-			} 
+			}
 			i++;
 		}
 	}
@@ -534,7 +519,7 @@ update_stop_list( GtkWidget *mnu, SPGradient *gradient, SPStop *new_stop)
 		gtk_menu_append (GTK_MENU (m), i);
 		gtk_widget_set_sensitive (mnu, FALSE);
 	} else {
-     
+
 		for (; sl != NULL; sl = sl->next){
 			SPStop *stop;
 			GtkWidget *i;
@@ -611,7 +596,7 @@ sp_grad_edit_select (GtkOptionMenu *mnu,  GtkWidget *tbl)
 
 	SPStop *next = NULL;
 	next = sp_next_stop(stop);
-	if (next != NULL ) { 
+	if (next != NULL ) {
 	  adj->upper = next->offset;
 	} else {
 	  isEndStop = true;
@@ -678,7 +663,7 @@ sp_grd_ed_add_stop (GtkWidget *widget,  GtkWidget *vb)
 
 	SPStop *stop = (SPStop *) g_object_get_data (G_OBJECT(gtk_menu_get_active (GTK_MENU(gtk_option_menu_get_menu (mnu)))), "stop");
 
-	if (stop == NULL) 
+	if (stop == NULL)
 		return;
 
 	Inkscape::XML::Node *new_stop_repr = NULL;
@@ -695,15 +680,15 @@ sp_grd_ed_add_stop (GtkWidget *widget,  GtkWidget *vb)
 
 	if (next != NULL) {
 		new_stop_repr = SP_OBJECT_REPR(stop)->duplicate();
-		sp_repr_add_child (SP_OBJECT_REPR(gradient), new_stop_repr, SP_OBJECT_REPR(stop));
+		SP_OBJECT_REPR(gradient)->addChild(new_stop_repr, SP_OBJECT_REPR(stop));
 	} else {
 		next = stop;
 		new_stop_repr = SP_OBJECT_REPR(sp_prev_stop(stop, gradient))->duplicate();
-		sp_repr_add_child (SP_OBJECT_REPR(gradient), new_stop_repr, SP_OBJECT_REPR(sp_prev_stop(stop, gradient)));
+		SP_OBJECT_REPR(gradient)->addChild(new_stop_repr, SP_OBJECT_REPR(sp_prev_stop(stop, gradient)));
 	}
 
 	SPStop *newstop = (SPStop *) SP_OBJECT_DOCUMENT(gradient)->getObjectByRepr(new_stop_repr);
-   
+
 	newstop->offset = (stop->offset + next->offset) * 0.5 ;
 
 	guint32 const c1 = sp_stop_get_rgba32(stop);
@@ -715,10 +700,10 @@ sp_grd_ed_add_stop (GtkWidget *widget,  GtkWidget *vb)
 	sp_svg_write_color (c, 64, cnew);
 	gdouble opacity = (gdouble) SP_RGBA32_A_F (cnew);
 	os << "stop-color:" << c << ";stop-opacity:" << opacity <<";";
-	sp_repr_set_attr (SP_OBJECT_REPR (newstop), "style", os.str().c_str());
+	SP_OBJECT_REPR (newstop)->setAttribute("style", os.str().c_str());
 
 	sp_gradient_vector_widget_load_gradient (vb, gradient);
-	sp_repr_unref (new_stop_repr);
+	Inkscape::GC::release(new_stop_repr);
 	update_stop_list(GTK_WIDGET(mnu), gradient, newstop);
 	GtkWidget *offspin = GTK_WIDGET (g_object_get_data (G_OBJECT (vb), "offspn"));
 	GtkWidget *offslide =GTK_WIDGET (g_object_get_data (G_OBJECT (vb), "offslide"));
@@ -752,7 +737,7 @@ sp_grd_ed_del_stop (GtkWidget *widget,  GtkWidget *vb)
 			}
 		}
 
-		sp_repr_remove_child (SP_OBJECT_REPR(gradient), SP_OBJECT_REPR(stop));
+		SP_OBJECT_REPR(gradient)->removeChild(SP_OBJECT_REPR(stop));
 		sp_gradient_vector_widget_load_gradient (vb, gradient);
 		update_stop_list(GTK_WIDGET(mnu), gradient, NULL);
 		sp_document_done (SP_OBJECT_DOCUMENT (gradient));
@@ -893,7 +878,11 @@ sp_gradient_vector_editor_new (SPGradient *gradient, SPStop *stop)
 			w = prefs_get_int_attribute (prefs_path, "w", 0);
 			h = prefs_get_int_attribute (prefs_path, "h", 0);
 		}
-		if (x != 0 || y != 0) 
+
+                if (x<0) x=0;
+                if (y<0) y=0;
+
+		if (x != 0 || y != 0)
 			gtk_window_move ((GtkWindow *) dlg, x, y);
 		else
 			gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
@@ -918,8 +907,8 @@ sp_gradient_vector_editor_new (SPGradient *gradient, SPStop *stop)
 		gtk_container_add (GTK_CONTAINER (dlg), wid);
 	} else {
 		// FIXME: temp fix for 0.38
-		// Simply load_gradient into the editor does not work for multi-stop gradients, 
-		// as the stop list and other widgets are in a wrong state and crash readily. 
+		// Simply load_gradient into the editor does not work for multi-stop gradients,
+		// as the stop list and other widgets are in a wrong state and crash readily.
 		// Instead we just delete the window (by sending the delete signal)
 		// and call sp_gradient_vector_editor_new again, so it creates the window anew.
 
@@ -966,7 +955,7 @@ sp_gradient_vector_widget_load_gradient (GtkWidget *widget, SPGradient *gradient
 		SPStop *stop = SP_STOP(g_object_get_data (G_OBJECT(gtk_menu_get_active (GTK_MENU(gtk_option_menu_get_menu (mnu)))), "stop"));
 		guint32 const c = sp_stop_get_rgba32(stop);
 
-		/// get the color selector 
+		/// get the color selector
 		SPColorSelector *csel = SP_COLOR_SELECTOR(g_object_get_data (G_OBJECT (widget), "cselector"));
 		// set alpha
 		csel->base->setAlpha(SP_RGBA32_A_F (c));
@@ -988,7 +977,7 @@ sp_gradient_vector_widget_load_gradient (GtkWidget *widget, SPGradient *gradient
 		SPDocument *document = SP_OBJECT_DOCUMENT (gradient);
 		gboolean saved = sp_document_get_undo_sensitive(document);
 		sp_document_set_undo_sensitive (document, FALSE);
-		sp_repr_set_attr (SP_OBJECT_REPR(gradient), "inkscape:collect", NULL);
+		SP_OBJECT_REPR(gradient)->setAttribute("inkscape:collect", NULL);
 		sp_document_set_undo_sensitive (document, saved);
 	}
 
@@ -1009,6 +998,9 @@ sp_gradient_vector_dialog_delete (GtkWidget *widget, GdkEvent *event, GtkWidget
 	gtk_window_get_position ((GtkWindow *) dlg, &x, &y);
 	gtk_window_get_size ((GtkWindow *) dlg, &w, &h);
 
+    if (x<0) x=0;
+    if (y<0) y=0;
+
 	prefs_set_int_attribute (prefs_path, "x", x);
 	prefs_set_int_attribute (prefs_path, "y", y);
 	prefs_set_int_attribute (prefs_path, "w", w);
@@ -1120,9 +1112,9 @@ sp_gradient_vector_color_changed (SPColorSelector *csel, GtkObject *object)
 	gchar c[64];
 	sp_svg_write_color (c, 64, rgb);
 	os << "stop-color:" << c << ";stop-opacity:" << (gdouble) alpha <<";";
-	sp_repr_set_attr (SP_OBJECT_REPR (stop), "style", os.str().c_str());
+	SP_OBJECT_REPR (stop)->setAttribute("style", os.str().c_str());
 		//	g_snprintf (c, 256, "stop-color:#%06x;stop-opacity:%g;", rgb >> 8, (gdouble) alpha);
-		//sp_repr_set_attr (SP_OBJECT_REPR (stop), "style", c);
+		//SP_OBJECT_REPR (stop)->setAttribute("style", c);
 
 	sp_document_done (SP_OBJECT_DOCUMENT (ngr));
 
