@@ -54,7 +54,7 @@ SPDocument *sp_gradient_vector_selector_get_document (SPGradientVectorSelector *
 SPGradient *sp_gradient_vector_selector_get_gradient (SPGradientVectorSelector *gvs);
 
 /* fixme: rethink this (Lauris) */
-GtkWidget *sp_gradient_vector_editor_new (SPGradient *gradient);
+GtkWidget *sp_gradient_vector_editor_new (SPGradient *gradient, SPStop *stop = NULL);
 
 
 
