@@ -9,33 +9,26 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <glibmm/i18n.h>
 
-#include <cstring>
-#include <algorithm>
-#include <functional>
-#include <gtkmm/liststore.h>
-#include <gtkmm/image.h>
-
 #include "desktop-handles.h"
-#include "selection.h"
 
 #include "widgets/layer-selector.h"
 #include "widgets/shrink-wrap-button.h"
 #include "widgets/icon.h"
 
-#include "util/list.h"
 #include "util/reverse-list.h"
 #include "util/filter-list.h"
 
-#include "sp-object.h"
 #include "sp-item.h"
 #include "desktop.h"
 #include "document.h"
 #include "dialogs/layer-properties.h"
-
-#include "xml/repr.h"
+#include "layer-manager.h"
 #include "xml/node-event-vector.h"
 
 namespace Inkscape {
@@ -45,7 +38,7 @@ namespace {
 
 class AlternateIcons : public Gtk::HBox {
 public:
-    AlternateIcons(GtkIconSize size, gchar const *a, gchar const *b)
+    AlternateIcons(Inkscape::IconSize size, gchar const *a, gchar const *b)
     : _a(NULL), _b(NULL)
     {
         if (a) {
@@ -54,7 +47,7 @@ public:
             add(*_a);
         }
         if (b) {
-            _b = Gtk::manage(sp_icon_get_icon(b,size));
+            _b = Gtk::manage(sp_icon_get_icon(b, size));
             _b->set_no_show_all(true);
             add(*_b);
         }
@@ -99,7 +92,7 @@ LayerSelector::LayerSelector(SPDesktop *desktop)
 {
     AlternateIcons *label;
 
-    label = Gtk::manage(new AlternateIcons(GTK_ICON_SIZE_MENU, "visible", "hidden"));
+    label = Gtk::manage(new AlternateIcons(Inkscape::ICON_SIZE_DECORATION, "visible", "hidden"));
     _visibility_toggle.add(*label);
     _visibility_toggle.signal_toggled().connect(
         sigc::compose(
@@ -119,7 +112,7 @@ LayerSelector::LayerSelector(SPDesktop *desktop)
     _tooltips.set_tip(_visibility_toggle, _("Toggle current layer visibility"));
     pack_start(_visibility_toggle, Gtk::PACK_EXPAND_PADDING);
 
-    label = Gtk::manage(new AlternateIcons(GTK_ICON_SIZE_MENU, "lock_unlocked", "width_height_lock"));
+    label = Gtk::manage(new AlternateIcons(Inkscape::ICON_SIZE_DECORATION, "lock_unlocked", "width_height_lock"));
     _lock_toggle.add(*label);
     _lock_toggle.signal_toggled().connect(
         sigc::compose(
@@ -298,9 +291,11 @@ void LayerSelector::_setDesktopLayer() {
     SPObject *layer=_selector.get_active()->get_value(_model_columns.object);
     if ( _desktop && layer ) {
         _layer_changed_connection.block();
-        _desktop->setCurrentLayer(layer);
+
+        _desktop->layer_manager->setCurrentLayer(layer);
+
         _layer_changed_connection.unblock();
-        SP_DT_SELECTION(_desktop)->clear();
+
         _selectLayer(_desktop->currentLayer());
     }
 }
@@ -426,6 +421,18 @@ void LayerSelector::_protectUpdate(sigc::slot<void> slot) {
     _visibility_toggled_connection.block(true);
     _lock_toggled_connection.block(true);
     slot();
+
+    SPObject *layer = _desktop ? _desktop->currentLayer() : 0;
+    if ( layer ) {
+        bool wantedValue = ( SP_IS_ITEM(layer) ? SP_ITEM(layer)->isLocked() : false );
+        if ( _lock_toggle.get_active() != wantedValue ) {
+            _lock_toggle.set_active( wantedValue );
+        }
+        wantedValue = ( SP_IS_ITEM(layer) ? SP_ITEM(layer)->isHidden() : false );
+        if ( _visibility_toggle.get_active() != wantedValue ) {
+            _visibility_toggle.set_active( wantedValue );
+        }
+    }
     _visibility_toggled_connection.block(visibility_blocked);
     _lock_toggled_connection.block(lock_blocked);
 }
@@ -484,7 +491,7 @@ void LayerSelector::_buildEntry(unsigned depth, SPObject &object) {
     sp_object_ref(&object, NULL);
     row->set_value(_model_columns.object, &object);
 
-    sp_repr_ref(SP_OBJECT_REPR(&object));
+    Inkscape::GC::anchor(SP_OBJECT_REPR(&object));
     row->set_value(_model_columns.repr, SP_OBJECT_REPR(&object));
 
     row->set_value(_model_columns.callbacks, reinterpret_cast<void *>(callbacks));
@@ -504,7 +511,7 @@ void LayerSelector::_destroyEntry(Gtk::ListStore::iterator const &row) {
     Inkscape::XML::Node *repr=row->get_value(_model_columns.repr);
     if (repr) {
         sp_repr_remove_listener_by_data(repr, callbacks);
-        sp_repr_unref(repr);
+        Inkscape::GC::release(repr);
     }
     delete callbacks;
 }
@@ -570,14 +577,14 @@ void LayerSelector::_prepareLabelRenderer(
 void LayerSelector::_lockLayer(bool lock) {
     if ( _layer && SP_IS_ITEM(_layer) ) {
         SP_ITEM(_layer)->setLocked(lock);
-        sp_document_maybe_done(SP_DT_DOCUMENT(_desktop), "LayerSelector:lock");
+        sp_document_maybe_done(sp_desktop_document(_desktop), "LayerSelector:lock");
     }
 }
 
 void LayerSelector::_hideLayer(bool hide) {
     if ( _layer && SP_IS_ITEM(_layer) ) {
         SP_ITEM(_layer)->setHidden(hide);
-        sp_document_maybe_done(SP_DT_DOCUMENT(_desktop), "LayerSelector:hide");
+        sp_document_maybe_done(sp_desktop_document(_desktop), "LayerSelector:hide");
     }
 }
 
@@ -588,9 +595,9 @@ void LayerSelector::_hideLayer(bool hide) {
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
