@@ -14,16 +14,8 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#include <string.h>
-#include <glib.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkmarshal.h>
-#include <gtk/gtklist.h>
-#include <gtk/gtkadjustment.h>
 #include "helper/sp-marshal.h"
 #include <glibmm/i18n.h>
-#include "../xml/repr.h"
 #include "../xml/node-event-vector.h"
 #include "sp-xmlview-attr-list.h"
 
@@ -73,11 +65,11 @@ sp_xmlview_attr_list_set_repr (SPXMLViewAttrList * list, Inkscape::XML::Node * r
 	if (list->repr) {
 		gtk_clist_clear (GTK_CLIST (list));
 		sp_repr_remove_listener_by_data (list->repr, list);
-		sp_repr_unref (list->repr);
+		Inkscape::GC::release(list->repr);
 	}
 	list->repr = repr;
 	if (repr) {
-		sp_repr_ref (repr);
+		Inkscape::GC::anchor(repr);
 		sp_repr_add_listener (repr, &repr_events, list);
 		sp_repr_synthesize_events (repr, &repr_events, list);
 	}
