@@ -11,17 +11,9 @@
  * Released under the GNU GPL; see COPYING for details
  */
 
-#include <string.h>
-#include <glib.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkmarshal.h>
-#include <gtk/gtkadjustment.h>
 
-#include "xml/repr.h"
 #include "xml/node-event-vector.h"
 #include "sp-xmlview-content.h"
-#include "macros.h"
 #include "desktop-handles.h"
 #include "document-private.h"
 #include "inkscape.h"
@@ -70,11 +62,11 @@ sp_xmlview_content_set_repr (SPXMLViewContent * text, Inkscape::XML::Node * repr
 	if ( repr == text->repr ) return;
 	if (text->repr) {
 		sp_repr_remove_listener_by_data (text->repr, text);
-		sp_repr_unref (text->repr);
+		Inkscape::GC::release(text->repr);
 	}
 	text->repr = repr;
 	if (repr) {
-		sp_repr_ref (repr);
+		Inkscape::GC::anchor(repr);
 		sp_repr_add_listener (repr, &repr_events, text);
 		sp_repr_synthesize_events (repr, &repr_events, text);
 	} else {
@@ -168,6 +160,6 @@ sp_xmlview_content_changed (GtkTextBuffer *tb, SPXMLViewContent *text)
 		text->repr->setContent(data);
 		g_free (data);
 		text->blocked = FALSE;
-		sp_document_done (SP_DT_DOCUMENT (SP_ACTIVE_DESKTOP));
+		sp_document_done (sp_desktop_document (SP_ACTIVE_DESKTOP));
 	}
 }
