@@ -11,16 +11,6 @@
  * Released under the GNU GPL; see COPYING for details
  */
 
-#include <string.h>
-#include <stdio.h>
-#include <glib.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkmarshal.h>
-#include <gtk/gtkclist.h>
-#include <gtk/gtkctree.h>
-#include <gtk/gtkcontainer.h>
-#include "../xml/repr.h"
 #include "../xml/node-event-vector.h"
 #include "sp-xmlview-tree.h"
 
@@ -111,12 +101,12 @@ sp_xmlview_tree_set_repr (SPXMLViewTree * tree, Inkscape::XML::Node * repr)
 	gtk_clist_freeze (GTK_CLIST (tree));
 	if (tree->repr) {
 		gtk_clist_clear (GTK_CLIST (tree));
-		sp_repr_unref (tree->repr);
+		Inkscape::GC::release(tree->repr);
 	}
 	tree->repr = repr;
 	if (repr) {
 		GtkCTreeNode * node;
-		sp_repr_ref (repr);
+		Inkscape::GC::anchor(repr);
 		node = add_node (tree, NULL, NULL, repr);
 		gtk_ctree_expand (GTK_CTREE (tree), node);
 	}
@@ -226,7 +216,7 @@ node_data_new (SPXMLViewTree * tree, GtkCTreeNode * node, Inkscape::XML::Node *
 	data->tree = tree;
 	data->node = node;
 	data->repr = repr;
-	sp_repr_ref (repr);
+	Inkscape::GC::anchor(repr);
 	return data;
 }
 
@@ -236,7 +226,7 @@ node_data_free (gpointer ptr) {
 	data = (NodeData *) ptr;
 	sp_repr_remove_listener_by_data (data->repr, data);
 	g_assert (data->repr != NULL);
-	sp_repr_unref (data->repr);
+	Inkscape::GC::release(data->repr);
 	g_free (data);
 }
 
@@ -341,7 +331,6 @@ tree_move (GtkCTree * tree, GtkCTreeNode * node, GtkCTreeNode * new_parent, GtkC
 {
 	GtkCTreeNode * old_parent;
 	Inkscape::XML::Node * ref;
-	int ok;
 
 	old_parent = GTK_CTREE_ROW (node)->parent;
 	if ( !old_parent || !new_parent ) return;
@@ -352,16 +341,14 @@ tree_move (GtkCTree * tree, GtkCTreeNode * node, GtkCTreeNode * new_parent, GtkC
 
 	SP_XMLVIEW_TREE (tree)->blocked++;
 	if (new_parent == old_parent) {
-		ok = sp_repr_change_order (NODE_DATA (old_parent)->repr, NODE_DATA (node)->repr, ref);
+		NODE_DATA (old_parent)->repr->changeOrder(NODE_DATA (node)->repr, ref);
 	} else {
-		ok = sp_repr_remove_child (NODE_DATA (old_parent)->repr, NODE_DATA (node)->repr) &&
-		     sp_repr_add_child (NODE_DATA (new_parent)->repr, NODE_DATA (node)->repr, ref);
+		NODE_DATA (old_parent)->repr->removeChild(NODE_DATA (node)->repr);
+		NODE_DATA (new_parent)->repr->addChild(NODE_DATA (node)->repr, ref);
 	}
 	SP_XMLVIEW_TREE (tree)->blocked--;
 
-	if (ok) {
-		parent_class->tree_move (tree, node, new_parent, new_sibling);
-	}
+	parent_class->tree_move (tree, node, new_parent, new_sibling);
 
 	gtk_clist_thaw (GTK_CLIST (tree));
 }
