@@ -27,12 +27,11 @@
 
 #define STATUS_BAR_FONT_SIZE 10000
 
-#define STATUS_ZOOM_FONT_SIZE 7700
 #define STATUS_ZOOM_WIDTH 57
 
-#define STATUS_COORD_FONT_SIZE 7700
-#define STATUS_COORD_SKIP 1
-#define STATUS_COORD_WIDTH 84
+#define SELECTED_STYLE_SB_WIDTH 40
+#define SELECTED_STYLE_WIDTH 150
+#define STYLE_SWATCH_WIDTH 80
 
 #define STATUS_LAYER_FONT_SIZE 7700
 
@@ -45,9 +44,9 @@
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
