@@ -13,18 +13,13 @@
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include "repr.h"
 #include "event.h"
 #include "event-fns.h"
-#include "util/list.h"
 #include "util/reverse-list.h"
-#include "xml/node.h"
 #include "xml/document.h"
-#include "xml/session.h"
 #include "xml/node-observer.h"
 #include "debug/event-tracker.h"
 #include "debug/simple-event.h"
-#include <cstring>
 
 using Inkscape::Util::List;
 using Inkscape::Util::reverse_list;
@@ -119,15 +114,15 @@ public:
 	}
 
 	void notifyAttributeChanged(Node &node, GQuark name,
-			            Inkscape::Util::SharedCStringPtr old_value,
-				    Inkscape::Util::SharedCStringPtr new_value)
+			            Inkscape::Util::ptr_shared<char> old_value,
+				    Inkscape::Util::ptr_shared<char> new_value)
 	{
 		node.setAttribute(g_quark_to_string(name), new_value);
 	}
 
 	void notifyContentChanged(Node &node,
-			          Inkscape::Util::SharedCStringPtr old_value,
-				  Inkscape::Util::SharedCStringPtr new_value)
+			          Inkscape::Util::ptr_shared<char> old_value,
+				  Inkscape::Util::ptr_shared<char> new_value)
 	{
 		node.setContent(new_value);
 	}
@@ -463,22 +458,22 @@ public:
 	}
 
 	void notifyAttributeChanged(Node &node, GQuark name,
-	                            Inkscape::Util::SharedCStringPtr old_value,
-				    Inkscape::Util::SharedCStringPtr new_value)
+	                            Inkscape::Util::ptr_shared<char> old_value,
+				    Inkscape::Util::ptr_shared<char> new_value)
 	{
 		if (new_value) {
-			g_warning("Event: Set attribute %s to \"%s\" on %s", g_quark_to_string(name), new_value.cString(), node_to_string(node).c_str());
+			g_warning("Event: Set attribute %s to \"%s\" on %s", g_quark_to_string(name), new_value.pointer(), node_to_string(node).c_str());
 		} else {
 			g_warning("Event: Unset attribute %s on %s", g_quark_to_string(name), node_to_string(node).c_str());
 		}
 	}
 
 	void notifyContentChanged(Node &node,
-			          Inkscape::Util::SharedCStringPtr old_value,
-				  Inkscape::Util::SharedCStringPtr new_value)
+			          Inkscape::Util::ptr_shared<char> old_value,
+				  Inkscape::Util::ptr_shared<char> new_value)
 	{
 		if (new_value) {
-			g_warning("Event: Set content of %s to \"%s\"", node_to_string(node).c_str(), new_value.cString());
+			g_warning("Event: Set content of %s to \"%s\"", node_to_string(node).c_str(), new_value.pointer());
 		} else {
 			g_warning("Event: Unset content of %s", node_to_string(node).c_str());
 		}
