@@ -16,7 +16,7 @@
 #define SEEN_INKSCAPE_XML_NODE_OBSERVER_H
 
 #include <glib/gquark.h>
-#include "util/shared-c-string-ptr.h"
+#include "util/share.h"
 
 namespace Inkscape {
 namespace XML {
@@ -43,12 +43,12 @@ public:
                                          Node *old_prev, Node *new_prev)=0;
 
     virtual void notifyContentChanged(Node &node,
-                                      Util::SharedCStringPtr old_content,
-                                      Util::SharedCStringPtr new_content)=0;
+                                      Util::ptr_shared<char> old_content,
+                                      Util::ptr_shared<char> new_content)=0;
 
     virtual void notifyAttributeChanged(Node &node, GQuark name,
-                                        Util::SharedCStringPtr old_value,
-                                        Util::SharedCStringPtr new_value)=0;
+                                        Util::ptr_shared<char> old_value,
+                                        Util::ptr_shared<char> new_value)=0;
 };
 
 }
@@ -60,9 +60,9 @@ public:
   Local Variables:
   mode:c++
   c-file-style:"stroustrup"
-  c-file-offsets:((innamespace . 0)(inline-open . 0))
+  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
   indent-tabs-mode:nil
   fill-column:99
   End:
 */
-// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
