@@ -15,31 +15,16 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#include <unistd.h>
-#include <string.h>
-#include <stdio.h>
-#include <ctype.h>
-#include <strings.h>
 
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-#include <libxml/tree.h>
-
-#include <glib.h>
+#include <stdexcept>
 
 #include "xml/repr.h"
 #include "xml/attribute-record.h"
 
 #include "io/sys.h"
-#include "io/inkscapestream.h"
 #include "io/uristream.h"
 #include "io/gzipstream.h"
 
-#include <map>
-#include <glibmm/ustring.h>
-#include <glibmm/quark.h>
-#include "util/list.h"
-#include "util/shared-c-string-ptr.h"
 
 using Inkscape::IO::Writer;
 using Inkscape::Util::List;
@@ -66,8 +51,9 @@ class XmlSource
 public:
     XmlSource()
         : filename(0),
+          encoding(0),
           fp(0),
-          first(false),
+          firstFewLen(0),
           dummy("x"),
           instr(0),
           gzin(0)
@@ -76,29 +62,90 @@ public:
     virtual ~XmlSource()
     {
         close();
+        if ( encoding ) {
+            g_free(encoding);
+            encoding = 0;
+        }
     }
 
-    void setFile( char const * filename );
-
-    static int readCb( void * context, char * buffer, int len);
-    static int closeCb(void * context);
+    int setFile( char const * filename );
 
+    static int readCb( void * context, char * buffer, int len );
+    static int closeCb( void * context );
 
+    char const* getEncoding() const { return encoding; }
     int read( char * buffer, int len );
     int close();
 private:
     const char* filename;
+    char* encoding;
     FILE* fp;
-    bool first;
+    unsigned char firstFew[4];
+    int firstFewLen;
     Inkscape::URI dummy;
     Inkscape::IO::UriInputStream* instr;
     Inkscape::IO::GzipInputStream* gzin;
 };
 
-void XmlSource::setFile( char const * filename ) {
+int XmlSource::setFile(char const *filename)
+{
+    int retVal = -1;
+
     this->filename = filename;
+
     fp = Inkscape::IO::fopen_utf8name(filename, "r");
-    first = true;
+    if ( fp ) {
+        // First peek in the file to see what it is
+        memset( firstFew, 0, sizeof(firstFew) );
+
+        size_t some = fread( firstFew, 1, 4, fp );
+        if ( fp ) {
+            // first check for compression
+            if ( (some >= 2) && (firstFew[0] == 0x1f) && (firstFew[1] == 0x8b) ) {
+                //g_message(" the file being read is gzip'd. extract it");
+                fclose(fp);
+                fp = 0;
+                fp = Inkscape::IO::fopen_utf8name(filename, "r");
+                instr = new Inkscape::IO::UriInputStream(fp, dummy);
+                gzin = new Inkscape::IO::GzipInputStream(*instr);
+
+                memset( firstFew, 0, sizeof(firstFew) );
+                some = 0;
+                int single = 0;
+                while ( some < 4 && single >= 0 )
+                {
+                    single = gzin->get();
+                    if ( single >= 0 ) {
+                        firstFew[some++] = 0x0ff & single;
+                    } else {
+                        break;
+                    }
+                }
+            }
+
+            int encSkip = 0;
+            if ( (some >= 2) &&(firstFew[0] == 0xfe) && (firstFew[1] == 0xff) ) {
+                encoding = g_strdup("UTF-16BE");
+                encSkip = 2;
+            } else if ( (some >= 2) && (firstFew[0] == 0xff) && (firstFew[1] == 0xfe) ) {
+                encoding = g_strdup("UTF-16LE");
+                encSkip = 2;
+            } else if ( (some >= 3) && (firstFew[0] == 0xef) && (firstFew[1] == 0xbb) && (firstFew[2] == 0xbf) ) {
+                encoding = g_strdup("UTF-8");
+                encSkip = 3;
+            }
+
+            if ( encSkip ) {
+                memmove( firstFew, firstFew + encSkip, (some - encSkip) );
+                some -= encSkip;
+            }
+
+            firstFewLen = some;
+            retVal = 0; // no error
+        }
+    }
+
+    return retVal;
 }
 
 
@@ -126,33 +173,14 @@ int XmlSource::read( char *buffer, int len )
     int retVal = 0;
     size_t got = 0;
 
-    if ( first ) {
-        first = false;
-        char tmp[] = {0,0};
-        size_t some = fread( tmp, 1, 2, fp );
-
-        if ( (some >= 2) && (tmp[0] == 0x1f) && ((unsigned char)(tmp[1]) == 0x8b) ) {
-            //g_message(" the file being read is gzip'd. extract it");
-            fclose(fp);
-            fp = 0;
-            fp = Inkscape::IO::fopen_utf8name(filename, "r");
-            instr = new Inkscape::IO::UriInputStream(fp, dummy);
-            gzin = new Inkscape::IO::GzipInputStream(*instr);
-            int single = 0;
-            while ( (int)got < len && single >= 0 )
-            {
-                single = gzin->get();
-                if ( single >= 0 ) {
-                    buffer[got++] = 0x0ff & single;
-                } else {
-                    break;
-                }
-            }
-            //g_message(" extracted %d bytes this pass", got );
-        } else {
-            memcpy( buffer, tmp, some );
-            got = some;
+    if ( firstFewLen > 0 ) {
+        int some = (len < firstFewLen) ? len : firstFewLen;
+        memcpy( buffer, firstFew, some );
+        if ( len < firstFewLen ) {
+            memmove( firstFew, firstFew + some, (firstFewLen - some) );
         }
+        firstFewLen -= some;
+        got = some;
     } else if ( gzin ) {
         int single = 0;
         while ( (int)got < len && single >= 0 )
@@ -164,18 +192,15 @@ int XmlSource::read( char *buffer, int len )
                 break;
             }
         }
-        //g_message(" extracted %d bytes this pass  b", got );
     } else {
         got = fread( buffer, 1, len, fp );
     }
 
     if ( feof(fp) ) {
         retVal = got;
-    }
-    else if ( ferror(fp) ) {
+    } else if ( ferror(fp) ) {
         retVal = -1;
-    }
-    else {
+    } else {
         retVal = got;
     }
 
@@ -228,43 +253,35 @@ sp_repr_read_file (const gchar * filename, const gchar *default_ns)
 
     Inkscape::IO::dump_fopen_call( filename, "N" );
 
-    XmlSource src;
-    src.setFile(filename);
-
-    xmlDocPtr doubleDoc = xmlReadIO( XmlSource::readCb,
-                                     XmlSource::closeCb,
-                                     &src,
-                                     localFilename,
-                                     NULL, //"UTF-8",
-                                     XML_PARSE_NOENT );
-
-
 #ifdef HAVE_LIBWMF
     if (strlen (localFilename) > 4) {
         if ( (strcmp (localFilename + strlen (localFilename) - 4,".wmf") == 0)
-          || (strcmp (localFilename + strlen (localFilename) - 4,".WMF") == 0))
+             || (strcmp (localFilename + strlen (localFilename) - 4,".WMF") == 0)) {
             doc = sp_wmf_convert (localFilename);
-        else
-            doc = xmlParseFile (localFilename);
+        }
     }
-    else {
-        doc = xmlParseFile (localFilename);
+#endif // !HAVE_LIBWMF
+
+    if ( !doc ) {
+        XmlSource src;
+
+        if ( (src.setFile(filename) == 0) ) {
+            doc = xmlReadIO( XmlSource::readCb,
+                             XmlSource::closeCb,
+                             &src,
+                             localFilename,
+                             src.getEncoding(),
+                             XML_PARSE_NOENT );
+        }
     }
-#else /* !HAVE_LIBWMF */
-    //doc = xmlParseFile (localFilename);
-#endif /* !HAVE_LIBWMF */
 
-    //rdoc = sp_repr_do_read (doc, default_ns);
-    rdoc = sp_repr_do_read (doubleDoc, default_ns);
-    if (doc)
-        xmlFreeDoc (doc);
+    rdoc = sp_repr_do_read( doc, default_ns );
+    if ( doc ) {
+        xmlFreeDoc( doc );
+    }
 
-    if ( localFilename != NULL )
-        g_free (localFilename);
-
-    if ( doubleDoc != NULL )
-    {
-        xmlFreeDoc( doubleDoc );
+    if ( localFilename ) {
+        g_free( localFilename );
     }
 
     return rdoc;
@@ -294,7 +311,7 @@ sp_repr_read_mem (const gchar * buffer, gint length, const gchar *default_ns)
 namespace Inkscape {
 
 struct compare_quark_ids {
-    bool operator()(Glib::QueryQuark const &a, Glib::QueryQuark const &b) {
+    bool operator()(Glib::QueryQuark const &a, Glib::QueryQuark const &b) const {
         return a.id() < b.id();
     }
 };
@@ -392,7 +409,7 @@ sp_repr_do_read (xmlDocPtr doc, const gchar *default_ns)
 
     for ( GSList *iter = reprs ; iter ; iter = iter->next ) {
         Node *repr=(Node *)iter->data;
-        sp_repr_unref(repr);
+        Inkscape::GC::release(repr);
     }
     g_slist_free(reprs);
 
@@ -457,7 +474,7 @@ sp_repr_svg_read_node (xmlNodePtr node, const gchar *default_ns, GHashTable *pre
     for (prop = node->properties; prop != NULL; prop = prop->next) {
         if (prop->children) {
             sp_repr_qualified_name (c, 256, prop->ns, prop->name, default_ns, prefix_map);
-            sp_repr_set_attr (repr, c, (gchar*)prop->children->content);
+            repr->setAttribute(c, (gchar*)prop->children->content);
             /* TODO remember prop->ns->prefix if prop->ns != NULL */
         }
     }
@@ -470,7 +487,7 @@ sp_repr_svg_read_node (xmlNodePtr node, const gchar *default_ns, GHashTable *pre
         crepr = sp_repr_svg_read_node (child, default_ns, prefix_map);
         if (crepr) {
             repr->appendChild(crepr);
-            sp_repr_unref (crepr);
+            Inkscape::GC::release(crepr);
         }
     }
 
@@ -589,7 +606,7 @@ repr_quote_write (Writer &out, const gchar * val)
 namespace {
 
 typedef std::map<Glib::QueryQuark, gchar const *, Inkscape::compare_quark_ids> LocalNameMap;
-typedef std::map<Glib::QueryQuark, Inkscape::Util::SharedCStringPtr, Inkscape::compare_quark_ids> NSMap;
+typedef std::map<Glib::QueryQuark, Inkscape::Util::ptr_shared<char>, Inkscape::compare_quark_ids> NSMap;
 
 gchar const *qname_local_name(Glib::QueryQuark qname) {
     static LocalNameMap local_name_map;
@@ -608,7 +625,8 @@ gchar const *qname_local_name(Glib::QueryQuark qname) {
 }
 
 void add_ns_map_entry(NSMap &ns_map, Glib::QueryQuark prefix) {
-    using Inkscape::Util::SharedCStringPtr;
+    using Inkscape::Util::ptr_shared;
+    using Inkscape::Util::share_unsafe;
 
     static const Glib::QueryQuark xml_prefix("xml");
 
@@ -617,12 +635,12 @@ void add_ns_map_entry(NSMap &ns_map, Glib::QueryQuark prefix) {
         if (prefix.id()) {
             gchar const *uri=sp_xml_ns_prefix_uri(g_quark_to_string(prefix));
             if (uri) {
-                ns_map.insert(NSMap::value_type(prefix, SharedCStringPtr::coerce(uri)));
+                ns_map.insert(NSMap::value_type(prefix, share_unsafe(uri)));
             } else if ( prefix != xml_prefix ) {
                 g_warning("No namespace known for normalized prefix %s", g_quark_to_string(prefix));
             }
         } else {
-            ns_map.insert(NSMap::value_type(prefix, SharedCStringPtr()));
+            ns_map.insert(NSMap::value_type(prefix, ptr_shared<char>()));
         }
     }
 }
@@ -651,7 +669,7 @@ void populate_ns_map(NSMap &ns_map, Node &repr) {
 void
 sp_repr_write_stream_root_element (Node *repr, Writer &out, gboolean add_whitespace, gchar const *default_ns)
 {
-    using Inkscape::Util::SharedCStringPtr;
+    using Inkscape::Util::ptr_shared;
     g_assert(repr != NULL);
     Glib::QueryQuark xml_prefix=g_quark_from_static_string("xml");
 
@@ -667,7 +685,7 @@ sp_repr_write_stream_root_element (Node *repr, Writer &out, gboolean add_whitesp
     for ( NSMap::iterator iter=ns_map.begin() ; iter != ns_map.end() ; ++iter ) 
     {
         Glib::QueryQuark prefix=(*iter).first;
-        SharedCStringPtr ns_uri=(*iter).second;
+        ptr_shared<char> ns_uri=(*iter).second;
 
         if (prefix.id()) {
             if ( prefix != xml_prefix ) {
