@@ -27,7 +27,6 @@
 # include <stdlib.h>
 #endif
 
-#include <stdio.h>
 
 #include <glib.h>
 
@@ -36,7 +35,6 @@
 
 #include "xml/repr.h"
 #include "xml/repr-sorting.h"
-#include "xml/attribute-record.h"
 
 struct SPXMLNs {
     SPXMLNs *next;
@@ -151,7 +149,7 @@ static SPXMLNs *namespaces=NULL;
 static void
 sp_xml_ns_register_defaults()
 {
-    static SPXMLNs defaults[7];
+    static SPXMLNs defaults[8];
 
     defaults[0].uri = g_quark_from_static_string(SP_SODIPODI_NS_URI);
     defaults[0].prefix = g_quark_from_static_string("sodipodi");
@@ -179,7 +177,17 @@ sp_xml_ns_register_defaults()
 
     defaults[6].uri = g_quark_from_static_string(SP_DC_NS_URI);
     defaults[6].prefix = g_quark_from_static_string("dc");
-    defaults[6].next = NULL;
+    defaults[6].next = &defaults[7];
+
+    // Inkscape versions prior to 0.44 would write this namespace
+    // URI instead of the correct sodipodi namespace; by adding this
+    // entry to the table last (where it gets used for URI -> prefix
+    // lookups, but not prefix -> URI lookups), we effectively transfer
+    // elements in this namespace to the correct sodipodi namespace:
+
+    defaults[7].uri = g_quark_from_static_string(SP_BROKEN_SODIPODI_NS_URI);
+    defaults[7].prefix = g_quark_from_static_string("sodipodi");
+    defaults[7].next = NULL;
 
     namespaces = &defaults[0];
 }
@@ -214,7 +222,6 @@ sp_xml_ns_auto_prefix(char const *uri)
 gchar const *
 sp_xml_ns_uri_prefix(gchar const *uri, gchar const *suggested)
 {
-    SPXMLNs *iter;
     char const *prefix;
 
     if (!uri) return NULL;
@@ -225,32 +232,46 @@ sp_xml_ns_uri_prefix(gchar const *uri, gchar const *suggested)
 
     GQuark const key = g_quark_from_string(uri);
     prefix = NULL;
-    for ( iter = namespaces ; iter ; iter = iter->next ) {
+    for ( SPXMLNs *iter=namespaces ; iter ; iter = iter->next ) {
         if ( iter->uri == key ) {
             prefix = g_quark_to_string(iter->prefix);
             break;
         }
     }
+
     if (!prefix) {
-        char const *new_prefix;
+        char *new_prefix;
         SPXMLNs *ns;
         if (suggested) {
-            new_prefix = suggested;
+            GQuark const prefix_key=g_quark_from_string(suggested);
+
+            SPXMLNs *found=namespaces;
+            while ( found && found->prefix != prefix_key ) {
+                found = found->next;
+            }
+
+            if (found) { // prefix already used?
+                new_prefix = sp_xml_ns_auto_prefix(uri);
+            } else { // safe to use suggested
+                new_prefix = g_strdup(suggested);
+            }
         } else {
             new_prefix = sp_xml_ns_auto_prefix(uri);
         }
+
         ns = g_new(SPXMLNs, 1);
-        if (ns) {
-            ns->uri = g_quark_from_string(uri);
-            ns->prefix = g_quark_from_string(new_prefix);
-            ns->next = namespaces;
-            namespaces = ns;
-            prefix = g_quark_to_string(ns->prefix);
-        }
-        if (!suggested) {
-            g_free((char *)new_prefix);
-        }
+        g_assert( ns != NULL );
+        ns->uri = g_quark_from_string(uri);
+        ns->prefix = g_quark_from_string(new_prefix);
+
+        g_free(new_prefix);
+
+        ns->next = namespaces;
+        namespaces = ns;
+
+        prefix = g_quark_to_string(ns->prefix);
     }
+
     return prefix;
 }
 
@@ -488,7 +509,8 @@ sp_repr_set_boolean(Inkscape::XML::Node *repr, gchar const *key, unsigned int va
     g_return_val_if_fail(repr != NULL, FALSE);
     g_return_val_if_fail(key != NULL, FALSE);
 
-    return sp_repr_set_attr(repr, key, (val) ? "true" : "false");
+    repr->setAttribute(key, (val) ? "true" : "false");
+    return true;
 }
 
 unsigned int
@@ -501,7 +523,8 @@ sp_repr_set_int(Inkscape::XML::Node *repr, gchar const *key, int val)
 
     g_snprintf(c, 32, "%d", val);
 
-    return sp_repr_set_attr(repr, key, c);
+    repr->setAttribute(key, c);
+    return true;
 }
 
 /**
@@ -518,7 +541,8 @@ sp_repr_set_css_double(Inkscape::XML::Node *repr, gchar const *key, double val)
     Inkscape::CSSOStringStream os;
     os << val;
 
-    return sp_repr_set_attr(repr, key, os.str().c_str());
+    repr->setAttribute(key, os.str().c_str());
+    return true;
 }
 
 /**
@@ -535,7 +559,8 @@ sp_repr_set_svg_double(Inkscape::XML::Node *repr, gchar const *key, double val)
     Inkscape::SVGOStringStream os;
     os << val;
 
-    return sp_repr_set_attr(repr, key, os.str().c_str());
+    repr->setAttribute(key, os.str().c_str());
+    return true;
 }
 
 
